// src/v1.16.15.ts
var Client = class {
  constructor(apiClient, baseUrl) {
    this.apiClient = apiClient;
    this.baseUrl = baseUrl.replace(/\/$/, "");
  }
  baseUrl;
  /**
   * get available API versions
   * operationId: getCoreAPIVersions
   * Request URI: /api/
   */
  async getCoreAPIVersions(params, option) {
    const url = this.baseUrl + `/api/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getCoreV1APIResources
   * Request URI: /api/v1/
   */
  async getCoreV1APIResources(params, option) {
    const url = this.baseUrl + `/api/v1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list objects of kind ComponentStatus
   * operationId: listCoreV1ComponentStatus
   * Request URI: /api/v1/componentstatuses
   */
  async listCoreV1ComponentStatus(params, option) {
    const url = this.baseUrl + `/api/v1/componentstatuses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified ComponentStatus
   * operationId: readCoreV1ComponentStatus
   * Request URI: /api/v1/componentstatuses/{name}
   */
  async readCoreV1ComponentStatus(params, option) {
    const url = this.baseUrl + `/api/v1/componentstatuses/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind ConfigMap
   * operationId: listCoreV1ConfigMapForAllNamespaces
   * Request URI: /api/v1/configmaps
   */
  async listCoreV1ConfigMapForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/configmaps`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Endpoints
   * operationId: listCoreV1EndpointsForAllNamespaces
   * Request URI: /api/v1/endpoints
   */
  async listCoreV1EndpointsForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/endpoints`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Event
   * operationId: listCoreV1EventForAllNamespaces
   * Request URI: /api/v1/events
   */
  async listCoreV1EventForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/events`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind LimitRange
   * operationId: listCoreV1LimitRangeForAllNamespaces
   * Request URI: /api/v1/limitranges
   */
  async listCoreV1LimitRangeForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/limitranges`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Namespace
   * operationId: listCoreV1Namespace
   * Request URI: /api/v1/namespaces
   */
  async listCoreV1Namespace(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a Namespace
   * operationId: createCoreV1Namespace
   * Request URI: /api/v1/namespaces
   */
  async createCoreV1Namespace(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * create a Binding
   * operationId: createCoreV1NamespacedBinding
   * Request URI: /api/v1/namespaces/{namespace}/bindings
   */
  async createCoreV1NamespacedBinding(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/bindings`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind ConfigMap
   * operationId: listCoreV1NamespacedConfigMap
   * Request URI: /api/v1/namespaces/{namespace}/configmaps
   */
  async listCoreV1NamespacedConfigMap(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/configmaps`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a ConfigMap
   * operationId: createCoreV1NamespacedConfigMap
   * Request URI: /api/v1/namespaces/{namespace}/configmaps
   */
  async createCoreV1NamespacedConfigMap(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/configmaps`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of ConfigMap
   * operationId: deleteCoreV1CollectionNamespacedConfigMap
   * Request URI: /api/v1/namespaces/{namespace}/configmaps
   */
  async deleteCoreV1CollectionNamespacedConfigMap(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/configmaps`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified ConfigMap
   * operationId: readCoreV1NamespacedConfigMap
   * Request URI: /api/v1/namespaces/{namespace}/configmaps/{name}
   */
  async readCoreV1NamespacedConfigMap(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/configmaps/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified ConfigMap
   * operationId: replaceCoreV1NamespacedConfigMap
   * Request URI: /api/v1/namespaces/{namespace}/configmaps/{name}
   */
  async replaceCoreV1NamespacedConfigMap(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/configmaps/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a ConfigMap
   * operationId: deleteCoreV1NamespacedConfigMap
   * Request URI: /api/v1/namespaces/{namespace}/configmaps/{name}
   */
  async deleteCoreV1NamespacedConfigMap(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/configmaps/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified ConfigMap
   * operationId: patchCoreV1NamespacedConfigMap
   * Request URI: /api/v1/namespaces/{namespace}/configmaps/{name}
   */
  async patchCoreV1NamespacedConfigMap(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/configmaps/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Endpoints
   * operationId: listCoreV1NamespacedEndpoints
   * Request URI: /api/v1/namespaces/{namespace}/endpoints
   */
  async listCoreV1NamespacedEndpoints(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/endpoints`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create Endpoints
   * operationId: createCoreV1NamespacedEndpoints
   * Request URI: /api/v1/namespaces/{namespace}/endpoints
   */
  async createCoreV1NamespacedEndpoints(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/endpoints`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of Endpoints
   * operationId: deleteCoreV1CollectionNamespacedEndpoints
   * Request URI: /api/v1/namespaces/{namespace}/endpoints
   */
  async deleteCoreV1CollectionNamespacedEndpoints(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/endpoints`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified Endpoints
   * operationId: readCoreV1NamespacedEndpoints
   * Request URI: /api/v1/namespaces/{namespace}/endpoints/{name}
   */
  async readCoreV1NamespacedEndpoints(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/endpoints/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified Endpoints
   * operationId: replaceCoreV1NamespacedEndpoints
   * Request URI: /api/v1/namespaces/{namespace}/endpoints/{name}
   */
  async replaceCoreV1NamespacedEndpoints(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/endpoints/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete Endpoints
   * operationId: deleteCoreV1NamespacedEndpoints
   * Request URI: /api/v1/namespaces/{namespace}/endpoints/{name}
   */
  async deleteCoreV1NamespacedEndpoints(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/endpoints/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified Endpoints
   * operationId: patchCoreV1NamespacedEndpoints
   * Request URI: /api/v1/namespaces/{namespace}/endpoints/{name}
   */
  async patchCoreV1NamespacedEndpoints(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/endpoints/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Event
   * operationId: listCoreV1NamespacedEvent
   * Request URI: /api/v1/namespaces/{namespace}/events
   */
  async listCoreV1NamespacedEvent(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/events`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create an Event
   * operationId: createCoreV1NamespacedEvent
   * Request URI: /api/v1/namespaces/{namespace}/events
   */
  async createCoreV1NamespacedEvent(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/events`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of Event
   * operationId: deleteCoreV1CollectionNamespacedEvent
   * Request URI: /api/v1/namespaces/{namespace}/events
   */
  async deleteCoreV1CollectionNamespacedEvent(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/events`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified Event
   * operationId: readCoreV1NamespacedEvent
   * Request URI: /api/v1/namespaces/{namespace}/events/{name}
   */
  async readCoreV1NamespacedEvent(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/events/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified Event
   * operationId: replaceCoreV1NamespacedEvent
   * Request URI: /api/v1/namespaces/{namespace}/events/{name}
   */
  async replaceCoreV1NamespacedEvent(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/events/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete an Event
   * operationId: deleteCoreV1NamespacedEvent
   * Request URI: /api/v1/namespaces/{namespace}/events/{name}
   */
  async deleteCoreV1NamespacedEvent(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/events/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified Event
   * operationId: patchCoreV1NamespacedEvent
   * Request URI: /api/v1/namespaces/{namespace}/events/{name}
   */
  async patchCoreV1NamespacedEvent(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/events/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind LimitRange
   * operationId: listCoreV1NamespacedLimitRange
   * Request URI: /api/v1/namespaces/{namespace}/limitranges
   */
  async listCoreV1NamespacedLimitRange(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/limitranges`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a LimitRange
   * operationId: createCoreV1NamespacedLimitRange
   * Request URI: /api/v1/namespaces/{namespace}/limitranges
   */
  async createCoreV1NamespacedLimitRange(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/limitranges`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of LimitRange
   * operationId: deleteCoreV1CollectionNamespacedLimitRange
   * Request URI: /api/v1/namespaces/{namespace}/limitranges
   */
  async deleteCoreV1CollectionNamespacedLimitRange(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/limitranges`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified LimitRange
   * operationId: readCoreV1NamespacedLimitRange
   * Request URI: /api/v1/namespaces/{namespace}/limitranges/{name}
   */
  async readCoreV1NamespacedLimitRange(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/limitranges/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified LimitRange
   * operationId: replaceCoreV1NamespacedLimitRange
   * Request URI: /api/v1/namespaces/{namespace}/limitranges/{name}
   */
  async replaceCoreV1NamespacedLimitRange(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/limitranges/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a LimitRange
   * operationId: deleteCoreV1NamespacedLimitRange
   * Request URI: /api/v1/namespaces/{namespace}/limitranges/{name}
   */
  async deleteCoreV1NamespacedLimitRange(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/limitranges/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified LimitRange
   * operationId: patchCoreV1NamespacedLimitRange
   * Request URI: /api/v1/namespaces/{namespace}/limitranges/{name}
   */
  async patchCoreV1NamespacedLimitRange(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/limitranges/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind PersistentVolumeClaim
   * operationId: listCoreV1NamespacedPersistentVolumeClaim
   * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims
   */
  async listCoreV1NamespacedPersistentVolumeClaim(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/persistentvolumeclaims`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a PersistentVolumeClaim
   * operationId: createCoreV1NamespacedPersistentVolumeClaim
   * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims
   */
  async createCoreV1NamespacedPersistentVolumeClaim(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/persistentvolumeclaims`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of PersistentVolumeClaim
   * operationId: deleteCoreV1CollectionNamespacedPersistentVolumeClaim
   * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims
   */
  async deleteCoreV1CollectionNamespacedPersistentVolumeClaim(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/persistentvolumeclaims`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified PersistentVolumeClaim
   * operationId: readCoreV1NamespacedPersistentVolumeClaim
   * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims/{name}
   */
  async readCoreV1NamespacedPersistentVolumeClaim(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/persistentvolumeclaims/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified PersistentVolumeClaim
   * operationId: replaceCoreV1NamespacedPersistentVolumeClaim
   * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims/{name}
   */
  async replaceCoreV1NamespacedPersistentVolumeClaim(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/persistentvolumeclaims/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a PersistentVolumeClaim
   * operationId: deleteCoreV1NamespacedPersistentVolumeClaim
   * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims/{name}
   */
  async deleteCoreV1NamespacedPersistentVolumeClaim(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/persistentvolumeclaims/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified PersistentVolumeClaim
   * operationId: patchCoreV1NamespacedPersistentVolumeClaim
   * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims/{name}
   */
  async patchCoreV1NamespacedPersistentVolumeClaim(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/persistentvolumeclaims/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified PersistentVolumeClaim
   * operationId: readCoreV1NamespacedPersistentVolumeClaimStatus
   * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims/{name}/status
   */
  async readCoreV1NamespacedPersistentVolumeClaimStatus(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/persistentvolumeclaims/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified PersistentVolumeClaim
   * operationId: replaceCoreV1NamespacedPersistentVolumeClaimStatus
   * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims/{name}/status
   */
  async replaceCoreV1NamespacedPersistentVolumeClaimStatus(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/persistentvolumeclaims/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified PersistentVolumeClaim
   * operationId: patchCoreV1NamespacedPersistentVolumeClaimStatus
   * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims/{name}/status
   */
  async patchCoreV1NamespacedPersistentVolumeClaimStatus(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/persistentvolumeclaims/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Pod
   * operationId: listCoreV1NamespacedPod
   * Request URI: /api/v1/namespaces/{namespace}/pods
   */
  async listCoreV1NamespacedPod(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a Pod
   * operationId: createCoreV1NamespacedPod
   * Request URI: /api/v1/namespaces/{namespace}/pods
   */
  async createCoreV1NamespacedPod(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of Pod
   * operationId: deleteCoreV1CollectionNamespacedPod
   * Request URI: /api/v1/namespaces/{namespace}/pods
   */
  async deleteCoreV1CollectionNamespacedPod(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified Pod
   * operationId: readCoreV1NamespacedPod
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}
   */
  async readCoreV1NamespacedPod(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified Pod
   * operationId: replaceCoreV1NamespacedPod
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}
   */
  async replaceCoreV1NamespacedPod(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a Pod
   * operationId: deleteCoreV1NamespacedPod
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}
   */
  async deleteCoreV1NamespacedPod(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified Pod
   * operationId: patchCoreV1NamespacedPod
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}
   */
  async patchCoreV1NamespacedPod(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * connect GET requests to attach of Pod
   * operationId: connectCoreV1GetNamespacedPodAttach
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/attach
   */
  async connectCoreV1GetNamespacedPodAttach(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/attach`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      container: { value: params.parameter.container, explode: false },
      stderr: { value: params.parameter.stderr, explode: false },
      stdin: { value: params.parameter.stdin, explode: false },
      stdout: { value: params.parameter.stdout, explode: false },
      tty: { value: params.parameter.tty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect POST requests to attach of Pod
   * operationId: connectCoreV1PostNamespacedPodAttach
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/attach
   */
  async connectCoreV1PostNamespacedPodAttach(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/attach`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      container: { value: params.parameter.container, explode: false },
      stderr: { value: params.parameter.stderr, explode: false },
      stdin: { value: params.parameter.stdin, explode: false },
      stdout: { value: params.parameter.stdout, explode: false },
      tty: { value: params.parameter.tty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create binding of a Pod
   * operationId: createCoreV1NamespacedPodBinding
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/binding
   */
  async createCoreV1NamespacedPodBinding(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/binding`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * create eviction of a Pod
   * operationId: createCoreV1NamespacedPodEviction
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/eviction
   */
  async createCoreV1NamespacedPodEviction(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/eviction`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * connect GET requests to exec of Pod
   * operationId: connectCoreV1GetNamespacedPodExec
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/exec
   */
  async connectCoreV1GetNamespacedPodExec(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/exec`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      command: { value: params.parameter.command, explode: false },
      container: { value: params.parameter.container, explode: false },
      stderr: { value: params.parameter.stderr, explode: false },
      stdin: { value: params.parameter.stdin, explode: false },
      stdout: { value: params.parameter.stdout, explode: false },
      tty: { value: params.parameter.tty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect POST requests to exec of Pod
   * operationId: connectCoreV1PostNamespacedPodExec
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/exec
   */
  async connectCoreV1PostNamespacedPodExec(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/exec`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      command: { value: params.parameter.command, explode: false },
      container: { value: params.parameter.container, explode: false },
      stderr: { value: params.parameter.stderr, explode: false },
      stdin: { value: params.parameter.stdin, explode: false },
      stdout: { value: params.parameter.stdout, explode: false },
      tty: { value: params.parameter.tty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * read log of the specified Pod
   * operationId: readCoreV1NamespacedPodLog
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/log
   */
  async readCoreV1NamespacedPodLog(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/log`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      container: { value: params.parameter.container, explode: false },
      follow: { value: params.parameter.follow, explode: false },
      limitBytes: { value: params.parameter.limitBytes, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      previous: { value: params.parameter.previous, explode: false },
      sinceSeconds: { value: params.parameter.sinceSeconds, explode: false },
      tailLines: { value: params.parameter.tailLines, explode: false },
      timestamps: { value: params.parameter.timestamps, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect GET requests to portforward of Pod
   * operationId: connectCoreV1GetNamespacedPodPortforward
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/portforward
   */
  async connectCoreV1GetNamespacedPodPortforward(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/portforward`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      ports: { value: params.parameter.ports, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect POST requests to portforward of Pod
   * operationId: connectCoreV1PostNamespacedPodPortforward
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/portforward
   */
  async connectCoreV1PostNamespacedPodPortforward(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/portforward`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      ports: { value: params.parameter.ports, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect GET requests to proxy of Pod
   * operationId: connectCoreV1GetNamespacedPodProxy
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy
   */
  async connectCoreV1GetNamespacedPodProxy(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/proxy`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect PUT requests to proxy of Pod
   * operationId: connectCoreV1PutNamespacedPodProxy
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy
   */
  async connectCoreV1PutNamespacedPodProxy(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/proxy`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect POST requests to proxy of Pod
   * operationId: connectCoreV1PostNamespacedPodProxy
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy
   */
  async connectCoreV1PostNamespacedPodProxy(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/proxy`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect DELETE requests to proxy of Pod
   * operationId: connectCoreV1DeleteNamespacedPodProxy
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy
   */
  async connectCoreV1DeleteNamespacedPodProxy(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/proxy`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect OPTIONS requests to proxy of Pod
   * operationId: connectCoreV1OptionsNamespacedPodProxy
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy
   */
  async connectCoreV1OptionsNamespacedPodProxy(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/proxy`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "OPTIONS",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect HEAD requests to proxy of Pod
   * operationId: connectCoreV1HeadNamespacedPodProxy
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy
   */
  async connectCoreV1HeadNamespacedPodProxy(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/proxy`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "HEAD",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect PATCH requests to proxy of Pod
   * operationId: connectCoreV1PatchNamespacedPodProxy
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy
   */
  async connectCoreV1PatchNamespacedPodProxy(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/proxy`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect GET requests to proxy of Pod
   * operationId: connectCoreV1GetNamespacedPodProxyWithPath
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy/{path}
   */
  async connectCoreV1GetNamespacedPodProxyWithPath(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/proxy/${params.parameter.path}`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect PUT requests to proxy of Pod
   * operationId: connectCoreV1PutNamespacedPodProxyWithPath
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy/{path}
   */
  async connectCoreV1PutNamespacedPodProxyWithPath(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/proxy/${params.parameter.path}`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect POST requests to proxy of Pod
   * operationId: connectCoreV1PostNamespacedPodProxyWithPath
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy/{path}
   */
  async connectCoreV1PostNamespacedPodProxyWithPath(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/proxy/${params.parameter.path}`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect DELETE requests to proxy of Pod
   * operationId: connectCoreV1DeleteNamespacedPodProxyWithPath
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy/{path}
   */
  async connectCoreV1DeleteNamespacedPodProxyWithPath(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/proxy/${params.parameter.path}`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect OPTIONS requests to proxy of Pod
   * operationId: connectCoreV1OptionsNamespacedPodProxyWithPath
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy/{path}
   */
  async connectCoreV1OptionsNamespacedPodProxyWithPath(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/proxy/${params.parameter.path}`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "OPTIONS",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect HEAD requests to proxy of Pod
   * operationId: connectCoreV1HeadNamespacedPodProxyWithPath
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy/{path}
   */
  async connectCoreV1HeadNamespacedPodProxyWithPath(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/proxy/${params.parameter.path}`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "HEAD",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect PATCH requests to proxy of Pod
   * operationId: connectCoreV1PatchNamespacedPodProxyWithPath
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy/{path}
   */
  async connectCoreV1PatchNamespacedPodProxyWithPath(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/proxy/${params.parameter.path}`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified Pod
   * operationId: readCoreV1NamespacedPodStatus
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/status
   */
  async readCoreV1NamespacedPodStatus(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified Pod
   * operationId: replaceCoreV1NamespacedPodStatus
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/status
   */
  async replaceCoreV1NamespacedPodStatus(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified Pod
   * operationId: patchCoreV1NamespacedPodStatus
   * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/status
   */
  async patchCoreV1NamespacedPodStatus(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind PodTemplate
   * operationId: listCoreV1NamespacedPodTemplate
   * Request URI: /api/v1/namespaces/{namespace}/podtemplates
   */
  async listCoreV1NamespacedPodTemplate(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/podtemplates`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a PodTemplate
   * operationId: createCoreV1NamespacedPodTemplate
   * Request URI: /api/v1/namespaces/{namespace}/podtemplates
   */
  async createCoreV1NamespacedPodTemplate(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/podtemplates`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of PodTemplate
   * operationId: deleteCoreV1CollectionNamespacedPodTemplate
   * Request URI: /api/v1/namespaces/{namespace}/podtemplates
   */
  async deleteCoreV1CollectionNamespacedPodTemplate(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/podtemplates`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified PodTemplate
   * operationId: readCoreV1NamespacedPodTemplate
   * Request URI: /api/v1/namespaces/{namespace}/podtemplates/{name}
   */
  async readCoreV1NamespacedPodTemplate(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/podtemplates/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified PodTemplate
   * operationId: replaceCoreV1NamespacedPodTemplate
   * Request URI: /api/v1/namespaces/{namespace}/podtemplates/{name}
   */
  async replaceCoreV1NamespacedPodTemplate(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/podtemplates/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a PodTemplate
   * operationId: deleteCoreV1NamespacedPodTemplate
   * Request URI: /api/v1/namespaces/{namespace}/podtemplates/{name}
   */
  async deleteCoreV1NamespacedPodTemplate(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/podtemplates/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified PodTemplate
   * operationId: patchCoreV1NamespacedPodTemplate
   * Request URI: /api/v1/namespaces/{namespace}/podtemplates/{name}
   */
  async patchCoreV1NamespacedPodTemplate(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/podtemplates/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind ReplicationController
   * operationId: listCoreV1NamespacedReplicationController
   * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers
   */
  async listCoreV1NamespacedReplicationController(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/replicationcontrollers`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a ReplicationController
   * operationId: createCoreV1NamespacedReplicationController
   * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers
   */
  async createCoreV1NamespacedReplicationController(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/replicationcontrollers`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of ReplicationController
   * operationId: deleteCoreV1CollectionNamespacedReplicationController
   * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers
   */
  async deleteCoreV1CollectionNamespacedReplicationController(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/replicationcontrollers`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified ReplicationController
   * operationId: readCoreV1NamespacedReplicationController
   * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}
   */
  async readCoreV1NamespacedReplicationController(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/replicationcontrollers/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified ReplicationController
   * operationId: replaceCoreV1NamespacedReplicationController
   * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}
   */
  async replaceCoreV1NamespacedReplicationController(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/replicationcontrollers/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a ReplicationController
   * operationId: deleteCoreV1NamespacedReplicationController
   * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}
   */
  async deleteCoreV1NamespacedReplicationController(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/replicationcontrollers/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified ReplicationController
   * operationId: patchCoreV1NamespacedReplicationController
   * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}
   */
  async patchCoreV1NamespacedReplicationController(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/replicationcontrollers/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read scale of the specified ReplicationController
   * operationId: readCoreV1NamespacedReplicationControllerScale
   * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}/scale
   */
  async readCoreV1NamespacedReplicationControllerScale(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/replicationcontrollers/${params.parameter.name}/scale`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace scale of the specified ReplicationController
   * operationId: replaceCoreV1NamespacedReplicationControllerScale
   * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}/scale
   */
  async replaceCoreV1NamespacedReplicationControllerScale(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/replicationcontrollers/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update scale of the specified ReplicationController
   * operationId: patchCoreV1NamespacedReplicationControllerScale
   * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}/scale
   */
  async patchCoreV1NamespacedReplicationControllerScale(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/replicationcontrollers/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified ReplicationController
   * operationId: readCoreV1NamespacedReplicationControllerStatus
   * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}/status
   */
  async readCoreV1NamespacedReplicationControllerStatus(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/replicationcontrollers/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified ReplicationController
   * operationId: replaceCoreV1NamespacedReplicationControllerStatus
   * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}/status
   */
  async replaceCoreV1NamespacedReplicationControllerStatus(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/replicationcontrollers/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified ReplicationController
   * operationId: patchCoreV1NamespacedReplicationControllerStatus
   * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}/status
   */
  async patchCoreV1NamespacedReplicationControllerStatus(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/replicationcontrollers/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind ResourceQuota
   * operationId: listCoreV1NamespacedResourceQuota
   * Request URI: /api/v1/namespaces/{namespace}/resourcequotas
   */
  async listCoreV1NamespacedResourceQuota(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/resourcequotas`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a ResourceQuota
   * operationId: createCoreV1NamespacedResourceQuota
   * Request URI: /api/v1/namespaces/{namespace}/resourcequotas
   */
  async createCoreV1NamespacedResourceQuota(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/resourcequotas`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of ResourceQuota
   * operationId: deleteCoreV1CollectionNamespacedResourceQuota
   * Request URI: /api/v1/namespaces/{namespace}/resourcequotas
   */
  async deleteCoreV1CollectionNamespacedResourceQuota(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/resourcequotas`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified ResourceQuota
   * operationId: readCoreV1NamespacedResourceQuota
   * Request URI: /api/v1/namespaces/{namespace}/resourcequotas/{name}
   */
  async readCoreV1NamespacedResourceQuota(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/resourcequotas/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified ResourceQuota
   * operationId: replaceCoreV1NamespacedResourceQuota
   * Request URI: /api/v1/namespaces/{namespace}/resourcequotas/{name}
   */
  async replaceCoreV1NamespacedResourceQuota(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/resourcequotas/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a ResourceQuota
   * operationId: deleteCoreV1NamespacedResourceQuota
   * Request URI: /api/v1/namespaces/{namespace}/resourcequotas/{name}
   */
  async deleteCoreV1NamespacedResourceQuota(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/resourcequotas/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified ResourceQuota
   * operationId: patchCoreV1NamespacedResourceQuota
   * Request URI: /api/v1/namespaces/{namespace}/resourcequotas/{name}
   */
  async patchCoreV1NamespacedResourceQuota(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/resourcequotas/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified ResourceQuota
   * operationId: readCoreV1NamespacedResourceQuotaStatus
   * Request URI: /api/v1/namespaces/{namespace}/resourcequotas/{name}/status
   */
  async readCoreV1NamespacedResourceQuotaStatus(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/resourcequotas/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified ResourceQuota
   * operationId: replaceCoreV1NamespacedResourceQuotaStatus
   * Request URI: /api/v1/namespaces/{namespace}/resourcequotas/{name}/status
   */
  async replaceCoreV1NamespacedResourceQuotaStatus(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/resourcequotas/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified ResourceQuota
   * operationId: patchCoreV1NamespacedResourceQuotaStatus
   * Request URI: /api/v1/namespaces/{namespace}/resourcequotas/{name}/status
   */
  async patchCoreV1NamespacedResourceQuotaStatus(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/resourcequotas/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Secret
   * operationId: listCoreV1NamespacedSecret
   * Request URI: /api/v1/namespaces/{namespace}/secrets
   */
  async listCoreV1NamespacedSecret(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/secrets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a Secret
   * operationId: createCoreV1NamespacedSecret
   * Request URI: /api/v1/namespaces/{namespace}/secrets
   */
  async createCoreV1NamespacedSecret(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/secrets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of Secret
   * operationId: deleteCoreV1CollectionNamespacedSecret
   * Request URI: /api/v1/namespaces/{namespace}/secrets
   */
  async deleteCoreV1CollectionNamespacedSecret(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/secrets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified Secret
   * operationId: readCoreV1NamespacedSecret
   * Request URI: /api/v1/namespaces/{namespace}/secrets/{name}
   */
  async readCoreV1NamespacedSecret(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/secrets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified Secret
   * operationId: replaceCoreV1NamespacedSecret
   * Request URI: /api/v1/namespaces/{namespace}/secrets/{name}
   */
  async replaceCoreV1NamespacedSecret(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/secrets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a Secret
   * operationId: deleteCoreV1NamespacedSecret
   * Request URI: /api/v1/namespaces/{namespace}/secrets/{name}
   */
  async deleteCoreV1NamespacedSecret(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/secrets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified Secret
   * operationId: patchCoreV1NamespacedSecret
   * Request URI: /api/v1/namespaces/{namespace}/secrets/{name}
   */
  async patchCoreV1NamespacedSecret(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/secrets/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind ServiceAccount
   * operationId: listCoreV1NamespacedServiceAccount
   * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts
   */
  async listCoreV1NamespacedServiceAccount(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/serviceaccounts`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a ServiceAccount
   * operationId: createCoreV1NamespacedServiceAccount
   * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts
   */
  async createCoreV1NamespacedServiceAccount(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/serviceaccounts`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of ServiceAccount
   * operationId: deleteCoreV1CollectionNamespacedServiceAccount
   * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts
   */
  async deleteCoreV1CollectionNamespacedServiceAccount(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/serviceaccounts`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified ServiceAccount
   * operationId: readCoreV1NamespacedServiceAccount
   * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts/{name}
   */
  async readCoreV1NamespacedServiceAccount(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/serviceaccounts/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified ServiceAccount
   * operationId: replaceCoreV1NamespacedServiceAccount
   * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts/{name}
   */
  async replaceCoreV1NamespacedServiceAccount(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/serviceaccounts/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a ServiceAccount
   * operationId: deleteCoreV1NamespacedServiceAccount
   * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts/{name}
   */
  async deleteCoreV1NamespacedServiceAccount(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/serviceaccounts/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified ServiceAccount
   * operationId: patchCoreV1NamespacedServiceAccount
   * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts/{name}
   */
  async patchCoreV1NamespacedServiceAccount(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/serviceaccounts/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * create token of a ServiceAccount
   * operationId: createCoreV1NamespacedServiceAccountToken
   * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts/{name}/token
   */
  async createCoreV1NamespacedServiceAccountToken(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/serviceaccounts/${params.parameter.name}/token`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Service
   * operationId: listCoreV1NamespacedService
   * Request URI: /api/v1/namespaces/{namespace}/services
   */
  async listCoreV1NamespacedService(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a Service
   * operationId: createCoreV1NamespacedService
   * Request URI: /api/v1/namespaces/{namespace}/services
   */
  async createCoreV1NamespacedService(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified Service
   * operationId: readCoreV1NamespacedService
   * Request URI: /api/v1/namespaces/{namespace}/services/{name}
   */
  async readCoreV1NamespacedService(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified Service
   * operationId: replaceCoreV1NamespacedService
   * Request URI: /api/v1/namespaces/{namespace}/services/{name}
   */
  async replaceCoreV1NamespacedService(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a Service
   * operationId: deleteCoreV1NamespacedService
   * Request URI: /api/v1/namespaces/{namespace}/services/{name}
   */
  async deleteCoreV1NamespacedService(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified Service
   * operationId: patchCoreV1NamespacedService
   * Request URI: /api/v1/namespaces/{namespace}/services/{name}
   */
  async patchCoreV1NamespacedService(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * connect GET requests to proxy of Service
   * operationId: connectCoreV1GetNamespacedServiceProxy
   * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy
   */
  async connectCoreV1GetNamespacedServiceProxy(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services/${params.parameter.name}/proxy`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect PUT requests to proxy of Service
   * operationId: connectCoreV1PutNamespacedServiceProxy
   * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy
   */
  async connectCoreV1PutNamespacedServiceProxy(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services/${params.parameter.name}/proxy`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect POST requests to proxy of Service
   * operationId: connectCoreV1PostNamespacedServiceProxy
   * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy
   */
  async connectCoreV1PostNamespacedServiceProxy(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services/${params.parameter.name}/proxy`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect DELETE requests to proxy of Service
   * operationId: connectCoreV1DeleteNamespacedServiceProxy
   * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy
   */
  async connectCoreV1DeleteNamespacedServiceProxy(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services/${params.parameter.name}/proxy`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect OPTIONS requests to proxy of Service
   * operationId: connectCoreV1OptionsNamespacedServiceProxy
   * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy
   */
  async connectCoreV1OptionsNamespacedServiceProxy(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services/${params.parameter.name}/proxy`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "OPTIONS",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect HEAD requests to proxy of Service
   * operationId: connectCoreV1HeadNamespacedServiceProxy
   * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy
   */
  async connectCoreV1HeadNamespacedServiceProxy(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services/${params.parameter.name}/proxy`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "HEAD",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect PATCH requests to proxy of Service
   * operationId: connectCoreV1PatchNamespacedServiceProxy
   * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy
   */
  async connectCoreV1PatchNamespacedServiceProxy(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services/${params.parameter.name}/proxy`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect GET requests to proxy of Service
   * operationId: connectCoreV1GetNamespacedServiceProxyWithPath
   * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy/{path}
   */
  async connectCoreV1GetNamespacedServiceProxyWithPath(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services/${params.parameter.name}/proxy/${params.parameter.path}`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect PUT requests to proxy of Service
   * operationId: connectCoreV1PutNamespacedServiceProxyWithPath
   * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy/{path}
   */
  async connectCoreV1PutNamespacedServiceProxyWithPath(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services/${params.parameter.name}/proxy/${params.parameter.path}`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect POST requests to proxy of Service
   * operationId: connectCoreV1PostNamespacedServiceProxyWithPath
   * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy/{path}
   */
  async connectCoreV1PostNamespacedServiceProxyWithPath(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services/${params.parameter.name}/proxy/${params.parameter.path}`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect DELETE requests to proxy of Service
   * operationId: connectCoreV1DeleteNamespacedServiceProxyWithPath
   * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy/{path}
   */
  async connectCoreV1DeleteNamespacedServiceProxyWithPath(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services/${params.parameter.name}/proxy/${params.parameter.path}`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect OPTIONS requests to proxy of Service
   * operationId: connectCoreV1OptionsNamespacedServiceProxyWithPath
   * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy/{path}
   */
  async connectCoreV1OptionsNamespacedServiceProxyWithPath(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services/${params.parameter.name}/proxy/${params.parameter.path}`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "OPTIONS",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect HEAD requests to proxy of Service
   * operationId: connectCoreV1HeadNamespacedServiceProxyWithPath
   * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy/{path}
   */
  async connectCoreV1HeadNamespacedServiceProxyWithPath(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services/${params.parameter.name}/proxy/${params.parameter.path}`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "HEAD",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect PATCH requests to proxy of Service
   * operationId: connectCoreV1PatchNamespacedServiceProxyWithPath
   * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy/{path}
   */
  async connectCoreV1PatchNamespacedServiceProxyWithPath(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services/${params.parameter.name}/proxy/${params.parameter.path}`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified Service
   * operationId: readCoreV1NamespacedServiceStatus
   * Request URI: /api/v1/namespaces/{namespace}/services/{name}/status
   */
  async readCoreV1NamespacedServiceStatus(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified Service
   * operationId: replaceCoreV1NamespacedServiceStatus
   * Request URI: /api/v1/namespaces/{namespace}/services/{name}/status
   */
  async replaceCoreV1NamespacedServiceStatus(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified Service
   * operationId: patchCoreV1NamespacedServiceStatus
   * Request URI: /api/v1/namespaces/{namespace}/services/{name}/status
   */
  async patchCoreV1NamespacedServiceStatus(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.namespace}/services/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified Namespace
   * operationId: readCoreV1Namespace
   * Request URI: /api/v1/namespaces/{name}
   */
  async readCoreV1Namespace(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified Namespace
   * operationId: replaceCoreV1Namespace
   * Request URI: /api/v1/namespaces/{name}
   */
  async replaceCoreV1Namespace(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a Namespace
   * operationId: deleteCoreV1Namespace
   * Request URI: /api/v1/namespaces/{name}
   */
  async deleteCoreV1Namespace(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified Namespace
   * operationId: patchCoreV1Namespace
   * Request URI: /api/v1/namespaces/{name}
   */
  async patchCoreV1Namespace(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * replace finalize of the specified Namespace
   * operationId: replaceCoreV1NamespaceFinalize
   * Request URI: /api/v1/namespaces/{name}/finalize
   */
  async replaceCoreV1NamespaceFinalize(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.name}/finalize`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified Namespace
   * operationId: readCoreV1NamespaceStatus
   * Request URI: /api/v1/namespaces/{name}/status
   */
  async readCoreV1NamespaceStatus(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified Namespace
   * operationId: replaceCoreV1NamespaceStatus
   * Request URI: /api/v1/namespaces/{name}/status
   */
  async replaceCoreV1NamespaceStatus(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified Namespace
   * operationId: patchCoreV1NamespaceStatus
   * Request URI: /api/v1/namespaces/{name}/status
   */
  async patchCoreV1NamespaceStatus(params, option) {
    const url = this.baseUrl + `/api/v1/namespaces/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Node
   * operationId: listCoreV1Node
   * Request URI: /api/v1/nodes
   */
  async listCoreV1Node(params, option) {
    const url = this.baseUrl + `/api/v1/nodes`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a Node
   * operationId: createCoreV1Node
   * Request URI: /api/v1/nodes
   */
  async createCoreV1Node(params, option) {
    const url = this.baseUrl + `/api/v1/nodes`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of Node
   * operationId: deleteCoreV1CollectionNode
   * Request URI: /api/v1/nodes
   */
  async deleteCoreV1CollectionNode(params, option) {
    const url = this.baseUrl + `/api/v1/nodes`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified Node
   * operationId: readCoreV1Node
   * Request URI: /api/v1/nodes/{name}
   */
  async readCoreV1Node(params, option) {
    const url = this.baseUrl + `/api/v1/nodes/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified Node
   * operationId: replaceCoreV1Node
   * Request URI: /api/v1/nodes/{name}
   */
  async replaceCoreV1Node(params, option) {
    const url = this.baseUrl + `/api/v1/nodes/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a Node
   * operationId: deleteCoreV1Node
   * Request URI: /api/v1/nodes/{name}
   */
  async deleteCoreV1Node(params, option) {
    const url = this.baseUrl + `/api/v1/nodes/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified Node
   * operationId: patchCoreV1Node
   * Request URI: /api/v1/nodes/{name}
   */
  async patchCoreV1Node(params, option) {
    const url = this.baseUrl + `/api/v1/nodes/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * connect GET requests to proxy of Node
   * operationId: connectCoreV1GetNodeProxy
   * Request URI: /api/v1/nodes/{name}/proxy
   */
  async connectCoreV1GetNodeProxy(params, option) {
    const url = this.baseUrl + `/api/v1/nodes/${params.parameter.name}/proxy`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect PUT requests to proxy of Node
   * operationId: connectCoreV1PutNodeProxy
   * Request URI: /api/v1/nodes/{name}/proxy
   */
  async connectCoreV1PutNodeProxy(params, option) {
    const url = this.baseUrl + `/api/v1/nodes/${params.parameter.name}/proxy`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect POST requests to proxy of Node
   * operationId: connectCoreV1PostNodeProxy
   * Request URI: /api/v1/nodes/{name}/proxy
   */
  async connectCoreV1PostNodeProxy(params, option) {
    const url = this.baseUrl + `/api/v1/nodes/${params.parameter.name}/proxy`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect DELETE requests to proxy of Node
   * operationId: connectCoreV1DeleteNodeProxy
   * Request URI: /api/v1/nodes/{name}/proxy
   */
  async connectCoreV1DeleteNodeProxy(params, option) {
    const url = this.baseUrl + `/api/v1/nodes/${params.parameter.name}/proxy`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect OPTIONS requests to proxy of Node
   * operationId: connectCoreV1OptionsNodeProxy
   * Request URI: /api/v1/nodes/{name}/proxy
   */
  async connectCoreV1OptionsNodeProxy(params, option) {
    const url = this.baseUrl + `/api/v1/nodes/${params.parameter.name}/proxy`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "OPTIONS",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect HEAD requests to proxy of Node
   * operationId: connectCoreV1HeadNodeProxy
   * Request URI: /api/v1/nodes/{name}/proxy
   */
  async connectCoreV1HeadNodeProxy(params, option) {
    const url = this.baseUrl + `/api/v1/nodes/${params.parameter.name}/proxy`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "HEAD",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect PATCH requests to proxy of Node
   * operationId: connectCoreV1PatchNodeProxy
   * Request URI: /api/v1/nodes/{name}/proxy
   */
  async connectCoreV1PatchNodeProxy(params, option) {
    const url = this.baseUrl + `/api/v1/nodes/${params.parameter.name}/proxy`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect GET requests to proxy of Node
   * operationId: connectCoreV1GetNodeProxyWithPath
   * Request URI: /api/v1/nodes/{name}/proxy/{path}
   */
  async connectCoreV1GetNodeProxyWithPath(params, option) {
    const url = this.baseUrl + `/api/v1/nodes/${params.parameter.name}/proxy/${params.parameter.path}`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect PUT requests to proxy of Node
   * operationId: connectCoreV1PutNodeProxyWithPath
   * Request URI: /api/v1/nodes/{name}/proxy/{path}
   */
  async connectCoreV1PutNodeProxyWithPath(params, option) {
    const url = this.baseUrl + `/api/v1/nodes/${params.parameter.name}/proxy/${params.parameter.path}`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect POST requests to proxy of Node
   * operationId: connectCoreV1PostNodeProxyWithPath
   * Request URI: /api/v1/nodes/{name}/proxy/{path}
   */
  async connectCoreV1PostNodeProxyWithPath(params, option) {
    const url = this.baseUrl + `/api/v1/nodes/${params.parameter.name}/proxy/${params.parameter.path}`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect DELETE requests to proxy of Node
   * operationId: connectCoreV1DeleteNodeProxyWithPath
   * Request URI: /api/v1/nodes/{name}/proxy/{path}
   */
  async connectCoreV1DeleteNodeProxyWithPath(params, option) {
    const url = this.baseUrl + `/api/v1/nodes/${params.parameter.name}/proxy/${params.parameter.path}`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect OPTIONS requests to proxy of Node
   * operationId: connectCoreV1OptionsNodeProxyWithPath
   * Request URI: /api/v1/nodes/{name}/proxy/{path}
   */
  async connectCoreV1OptionsNodeProxyWithPath(params, option) {
    const url = this.baseUrl + `/api/v1/nodes/${params.parameter.name}/proxy/${params.parameter.path}`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "OPTIONS",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect HEAD requests to proxy of Node
   * operationId: connectCoreV1HeadNodeProxyWithPath
   * Request URI: /api/v1/nodes/{name}/proxy/{path}
   */
  async connectCoreV1HeadNodeProxyWithPath(params, option) {
    const url = this.baseUrl + `/api/v1/nodes/${params.parameter.name}/proxy/${params.parameter.path}`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "HEAD",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * connect PATCH requests to proxy of Node
   * operationId: connectCoreV1PatchNodeProxyWithPath
   * Request URI: /api/v1/nodes/{name}/proxy/{path}
   */
  async connectCoreV1PatchNodeProxyWithPath(params, option) {
    const url = this.baseUrl + `/api/v1/nodes/${params.parameter.name}/proxy/${params.parameter.path}`;
    const headers = {
      Accept: "*/*"
    };
    const queryParameters = {
      path: { value: params.parameter.path, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified Node
   * operationId: readCoreV1NodeStatus
   * Request URI: /api/v1/nodes/{name}/status
   */
  async readCoreV1NodeStatus(params, option) {
    const url = this.baseUrl + `/api/v1/nodes/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified Node
   * operationId: replaceCoreV1NodeStatus
   * Request URI: /api/v1/nodes/{name}/status
   */
  async replaceCoreV1NodeStatus(params, option) {
    const url = this.baseUrl + `/api/v1/nodes/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified Node
   * operationId: patchCoreV1NodeStatus
   * Request URI: /api/v1/nodes/{name}/status
   */
  async patchCoreV1NodeStatus(params, option) {
    const url = this.baseUrl + `/api/v1/nodes/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind PersistentVolumeClaim
   * operationId: listCoreV1PersistentVolumeClaimForAllNamespaces
   * Request URI: /api/v1/persistentvolumeclaims
   */
  async listCoreV1PersistentVolumeClaimForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/persistentvolumeclaims`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind PersistentVolume
   * operationId: listCoreV1PersistentVolume
   * Request URI: /api/v1/persistentvolumes
   */
  async listCoreV1PersistentVolume(params, option) {
    const url = this.baseUrl + `/api/v1/persistentvolumes`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a PersistentVolume
   * operationId: createCoreV1PersistentVolume
   * Request URI: /api/v1/persistentvolumes
   */
  async createCoreV1PersistentVolume(params, option) {
    const url = this.baseUrl + `/api/v1/persistentvolumes`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of PersistentVolume
   * operationId: deleteCoreV1CollectionPersistentVolume
   * Request URI: /api/v1/persistentvolumes
   */
  async deleteCoreV1CollectionPersistentVolume(params, option) {
    const url = this.baseUrl + `/api/v1/persistentvolumes`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified PersistentVolume
   * operationId: readCoreV1PersistentVolume
   * Request URI: /api/v1/persistentvolumes/{name}
   */
  async readCoreV1PersistentVolume(params, option) {
    const url = this.baseUrl + `/api/v1/persistentvolumes/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified PersistentVolume
   * operationId: replaceCoreV1PersistentVolume
   * Request URI: /api/v1/persistentvolumes/{name}
   */
  async replaceCoreV1PersistentVolume(params, option) {
    const url = this.baseUrl + `/api/v1/persistentvolumes/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a PersistentVolume
   * operationId: deleteCoreV1PersistentVolume
   * Request URI: /api/v1/persistentvolumes/{name}
   */
  async deleteCoreV1PersistentVolume(params, option) {
    const url = this.baseUrl + `/api/v1/persistentvolumes/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified PersistentVolume
   * operationId: patchCoreV1PersistentVolume
   * Request URI: /api/v1/persistentvolumes/{name}
   */
  async patchCoreV1PersistentVolume(params, option) {
    const url = this.baseUrl + `/api/v1/persistentvolumes/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified PersistentVolume
   * operationId: readCoreV1PersistentVolumeStatus
   * Request URI: /api/v1/persistentvolumes/{name}/status
   */
  async readCoreV1PersistentVolumeStatus(params, option) {
    const url = this.baseUrl + `/api/v1/persistentvolumes/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified PersistentVolume
   * operationId: replaceCoreV1PersistentVolumeStatus
   * Request URI: /api/v1/persistentvolumes/{name}/status
   */
  async replaceCoreV1PersistentVolumeStatus(params, option) {
    const url = this.baseUrl + `/api/v1/persistentvolumes/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified PersistentVolume
   * operationId: patchCoreV1PersistentVolumeStatus
   * Request URI: /api/v1/persistentvolumes/{name}/status
   */
  async patchCoreV1PersistentVolumeStatus(params, option) {
    const url = this.baseUrl + `/api/v1/persistentvolumes/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Pod
   * operationId: listCoreV1PodForAllNamespaces
   * Request URI: /api/v1/pods
   */
  async listCoreV1PodForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/pods`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind PodTemplate
   * operationId: listCoreV1PodTemplateForAllNamespaces
   * Request URI: /api/v1/podtemplates
   */
  async listCoreV1PodTemplateForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/podtemplates`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind ReplicationController
   * operationId: listCoreV1ReplicationControllerForAllNamespaces
   * Request URI: /api/v1/replicationcontrollers
   */
  async listCoreV1ReplicationControllerForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/replicationcontrollers`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind ResourceQuota
   * operationId: listCoreV1ResourceQuotaForAllNamespaces
   * Request URI: /api/v1/resourcequotas
   */
  async listCoreV1ResourceQuotaForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/resourcequotas`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Secret
   * operationId: listCoreV1SecretForAllNamespaces
   * Request URI: /api/v1/secrets
   */
  async listCoreV1SecretForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/secrets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind ServiceAccount
   * operationId: listCoreV1ServiceAccountForAllNamespaces
   * Request URI: /api/v1/serviceaccounts
   */
  async listCoreV1ServiceAccountForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/serviceaccounts`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Service
   * operationId: listCoreV1ServiceForAllNamespaces
   * Request URI: /api/v1/services
   */
  async listCoreV1ServiceForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/services`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ConfigMap. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1ConfigMapListForAllNamespaces
   * Request URI: /api/v1/watch/configmaps
   */
  async watchCoreV1ConfigMapListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/watch/configmaps`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Endpoints. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1EndpointsListForAllNamespaces
   * Request URI: /api/v1/watch/endpoints
   */
  async watchCoreV1EndpointsListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/watch/endpoints`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Event. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1EventListForAllNamespaces
   * Request URI: /api/v1/watch/events
   */
  async watchCoreV1EventListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/watch/events`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of LimitRange. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1LimitRangeListForAllNamespaces
   * Request URI: /api/v1/watch/limitranges
   */
  async watchCoreV1LimitRangeListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/watch/limitranges`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Namespace. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1NamespaceList
   * Request URI: /api/v1/watch/namespaces
   */
  async watchCoreV1NamespaceList(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ConfigMap. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1NamespacedConfigMapList
   * Request URI: /api/v1/watch/namespaces/{namespace}/configmaps
   */
  async watchCoreV1NamespacedConfigMapList(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/configmaps`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind ConfigMap. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchCoreV1NamespacedConfigMap
   * Request URI: /api/v1/watch/namespaces/{namespace}/configmaps/{name}
   */
  async watchCoreV1NamespacedConfigMap(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/configmaps/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Endpoints. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1NamespacedEndpointsList
   * Request URI: /api/v1/watch/namespaces/{namespace}/endpoints
   */
  async watchCoreV1NamespacedEndpointsList(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/endpoints`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind Endpoints. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchCoreV1NamespacedEndpoints
   * Request URI: /api/v1/watch/namespaces/{namespace}/endpoints/{name}
   */
  async watchCoreV1NamespacedEndpoints(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/endpoints/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Event. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1NamespacedEventList
   * Request URI: /api/v1/watch/namespaces/{namespace}/events
   */
  async watchCoreV1NamespacedEventList(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/events`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind Event. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchCoreV1NamespacedEvent
   * Request URI: /api/v1/watch/namespaces/{namespace}/events/{name}
   */
  async watchCoreV1NamespacedEvent(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/events/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of LimitRange. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1NamespacedLimitRangeList
   * Request URI: /api/v1/watch/namespaces/{namespace}/limitranges
   */
  async watchCoreV1NamespacedLimitRangeList(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/limitranges`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind LimitRange. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchCoreV1NamespacedLimitRange
   * Request URI: /api/v1/watch/namespaces/{namespace}/limitranges/{name}
   */
  async watchCoreV1NamespacedLimitRange(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/limitranges/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of PersistentVolumeClaim. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1NamespacedPersistentVolumeClaimList
   * Request URI: /api/v1/watch/namespaces/{namespace}/persistentvolumeclaims
   */
  async watchCoreV1NamespacedPersistentVolumeClaimList(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/persistentvolumeclaims`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind PersistentVolumeClaim. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchCoreV1NamespacedPersistentVolumeClaim
   * Request URI: /api/v1/watch/namespaces/{namespace}/persistentvolumeclaims/{name}
   */
  async watchCoreV1NamespacedPersistentVolumeClaim(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/persistentvolumeclaims/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Pod. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1NamespacedPodList
   * Request URI: /api/v1/watch/namespaces/{namespace}/pods
   */
  async watchCoreV1NamespacedPodList(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/pods`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind Pod. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchCoreV1NamespacedPod
   * Request URI: /api/v1/watch/namespaces/{namespace}/pods/{name}
   */
  async watchCoreV1NamespacedPod(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/pods/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of PodTemplate. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1NamespacedPodTemplateList
   * Request URI: /api/v1/watch/namespaces/{namespace}/podtemplates
   */
  async watchCoreV1NamespacedPodTemplateList(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/podtemplates`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind PodTemplate. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchCoreV1NamespacedPodTemplate
   * Request URI: /api/v1/watch/namespaces/{namespace}/podtemplates/{name}
   */
  async watchCoreV1NamespacedPodTemplate(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/podtemplates/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ReplicationController. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1NamespacedReplicationControllerList
   * Request URI: /api/v1/watch/namespaces/{namespace}/replicationcontrollers
   */
  async watchCoreV1NamespacedReplicationControllerList(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/replicationcontrollers`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind ReplicationController. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchCoreV1NamespacedReplicationController
   * Request URI: /api/v1/watch/namespaces/{namespace}/replicationcontrollers/{name}
   */
  async watchCoreV1NamespacedReplicationController(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/replicationcontrollers/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ResourceQuota. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1NamespacedResourceQuotaList
   * Request URI: /api/v1/watch/namespaces/{namespace}/resourcequotas
   */
  async watchCoreV1NamespacedResourceQuotaList(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/resourcequotas`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind ResourceQuota. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchCoreV1NamespacedResourceQuota
   * Request URI: /api/v1/watch/namespaces/{namespace}/resourcequotas/{name}
   */
  async watchCoreV1NamespacedResourceQuota(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/resourcequotas/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Secret. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1NamespacedSecretList
   * Request URI: /api/v1/watch/namespaces/{namespace}/secrets
   */
  async watchCoreV1NamespacedSecretList(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/secrets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind Secret. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchCoreV1NamespacedSecret
   * Request URI: /api/v1/watch/namespaces/{namespace}/secrets/{name}
   */
  async watchCoreV1NamespacedSecret(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/secrets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ServiceAccount. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1NamespacedServiceAccountList
   * Request URI: /api/v1/watch/namespaces/{namespace}/serviceaccounts
   */
  async watchCoreV1NamespacedServiceAccountList(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/serviceaccounts`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind ServiceAccount. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchCoreV1NamespacedServiceAccount
   * Request URI: /api/v1/watch/namespaces/{namespace}/serviceaccounts/{name}
   */
  async watchCoreV1NamespacedServiceAccount(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/serviceaccounts/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Service. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1NamespacedServiceList
   * Request URI: /api/v1/watch/namespaces/{namespace}/services
   */
  async watchCoreV1NamespacedServiceList(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/services`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind Service. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchCoreV1NamespacedService
   * Request URI: /api/v1/watch/namespaces/{namespace}/services/{name}
   */
  async watchCoreV1NamespacedService(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.namespace}/services/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind Namespace. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchCoreV1Namespace
   * Request URI: /api/v1/watch/namespaces/{name}
   */
  async watchCoreV1Namespace(params, option) {
    const url = this.baseUrl + `/api/v1/watch/namespaces/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Node. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1NodeList
   * Request URI: /api/v1/watch/nodes
   */
  async watchCoreV1NodeList(params, option) {
    const url = this.baseUrl + `/api/v1/watch/nodes`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind Node. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchCoreV1Node
   * Request URI: /api/v1/watch/nodes/{name}
   */
  async watchCoreV1Node(params, option) {
    const url = this.baseUrl + `/api/v1/watch/nodes/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of PersistentVolumeClaim. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1PersistentVolumeClaimListForAllNamespaces
   * Request URI: /api/v1/watch/persistentvolumeclaims
   */
  async watchCoreV1PersistentVolumeClaimListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/watch/persistentvolumeclaims`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of PersistentVolume. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1PersistentVolumeList
   * Request URI: /api/v1/watch/persistentvolumes
   */
  async watchCoreV1PersistentVolumeList(params, option) {
    const url = this.baseUrl + `/api/v1/watch/persistentvolumes`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind PersistentVolume. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchCoreV1PersistentVolume
   * Request URI: /api/v1/watch/persistentvolumes/{name}
   */
  async watchCoreV1PersistentVolume(params, option) {
    const url = this.baseUrl + `/api/v1/watch/persistentvolumes/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Pod. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1PodListForAllNamespaces
   * Request URI: /api/v1/watch/pods
   */
  async watchCoreV1PodListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/watch/pods`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of PodTemplate. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1PodTemplateListForAllNamespaces
   * Request URI: /api/v1/watch/podtemplates
   */
  async watchCoreV1PodTemplateListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/watch/podtemplates`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ReplicationController. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1ReplicationControllerListForAllNamespaces
   * Request URI: /api/v1/watch/replicationcontrollers
   */
  async watchCoreV1ReplicationControllerListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/watch/replicationcontrollers`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ResourceQuota. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1ResourceQuotaListForAllNamespaces
   * Request URI: /api/v1/watch/resourcequotas
   */
  async watchCoreV1ResourceQuotaListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/watch/resourcequotas`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Secret. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1SecretListForAllNamespaces
   * Request URI: /api/v1/watch/secrets
   */
  async watchCoreV1SecretListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/watch/secrets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ServiceAccount. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1ServiceAccountListForAllNamespaces
   * Request URI: /api/v1/watch/serviceaccounts
   */
  async watchCoreV1ServiceAccountListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/watch/serviceaccounts`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Service. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoreV1ServiceListForAllNamespaces
   * Request URI: /api/v1/watch/services
   */
  async watchCoreV1ServiceListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/api/v1/watch/services`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get available API versions
   * operationId: getAPIVersions
   * Request URI: /apis/
   */
  async getAPIVersions(params, option) {
    const url = this.baseUrl + `/apis/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get information of a group
   * operationId: getAdmissionregistrationAPIGroup
   * Request URI: /apis/admissionregistration.k8s.io/
   */
  async getAdmissionregistrationAPIGroup(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getAdmissionregistrationV1APIResources
   * Request URI: /apis/admissionregistration.k8s.io/v1/
   */
  async getAdmissionregistrationV1APIResources(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind MutatingWebhookConfiguration
   * operationId: listAdmissionregistrationV1MutatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations
   */
  async listAdmissionregistrationV1MutatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a MutatingWebhookConfiguration
   * operationId: createAdmissionregistrationV1MutatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations
   */
  async createAdmissionregistrationV1MutatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of MutatingWebhookConfiguration
   * operationId: deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations
   */
  async deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified MutatingWebhookConfiguration
   * operationId: readAdmissionregistrationV1MutatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations/{name}
   */
  async readAdmissionregistrationV1MutatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified MutatingWebhookConfiguration
   * operationId: replaceAdmissionregistrationV1MutatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations/{name}
   */
  async replaceAdmissionregistrationV1MutatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a MutatingWebhookConfiguration
   * operationId: deleteAdmissionregistrationV1MutatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations/{name}
   */
  async deleteAdmissionregistrationV1MutatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified MutatingWebhookConfiguration
   * operationId: patchAdmissionregistrationV1MutatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations/{name}
   */
  async patchAdmissionregistrationV1MutatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind ValidatingWebhookConfiguration
   * operationId: listAdmissionregistrationV1ValidatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations
   */
  async listAdmissionregistrationV1ValidatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a ValidatingWebhookConfiguration
   * operationId: createAdmissionregistrationV1ValidatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations
   */
  async createAdmissionregistrationV1ValidatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of ValidatingWebhookConfiguration
   * operationId: deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations
   */
  async deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified ValidatingWebhookConfiguration
   * operationId: readAdmissionregistrationV1ValidatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations/{name}
   */
  async readAdmissionregistrationV1ValidatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified ValidatingWebhookConfiguration
   * operationId: replaceAdmissionregistrationV1ValidatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations/{name}
   */
  async replaceAdmissionregistrationV1ValidatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a ValidatingWebhookConfiguration
   * operationId: deleteAdmissionregistrationV1ValidatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations/{name}
   */
  async deleteAdmissionregistrationV1ValidatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified ValidatingWebhookConfiguration
   * operationId: patchAdmissionregistrationV1ValidatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations/{name}
   */
  async patchAdmissionregistrationV1ValidatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of MutatingWebhookConfiguration. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAdmissionregistrationV1MutatingWebhookConfigurationList
   * Request URI: /apis/admissionregistration.k8s.io/v1/watch/mutatingwebhookconfigurations
   */
  async watchAdmissionregistrationV1MutatingWebhookConfigurationList(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1/watch/mutatingwebhookconfigurations`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind MutatingWebhookConfiguration. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchAdmissionregistrationV1MutatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1/watch/mutatingwebhookconfigurations/{name}
   */
  async watchAdmissionregistrationV1MutatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1/watch/mutatingwebhookconfigurations/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ValidatingWebhookConfiguration. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAdmissionregistrationV1ValidatingWebhookConfigurationList
   * Request URI: /apis/admissionregistration.k8s.io/v1/watch/validatingwebhookconfigurations
   */
  async watchAdmissionregistrationV1ValidatingWebhookConfigurationList(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1/watch/validatingwebhookconfigurations`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind ValidatingWebhookConfiguration. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchAdmissionregistrationV1ValidatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1/watch/validatingwebhookconfigurations/{name}
   */
  async watchAdmissionregistrationV1ValidatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1/watch/validatingwebhookconfigurations/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getAdmissionregistrationV1beta1APIResources
   * Request URI: /apis/admissionregistration.k8s.io/v1beta1/
   */
  async getAdmissionregistrationV1beta1APIResources(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1beta1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind MutatingWebhookConfiguration
   * operationId: listAdmissionregistrationV1beta1MutatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1beta1/mutatingwebhookconfigurations
   */
  async listAdmissionregistrationV1beta1MutatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1beta1/mutatingwebhookconfigurations`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a MutatingWebhookConfiguration
   * operationId: createAdmissionregistrationV1beta1MutatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1beta1/mutatingwebhookconfigurations
   */
  async createAdmissionregistrationV1beta1MutatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1beta1/mutatingwebhookconfigurations`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of MutatingWebhookConfiguration
   * operationId: deleteAdmissionregistrationV1beta1CollectionMutatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1beta1/mutatingwebhookconfigurations
   */
  async deleteAdmissionregistrationV1beta1CollectionMutatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1beta1/mutatingwebhookconfigurations`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified MutatingWebhookConfiguration
   * operationId: readAdmissionregistrationV1beta1MutatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1beta1/mutatingwebhookconfigurations/{name}
   */
  async readAdmissionregistrationV1beta1MutatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1beta1/mutatingwebhookconfigurations/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified MutatingWebhookConfiguration
   * operationId: replaceAdmissionregistrationV1beta1MutatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1beta1/mutatingwebhookconfigurations/{name}
   */
  async replaceAdmissionregistrationV1beta1MutatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1beta1/mutatingwebhookconfigurations/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a MutatingWebhookConfiguration
   * operationId: deleteAdmissionregistrationV1beta1MutatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1beta1/mutatingwebhookconfigurations/{name}
   */
  async deleteAdmissionregistrationV1beta1MutatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1beta1/mutatingwebhookconfigurations/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified MutatingWebhookConfiguration
   * operationId: patchAdmissionregistrationV1beta1MutatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1beta1/mutatingwebhookconfigurations/{name}
   */
  async patchAdmissionregistrationV1beta1MutatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1beta1/mutatingwebhookconfigurations/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind ValidatingWebhookConfiguration
   * operationId: listAdmissionregistrationV1beta1ValidatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1beta1/validatingwebhookconfigurations
   */
  async listAdmissionregistrationV1beta1ValidatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1beta1/validatingwebhookconfigurations`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a ValidatingWebhookConfiguration
   * operationId: createAdmissionregistrationV1beta1ValidatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1beta1/validatingwebhookconfigurations
   */
  async createAdmissionregistrationV1beta1ValidatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1beta1/validatingwebhookconfigurations`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of ValidatingWebhookConfiguration
   * operationId: deleteAdmissionregistrationV1beta1CollectionValidatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1beta1/validatingwebhookconfigurations
   */
  async deleteAdmissionregistrationV1beta1CollectionValidatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1beta1/validatingwebhookconfigurations`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified ValidatingWebhookConfiguration
   * operationId: readAdmissionregistrationV1beta1ValidatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1beta1/validatingwebhookconfigurations/{name}
   */
  async readAdmissionregistrationV1beta1ValidatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1beta1/validatingwebhookconfigurations/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified ValidatingWebhookConfiguration
   * operationId: replaceAdmissionregistrationV1beta1ValidatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1beta1/validatingwebhookconfigurations/{name}
   */
  async replaceAdmissionregistrationV1beta1ValidatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1beta1/validatingwebhookconfigurations/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a ValidatingWebhookConfiguration
   * operationId: deleteAdmissionregistrationV1beta1ValidatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1beta1/validatingwebhookconfigurations/{name}
   */
  async deleteAdmissionregistrationV1beta1ValidatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1beta1/validatingwebhookconfigurations/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified ValidatingWebhookConfiguration
   * operationId: patchAdmissionregistrationV1beta1ValidatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1beta1/validatingwebhookconfigurations/{name}
   */
  async patchAdmissionregistrationV1beta1ValidatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1beta1/validatingwebhookconfigurations/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of MutatingWebhookConfiguration. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAdmissionregistrationV1beta1MutatingWebhookConfigurationList
   * Request URI: /apis/admissionregistration.k8s.io/v1beta1/watch/mutatingwebhookconfigurations
   */
  async watchAdmissionregistrationV1beta1MutatingWebhookConfigurationList(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1beta1/watch/mutatingwebhookconfigurations`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind MutatingWebhookConfiguration. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchAdmissionregistrationV1beta1MutatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1beta1/watch/mutatingwebhookconfigurations/{name}
   */
  async watchAdmissionregistrationV1beta1MutatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1beta1/watch/mutatingwebhookconfigurations/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ValidatingWebhookConfiguration. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAdmissionregistrationV1beta1ValidatingWebhookConfigurationList
   * Request URI: /apis/admissionregistration.k8s.io/v1beta1/watch/validatingwebhookconfigurations
   */
  async watchAdmissionregistrationV1beta1ValidatingWebhookConfigurationList(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1beta1/watch/validatingwebhookconfigurations`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind ValidatingWebhookConfiguration. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchAdmissionregistrationV1beta1ValidatingWebhookConfiguration
   * Request URI: /apis/admissionregistration.k8s.io/v1beta1/watch/validatingwebhookconfigurations/{name}
   */
  async watchAdmissionregistrationV1beta1ValidatingWebhookConfiguration(params, option) {
    const url = this.baseUrl + `/apis/admissionregistration.k8s.io/v1beta1/watch/validatingwebhookconfigurations/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get information of a group
   * operationId: getApiextensionsAPIGroup
   * Request URI: /apis/apiextensions.k8s.io/
   */
  async getApiextensionsAPIGroup(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getApiextensionsV1APIResources
   * Request URI: /apis/apiextensions.k8s.io/v1/
   */
  async getApiextensionsV1APIResources(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind CustomResourceDefinition
   * operationId: listApiextensionsV1CustomResourceDefinition
   * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions
   */
  async listApiextensionsV1CustomResourceDefinition(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1/customresourcedefinitions`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a CustomResourceDefinition
   * operationId: createApiextensionsV1CustomResourceDefinition
   * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions
   */
  async createApiextensionsV1CustomResourceDefinition(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1/customresourcedefinitions`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of CustomResourceDefinition
   * operationId: deleteApiextensionsV1CollectionCustomResourceDefinition
   * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions
   */
  async deleteApiextensionsV1CollectionCustomResourceDefinition(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1/customresourcedefinitions`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified CustomResourceDefinition
   * operationId: readApiextensionsV1CustomResourceDefinition
   * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions/{name}
   */
  async readApiextensionsV1CustomResourceDefinition(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1/customresourcedefinitions/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified CustomResourceDefinition
   * operationId: replaceApiextensionsV1CustomResourceDefinition
   * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions/{name}
   */
  async replaceApiextensionsV1CustomResourceDefinition(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1/customresourcedefinitions/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a CustomResourceDefinition
   * operationId: deleteApiextensionsV1CustomResourceDefinition
   * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions/{name}
   */
  async deleteApiextensionsV1CustomResourceDefinition(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1/customresourcedefinitions/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified CustomResourceDefinition
   * operationId: patchApiextensionsV1CustomResourceDefinition
   * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions/{name}
   */
  async patchApiextensionsV1CustomResourceDefinition(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1/customresourcedefinitions/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified CustomResourceDefinition
   * operationId: readApiextensionsV1CustomResourceDefinitionStatus
   * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions/{name}/status
   */
  async readApiextensionsV1CustomResourceDefinitionStatus(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1/customresourcedefinitions/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified CustomResourceDefinition
   * operationId: replaceApiextensionsV1CustomResourceDefinitionStatus
   * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions/{name}/status
   */
  async replaceApiextensionsV1CustomResourceDefinitionStatus(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1/customresourcedefinitions/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified CustomResourceDefinition
   * operationId: patchApiextensionsV1CustomResourceDefinitionStatus
   * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions/{name}/status
   */
  async patchApiextensionsV1CustomResourceDefinitionStatus(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1/customresourcedefinitions/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of CustomResourceDefinition. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchApiextensionsV1CustomResourceDefinitionList
   * Request URI: /apis/apiextensions.k8s.io/v1/watch/customresourcedefinitions
   */
  async watchApiextensionsV1CustomResourceDefinitionList(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1/watch/customresourcedefinitions`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind CustomResourceDefinition. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchApiextensionsV1CustomResourceDefinition
   * Request URI: /apis/apiextensions.k8s.io/v1/watch/customresourcedefinitions/{name}
   */
  async watchApiextensionsV1CustomResourceDefinition(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1/watch/customresourcedefinitions/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getApiextensionsV1beta1APIResources
   * Request URI: /apis/apiextensions.k8s.io/v1beta1/
   */
  async getApiextensionsV1beta1APIResources(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1beta1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind CustomResourceDefinition
   * operationId: listApiextensionsV1beta1CustomResourceDefinition
   * Request URI: /apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions
   */
  async listApiextensionsV1beta1CustomResourceDefinition(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a CustomResourceDefinition
   * operationId: createApiextensionsV1beta1CustomResourceDefinition
   * Request URI: /apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions
   */
  async createApiextensionsV1beta1CustomResourceDefinition(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of CustomResourceDefinition
   * operationId: deleteApiextensionsV1beta1CollectionCustomResourceDefinition
   * Request URI: /apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions
   */
  async deleteApiextensionsV1beta1CollectionCustomResourceDefinition(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified CustomResourceDefinition
   * operationId: readApiextensionsV1beta1CustomResourceDefinition
   * Request URI: /apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions/{name}
   */
  async readApiextensionsV1beta1CustomResourceDefinition(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified CustomResourceDefinition
   * operationId: replaceApiextensionsV1beta1CustomResourceDefinition
   * Request URI: /apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions/{name}
   */
  async replaceApiextensionsV1beta1CustomResourceDefinition(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a CustomResourceDefinition
   * operationId: deleteApiextensionsV1beta1CustomResourceDefinition
   * Request URI: /apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions/{name}
   */
  async deleteApiextensionsV1beta1CustomResourceDefinition(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified CustomResourceDefinition
   * operationId: patchApiextensionsV1beta1CustomResourceDefinition
   * Request URI: /apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions/{name}
   */
  async patchApiextensionsV1beta1CustomResourceDefinition(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified CustomResourceDefinition
   * operationId: readApiextensionsV1beta1CustomResourceDefinitionStatus
   * Request URI: /apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions/{name}/status
   */
  async readApiextensionsV1beta1CustomResourceDefinitionStatus(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified CustomResourceDefinition
   * operationId: replaceApiextensionsV1beta1CustomResourceDefinitionStatus
   * Request URI: /apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions/{name}/status
   */
  async replaceApiextensionsV1beta1CustomResourceDefinitionStatus(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified CustomResourceDefinition
   * operationId: patchApiextensionsV1beta1CustomResourceDefinitionStatus
   * Request URI: /apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions/{name}/status
   */
  async patchApiextensionsV1beta1CustomResourceDefinitionStatus(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1beta1/customresourcedefinitions/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of CustomResourceDefinition. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchApiextensionsV1beta1CustomResourceDefinitionList
   * Request URI: /apis/apiextensions.k8s.io/v1beta1/watch/customresourcedefinitions
   */
  async watchApiextensionsV1beta1CustomResourceDefinitionList(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1beta1/watch/customresourcedefinitions`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind CustomResourceDefinition. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchApiextensionsV1beta1CustomResourceDefinition
   * Request URI: /apis/apiextensions.k8s.io/v1beta1/watch/customresourcedefinitions/{name}
   */
  async watchApiextensionsV1beta1CustomResourceDefinition(params, option) {
    const url = this.baseUrl + `/apis/apiextensions.k8s.io/v1beta1/watch/customresourcedefinitions/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get information of a group
   * operationId: getApiregistrationAPIGroup
   * Request URI: /apis/apiregistration.k8s.io/
   */
  async getApiregistrationAPIGroup(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getApiregistrationV1APIResources
   * Request URI: /apis/apiregistration.k8s.io/v1/
   */
  async getApiregistrationV1APIResources(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind APIService
   * operationId: listApiregistrationV1APIService
   * Request URI: /apis/apiregistration.k8s.io/v1/apiservices
   */
  async listApiregistrationV1APIService(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1/apiservices`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create an APIService
   * operationId: createApiregistrationV1APIService
   * Request URI: /apis/apiregistration.k8s.io/v1/apiservices
   */
  async createApiregistrationV1APIService(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1/apiservices`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of APIService
   * operationId: deleteApiregistrationV1CollectionAPIService
   * Request URI: /apis/apiregistration.k8s.io/v1/apiservices
   */
  async deleteApiregistrationV1CollectionAPIService(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1/apiservices`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified APIService
   * operationId: readApiregistrationV1APIService
   * Request URI: /apis/apiregistration.k8s.io/v1/apiservices/{name}
   */
  async readApiregistrationV1APIService(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1/apiservices/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified APIService
   * operationId: replaceApiregistrationV1APIService
   * Request URI: /apis/apiregistration.k8s.io/v1/apiservices/{name}
   */
  async replaceApiregistrationV1APIService(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1/apiservices/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete an APIService
   * operationId: deleteApiregistrationV1APIService
   * Request URI: /apis/apiregistration.k8s.io/v1/apiservices/{name}
   */
  async deleteApiregistrationV1APIService(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1/apiservices/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified APIService
   * operationId: patchApiregistrationV1APIService
   * Request URI: /apis/apiregistration.k8s.io/v1/apiservices/{name}
   */
  async patchApiregistrationV1APIService(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1/apiservices/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified APIService
   * operationId: readApiregistrationV1APIServiceStatus
   * Request URI: /apis/apiregistration.k8s.io/v1/apiservices/{name}/status
   */
  async readApiregistrationV1APIServiceStatus(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1/apiservices/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified APIService
   * operationId: replaceApiregistrationV1APIServiceStatus
   * Request URI: /apis/apiregistration.k8s.io/v1/apiservices/{name}/status
   */
  async replaceApiregistrationV1APIServiceStatus(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1/apiservices/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified APIService
   * operationId: patchApiregistrationV1APIServiceStatus
   * Request URI: /apis/apiregistration.k8s.io/v1/apiservices/{name}/status
   */
  async patchApiregistrationV1APIServiceStatus(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1/apiservices/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of APIService. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchApiregistrationV1APIServiceList
   * Request URI: /apis/apiregistration.k8s.io/v1/watch/apiservices
   */
  async watchApiregistrationV1APIServiceList(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1/watch/apiservices`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind APIService. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchApiregistrationV1APIService
   * Request URI: /apis/apiregistration.k8s.io/v1/watch/apiservices/{name}
   */
  async watchApiregistrationV1APIService(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1/watch/apiservices/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getApiregistrationV1beta1APIResources
   * Request URI: /apis/apiregistration.k8s.io/v1beta1/
   */
  async getApiregistrationV1beta1APIResources(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1beta1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind APIService
   * operationId: listApiregistrationV1beta1APIService
   * Request URI: /apis/apiregistration.k8s.io/v1beta1/apiservices
   */
  async listApiregistrationV1beta1APIService(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1beta1/apiservices`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create an APIService
   * operationId: createApiregistrationV1beta1APIService
   * Request URI: /apis/apiregistration.k8s.io/v1beta1/apiservices
   */
  async createApiregistrationV1beta1APIService(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1beta1/apiservices`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of APIService
   * operationId: deleteApiregistrationV1beta1CollectionAPIService
   * Request URI: /apis/apiregistration.k8s.io/v1beta1/apiservices
   */
  async deleteApiregistrationV1beta1CollectionAPIService(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1beta1/apiservices`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified APIService
   * operationId: readApiregistrationV1beta1APIService
   * Request URI: /apis/apiregistration.k8s.io/v1beta1/apiservices/{name}
   */
  async readApiregistrationV1beta1APIService(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1beta1/apiservices/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified APIService
   * operationId: replaceApiregistrationV1beta1APIService
   * Request URI: /apis/apiregistration.k8s.io/v1beta1/apiservices/{name}
   */
  async replaceApiregistrationV1beta1APIService(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1beta1/apiservices/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete an APIService
   * operationId: deleteApiregistrationV1beta1APIService
   * Request URI: /apis/apiregistration.k8s.io/v1beta1/apiservices/{name}
   */
  async deleteApiregistrationV1beta1APIService(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1beta1/apiservices/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified APIService
   * operationId: patchApiregistrationV1beta1APIService
   * Request URI: /apis/apiregistration.k8s.io/v1beta1/apiservices/{name}
   */
  async patchApiregistrationV1beta1APIService(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1beta1/apiservices/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified APIService
   * operationId: readApiregistrationV1beta1APIServiceStatus
   * Request URI: /apis/apiregistration.k8s.io/v1beta1/apiservices/{name}/status
   */
  async readApiregistrationV1beta1APIServiceStatus(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1beta1/apiservices/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified APIService
   * operationId: replaceApiregistrationV1beta1APIServiceStatus
   * Request URI: /apis/apiregistration.k8s.io/v1beta1/apiservices/{name}/status
   */
  async replaceApiregistrationV1beta1APIServiceStatus(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1beta1/apiservices/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified APIService
   * operationId: patchApiregistrationV1beta1APIServiceStatus
   * Request URI: /apis/apiregistration.k8s.io/v1beta1/apiservices/{name}/status
   */
  async patchApiregistrationV1beta1APIServiceStatus(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1beta1/apiservices/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of APIService. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchApiregistrationV1beta1APIServiceList
   * Request URI: /apis/apiregistration.k8s.io/v1beta1/watch/apiservices
   */
  async watchApiregistrationV1beta1APIServiceList(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1beta1/watch/apiservices`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind APIService. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchApiregistrationV1beta1APIService
   * Request URI: /apis/apiregistration.k8s.io/v1beta1/watch/apiservices/{name}
   */
  async watchApiregistrationV1beta1APIService(params, option) {
    const url = this.baseUrl + `/apis/apiregistration.k8s.io/v1beta1/watch/apiservices/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get information of a group
   * operationId: getAppsAPIGroup
   * Request URI: /apis/apps/
   */
  async getAppsAPIGroup(params, option) {
    const url = this.baseUrl + `/apis/apps/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getAppsV1APIResources
   * Request URI: /apis/apps/v1/
   */
  async getAppsV1APIResources(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind ControllerRevision
   * operationId: listAppsV1ControllerRevisionForAllNamespaces
   * Request URI: /apis/apps/v1/controllerrevisions
   */
  async listAppsV1ControllerRevisionForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/controllerrevisions`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind DaemonSet
   * operationId: listAppsV1DaemonSetForAllNamespaces
   * Request URI: /apis/apps/v1/daemonsets
   */
  async listAppsV1DaemonSetForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/daemonsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Deployment
   * operationId: listAppsV1DeploymentForAllNamespaces
   * Request URI: /apis/apps/v1/deployments
   */
  async listAppsV1DeploymentForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/deployments`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind ControllerRevision
   * operationId: listAppsV1NamespacedControllerRevision
   * Request URI: /apis/apps/v1/namespaces/{namespace}/controllerrevisions
   */
  async listAppsV1NamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/controllerrevisions`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a ControllerRevision
   * operationId: createAppsV1NamespacedControllerRevision
   * Request URI: /apis/apps/v1/namespaces/{namespace}/controllerrevisions
   */
  async createAppsV1NamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/controllerrevisions`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of ControllerRevision
   * operationId: deleteAppsV1CollectionNamespacedControllerRevision
   * Request URI: /apis/apps/v1/namespaces/{namespace}/controllerrevisions
   */
  async deleteAppsV1CollectionNamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/controllerrevisions`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified ControllerRevision
   * operationId: readAppsV1NamespacedControllerRevision
   * Request URI: /apis/apps/v1/namespaces/{namespace}/controllerrevisions/{name}
   */
  async readAppsV1NamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/controllerrevisions/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified ControllerRevision
   * operationId: replaceAppsV1NamespacedControllerRevision
   * Request URI: /apis/apps/v1/namespaces/{namespace}/controllerrevisions/{name}
   */
  async replaceAppsV1NamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/controllerrevisions/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a ControllerRevision
   * operationId: deleteAppsV1NamespacedControllerRevision
   * Request URI: /apis/apps/v1/namespaces/{namespace}/controllerrevisions/{name}
   */
  async deleteAppsV1NamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/controllerrevisions/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified ControllerRevision
   * operationId: patchAppsV1NamespacedControllerRevision
   * Request URI: /apis/apps/v1/namespaces/{namespace}/controllerrevisions/{name}
   */
  async patchAppsV1NamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/controllerrevisions/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind DaemonSet
   * operationId: listAppsV1NamespacedDaemonSet
   * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets
   */
  async listAppsV1NamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/daemonsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a DaemonSet
   * operationId: createAppsV1NamespacedDaemonSet
   * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets
   */
  async createAppsV1NamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/daemonsets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of DaemonSet
   * operationId: deleteAppsV1CollectionNamespacedDaemonSet
   * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets
   */
  async deleteAppsV1CollectionNamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/daemonsets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified DaemonSet
   * operationId: readAppsV1NamespacedDaemonSet
   * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets/{name}
   */
  async readAppsV1NamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified DaemonSet
   * operationId: replaceAppsV1NamespacedDaemonSet
   * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets/{name}
   */
  async replaceAppsV1NamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a DaemonSet
   * operationId: deleteAppsV1NamespacedDaemonSet
   * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets/{name}
   */
  async deleteAppsV1NamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified DaemonSet
   * operationId: patchAppsV1NamespacedDaemonSet
   * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets/{name}
   */
  async patchAppsV1NamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified DaemonSet
   * operationId: readAppsV1NamespacedDaemonSetStatus
   * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets/{name}/status
   */
  async readAppsV1NamespacedDaemonSetStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified DaemonSet
   * operationId: replaceAppsV1NamespacedDaemonSetStatus
   * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets/{name}/status
   */
  async replaceAppsV1NamespacedDaemonSetStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified DaemonSet
   * operationId: patchAppsV1NamespacedDaemonSetStatus
   * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets/{name}/status
   */
  async patchAppsV1NamespacedDaemonSetStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Deployment
   * operationId: listAppsV1NamespacedDeployment
   * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments
   */
  async listAppsV1NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/deployments`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a Deployment
   * operationId: createAppsV1NamespacedDeployment
   * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments
   */
  async createAppsV1NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/deployments`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of Deployment
   * operationId: deleteAppsV1CollectionNamespacedDeployment
   * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments
   */
  async deleteAppsV1CollectionNamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/deployments`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified Deployment
   * operationId: readAppsV1NamespacedDeployment
   * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}
   */
  async readAppsV1NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified Deployment
   * operationId: replaceAppsV1NamespacedDeployment
   * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}
   */
  async replaceAppsV1NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a Deployment
   * operationId: deleteAppsV1NamespacedDeployment
   * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}
   */
  async deleteAppsV1NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified Deployment
   * operationId: patchAppsV1NamespacedDeployment
   * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}
   */
  async patchAppsV1NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read scale of the specified Deployment
   * operationId: readAppsV1NamespacedDeploymentScale
   * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}/scale
   */
  async readAppsV1NamespacedDeploymentScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/scale`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace scale of the specified Deployment
   * operationId: replaceAppsV1NamespacedDeploymentScale
   * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}/scale
   */
  async replaceAppsV1NamespacedDeploymentScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update scale of the specified Deployment
   * operationId: patchAppsV1NamespacedDeploymentScale
   * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}/scale
   */
  async patchAppsV1NamespacedDeploymentScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified Deployment
   * operationId: readAppsV1NamespacedDeploymentStatus
   * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}/status
   */
  async readAppsV1NamespacedDeploymentStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified Deployment
   * operationId: replaceAppsV1NamespacedDeploymentStatus
   * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}/status
   */
  async replaceAppsV1NamespacedDeploymentStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified Deployment
   * operationId: patchAppsV1NamespacedDeploymentStatus
   * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}/status
   */
  async patchAppsV1NamespacedDeploymentStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind ReplicaSet
   * operationId: listAppsV1NamespacedReplicaSet
   * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets
   */
  async listAppsV1NamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/replicasets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a ReplicaSet
   * operationId: createAppsV1NamespacedReplicaSet
   * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets
   */
  async createAppsV1NamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/replicasets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of ReplicaSet
   * operationId: deleteAppsV1CollectionNamespacedReplicaSet
   * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets
   */
  async deleteAppsV1CollectionNamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/replicasets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified ReplicaSet
   * operationId: readAppsV1NamespacedReplicaSet
   * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}
   */
  async readAppsV1NamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified ReplicaSet
   * operationId: replaceAppsV1NamespacedReplicaSet
   * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}
   */
  async replaceAppsV1NamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a ReplicaSet
   * operationId: deleteAppsV1NamespacedReplicaSet
   * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}
   */
  async deleteAppsV1NamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified ReplicaSet
   * operationId: patchAppsV1NamespacedReplicaSet
   * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}
   */
  async patchAppsV1NamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read scale of the specified ReplicaSet
   * operationId: readAppsV1NamespacedReplicaSetScale
   * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}/scale
   */
  async readAppsV1NamespacedReplicaSetScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}/scale`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace scale of the specified ReplicaSet
   * operationId: replaceAppsV1NamespacedReplicaSetScale
   * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}/scale
   */
  async replaceAppsV1NamespacedReplicaSetScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update scale of the specified ReplicaSet
   * operationId: patchAppsV1NamespacedReplicaSetScale
   * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}/scale
   */
  async patchAppsV1NamespacedReplicaSetScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified ReplicaSet
   * operationId: readAppsV1NamespacedReplicaSetStatus
   * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}/status
   */
  async readAppsV1NamespacedReplicaSetStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified ReplicaSet
   * operationId: replaceAppsV1NamespacedReplicaSetStatus
   * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}/status
   */
  async replaceAppsV1NamespacedReplicaSetStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified ReplicaSet
   * operationId: patchAppsV1NamespacedReplicaSetStatus
   * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}/status
   */
  async patchAppsV1NamespacedReplicaSetStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind StatefulSet
   * operationId: listAppsV1NamespacedStatefulSet
   * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets
   */
  async listAppsV1NamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/statefulsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a StatefulSet
   * operationId: createAppsV1NamespacedStatefulSet
   * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets
   */
  async createAppsV1NamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/statefulsets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of StatefulSet
   * operationId: deleteAppsV1CollectionNamespacedStatefulSet
   * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets
   */
  async deleteAppsV1CollectionNamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/statefulsets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified StatefulSet
   * operationId: readAppsV1NamespacedStatefulSet
   * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}
   */
  async readAppsV1NamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified StatefulSet
   * operationId: replaceAppsV1NamespacedStatefulSet
   * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}
   */
  async replaceAppsV1NamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a StatefulSet
   * operationId: deleteAppsV1NamespacedStatefulSet
   * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}
   */
  async deleteAppsV1NamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified StatefulSet
   * operationId: patchAppsV1NamespacedStatefulSet
   * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}
   */
  async patchAppsV1NamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read scale of the specified StatefulSet
   * operationId: readAppsV1NamespacedStatefulSetScale
   * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}/scale
   */
  async readAppsV1NamespacedStatefulSetScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}/scale`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace scale of the specified StatefulSet
   * operationId: replaceAppsV1NamespacedStatefulSetScale
   * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}/scale
   */
  async replaceAppsV1NamespacedStatefulSetScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update scale of the specified StatefulSet
   * operationId: patchAppsV1NamespacedStatefulSetScale
   * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}/scale
   */
  async patchAppsV1NamespacedStatefulSetScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified StatefulSet
   * operationId: readAppsV1NamespacedStatefulSetStatus
   * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}/status
   */
  async readAppsV1NamespacedStatefulSetStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified StatefulSet
   * operationId: replaceAppsV1NamespacedStatefulSetStatus
   * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}/status
   */
  async replaceAppsV1NamespacedStatefulSetStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified StatefulSet
   * operationId: patchAppsV1NamespacedStatefulSetStatus
   * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}/status
   */
  async patchAppsV1NamespacedStatefulSetStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind ReplicaSet
   * operationId: listAppsV1ReplicaSetForAllNamespaces
   * Request URI: /apis/apps/v1/replicasets
   */
  async listAppsV1ReplicaSetForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/replicasets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind StatefulSet
   * operationId: listAppsV1StatefulSetForAllNamespaces
   * Request URI: /apis/apps/v1/statefulsets
   */
  async listAppsV1StatefulSetForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/statefulsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ControllerRevision. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1ControllerRevisionListForAllNamespaces
   * Request URI: /apis/apps/v1/watch/controllerrevisions
   */
  async watchAppsV1ControllerRevisionListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/watch/controllerrevisions`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of DaemonSet. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1DaemonSetListForAllNamespaces
   * Request URI: /apis/apps/v1/watch/daemonsets
   */
  async watchAppsV1DaemonSetListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/watch/daemonsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Deployment. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1DeploymentListForAllNamespaces
   * Request URI: /apis/apps/v1/watch/deployments
   */
  async watchAppsV1DeploymentListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/watch/deployments`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ControllerRevision. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1NamespacedControllerRevisionList
   * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/controllerrevisions
   */
  async watchAppsV1NamespacedControllerRevisionList(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/watch/namespaces/${params.parameter.namespace}/controllerrevisions`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind ControllerRevision. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchAppsV1NamespacedControllerRevision
   * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/controllerrevisions/{name}
   */
  async watchAppsV1NamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/watch/namespaces/${params.parameter.namespace}/controllerrevisions/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of DaemonSet. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1NamespacedDaemonSetList
   * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/daemonsets
   */
  async watchAppsV1NamespacedDaemonSetList(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/watch/namespaces/${params.parameter.namespace}/daemonsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind DaemonSet. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchAppsV1NamespacedDaemonSet
   * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/daemonsets/{name}
   */
  async watchAppsV1NamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/watch/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Deployment. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1NamespacedDeploymentList
   * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/deployments
   */
  async watchAppsV1NamespacedDeploymentList(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/watch/namespaces/${params.parameter.namespace}/deployments`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind Deployment. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchAppsV1NamespacedDeployment
   * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/deployments/{name}
   */
  async watchAppsV1NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/watch/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ReplicaSet. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1NamespacedReplicaSetList
   * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/replicasets
   */
  async watchAppsV1NamespacedReplicaSetList(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/watch/namespaces/${params.parameter.namespace}/replicasets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind ReplicaSet. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchAppsV1NamespacedReplicaSet
   * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/replicasets/{name}
   */
  async watchAppsV1NamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/watch/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of StatefulSet. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1NamespacedStatefulSetList
   * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/statefulsets
   */
  async watchAppsV1NamespacedStatefulSetList(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/watch/namespaces/${params.parameter.namespace}/statefulsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind StatefulSet. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchAppsV1NamespacedStatefulSet
   * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/statefulsets/{name}
   */
  async watchAppsV1NamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/watch/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ReplicaSet. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1ReplicaSetListForAllNamespaces
   * Request URI: /apis/apps/v1/watch/replicasets
   */
  async watchAppsV1ReplicaSetListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/watch/replicasets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of StatefulSet. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1StatefulSetListForAllNamespaces
   * Request URI: /apis/apps/v1/watch/statefulsets
   */
  async watchAppsV1StatefulSetListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1/watch/statefulsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getAppsV1beta1APIResources
   * Request URI: /apis/apps/v1beta1/
   */
  async getAppsV1beta1APIResources(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind ControllerRevision
   * operationId: listAppsV1beta1ControllerRevisionForAllNamespaces
   * Request URI: /apis/apps/v1beta1/controllerrevisions
   */
  async listAppsV1beta1ControllerRevisionForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/controllerrevisions`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Deployment
   * operationId: listAppsV1beta1DeploymentForAllNamespaces
   * Request URI: /apis/apps/v1beta1/deployments
   */
  async listAppsV1beta1DeploymentForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/deployments`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind ControllerRevision
   * operationId: listAppsV1beta1NamespacedControllerRevision
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/controllerrevisions
   */
  async listAppsV1beta1NamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/controllerrevisions`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a ControllerRevision
   * operationId: createAppsV1beta1NamespacedControllerRevision
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/controllerrevisions
   */
  async createAppsV1beta1NamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/controllerrevisions`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of ControllerRevision
   * operationId: deleteAppsV1beta1CollectionNamespacedControllerRevision
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/controllerrevisions
   */
  async deleteAppsV1beta1CollectionNamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/controllerrevisions`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified ControllerRevision
   * operationId: readAppsV1beta1NamespacedControllerRevision
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/controllerrevisions/{name}
   */
  async readAppsV1beta1NamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/controllerrevisions/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified ControllerRevision
   * operationId: replaceAppsV1beta1NamespacedControllerRevision
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/controllerrevisions/{name}
   */
  async replaceAppsV1beta1NamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/controllerrevisions/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a ControllerRevision
   * operationId: deleteAppsV1beta1NamespacedControllerRevision
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/controllerrevisions/{name}
   */
  async deleteAppsV1beta1NamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/controllerrevisions/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified ControllerRevision
   * operationId: patchAppsV1beta1NamespacedControllerRevision
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/controllerrevisions/{name}
   */
  async patchAppsV1beta1NamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/controllerrevisions/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Deployment
   * operationId: listAppsV1beta1NamespacedDeployment
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/deployments
   */
  async listAppsV1beta1NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/deployments`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a Deployment
   * operationId: createAppsV1beta1NamespacedDeployment
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/deployments
   */
  async createAppsV1beta1NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/deployments`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of Deployment
   * operationId: deleteAppsV1beta1CollectionNamespacedDeployment
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/deployments
   */
  async deleteAppsV1beta1CollectionNamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/deployments`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified Deployment
   * operationId: readAppsV1beta1NamespacedDeployment
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/deployments/{name}
   */
  async readAppsV1beta1NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified Deployment
   * operationId: replaceAppsV1beta1NamespacedDeployment
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/deployments/{name}
   */
  async replaceAppsV1beta1NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a Deployment
   * operationId: deleteAppsV1beta1NamespacedDeployment
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/deployments/{name}
   */
  async deleteAppsV1beta1NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified Deployment
   * operationId: patchAppsV1beta1NamespacedDeployment
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/deployments/{name}
   */
  async patchAppsV1beta1NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * create rollback of a Deployment
   * operationId: createAppsV1beta1NamespacedDeploymentRollback
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/deployments/{name}/rollback
   */
  async createAppsV1beta1NamespacedDeploymentRollback(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/rollback`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read scale of the specified Deployment
   * operationId: readAppsV1beta1NamespacedDeploymentScale
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/deployments/{name}/scale
   */
  async readAppsV1beta1NamespacedDeploymentScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/scale`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace scale of the specified Deployment
   * operationId: replaceAppsV1beta1NamespacedDeploymentScale
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/deployments/{name}/scale
   */
  async replaceAppsV1beta1NamespacedDeploymentScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update scale of the specified Deployment
   * operationId: patchAppsV1beta1NamespacedDeploymentScale
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/deployments/{name}/scale
   */
  async patchAppsV1beta1NamespacedDeploymentScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified Deployment
   * operationId: readAppsV1beta1NamespacedDeploymentStatus
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/deployments/{name}/status
   */
  async readAppsV1beta1NamespacedDeploymentStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified Deployment
   * operationId: replaceAppsV1beta1NamespacedDeploymentStatus
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/deployments/{name}/status
   */
  async replaceAppsV1beta1NamespacedDeploymentStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified Deployment
   * operationId: patchAppsV1beta1NamespacedDeploymentStatus
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/deployments/{name}/status
   */
  async patchAppsV1beta1NamespacedDeploymentStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind StatefulSet
   * operationId: listAppsV1beta1NamespacedStatefulSet
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/statefulsets
   */
  async listAppsV1beta1NamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/statefulsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a StatefulSet
   * operationId: createAppsV1beta1NamespacedStatefulSet
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/statefulsets
   */
  async createAppsV1beta1NamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/statefulsets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of StatefulSet
   * operationId: deleteAppsV1beta1CollectionNamespacedStatefulSet
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/statefulsets
   */
  async deleteAppsV1beta1CollectionNamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/statefulsets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified StatefulSet
   * operationId: readAppsV1beta1NamespacedStatefulSet
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/statefulsets/{name}
   */
  async readAppsV1beta1NamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified StatefulSet
   * operationId: replaceAppsV1beta1NamespacedStatefulSet
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/statefulsets/{name}
   */
  async replaceAppsV1beta1NamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a StatefulSet
   * operationId: deleteAppsV1beta1NamespacedStatefulSet
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/statefulsets/{name}
   */
  async deleteAppsV1beta1NamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified StatefulSet
   * operationId: patchAppsV1beta1NamespacedStatefulSet
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/statefulsets/{name}
   */
  async patchAppsV1beta1NamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read scale of the specified StatefulSet
   * operationId: readAppsV1beta1NamespacedStatefulSetScale
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/statefulsets/{name}/scale
   */
  async readAppsV1beta1NamespacedStatefulSetScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}/scale`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace scale of the specified StatefulSet
   * operationId: replaceAppsV1beta1NamespacedStatefulSetScale
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/statefulsets/{name}/scale
   */
  async replaceAppsV1beta1NamespacedStatefulSetScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update scale of the specified StatefulSet
   * operationId: patchAppsV1beta1NamespacedStatefulSetScale
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/statefulsets/{name}/scale
   */
  async patchAppsV1beta1NamespacedStatefulSetScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified StatefulSet
   * operationId: readAppsV1beta1NamespacedStatefulSetStatus
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/statefulsets/{name}/status
   */
  async readAppsV1beta1NamespacedStatefulSetStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified StatefulSet
   * operationId: replaceAppsV1beta1NamespacedStatefulSetStatus
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/statefulsets/{name}/status
   */
  async replaceAppsV1beta1NamespacedStatefulSetStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified StatefulSet
   * operationId: patchAppsV1beta1NamespacedStatefulSetStatus
   * Request URI: /apis/apps/v1beta1/namespaces/{namespace}/statefulsets/{name}/status
   */
  async patchAppsV1beta1NamespacedStatefulSetStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind StatefulSet
   * operationId: listAppsV1beta1StatefulSetForAllNamespaces
   * Request URI: /apis/apps/v1beta1/statefulsets
   */
  async listAppsV1beta1StatefulSetForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/statefulsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ControllerRevision. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1beta1ControllerRevisionListForAllNamespaces
   * Request URI: /apis/apps/v1beta1/watch/controllerrevisions
   */
  async watchAppsV1beta1ControllerRevisionListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/watch/controllerrevisions`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Deployment. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1beta1DeploymentListForAllNamespaces
   * Request URI: /apis/apps/v1beta1/watch/deployments
   */
  async watchAppsV1beta1DeploymentListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/watch/deployments`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ControllerRevision. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1beta1NamespacedControllerRevisionList
   * Request URI: /apis/apps/v1beta1/watch/namespaces/{namespace}/controllerrevisions
   */
  async watchAppsV1beta1NamespacedControllerRevisionList(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/watch/namespaces/${params.parameter.namespace}/controllerrevisions`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind ControllerRevision. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchAppsV1beta1NamespacedControllerRevision
   * Request URI: /apis/apps/v1beta1/watch/namespaces/{namespace}/controllerrevisions/{name}
   */
  async watchAppsV1beta1NamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/watch/namespaces/${params.parameter.namespace}/controllerrevisions/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Deployment. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1beta1NamespacedDeploymentList
   * Request URI: /apis/apps/v1beta1/watch/namespaces/{namespace}/deployments
   */
  async watchAppsV1beta1NamespacedDeploymentList(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/watch/namespaces/${params.parameter.namespace}/deployments`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind Deployment. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchAppsV1beta1NamespacedDeployment
   * Request URI: /apis/apps/v1beta1/watch/namespaces/{namespace}/deployments/{name}
   */
  async watchAppsV1beta1NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/watch/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of StatefulSet. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1beta1NamespacedStatefulSetList
   * Request URI: /apis/apps/v1beta1/watch/namespaces/{namespace}/statefulsets
   */
  async watchAppsV1beta1NamespacedStatefulSetList(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/watch/namespaces/${params.parameter.namespace}/statefulsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind StatefulSet. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchAppsV1beta1NamespacedStatefulSet
   * Request URI: /apis/apps/v1beta1/watch/namespaces/{namespace}/statefulsets/{name}
   */
  async watchAppsV1beta1NamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/watch/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of StatefulSet. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1beta1StatefulSetListForAllNamespaces
   * Request URI: /apis/apps/v1beta1/watch/statefulsets
   */
  async watchAppsV1beta1StatefulSetListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta1/watch/statefulsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getAppsV1beta2APIResources
   * Request URI: /apis/apps/v1beta2/
   */
  async getAppsV1beta2APIResources(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind ControllerRevision
   * operationId: listAppsV1beta2ControllerRevisionForAllNamespaces
   * Request URI: /apis/apps/v1beta2/controllerrevisions
   */
  async listAppsV1beta2ControllerRevisionForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/controllerrevisions`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind DaemonSet
   * operationId: listAppsV1beta2DaemonSetForAllNamespaces
   * Request URI: /apis/apps/v1beta2/daemonsets
   */
  async listAppsV1beta2DaemonSetForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/daemonsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Deployment
   * operationId: listAppsV1beta2DeploymentForAllNamespaces
   * Request URI: /apis/apps/v1beta2/deployments
   */
  async listAppsV1beta2DeploymentForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/deployments`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind ControllerRevision
   * operationId: listAppsV1beta2NamespacedControllerRevision
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/controllerrevisions
   */
  async listAppsV1beta2NamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/controllerrevisions`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a ControllerRevision
   * operationId: createAppsV1beta2NamespacedControllerRevision
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/controllerrevisions
   */
  async createAppsV1beta2NamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/controllerrevisions`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of ControllerRevision
   * operationId: deleteAppsV1beta2CollectionNamespacedControllerRevision
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/controllerrevisions
   */
  async deleteAppsV1beta2CollectionNamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/controllerrevisions`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified ControllerRevision
   * operationId: readAppsV1beta2NamespacedControllerRevision
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/controllerrevisions/{name}
   */
  async readAppsV1beta2NamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/controllerrevisions/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified ControllerRevision
   * operationId: replaceAppsV1beta2NamespacedControllerRevision
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/controllerrevisions/{name}
   */
  async replaceAppsV1beta2NamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/controllerrevisions/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a ControllerRevision
   * operationId: deleteAppsV1beta2NamespacedControllerRevision
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/controllerrevisions/{name}
   */
  async deleteAppsV1beta2NamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/controllerrevisions/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified ControllerRevision
   * operationId: patchAppsV1beta2NamespacedControllerRevision
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/controllerrevisions/{name}
   */
  async patchAppsV1beta2NamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/controllerrevisions/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind DaemonSet
   * operationId: listAppsV1beta2NamespacedDaemonSet
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/daemonsets
   */
  async listAppsV1beta2NamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/daemonsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a DaemonSet
   * operationId: createAppsV1beta2NamespacedDaemonSet
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/daemonsets
   */
  async createAppsV1beta2NamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/daemonsets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of DaemonSet
   * operationId: deleteAppsV1beta2CollectionNamespacedDaemonSet
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/daemonsets
   */
  async deleteAppsV1beta2CollectionNamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/daemonsets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified DaemonSet
   * operationId: readAppsV1beta2NamespacedDaemonSet
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/daemonsets/{name}
   */
  async readAppsV1beta2NamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified DaemonSet
   * operationId: replaceAppsV1beta2NamespacedDaemonSet
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/daemonsets/{name}
   */
  async replaceAppsV1beta2NamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a DaemonSet
   * operationId: deleteAppsV1beta2NamespacedDaemonSet
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/daemonsets/{name}
   */
  async deleteAppsV1beta2NamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified DaemonSet
   * operationId: patchAppsV1beta2NamespacedDaemonSet
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/daemonsets/{name}
   */
  async patchAppsV1beta2NamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified DaemonSet
   * operationId: readAppsV1beta2NamespacedDaemonSetStatus
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/daemonsets/{name}/status
   */
  async readAppsV1beta2NamespacedDaemonSetStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified DaemonSet
   * operationId: replaceAppsV1beta2NamespacedDaemonSetStatus
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/daemonsets/{name}/status
   */
  async replaceAppsV1beta2NamespacedDaemonSetStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified DaemonSet
   * operationId: patchAppsV1beta2NamespacedDaemonSetStatus
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/daemonsets/{name}/status
   */
  async patchAppsV1beta2NamespacedDaemonSetStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Deployment
   * operationId: listAppsV1beta2NamespacedDeployment
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/deployments
   */
  async listAppsV1beta2NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/deployments`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a Deployment
   * operationId: createAppsV1beta2NamespacedDeployment
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/deployments
   */
  async createAppsV1beta2NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/deployments`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of Deployment
   * operationId: deleteAppsV1beta2CollectionNamespacedDeployment
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/deployments
   */
  async deleteAppsV1beta2CollectionNamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/deployments`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified Deployment
   * operationId: readAppsV1beta2NamespacedDeployment
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/deployments/{name}
   */
  async readAppsV1beta2NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified Deployment
   * operationId: replaceAppsV1beta2NamespacedDeployment
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/deployments/{name}
   */
  async replaceAppsV1beta2NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a Deployment
   * operationId: deleteAppsV1beta2NamespacedDeployment
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/deployments/{name}
   */
  async deleteAppsV1beta2NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified Deployment
   * operationId: patchAppsV1beta2NamespacedDeployment
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/deployments/{name}
   */
  async patchAppsV1beta2NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read scale of the specified Deployment
   * operationId: readAppsV1beta2NamespacedDeploymentScale
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/deployments/{name}/scale
   */
  async readAppsV1beta2NamespacedDeploymentScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/scale`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace scale of the specified Deployment
   * operationId: replaceAppsV1beta2NamespacedDeploymentScale
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/deployments/{name}/scale
   */
  async replaceAppsV1beta2NamespacedDeploymentScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update scale of the specified Deployment
   * operationId: patchAppsV1beta2NamespacedDeploymentScale
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/deployments/{name}/scale
   */
  async patchAppsV1beta2NamespacedDeploymentScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified Deployment
   * operationId: readAppsV1beta2NamespacedDeploymentStatus
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/deployments/{name}/status
   */
  async readAppsV1beta2NamespacedDeploymentStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified Deployment
   * operationId: replaceAppsV1beta2NamespacedDeploymentStatus
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/deployments/{name}/status
   */
  async replaceAppsV1beta2NamespacedDeploymentStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified Deployment
   * operationId: patchAppsV1beta2NamespacedDeploymentStatus
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/deployments/{name}/status
   */
  async patchAppsV1beta2NamespacedDeploymentStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind ReplicaSet
   * operationId: listAppsV1beta2NamespacedReplicaSet
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/replicasets
   */
  async listAppsV1beta2NamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/replicasets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a ReplicaSet
   * operationId: createAppsV1beta2NamespacedReplicaSet
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/replicasets
   */
  async createAppsV1beta2NamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/replicasets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of ReplicaSet
   * operationId: deleteAppsV1beta2CollectionNamespacedReplicaSet
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/replicasets
   */
  async deleteAppsV1beta2CollectionNamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/replicasets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified ReplicaSet
   * operationId: readAppsV1beta2NamespacedReplicaSet
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/replicasets/{name}
   */
  async readAppsV1beta2NamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified ReplicaSet
   * operationId: replaceAppsV1beta2NamespacedReplicaSet
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/replicasets/{name}
   */
  async replaceAppsV1beta2NamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a ReplicaSet
   * operationId: deleteAppsV1beta2NamespacedReplicaSet
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/replicasets/{name}
   */
  async deleteAppsV1beta2NamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified ReplicaSet
   * operationId: patchAppsV1beta2NamespacedReplicaSet
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/replicasets/{name}
   */
  async patchAppsV1beta2NamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read scale of the specified ReplicaSet
   * operationId: readAppsV1beta2NamespacedReplicaSetScale
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/replicasets/{name}/scale
   */
  async readAppsV1beta2NamespacedReplicaSetScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}/scale`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace scale of the specified ReplicaSet
   * operationId: replaceAppsV1beta2NamespacedReplicaSetScale
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/replicasets/{name}/scale
   */
  async replaceAppsV1beta2NamespacedReplicaSetScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update scale of the specified ReplicaSet
   * operationId: patchAppsV1beta2NamespacedReplicaSetScale
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/replicasets/{name}/scale
   */
  async patchAppsV1beta2NamespacedReplicaSetScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified ReplicaSet
   * operationId: readAppsV1beta2NamespacedReplicaSetStatus
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/replicasets/{name}/status
   */
  async readAppsV1beta2NamespacedReplicaSetStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified ReplicaSet
   * operationId: replaceAppsV1beta2NamespacedReplicaSetStatus
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/replicasets/{name}/status
   */
  async replaceAppsV1beta2NamespacedReplicaSetStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified ReplicaSet
   * operationId: patchAppsV1beta2NamespacedReplicaSetStatus
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/replicasets/{name}/status
   */
  async patchAppsV1beta2NamespacedReplicaSetStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind StatefulSet
   * operationId: listAppsV1beta2NamespacedStatefulSet
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/statefulsets
   */
  async listAppsV1beta2NamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/statefulsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a StatefulSet
   * operationId: createAppsV1beta2NamespacedStatefulSet
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/statefulsets
   */
  async createAppsV1beta2NamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/statefulsets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of StatefulSet
   * operationId: deleteAppsV1beta2CollectionNamespacedStatefulSet
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/statefulsets
   */
  async deleteAppsV1beta2CollectionNamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/statefulsets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified StatefulSet
   * operationId: readAppsV1beta2NamespacedStatefulSet
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/statefulsets/{name}
   */
  async readAppsV1beta2NamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified StatefulSet
   * operationId: replaceAppsV1beta2NamespacedStatefulSet
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/statefulsets/{name}
   */
  async replaceAppsV1beta2NamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a StatefulSet
   * operationId: deleteAppsV1beta2NamespacedStatefulSet
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/statefulsets/{name}
   */
  async deleteAppsV1beta2NamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified StatefulSet
   * operationId: patchAppsV1beta2NamespacedStatefulSet
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/statefulsets/{name}
   */
  async patchAppsV1beta2NamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read scale of the specified StatefulSet
   * operationId: readAppsV1beta2NamespacedStatefulSetScale
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/statefulsets/{name}/scale
   */
  async readAppsV1beta2NamespacedStatefulSetScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}/scale`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace scale of the specified StatefulSet
   * operationId: replaceAppsV1beta2NamespacedStatefulSetScale
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/statefulsets/{name}/scale
   */
  async replaceAppsV1beta2NamespacedStatefulSetScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update scale of the specified StatefulSet
   * operationId: patchAppsV1beta2NamespacedStatefulSetScale
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/statefulsets/{name}/scale
   */
  async patchAppsV1beta2NamespacedStatefulSetScale(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified StatefulSet
   * operationId: readAppsV1beta2NamespacedStatefulSetStatus
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/statefulsets/{name}/status
   */
  async readAppsV1beta2NamespacedStatefulSetStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified StatefulSet
   * operationId: replaceAppsV1beta2NamespacedStatefulSetStatus
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/statefulsets/{name}/status
   */
  async replaceAppsV1beta2NamespacedStatefulSetStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified StatefulSet
   * operationId: patchAppsV1beta2NamespacedStatefulSetStatus
   * Request URI: /apis/apps/v1beta2/namespaces/{namespace}/statefulsets/{name}/status
   */
  async patchAppsV1beta2NamespacedStatefulSetStatus(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind ReplicaSet
   * operationId: listAppsV1beta2ReplicaSetForAllNamespaces
   * Request URI: /apis/apps/v1beta2/replicasets
   */
  async listAppsV1beta2ReplicaSetForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/replicasets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind StatefulSet
   * operationId: listAppsV1beta2StatefulSetForAllNamespaces
   * Request URI: /apis/apps/v1beta2/statefulsets
   */
  async listAppsV1beta2StatefulSetForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/statefulsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ControllerRevision. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1beta2ControllerRevisionListForAllNamespaces
   * Request URI: /apis/apps/v1beta2/watch/controllerrevisions
   */
  async watchAppsV1beta2ControllerRevisionListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/watch/controllerrevisions`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of DaemonSet. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1beta2DaemonSetListForAllNamespaces
   * Request URI: /apis/apps/v1beta2/watch/daemonsets
   */
  async watchAppsV1beta2DaemonSetListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/watch/daemonsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Deployment. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1beta2DeploymentListForAllNamespaces
   * Request URI: /apis/apps/v1beta2/watch/deployments
   */
  async watchAppsV1beta2DeploymentListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/watch/deployments`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ControllerRevision. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1beta2NamespacedControllerRevisionList
   * Request URI: /apis/apps/v1beta2/watch/namespaces/{namespace}/controllerrevisions
   */
  async watchAppsV1beta2NamespacedControllerRevisionList(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/watch/namespaces/${params.parameter.namespace}/controllerrevisions`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind ControllerRevision. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchAppsV1beta2NamespacedControllerRevision
   * Request URI: /apis/apps/v1beta2/watch/namespaces/{namespace}/controllerrevisions/{name}
   */
  async watchAppsV1beta2NamespacedControllerRevision(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/watch/namespaces/${params.parameter.namespace}/controllerrevisions/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of DaemonSet. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1beta2NamespacedDaemonSetList
   * Request URI: /apis/apps/v1beta2/watch/namespaces/{namespace}/daemonsets
   */
  async watchAppsV1beta2NamespacedDaemonSetList(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/watch/namespaces/${params.parameter.namespace}/daemonsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind DaemonSet. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchAppsV1beta2NamespacedDaemonSet
   * Request URI: /apis/apps/v1beta2/watch/namespaces/{namespace}/daemonsets/{name}
   */
  async watchAppsV1beta2NamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/watch/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Deployment. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1beta2NamespacedDeploymentList
   * Request URI: /apis/apps/v1beta2/watch/namespaces/{namespace}/deployments
   */
  async watchAppsV1beta2NamespacedDeploymentList(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/watch/namespaces/${params.parameter.namespace}/deployments`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind Deployment. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchAppsV1beta2NamespacedDeployment
   * Request URI: /apis/apps/v1beta2/watch/namespaces/{namespace}/deployments/{name}
   */
  async watchAppsV1beta2NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/watch/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ReplicaSet. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1beta2NamespacedReplicaSetList
   * Request URI: /apis/apps/v1beta2/watch/namespaces/{namespace}/replicasets
   */
  async watchAppsV1beta2NamespacedReplicaSetList(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/watch/namespaces/${params.parameter.namespace}/replicasets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind ReplicaSet. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchAppsV1beta2NamespacedReplicaSet
   * Request URI: /apis/apps/v1beta2/watch/namespaces/{namespace}/replicasets/{name}
   */
  async watchAppsV1beta2NamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/watch/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of StatefulSet. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1beta2NamespacedStatefulSetList
   * Request URI: /apis/apps/v1beta2/watch/namespaces/{namespace}/statefulsets
   */
  async watchAppsV1beta2NamespacedStatefulSetList(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/watch/namespaces/${params.parameter.namespace}/statefulsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind StatefulSet. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchAppsV1beta2NamespacedStatefulSet
   * Request URI: /apis/apps/v1beta2/watch/namespaces/{namespace}/statefulsets/{name}
   */
  async watchAppsV1beta2NamespacedStatefulSet(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/watch/namespaces/${params.parameter.namespace}/statefulsets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ReplicaSet. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1beta2ReplicaSetListForAllNamespaces
   * Request URI: /apis/apps/v1beta2/watch/replicasets
   */
  async watchAppsV1beta2ReplicaSetListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/watch/replicasets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of StatefulSet. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAppsV1beta2StatefulSetListForAllNamespaces
   * Request URI: /apis/apps/v1beta2/watch/statefulsets
   */
  async watchAppsV1beta2StatefulSetListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/apps/v1beta2/watch/statefulsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get information of a group
   * operationId: getAuditregistrationAPIGroup
   * Request URI: /apis/auditregistration.k8s.io/
   */
  async getAuditregistrationAPIGroup(params, option) {
    const url = this.baseUrl + `/apis/auditregistration.k8s.io/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getAuditregistrationV1alpha1APIResources
   * Request URI: /apis/auditregistration.k8s.io/v1alpha1/
   */
  async getAuditregistrationV1alpha1APIResources(params, option) {
    const url = this.baseUrl + `/apis/auditregistration.k8s.io/v1alpha1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind AuditSink
   * operationId: listAuditregistrationV1alpha1AuditSink
   * Request URI: /apis/auditregistration.k8s.io/v1alpha1/auditsinks
   */
  async listAuditregistrationV1alpha1AuditSink(params, option) {
    const url = this.baseUrl + `/apis/auditregistration.k8s.io/v1alpha1/auditsinks`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create an AuditSink
   * operationId: createAuditregistrationV1alpha1AuditSink
   * Request URI: /apis/auditregistration.k8s.io/v1alpha1/auditsinks
   */
  async createAuditregistrationV1alpha1AuditSink(params, option) {
    const url = this.baseUrl + `/apis/auditregistration.k8s.io/v1alpha1/auditsinks`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of AuditSink
   * operationId: deleteAuditregistrationV1alpha1CollectionAuditSink
   * Request URI: /apis/auditregistration.k8s.io/v1alpha1/auditsinks
   */
  async deleteAuditregistrationV1alpha1CollectionAuditSink(params, option) {
    const url = this.baseUrl + `/apis/auditregistration.k8s.io/v1alpha1/auditsinks`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified AuditSink
   * operationId: readAuditregistrationV1alpha1AuditSink
   * Request URI: /apis/auditregistration.k8s.io/v1alpha1/auditsinks/{name}
   */
  async readAuditregistrationV1alpha1AuditSink(params, option) {
    const url = this.baseUrl + `/apis/auditregistration.k8s.io/v1alpha1/auditsinks/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified AuditSink
   * operationId: replaceAuditregistrationV1alpha1AuditSink
   * Request URI: /apis/auditregistration.k8s.io/v1alpha1/auditsinks/{name}
   */
  async replaceAuditregistrationV1alpha1AuditSink(params, option) {
    const url = this.baseUrl + `/apis/auditregistration.k8s.io/v1alpha1/auditsinks/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete an AuditSink
   * operationId: deleteAuditregistrationV1alpha1AuditSink
   * Request URI: /apis/auditregistration.k8s.io/v1alpha1/auditsinks/{name}
   */
  async deleteAuditregistrationV1alpha1AuditSink(params, option) {
    const url = this.baseUrl + `/apis/auditregistration.k8s.io/v1alpha1/auditsinks/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified AuditSink
   * operationId: patchAuditregistrationV1alpha1AuditSink
   * Request URI: /apis/auditregistration.k8s.io/v1alpha1/auditsinks/{name}
   */
  async patchAuditregistrationV1alpha1AuditSink(params, option) {
    const url = this.baseUrl + `/apis/auditregistration.k8s.io/v1alpha1/auditsinks/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of AuditSink. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAuditregistrationV1alpha1AuditSinkList
   * Request URI: /apis/auditregistration.k8s.io/v1alpha1/watch/auditsinks
   */
  async watchAuditregistrationV1alpha1AuditSinkList(params, option) {
    const url = this.baseUrl + `/apis/auditregistration.k8s.io/v1alpha1/watch/auditsinks`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind AuditSink. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchAuditregistrationV1alpha1AuditSink
   * Request URI: /apis/auditregistration.k8s.io/v1alpha1/watch/auditsinks/{name}
   */
  async watchAuditregistrationV1alpha1AuditSink(params, option) {
    const url = this.baseUrl + `/apis/auditregistration.k8s.io/v1alpha1/watch/auditsinks/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get information of a group
   * operationId: getAuthenticationAPIGroup
   * Request URI: /apis/authentication.k8s.io/
   */
  async getAuthenticationAPIGroup(params, option) {
    const url = this.baseUrl + `/apis/authentication.k8s.io/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getAuthenticationV1APIResources
   * Request URI: /apis/authentication.k8s.io/v1/
   */
  async getAuthenticationV1APIResources(params, option) {
    const url = this.baseUrl + `/apis/authentication.k8s.io/v1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * create a TokenReview
   * operationId: createAuthenticationV1TokenReview
   * Request URI: /apis/authentication.k8s.io/v1/tokenreviews
   */
  async createAuthenticationV1TokenReview(params, option) {
    const url = this.baseUrl + `/apis/authentication.k8s.io/v1/tokenreviews`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getAuthenticationV1beta1APIResources
   * Request URI: /apis/authentication.k8s.io/v1beta1/
   */
  async getAuthenticationV1beta1APIResources(params, option) {
    const url = this.baseUrl + `/apis/authentication.k8s.io/v1beta1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * create a TokenReview
   * operationId: createAuthenticationV1beta1TokenReview
   * Request URI: /apis/authentication.k8s.io/v1beta1/tokenreviews
   */
  async createAuthenticationV1beta1TokenReview(params, option) {
    const url = this.baseUrl + `/apis/authentication.k8s.io/v1beta1/tokenreviews`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * get information of a group
   * operationId: getAuthorizationAPIGroup
   * Request URI: /apis/authorization.k8s.io/
   */
  async getAuthorizationAPIGroup(params, option) {
    const url = this.baseUrl + `/apis/authorization.k8s.io/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getAuthorizationV1APIResources
   * Request URI: /apis/authorization.k8s.io/v1/
   */
  async getAuthorizationV1APIResources(params, option) {
    const url = this.baseUrl + `/apis/authorization.k8s.io/v1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * create a LocalSubjectAccessReview
   * operationId: createAuthorizationV1NamespacedLocalSubjectAccessReview
   * Request URI: /apis/authorization.k8s.io/v1/namespaces/{namespace}/localsubjectaccessreviews
   */
  async createAuthorizationV1NamespacedLocalSubjectAccessReview(params, option) {
    const url = this.baseUrl + `/apis/authorization.k8s.io/v1/namespaces/${params.parameter.namespace}/localsubjectaccessreviews`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * create a SelfSubjectAccessReview
   * operationId: createAuthorizationV1SelfSubjectAccessReview
   * Request URI: /apis/authorization.k8s.io/v1/selfsubjectaccessreviews
   */
  async createAuthorizationV1SelfSubjectAccessReview(params, option) {
    const url = this.baseUrl + `/apis/authorization.k8s.io/v1/selfsubjectaccessreviews`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * create a SelfSubjectRulesReview
   * operationId: createAuthorizationV1SelfSubjectRulesReview
   * Request URI: /apis/authorization.k8s.io/v1/selfsubjectrulesreviews
   */
  async createAuthorizationV1SelfSubjectRulesReview(params, option) {
    const url = this.baseUrl + `/apis/authorization.k8s.io/v1/selfsubjectrulesreviews`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * create a SubjectAccessReview
   * operationId: createAuthorizationV1SubjectAccessReview
   * Request URI: /apis/authorization.k8s.io/v1/subjectaccessreviews
   */
  async createAuthorizationV1SubjectAccessReview(params, option) {
    const url = this.baseUrl + `/apis/authorization.k8s.io/v1/subjectaccessreviews`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getAuthorizationV1beta1APIResources
   * Request URI: /apis/authorization.k8s.io/v1beta1/
   */
  async getAuthorizationV1beta1APIResources(params, option) {
    const url = this.baseUrl + `/apis/authorization.k8s.io/v1beta1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * create a LocalSubjectAccessReview
   * operationId: createAuthorizationV1beta1NamespacedLocalSubjectAccessReview
   * Request URI: /apis/authorization.k8s.io/v1beta1/namespaces/{namespace}/localsubjectaccessreviews
   */
  async createAuthorizationV1beta1NamespacedLocalSubjectAccessReview(params, option) {
    const url = this.baseUrl + `/apis/authorization.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/localsubjectaccessreviews`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * create a SelfSubjectAccessReview
   * operationId: createAuthorizationV1beta1SelfSubjectAccessReview
   * Request URI: /apis/authorization.k8s.io/v1beta1/selfsubjectaccessreviews
   */
  async createAuthorizationV1beta1SelfSubjectAccessReview(params, option) {
    const url = this.baseUrl + `/apis/authorization.k8s.io/v1beta1/selfsubjectaccessreviews`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * create a SelfSubjectRulesReview
   * operationId: createAuthorizationV1beta1SelfSubjectRulesReview
   * Request URI: /apis/authorization.k8s.io/v1beta1/selfsubjectrulesreviews
   */
  async createAuthorizationV1beta1SelfSubjectRulesReview(params, option) {
    const url = this.baseUrl + `/apis/authorization.k8s.io/v1beta1/selfsubjectrulesreviews`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * create a SubjectAccessReview
   * operationId: createAuthorizationV1beta1SubjectAccessReview
   * Request URI: /apis/authorization.k8s.io/v1beta1/subjectaccessreviews
   */
  async createAuthorizationV1beta1SubjectAccessReview(params, option) {
    const url = this.baseUrl + `/apis/authorization.k8s.io/v1beta1/subjectaccessreviews`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * get information of a group
   * operationId: getAutoscalingAPIGroup
   * Request URI: /apis/autoscaling/
   */
  async getAutoscalingAPIGroup(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getAutoscalingV1APIResources
   * Request URI: /apis/autoscaling/v1/
   */
  async getAutoscalingV1APIResources(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind HorizontalPodAutoscaler
   * operationId: listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces
   * Request URI: /apis/autoscaling/v1/horizontalpodautoscalers
   */
  async listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v1/horizontalpodautoscalers`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind HorizontalPodAutoscaler
   * operationId: listAutoscalingV1NamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers
   */
  async listAutoscalingV1NamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v1/namespaces/${params.parameter.namespace}/horizontalpodautoscalers`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a HorizontalPodAutoscaler
   * operationId: createAutoscalingV1NamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers
   */
  async createAutoscalingV1NamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v1/namespaces/${params.parameter.namespace}/horizontalpodautoscalers`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of HorizontalPodAutoscaler
   * operationId: deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers
   */
  async deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v1/namespaces/${params.parameter.namespace}/horizontalpodautoscalers`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified HorizontalPodAutoscaler
   * operationId: readAutoscalingV1NamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers/{name}
   */
  async readAutoscalingV1NamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v1/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified HorizontalPodAutoscaler
   * operationId: replaceAutoscalingV1NamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers/{name}
   */
  async replaceAutoscalingV1NamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v1/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a HorizontalPodAutoscaler
   * operationId: deleteAutoscalingV1NamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers/{name}
   */
  async deleteAutoscalingV1NamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v1/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified HorizontalPodAutoscaler
   * operationId: patchAutoscalingV1NamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers/{name}
   */
  async patchAutoscalingV1NamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v1/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified HorizontalPodAutoscaler
   * operationId: readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus
   * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
   */
  async readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v1/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified HorizontalPodAutoscaler
   * operationId: replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus
   * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
   */
  async replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v1/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified HorizontalPodAutoscaler
   * operationId: patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus
   * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
   */
  async patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v1/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces
   * Request URI: /apis/autoscaling/v1/watch/horizontalpodautoscalers
   */
  async watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v1/watch/horizontalpodautoscalers`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAutoscalingV1NamespacedHorizontalPodAutoscalerList
   * Request URI: /apis/autoscaling/v1/watch/namespaces/{namespace}/horizontalpodautoscalers
   */
  async watchAutoscalingV1NamespacedHorizontalPodAutoscalerList(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v1/watch/namespaces/${params.parameter.namespace}/horizontalpodautoscalers`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchAutoscalingV1NamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v1/watch/namespaces/{namespace}/horizontalpodautoscalers/{name}
   */
  async watchAutoscalingV1NamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v1/watch/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getAutoscalingV2beta1APIResources
   * Request URI: /apis/autoscaling/v2beta1/
   */
  async getAutoscalingV2beta1APIResources(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind HorizontalPodAutoscaler
   * operationId: listAutoscalingV2beta1HorizontalPodAutoscalerForAllNamespaces
   * Request URI: /apis/autoscaling/v2beta1/horizontalpodautoscalers
   */
  async listAutoscalingV2beta1HorizontalPodAutoscalerForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta1/horizontalpodautoscalers`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind HorizontalPodAutoscaler
   * operationId: listAutoscalingV2beta1NamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v2beta1/namespaces/{namespace}/horizontalpodautoscalers
   */
  async listAutoscalingV2beta1NamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta1/namespaces/${params.parameter.namespace}/horizontalpodautoscalers`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a HorizontalPodAutoscaler
   * operationId: createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v2beta1/namespaces/{namespace}/horizontalpodautoscalers
   */
  async createAutoscalingV2beta1NamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta1/namespaces/${params.parameter.namespace}/horizontalpodautoscalers`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of HorizontalPodAutoscaler
   * operationId: deleteAutoscalingV2beta1CollectionNamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v2beta1/namespaces/{namespace}/horizontalpodautoscalers
   */
  async deleteAutoscalingV2beta1CollectionNamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta1/namespaces/${params.parameter.namespace}/horizontalpodautoscalers`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified HorizontalPodAutoscaler
   * operationId: readAutoscalingV2beta1NamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v2beta1/namespaces/{namespace}/horizontalpodautoscalers/{name}
   */
  async readAutoscalingV2beta1NamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta1/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified HorizontalPodAutoscaler
   * operationId: replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v2beta1/namespaces/{namespace}/horizontalpodautoscalers/{name}
   */
  async replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta1/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a HorizontalPodAutoscaler
   * operationId: deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v2beta1/namespaces/{namespace}/horizontalpodautoscalers/{name}
   */
  async deleteAutoscalingV2beta1NamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta1/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified HorizontalPodAutoscaler
   * operationId: patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v2beta1/namespaces/{namespace}/horizontalpodautoscalers/{name}
   */
  async patchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta1/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified HorizontalPodAutoscaler
   * operationId: readAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus
   * Request URI: /apis/autoscaling/v2beta1/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
   */
  async readAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta1/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified HorizontalPodAutoscaler
   * operationId: replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus
   * Request URI: /apis/autoscaling/v2beta1/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
   */
  async replaceAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta1/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified HorizontalPodAutoscaler
   * operationId: patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus
   * Request URI: /apis/autoscaling/v2beta1/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
   */
  async patchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerStatus(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta1/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAutoscalingV2beta1HorizontalPodAutoscalerListForAllNamespaces
   * Request URI: /apis/autoscaling/v2beta1/watch/horizontalpodautoscalers
   */
  async watchAutoscalingV2beta1HorizontalPodAutoscalerListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta1/watch/horizontalpodautoscalers`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerList
   * Request URI: /apis/autoscaling/v2beta1/watch/namespaces/{namespace}/horizontalpodautoscalers
   */
  async watchAutoscalingV2beta1NamespacedHorizontalPodAutoscalerList(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta1/watch/namespaces/${params.parameter.namespace}/horizontalpodautoscalers`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v2beta1/watch/namespaces/{namespace}/horizontalpodautoscalers/{name}
   */
  async watchAutoscalingV2beta1NamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta1/watch/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getAutoscalingV2beta2APIResources
   * Request URI: /apis/autoscaling/v2beta2/
   */
  async getAutoscalingV2beta2APIResources(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta2/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind HorizontalPodAutoscaler
   * operationId: listAutoscalingV2beta2HorizontalPodAutoscalerForAllNamespaces
   * Request URI: /apis/autoscaling/v2beta2/horizontalpodautoscalers
   */
  async listAutoscalingV2beta2HorizontalPodAutoscalerForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta2/horizontalpodautoscalers`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind HorizontalPodAutoscaler
   * operationId: listAutoscalingV2beta2NamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v2beta2/namespaces/{namespace}/horizontalpodautoscalers
   */
  async listAutoscalingV2beta2NamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta2/namespaces/${params.parameter.namespace}/horizontalpodautoscalers`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a HorizontalPodAutoscaler
   * operationId: createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v2beta2/namespaces/{namespace}/horizontalpodautoscalers
   */
  async createAutoscalingV2beta2NamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta2/namespaces/${params.parameter.namespace}/horizontalpodautoscalers`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of HorizontalPodAutoscaler
   * operationId: deleteAutoscalingV2beta2CollectionNamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v2beta2/namespaces/{namespace}/horizontalpodautoscalers
   */
  async deleteAutoscalingV2beta2CollectionNamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta2/namespaces/${params.parameter.namespace}/horizontalpodautoscalers`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified HorizontalPodAutoscaler
   * operationId: readAutoscalingV2beta2NamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v2beta2/namespaces/{namespace}/horizontalpodautoscalers/{name}
   */
  async readAutoscalingV2beta2NamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta2/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified HorizontalPodAutoscaler
   * operationId: replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v2beta2/namespaces/{namespace}/horizontalpodautoscalers/{name}
   */
  async replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta2/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a HorizontalPodAutoscaler
   * operationId: deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v2beta2/namespaces/{namespace}/horizontalpodautoscalers/{name}
   */
  async deleteAutoscalingV2beta2NamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta2/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified HorizontalPodAutoscaler
   * operationId: patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v2beta2/namespaces/{namespace}/horizontalpodautoscalers/{name}
   */
  async patchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta2/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified HorizontalPodAutoscaler
   * operationId: readAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus
   * Request URI: /apis/autoscaling/v2beta2/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
   */
  async readAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta2/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified HorizontalPodAutoscaler
   * operationId: replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus
   * Request URI: /apis/autoscaling/v2beta2/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
   */
  async replaceAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta2/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified HorizontalPodAutoscaler
   * operationId: patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus
   * Request URI: /apis/autoscaling/v2beta2/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
   */
  async patchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerStatus(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta2/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAutoscalingV2beta2HorizontalPodAutoscalerListForAllNamespaces
   * Request URI: /apis/autoscaling/v2beta2/watch/horizontalpodautoscalers
   */
  async watchAutoscalingV2beta2HorizontalPodAutoscalerListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta2/watch/horizontalpodautoscalers`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerList
   * Request URI: /apis/autoscaling/v2beta2/watch/namespaces/{namespace}/horizontalpodautoscalers
   */
  async watchAutoscalingV2beta2NamespacedHorizontalPodAutoscalerList(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta2/watch/namespaces/${params.parameter.namespace}/horizontalpodautoscalers`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler
   * Request URI: /apis/autoscaling/v2beta2/watch/namespaces/{namespace}/horizontalpodautoscalers/{name}
   */
  async watchAutoscalingV2beta2NamespacedHorizontalPodAutoscaler(params, option) {
    const url = this.baseUrl + `/apis/autoscaling/v2beta2/watch/namespaces/${params.parameter.namespace}/horizontalpodautoscalers/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get information of a group
   * operationId: getBatchAPIGroup
   * Request URI: /apis/batch/
   */
  async getBatchAPIGroup(params, option) {
    const url = this.baseUrl + `/apis/batch/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getBatchV1APIResources
   * Request URI: /apis/batch/v1/
   */
  async getBatchV1APIResources(params, option) {
    const url = this.baseUrl + `/apis/batch/v1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind Job
   * operationId: listBatchV1JobForAllNamespaces
   * Request URI: /apis/batch/v1/jobs
   */
  async listBatchV1JobForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/batch/v1/jobs`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Job
   * operationId: listBatchV1NamespacedJob
   * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs
   */
  async listBatchV1NamespacedJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v1/namespaces/${params.parameter.namespace}/jobs`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a Job
   * operationId: createBatchV1NamespacedJob
   * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs
   */
  async createBatchV1NamespacedJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v1/namespaces/${params.parameter.namespace}/jobs`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of Job
   * operationId: deleteBatchV1CollectionNamespacedJob
   * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs
   */
  async deleteBatchV1CollectionNamespacedJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v1/namespaces/${params.parameter.namespace}/jobs`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified Job
   * operationId: readBatchV1NamespacedJob
   * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs/{name}
   */
  async readBatchV1NamespacedJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v1/namespaces/${params.parameter.namespace}/jobs/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified Job
   * operationId: replaceBatchV1NamespacedJob
   * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs/{name}
   */
  async replaceBatchV1NamespacedJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v1/namespaces/${params.parameter.namespace}/jobs/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a Job
   * operationId: deleteBatchV1NamespacedJob
   * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs/{name}
   */
  async deleteBatchV1NamespacedJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v1/namespaces/${params.parameter.namespace}/jobs/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified Job
   * operationId: patchBatchV1NamespacedJob
   * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs/{name}
   */
  async patchBatchV1NamespacedJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v1/namespaces/${params.parameter.namespace}/jobs/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified Job
   * operationId: readBatchV1NamespacedJobStatus
   * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs/{name}/status
   */
  async readBatchV1NamespacedJobStatus(params, option) {
    const url = this.baseUrl + `/apis/batch/v1/namespaces/${params.parameter.namespace}/jobs/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified Job
   * operationId: replaceBatchV1NamespacedJobStatus
   * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs/{name}/status
   */
  async replaceBatchV1NamespacedJobStatus(params, option) {
    const url = this.baseUrl + `/apis/batch/v1/namespaces/${params.parameter.namespace}/jobs/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified Job
   * operationId: patchBatchV1NamespacedJobStatus
   * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs/{name}/status
   */
  async patchBatchV1NamespacedJobStatus(params, option) {
    const url = this.baseUrl + `/apis/batch/v1/namespaces/${params.parameter.namespace}/jobs/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Job. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchBatchV1JobListForAllNamespaces
   * Request URI: /apis/batch/v1/watch/jobs
   */
  async watchBatchV1JobListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/batch/v1/watch/jobs`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Job. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchBatchV1NamespacedJobList
   * Request URI: /apis/batch/v1/watch/namespaces/{namespace}/jobs
   */
  async watchBatchV1NamespacedJobList(params, option) {
    const url = this.baseUrl + `/apis/batch/v1/watch/namespaces/${params.parameter.namespace}/jobs`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind Job. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchBatchV1NamespacedJob
   * Request URI: /apis/batch/v1/watch/namespaces/{namespace}/jobs/{name}
   */
  async watchBatchV1NamespacedJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v1/watch/namespaces/${params.parameter.namespace}/jobs/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getBatchV1beta1APIResources
   * Request URI: /apis/batch/v1beta1/
   */
  async getBatchV1beta1APIResources(params, option) {
    const url = this.baseUrl + `/apis/batch/v1beta1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind CronJob
   * operationId: listBatchV1beta1CronJobForAllNamespaces
   * Request URI: /apis/batch/v1beta1/cronjobs
   */
  async listBatchV1beta1CronJobForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/batch/v1beta1/cronjobs`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind CronJob
   * operationId: listBatchV1beta1NamespacedCronJob
   * Request URI: /apis/batch/v1beta1/namespaces/{namespace}/cronjobs
   */
  async listBatchV1beta1NamespacedCronJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v1beta1/namespaces/${params.parameter.namespace}/cronjobs`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a CronJob
   * operationId: createBatchV1beta1NamespacedCronJob
   * Request URI: /apis/batch/v1beta1/namespaces/{namespace}/cronjobs
   */
  async createBatchV1beta1NamespacedCronJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v1beta1/namespaces/${params.parameter.namespace}/cronjobs`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of CronJob
   * operationId: deleteBatchV1beta1CollectionNamespacedCronJob
   * Request URI: /apis/batch/v1beta1/namespaces/{namespace}/cronjobs
   */
  async deleteBatchV1beta1CollectionNamespacedCronJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v1beta1/namespaces/${params.parameter.namespace}/cronjobs`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified CronJob
   * operationId: readBatchV1beta1NamespacedCronJob
   * Request URI: /apis/batch/v1beta1/namespaces/{namespace}/cronjobs/{name}
   */
  async readBatchV1beta1NamespacedCronJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v1beta1/namespaces/${params.parameter.namespace}/cronjobs/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified CronJob
   * operationId: replaceBatchV1beta1NamespacedCronJob
   * Request URI: /apis/batch/v1beta1/namespaces/{namespace}/cronjobs/{name}
   */
  async replaceBatchV1beta1NamespacedCronJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v1beta1/namespaces/${params.parameter.namespace}/cronjobs/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a CronJob
   * operationId: deleteBatchV1beta1NamespacedCronJob
   * Request URI: /apis/batch/v1beta1/namespaces/{namespace}/cronjobs/{name}
   */
  async deleteBatchV1beta1NamespacedCronJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v1beta1/namespaces/${params.parameter.namespace}/cronjobs/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified CronJob
   * operationId: patchBatchV1beta1NamespacedCronJob
   * Request URI: /apis/batch/v1beta1/namespaces/{namespace}/cronjobs/{name}
   */
  async patchBatchV1beta1NamespacedCronJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v1beta1/namespaces/${params.parameter.namespace}/cronjobs/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified CronJob
   * operationId: readBatchV1beta1NamespacedCronJobStatus
   * Request URI: /apis/batch/v1beta1/namespaces/{namespace}/cronjobs/{name}/status
   */
  async readBatchV1beta1NamespacedCronJobStatus(params, option) {
    const url = this.baseUrl + `/apis/batch/v1beta1/namespaces/${params.parameter.namespace}/cronjobs/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified CronJob
   * operationId: replaceBatchV1beta1NamespacedCronJobStatus
   * Request URI: /apis/batch/v1beta1/namespaces/{namespace}/cronjobs/{name}/status
   */
  async replaceBatchV1beta1NamespacedCronJobStatus(params, option) {
    const url = this.baseUrl + `/apis/batch/v1beta1/namespaces/${params.parameter.namespace}/cronjobs/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified CronJob
   * operationId: patchBatchV1beta1NamespacedCronJobStatus
   * Request URI: /apis/batch/v1beta1/namespaces/{namespace}/cronjobs/{name}/status
   */
  async patchBatchV1beta1NamespacedCronJobStatus(params, option) {
    const url = this.baseUrl + `/apis/batch/v1beta1/namespaces/${params.parameter.namespace}/cronjobs/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of CronJob. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchBatchV1beta1CronJobListForAllNamespaces
   * Request URI: /apis/batch/v1beta1/watch/cronjobs
   */
  async watchBatchV1beta1CronJobListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/batch/v1beta1/watch/cronjobs`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of CronJob. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchBatchV1beta1NamespacedCronJobList
   * Request URI: /apis/batch/v1beta1/watch/namespaces/{namespace}/cronjobs
   */
  async watchBatchV1beta1NamespacedCronJobList(params, option) {
    const url = this.baseUrl + `/apis/batch/v1beta1/watch/namespaces/${params.parameter.namespace}/cronjobs`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind CronJob. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchBatchV1beta1NamespacedCronJob
   * Request URI: /apis/batch/v1beta1/watch/namespaces/{namespace}/cronjobs/{name}
   */
  async watchBatchV1beta1NamespacedCronJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v1beta1/watch/namespaces/${params.parameter.namespace}/cronjobs/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getBatchV2alpha1APIResources
   * Request URI: /apis/batch/v2alpha1/
   */
  async getBatchV2alpha1APIResources(params, option) {
    const url = this.baseUrl + `/apis/batch/v2alpha1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind CronJob
   * operationId: listBatchV2alpha1CronJobForAllNamespaces
   * Request URI: /apis/batch/v2alpha1/cronjobs
   */
  async listBatchV2alpha1CronJobForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/batch/v2alpha1/cronjobs`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind CronJob
   * operationId: listBatchV2alpha1NamespacedCronJob
   * Request URI: /apis/batch/v2alpha1/namespaces/{namespace}/cronjobs
   */
  async listBatchV2alpha1NamespacedCronJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v2alpha1/namespaces/${params.parameter.namespace}/cronjobs`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a CronJob
   * operationId: createBatchV2alpha1NamespacedCronJob
   * Request URI: /apis/batch/v2alpha1/namespaces/{namespace}/cronjobs
   */
  async createBatchV2alpha1NamespacedCronJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v2alpha1/namespaces/${params.parameter.namespace}/cronjobs`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of CronJob
   * operationId: deleteBatchV2alpha1CollectionNamespacedCronJob
   * Request URI: /apis/batch/v2alpha1/namespaces/{namespace}/cronjobs
   */
  async deleteBatchV2alpha1CollectionNamespacedCronJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v2alpha1/namespaces/${params.parameter.namespace}/cronjobs`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified CronJob
   * operationId: readBatchV2alpha1NamespacedCronJob
   * Request URI: /apis/batch/v2alpha1/namespaces/{namespace}/cronjobs/{name}
   */
  async readBatchV2alpha1NamespacedCronJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v2alpha1/namespaces/${params.parameter.namespace}/cronjobs/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified CronJob
   * operationId: replaceBatchV2alpha1NamespacedCronJob
   * Request URI: /apis/batch/v2alpha1/namespaces/{namespace}/cronjobs/{name}
   */
  async replaceBatchV2alpha1NamespacedCronJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v2alpha1/namespaces/${params.parameter.namespace}/cronjobs/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a CronJob
   * operationId: deleteBatchV2alpha1NamespacedCronJob
   * Request URI: /apis/batch/v2alpha1/namespaces/{namespace}/cronjobs/{name}
   */
  async deleteBatchV2alpha1NamespacedCronJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v2alpha1/namespaces/${params.parameter.namespace}/cronjobs/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified CronJob
   * operationId: patchBatchV2alpha1NamespacedCronJob
   * Request URI: /apis/batch/v2alpha1/namespaces/{namespace}/cronjobs/{name}
   */
  async patchBatchV2alpha1NamespacedCronJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v2alpha1/namespaces/${params.parameter.namespace}/cronjobs/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified CronJob
   * operationId: readBatchV2alpha1NamespacedCronJobStatus
   * Request URI: /apis/batch/v2alpha1/namespaces/{namespace}/cronjobs/{name}/status
   */
  async readBatchV2alpha1NamespacedCronJobStatus(params, option) {
    const url = this.baseUrl + `/apis/batch/v2alpha1/namespaces/${params.parameter.namespace}/cronjobs/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified CronJob
   * operationId: replaceBatchV2alpha1NamespacedCronJobStatus
   * Request URI: /apis/batch/v2alpha1/namespaces/{namespace}/cronjobs/{name}/status
   */
  async replaceBatchV2alpha1NamespacedCronJobStatus(params, option) {
    const url = this.baseUrl + `/apis/batch/v2alpha1/namespaces/${params.parameter.namespace}/cronjobs/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified CronJob
   * operationId: patchBatchV2alpha1NamespacedCronJobStatus
   * Request URI: /apis/batch/v2alpha1/namespaces/{namespace}/cronjobs/{name}/status
   */
  async patchBatchV2alpha1NamespacedCronJobStatus(params, option) {
    const url = this.baseUrl + `/apis/batch/v2alpha1/namespaces/${params.parameter.namespace}/cronjobs/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of CronJob. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchBatchV2alpha1CronJobListForAllNamespaces
   * Request URI: /apis/batch/v2alpha1/watch/cronjobs
   */
  async watchBatchV2alpha1CronJobListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/batch/v2alpha1/watch/cronjobs`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of CronJob. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchBatchV2alpha1NamespacedCronJobList
   * Request URI: /apis/batch/v2alpha1/watch/namespaces/{namespace}/cronjobs
   */
  async watchBatchV2alpha1NamespacedCronJobList(params, option) {
    const url = this.baseUrl + `/apis/batch/v2alpha1/watch/namespaces/${params.parameter.namespace}/cronjobs`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind CronJob. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchBatchV2alpha1NamespacedCronJob
   * Request URI: /apis/batch/v2alpha1/watch/namespaces/{namespace}/cronjobs/{name}
   */
  async watchBatchV2alpha1NamespacedCronJob(params, option) {
    const url = this.baseUrl + `/apis/batch/v2alpha1/watch/namespaces/${params.parameter.namespace}/cronjobs/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get information of a group
   * operationId: getCertificatesAPIGroup
   * Request URI: /apis/certificates.k8s.io/
   */
  async getCertificatesAPIGroup(params, option) {
    const url = this.baseUrl + `/apis/certificates.k8s.io/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getCertificatesV1beta1APIResources
   * Request URI: /apis/certificates.k8s.io/v1beta1/
   */
  async getCertificatesV1beta1APIResources(params, option) {
    const url = this.baseUrl + `/apis/certificates.k8s.io/v1beta1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind CertificateSigningRequest
   * operationId: listCertificatesV1beta1CertificateSigningRequest
   * Request URI: /apis/certificates.k8s.io/v1beta1/certificatesigningrequests
   */
  async listCertificatesV1beta1CertificateSigningRequest(params, option) {
    const url = this.baseUrl + `/apis/certificates.k8s.io/v1beta1/certificatesigningrequests`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a CertificateSigningRequest
   * operationId: createCertificatesV1beta1CertificateSigningRequest
   * Request URI: /apis/certificates.k8s.io/v1beta1/certificatesigningrequests
   */
  async createCertificatesV1beta1CertificateSigningRequest(params, option) {
    const url = this.baseUrl + `/apis/certificates.k8s.io/v1beta1/certificatesigningrequests`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of CertificateSigningRequest
   * operationId: deleteCertificatesV1beta1CollectionCertificateSigningRequest
   * Request URI: /apis/certificates.k8s.io/v1beta1/certificatesigningrequests
   */
  async deleteCertificatesV1beta1CollectionCertificateSigningRequest(params, option) {
    const url = this.baseUrl + `/apis/certificates.k8s.io/v1beta1/certificatesigningrequests`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified CertificateSigningRequest
   * operationId: readCertificatesV1beta1CertificateSigningRequest
   * Request URI: /apis/certificates.k8s.io/v1beta1/certificatesigningrequests/{name}
   */
  async readCertificatesV1beta1CertificateSigningRequest(params, option) {
    const url = this.baseUrl + `/apis/certificates.k8s.io/v1beta1/certificatesigningrequests/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified CertificateSigningRequest
   * operationId: replaceCertificatesV1beta1CertificateSigningRequest
   * Request URI: /apis/certificates.k8s.io/v1beta1/certificatesigningrequests/{name}
   */
  async replaceCertificatesV1beta1CertificateSigningRequest(params, option) {
    const url = this.baseUrl + `/apis/certificates.k8s.io/v1beta1/certificatesigningrequests/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a CertificateSigningRequest
   * operationId: deleteCertificatesV1beta1CertificateSigningRequest
   * Request URI: /apis/certificates.k8s.io/v1beta1/certificatesigningrequests/{name}
   */
  async deleteCertificatesV1beta1CertificateSigningRequest(params, option) {
    const url = this.baseUrl + `/apis/certificates.k8s.io/v1beta1/certificatesigningrequests/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified CertificateSigningRequest
   * operationId: patchCertificatesV1beta1CertificateSigningRequest
   * Request URI: /apis/certificates.k8s.io/v1beta1/certificatesigningrequests/{name}
   */
  async patchCertificatesV1beta1CertificateSigningRequest(params, option) {
    const url = this.baseUrl + `/apis/certificates.k8s.io/v1beta1/certificatesigningrequests/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * replace approval of the specified CertificateSigningRequest
   * operationId: replaceCertificatesV1beta1CertificateSigningRequestApproval
   * Request URI: /apis/certificates.k8s.io/v1beta1/certificatesigningrequests/{name}/approval
   */
  async replaceCertificatesV1beta1CertificateSigningRequestApproval(params, option) {
    const url = this.baseUrl + `/apis/certificates.k8s.io/v1beta1/certificatesigningrequests/${params.parameter.name}/approval`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified CertificateSigningRequest
   * operationId: readCertificatesV1beta1CertificateSigningRequestStatus
   * Request URI: /apis/certificates.k8s.io/v1beta1/certificatesigningrequests/{name}/status
   */
  async readCertificatesV1beta1CertificateSigningRequestStatus(params, option) {
    const url = this.baseUrl + `/apis/certificates.k8s.io/v1beta1/certificatesigningrequests/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified CertificateSigningRequest
   * operationId: replaceCertificatesV1beta1CertificateSigningRequestStatus
   * Request URI: /apis/certificates.k8s.io/v1beta1/certificatesigningrequests/{name}/status
   */
  async replaceCertificatesV1beta1CertificateSigningRequestStatus(params, option) {
    const url = this.baseUrl + `/apis/certificates.k8s.io/v1beta1/certificatesigningrequests/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified CertificateSigningRequest
   * operationId: patchCertificatesV1beta1CertificateSigningRequestStatus
   * Request URI: /apis/certificates.k8s.io/v1beta1/certificatesigningrequests/{name}/status
   */
  async patchCertificatesV1beta1CertificateSigningRequestStatus(params, option) {
    const url = this.baseUrl + `/apis/certificates.k8s.io/v1beta1/certificatesigningrequests/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of CertificateSigningRequest. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCertificatesV1beta1CertificateSigningRequestList
   * Request URI: /apis/certificates.k8s.io/v1beta1/watch/certificatesigningrequests
   */
  async watchCertificatesV1beta1CertificateSigningRequestList(params, option) {
    const url = this.baseUrl + `/apis/certificates.k8s.io/v1beta1/watch/certificatesigningrequests`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind CertificateSigningRequest. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchCertificatesV1beta1CertificateSigningRequest
   * Request URI: /apis/certificates.k8s.io/v1beta1/watch/certificatesigningrequests/{name}
   */
  async watchCertificatesV1beta1CertificateSigningRequest(params, option) {
    const url = this.baseUrl + `/apis/certificates.k8s.io/v1beta1/watch/certificatesigningrequests/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get information of a group
   * operationId: getCoordinationAPIGroup
   * Request URI: /apis/coordination.k8s.io/
   */
  async getCoordinationAPIGroup(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getCoordinationV1APIResources
   * Request URI: /apis/coordination.k8s.io/v1/
   */
  async getCoordinationV1APIResources(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind Lease
   * operationId: listCoordinationV1LeaseForAllNamespaces
   * Request URI: /apis/coordination.k8s.io/v1/leases
   */
  async listCoordinationV1LeaseForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1/leases`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Lease
   * operationId: listCoordinationV1NamespacedLease
   * Request URI: /apis/coordination.k8s.io/v1/namespaces/{namespace}/leases
   */
  async listCoordinationV1NamespacedLease(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1/namespaces/${params.parameter.namespace}/leases`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a Lease
   * operationId: createCoordinationV1NamespacedLease
   * Request URI: /apis/coordination.k8s.io/v1/namespaces/{namespace}/leases
   */
  async createCoordinationV1NamespacedLease(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1/namespaces/${params.parameter.namespace}/leases`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of Lease
   * operationId: deleteCoordinationV1CollectionNamespacedLease
   * Request URI: /apis/coordination.k8s.io/v1/namespaces/{namespace}/leases
   */
  async deleteCoordinationV1CollectionNamespacedLease(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1/namespaces/${params.parameter.namespace}/leases`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified Lease
   * operationId: readCoordinationV1NamespacedLease
   * Request URI: /apis/coordination.k8s.io/v1/namespaces/{namespace}/leases/{name}
   */
  async readCoordinationV1NamespacedLease(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1/namespaces/${params.parameter.namespace}/leases/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified Lease
   * operationId: replaceCoordinationV1NamespacedLease
   * Request URI: /apis/coordination.k8s.io/v1/namespaces/{namespace}/leases/{name}
   */
  async replaceCoordinationV1NamespacedLease(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1/namespaces/${params.parameter.namespace}/leases/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a Lease
   * operationId: deleteCoordinationV1NamespacedLease
   * Request URI: /apis/coordination.k8s.io/v1/namespaces/{namespace}/leases/{name}
   */
  async deleteCoordinationV1NamespacedLease(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1/namespaces/${params.parameter.namespace}/leases/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified Lease
   * operationId: patchCoordinationV1NamespacedLease
   * Request URI: /apis/coordination.k8s.io/v1/namespaces/{namespace}/leases/{name}
   */
  async patchCoordinationV1NamespacedLease(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1/namespaces/${params.parameter.namespace}/leases/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Lease. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoordinationV1LeaseListForAllNamespaces
   * Request URI: /apis/coordination.k8s.io/v1/watch/leases
   */
  async watchCoordinationV1LeaseListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1/watch/leases`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Lease. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoordinationV1NamespacedLeaseList
   * Request URI: /apis/coordination.k8s.io/v1/watch/namespaces/{namespace}/leases
   */
  async watchCoordinationV1NamespacedLeaseList(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1/watch/namespaces/${params.parameter.namespace}/leases`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind Lease. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchCoordinationV1NamespacedLease
   * Request URI: /apis/coordination.k8s.io/v1/watch/namespaces/{namespace}/leases/{name}
   */
  async watchCoordinationV1NamespacedLease(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1/watch/namespaces/${params.parameter.namespace}/leases/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getCoordinationV1beta1APIResources
   * Request URI: /apis/coordination.k8s.io/v1beta1/
   */
  async getCoordinationV1beta1APIResources(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1beta1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind Lease
   * operationId: listCoordinationV1beta1LeaseForAllNamespaces
   * Request URI: /apis/coordination.k8s.io/v1beta1/leases
   */
  async listCoordinationV1beta1LeaseForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1beta1/leases`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Lease
   * operationId: listCoordinationV1beta1NamespacedLease
   * Request URI: /apis/coordination.k8s.io/v1beta1/namespaces/{namespace}/leases
   */
  async listCoordinationV1beta1NamespacedLease(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/leases`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a Lease
   * operationId: createCoordinationV1beta1NamespacedLease
   * Request URI: /apis/coordination.k8s.io/v1beta1/namespaces/{namespace}/leases
   */
  async createCoordinationV1beta1NamespacedLease(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/leases`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of Lease
   * operationId: deleteCoordinationV1beta1CollectionNamespacedLease
   * Request URI: /apis/coordination.k8s.io/v1beta1/namespaces/{namespace}/leases
   */
  async deleteCoordinationV1beta1CollectionNamespacedLease(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/leases`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified Lease
   * operationId: readCoordinationV1beta1NamespacedLease
   * Request URI: /apis/coordination.k8s.io/v1beta1/namespaces/{namespace}/leases/{name}
   */
  async readCoordinationV1beta1NamespacedLease(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/leases/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified Lease
   * operationId: replaceCoordinationV1beta1NamespacedLease
   * Request URI: /apis/coordination.k8s.io/v1beta1/namespaces/{namespace}/leases/{name}
   */
  async replaceCoordinationV1beta1NamespacedLease(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/leases/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a Lease
   * operationId: deleteCoordinationV1beta1NamespacedLease
   * Request URI: /apis/coordination.k8s.io/v1beta1/namespaces/{namespace}/leases/{name}
   */
  async deleteCoordinationV1beta1NamespacedLease(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/leases/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified Lease
   * operationId: patchCoordinationV1beta1NamespacedLease
   * Request URI: /apis/coordination.k8s.io/v1beta1/namespaces/{namespace}/leases/{name}
   */
  async patchCoordinationV1beta1NamespacedLease(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/leases/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Lease. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoordinationV1beta1LeaseListForAllNamespaces
   * Request URI: /apis/coordination.k8s.io/v1beta1/watch/leases
   */
  async watchCoordinationV1beta1LeaseListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1beta1/watch/leases`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Lease. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchCoordinationV1beta1NamespacedLeaseList
   * Request URI: /apis/coordination.k8s.io/v1beta1/watch/namespaces/{namespace}/leases
   */
  async watchCoordinationV1beta1NamespacedLeaseList(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1beta1/watch/namespaces/${params.parameter.namespace}/leases`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind Lease. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchCoordinationV1beta1NamespacedLease
   * Request URI: /apis/coordination.k8s.io/v1beta1/watch/namespaces/{namespace}/leases/{name}
   */
  async watchCoordinationV1beta1NamespacedLease(params, option) {
    const url = this.baseUrl + `/apis/coordination.k8s.io/v1beta1/watch/namespaces/${params.parameter.namespace}/leases/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get information of a group
   * operationId: getDiscoveryAPIGroup
   * Request URI: /apis/discovery.k8s.io/
   */
  async getDiscoveryAPIGroup(params, option) {
    const url = this.baseUrl + `/apis/discovery.k8s.io/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getDiscoveryV1alpha1APIResources
   * Request URI: /apis/discovery.k8s.io/v1alpha1/
   */
  async getDiscoveryV1alpha1APIResources(params, option) {
    const url = this.baseUrl + `/apis/discovery.k8s.io/v1alpha1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind EndpointSlice
   * operationId: listDiscoveryV1alpha1EndpointSliceForAllNamespaces
   * Request URI: /apis/discovery.k8s.io/v1alpha1/endpointslices
   */
  async listDiscoveryV1alpha1EndpointSliceForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/discovery.k8s.io/v1alpha1/endpointslices`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind EndpointSlice
   * operationId: listDiscoveryV1alpha1NamespacedEndpointSlice
   * Request URI: /apis/discovery.k8s.io/v1alpha1/namespaces/{namespace}/endpointslices
   */
  async listDiscoveryV1alpha1NamespacedEndpointSlice(params, option) {
    const url = this.baseUrl + `/apis/discovery.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/endpointslices`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create an EndpointSlice
   * operationId: createDiscoveryV1alpha1NamespacedEndpointSlice
   * Request URI: /apis/discovery.k8s.io/v1alpha1/namespaces/{namespace}/endpointslices
   */
  async createDiscoveryV1alpha1NamespacedEndpointSlice(params, option) {
    const url = this.baseUrl + `/apis/discovery.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/endpointslices`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of EndpointSlice
   * operationId: deleteDiscoveryV1alpha1CollectionNamespacedEndpointSlice
   * Request URI: /apis/discovery.k8s.io/v1alpha1/namespaces/{namespace}/endpointslices
   */
  async deleteDiscoveryV1alpha1CollectionNamespacedEndpointSlice(params, option) {
    const url = this.baseUrl + `/apis/discovery.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/endpointslices`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified EndpointSlice
   * operationId: readDiscoveryV1alpha1NamespacedEndpointSlice
   * Request URI: /apis/discovery.k8s.io/v1alpha1/namespaces/{namespace}/endpointslices/{name}
   */
  async readDiscoveryV1alpha1NamespacedEndpointSlice(params, option) {
    const url = this.baseUrl + `/apis/discovery.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/endpointslices/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified EndpointSlice
   * operationId: replaceDiscoveryV1alpha1NamespacedEndpointSlice
   * Request URI: /apis/discovery.k8s.io/v1alpha1/namespaces/{namespace}/endpointslices/{name}
   */
  async replaceDiscoveryV1alpha1NamespacedEndpointSlice(params, option) {
    const url = this.baseUrl + `/apis/discovery.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/endpointslices/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete an EndpointSlice
   * operationId: deleteDiscoveryV1alpha1NamespacedEndpointSlice
   * Request URI: /apis/discovery.k8s.io/v1alpha1/namespaces/{namespace}/endpointslices/{name}
   */
  async deleteDiscoveryV1alpha1NamespacedEndpointSlice(params, option) {
    const url = this.baseUrl + `/apis/discovery.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/endpointslices/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified EndpointSlice
   * operationId: patchDiscoveryV1alpha1NamespacedEndpointSlice
   * Request URI: /apis/discovery.k8s.io/v1alpha1/namespaces/{namespace}/endpointslices/{name}
   */
  async patchDiscoveryV1alpha1NamespacedEndpointSlice(params, option) {
    const url = this.baseUrl + `/apis/discovery.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/endpointslices/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of EndpointSlice. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchDiscoveryV1alpha1EndpointSliceListForAllNamespaces
   * Request URI: /apis/discovery.k8s.io/v1alpha1/watch/endpointslices
   */
  async watchDiscoveryV1alpha1EndpointSliceListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/discovery.k8s.io/v1alpha1/watch/endpointslices`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of EndpointSlice. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchDiscoveryV1alpha1NamespacedEndpointSliceList
   * Request URI: /apis/discovery.k8s.io/v1alpha1/watch/namespaces/{namespace}/endpointslices
   */
  async watchDiscoveryV1alpha1NamespacedEndpointSliceList(params, option) {
    const url = this.baseUrl + `/apis/discovery.k8s.io/v1alpha1/watch/namespaces/${params.parameter.namespace}/endpointslices`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind EndpointSlice. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchDiscoveryV1alpha1NamespacedEndpointSlice
   * Request URI: /apis/discovery.k8s.io/v1alpha1/watch/namespaces/{namespace}/endpointslices/{name}
   */
  async watchDiscoveryV1alpha1NamespacedEndpointSlice(params, option) {
    const url = this.baseUrl + `/apis/discovery.k8s.io/v1alpha1/watch/namespaces/${params.parameter.namespace}/endpointslices/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get information of a group
   * operationId: getEventsAPIGroup
   * Request URI: /apis/events.k8s.io/
   */
  async getEventsAPIGroup(params, option) {
    const url = this.baseUrl + `/apis/events.k8s.io/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getEventsV1beta1APIResources
   * Request URI: /apis/events.k8s.io/v1beta1/
   */
  async getEventsV1beta1APIResources(params, option) {
    const url = this.baseUrl + `/apis/events.k8s.io/v1beta1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind Event
   * operationId: listEventsV1beta1EventForAllNamespaces
   * Request URI: /apis/events.k8s.io/v1beta1/events
   */
  async listEventsV1beta1EventForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/events.k8s.io/v1beta1/events`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Event
   * operationId: listEventsV1beta1NamespacedEvent
   * Request URI: /apis/events.k8s.io/v1beta1/namespaces/{namespace}/events
   */
  async listEventsV1beta1NamespacedEvent(params, option) {
    const url = this.baseUrl + `/apis/events.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/events`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create an Event
   * operationId: createEventsV1beta1NamespacedEvent
   * Request URI: /apis/events.k8s.io/v1beta1/namespaces/{namespace}/events
   */
  async createEventsV1beta1NamespacedEvent(params, option) {
    const url = this.baseUrl + `/apis/events.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/events`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of Event
   * operationId: deleteEventsV1beta1CollectionNamespacedEvent
   * Request URI: /apis/events.k8s.io/v1beta1/namespaces/{namespace}/events
   */
  async deleteEventsV1beta1CollectionNamespacedEvent(params, option) {
    const url = this.baseUrl + `/apis/events.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/events`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified Event
   * operationId: readEventsV1beta1NamespacedEvent
   * Request URI: /apis/events.k8s.io/v1beta1/namespaces/{namespace}/events/{name}
   */
  async readEventsV1beta1NamespacedEvent(params, option) {
    const url = this.baseUrl + `/apis/events.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/events/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified Event
   * operationId: replaceEventsV1beta1NamespacedEvent
   * Request URI: /apis/events.k8s.io/v1beta1/namespaces/{namespace}/events/{name}
   */
  async replaceEventsV1beta1NamespacedEvent(params, option) {
    const url = this.baseUrl + `/apis/events.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/events/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete an Event
   * operationId: deleteEventsV1beta1NamespacedEvent
   * Request URI: /apis/events.k8s.io/v1beta1/namespaces/{namespace}/events/{name}
   */
  async deleteEventsV1beta1NamespacedEvent(params, option) {
    const url = this.baseUrl + `/apis/events.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/events/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified Event
   * operationId: patchEventsV1beta1NamespacedEvent
   * Request URI: /apis/events.k8s.io/v1beta1/namespaces/{namespace}/events/{name}
   */
  async patchEventsV1beta1NamespacedEvent(params, option) {
    const url = this.baseUrl + `/apis/events.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/events/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Event. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchEventsV1beta1EventListForAllNamespaces
   * Request URI: /apis/events.k8s.io/v1beta1/watch/events
   */
  async watchEventsV1beta1EventListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/events.k8s.io/v1beta1/watch/events`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Event. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchEventsV1beta1NamespacedEventList
   * Request URI: /apis/events.k8s.io/v1beta1/watch/namespaces/{namespace}/events
   */
  async watchEventsV1beta1NamespacedEventList(params, option) {
    const url = this.baseUrl + `/apis/events.k8s.io/v1beta1/watch/namespaces/${params.parameter.namespace}/events`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind Event. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchEventsV1beta1NamespacedEvent
   * Request URI: /apis/events.k8s.io/v1beta1/watch/namespaces/{namespace}/events/{name}
   */
  async watchEventsV1beta1NamespacedEvent(params, option) {
    const url = this.baseUrl + `/apis/events.k8s.io/v1beta1/watch/namespaces/${params.parameter.namespace}/events/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get information of a group
   * operationId: getExtensionsAPIGroup
   * Request URI: /apis/extensions/
   */
  async getExtensionsAPIGroup(params, option) {
    const url = this.baseUrl + `/apis/extensions/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getExtensionsV1beta1APIResources
   * Request URI: /apis/extensions/v1beta1/
   */
  async getExtensionsV1beta1APIResources(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind DaemonSet
   * operationId: listExtensionsV1beta1DaemonSetForAllNamespaces
   * Request URI: /apis/extensions/v1beta1/daemonsets
   */
  async listExtensionsV1beta1DaemonSetForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/daemonsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Deployment
   * operationId: listExtensionsV1beta1DeploymentForAllNamespaces
   * Request URI: /apis/extensions/v1beta1/deployments
   */
  async listExtensionsV1beta1DeploymentForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/deployments`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Ingress
   * operationId: listExtensionsV1beta1IngressForAllNamespaces
   * Request URI: /apis/extensions/v1beta1/ingresses
   */
  async listExtensionsV1beta1IngressForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/ingresses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind DaemonSet
   * operationId: listExtensionsV1beta1NamespacedDaemonSet
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/daemonsets
   */
  async listExtensionsV1beta1NamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/daemonsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a DaemonSet
   * operationId: createExtensionsV1beta1NamespacedDaemonSet
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/daemonsets
   */
  async createExtensionsV1beta1NamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/daemonsets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of DaemonSet
   * operationId: deleteExtensionsV1beta1CollectionNamespacedDaemonSet
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/daemonsets
   */
  async deleteExtensionsV1beta1CollectionNamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/daemonsets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified DaemonSet
   * operationId: readExtensionsV1beta1NamespacedDaemonSet
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/daemonsets/{name}
   */
  async readExtensionsV1beta1NamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified DaemonSet
   * operationId: replaceExtensionsV1beta1NamespacedDaemonSet
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/daemonsets/{name}
   */
  async replaceExtensionsV1beta1NamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a DaemonSet
   * operationId: deleteExtensionsV1beta1NamespacedDaemonSet
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/daemonsets/{name}
   */
  async deleteExtensionsV1beta1NamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified DaemonSet
   * operationId: patchExtensionsV1beta1NamespacedDaemonSet
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/daemonsets/{name}
   */
  async patchExtensionsV1beta1NamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified DaemonSet
   * operationId: readExtensionsV1beta1NamespacedDaemonSetStatus
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/daemonsets/{name}/status
   */
  async readExtensionsV1beta1NamespacedDaemonSetStatus(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified DaemonSet
   * operationId: replaceExtensionsV1beta1NamespacedDaemonSetStatus
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/daemonsets/{name}/status
   */
  async replaceExtensionsV1beta1NamespacedDaemonSetStatus(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified DaemonSet
   * operationId: patchExtensionsV1beta1NamespacedDaemonSetStatus
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/daemonsets/{name}/status
   */
  async patchExtensionsV1beta1NamespacedDaemonSetStatus(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Deployment
   * operationId: listExtensionsV1beta1NamespacedDeployment
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/deployments
   */
  async listExtensionsV1beta1NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/deployments`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a Deployment
   * operationId: createExtensionsV1beta1NamespacedDeployment
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/deployments
   */
  async createExtensionsV1beta1NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/deployments`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of Deployment
   * operationId: deleteExtensionsV1beta1CollectionNamespacedDeployment
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/deployments
   */
  async deleteExtensionsV1beta1CollectionNamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/deployments`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified Deployment
   * operationId: readExtensionsV1beta1NamespacedDeployment
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/deployments/{name}
   */
  async readExtensionsV1beta1NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified Deployment
   * operationId: replaceExtensionsV1beta1NamespacedDeployment
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/deployments/{name}
   */
  async replaceExtensionsV1beta1NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a Deployment
   * operationId: deleteExtensionsV1beta1NamespacedDeployment
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/deployments/{name}
   */
  async deleteExtensionsV1beta1NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified Deployment
   * operationId: patchExtensionsV1beta1NamespacedDeployment
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/deployments/{name}
   */
  async patchExtensionsV1beta1NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * create rollback of a Deployment
   * operationId: createExtensionsV1beta1NamespacedDeploymentRollback
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/deployments/{name}/rollback
   */
  async createExtensionsV1beta1NamespacedDeploymentRollback(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/rollback`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read scale of the specified Deployment
   * operationId: readExtensionsV1beta1NamespacedDeploymentScale
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/deployments/{name}/scale
   */
  async readExtensionsV1beta1NamespacedDeploymentScale(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/scale`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace scale of the specified Deployment
   * operationId: replaceExtensionsV1beta1NamespacedDeploymentScale
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/deployments/{name}/scale
   */
  async replaceExtensionsV1beta1NamespacedDeploymentScale(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update scale of the specified Deployment
   * operationId: patchExtensionsV1beta1NamespacedDeploymentScale
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/deployments/{name}/scale
   */
  async patchExtensionsV1beta1NamespacedDeploymentScale(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified Deployment
   * operationId: readExtensionsV1beta1NamespacedDeploymentStatus
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/deployments/{name}/status
   */
  async readExtensionsV1beta1NamespacedDeploymentStatus(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified Deployment
   * operationId: replaceExtensionsV1beta1NamespacedDeploymentStatus
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/deployments/{name}/status
   */
  async replaceExtensionsV1beta1NamespacedDeploymentStatus(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified Deployment
   * operationId: patchExtensionsV1beta1NamespacedDeploymentStatus
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/deployments/{name}/status
   */
  async patchExtensionsV1beta1NamespacedDeploymentStatus(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Ingress
   * operationId: listExtensionsV1beta1NamespacedIngress
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/ingresses
   */
  async listExtensionsV1beta1NamespacedIngress(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/ingresses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create an Ingress
   * operationId: createExtensionsV1beta1NamespacedIngress
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/ingresses
   */
  async createExtensionsV1beta1NamespacedIngress(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/ingresses`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of Ingress
   * operationId: deleteExtensionsV1beta1CollectionNamespacedIngress
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/ingresses
   */
  async deleteExtensionsV1beta1CollectionNamespacedIngress(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/ingresses`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified Ingress
   * operationId: readExtensionsV1beta1NamespacedIngress
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/ingresses/{name}
   */
  async readExtensionsV1beta1NamespacedIngress(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/ingresses/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified Ingress
   * operationId: replaceExtensionsV1beta1NamespacedIngress
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/ingresses/{name}
   */
  async replaceExtensionsV1beta1NamespacedIngress(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/ingresses/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete an Ingress
   * operationId: deleteExtensionsV1beta1NamespacedIngress
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/ingresses/{name}
   */
  async deleteExtensionsV1beta1NamespacedIngress(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/ingresses/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified Ingress
   * operationId: patchExtensionsV1beta1NamespacedIngress
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/ingresses/{name}
   */
  async patchExtensionsV1beta1NamespacedIngress(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/ingresses/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified Ingress
   * operationId: readExtensionsV1beta1NamespacedIngressStatus
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/ingresses/{name}/status
   */
  async readExtensionsV1beta1NamespacedIngressStatus(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/ingresses/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified Ingress
   * operationId: replaceExtensionsV1beta1NamespacedIngressStatus
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/ingresses/{name}/status
   */
  async replaceExtensionsV1beta1NamespacedIngressStatus(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/ingresses/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified Ingress
   * operationId: patchExtensionsV1beta1NamespacedIngressStatus
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/ingresses/{name}/status
   */
  async patchExtensionsV1beta1NamespacedIngressStatus(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/ingresses/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind NetworkPolicy
   * operationId: listExtensionsV1beta1NamespacedNetworkPolicy
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/networkpolicies
   */
  async listExtensionsV1beta1NamespacedNetworkPolicy(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/networkpolicies`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a NetworkPolicy
   * operationId: createExtensionsV1beta1NamespacedNetworkPolicy
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/networkpolicies
   */
  async createExtensionsV1beta1NamespacedNetworkPolicy(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/networkpolicies`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of NetworkPolicy
   * operationId: deleteExtensionsV1beta1CollectionNamespacedNetworkPolicy
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/networkpolicies
   */
  async deleteExtensionsV1beta1CollectionNamespacedNetworkPolicy(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/networkpolicies`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified NetworkPolicy
   * operationId: readExtensionsV1beta1NamespacedNetworkPolicy
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/networkpolicies/{name}
   */
  async readExtensionsV1beta1NamespacedNetworkPolicy(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/networkpolicies/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified NetworkPolicy
   * operationId: replaceExtensionsV1beta1NamespacedNetworkPolicy
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/networkpolicies/{name}
   */
  async replaceExtensionsV1beta1NamespacedNetworkPolicy(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/networkpolicies/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a NetworkPolicy
   * operationId: deleteExtensionsV1beta1NamespacedNetworkPolicy
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/networkpolicies/{name}
   */
  async deleteExtensionsV1beta1NamespacedNetworkPolicy(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/networkpolicies/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified NetworkPolicy
   * operationId: patchExtensionsV1beta1NamespacedNetworkPolicy
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/networkpolicies/{name}
   */
  async patchExtensionsV1beta1NamespacedNetworkPolicy(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/networkpolicies/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind ReplicaSet
   * operationId: listExtensionsV1beta1NamespacedReplicaSet
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/replicasets
   */
  async listExtensionsV1beta1NamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/replicasets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a ReplicaSet
   * operationId: createExtensionsV1beta1NamespacedReplicaSet
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/replicasets
   */
  async createExtensionsV1beta1NamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/replicasets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of ReplicaSet
   * operationId: deleteExtensionsV1beta1CollectionNamespacedReplicaSet
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/replicasets
   */
  async deleteExtensionsV1beta1CollectionNamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/replicasets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified ReplicaSet
   * operationId: readExtensionsV1beta1NamespacedReplicaSet
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/replicasets/{name}
   */
  async readExtensionsV1beta1NamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified ReplicaSet
   * operationId: replaceExtensionsV1beta1NamespacedReplicaSet
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/replicasets/{name}
   */
  async replaceExtensionsV1beta1NamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a ReplicaSet
   * operationId: deleteExtensionsV1beta1NamespacedReplicaSet
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/replicasets/{name}
   */
  async deleteExtensionsV1beta1NamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified ReplicaSet
   * operationId: patchExtensionsV1beta1NamespacedReplicaSet
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/replicasets/{name}
   */
  async patchExtensionsV1beta1NamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read scale of the specified ReplicaSet
   * operationId: readExtensionsV1beta1NamespacedReplicaSetScale
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/replicasets/{name}/scale
   */
  async readExtensionsV1beta1NamespacedReplicaSetScale(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}/scale`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace scale of the specified ReplicaSet
   * operationId: replaceExtensionsV1beta1NamespacedReplicaSetScale
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/replicasets/{name}/scale
   */
  async replaceExtensionsV1beta1NamespacedReplicaSetScale(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update scale of the specified ReplicaSet
   * operationId: patchExtensionsV1beta1NamespacedReplicaSetScale
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/replicasets/{name}/scale
   */
  async patchExtensionsV1beta1NamespacedReplicaSetScale(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified ReplicaSet
   * operationId: readExtensionsV1beta1NamespacedReplicaSetStatus
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/replicasets/{name}/status
   */
  async readExtensionsV1beta1NamespacedReplicaSetStatus(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified ReplicaSet
   * operationId: replaceExtensionsV1beta1NamespacedReplicaSetStatus
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/replicasets/{name}/status
   */
  async replaceExtensionsV1beta1NamespacedReplicaSetStatus(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified ReplicaSet
   * operationId: patchExtensionsV1beta1NamespacedReplicaSetStatus
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/replicasets/{name}/status
   */
  async patchExtensionsV1beta1NamespacedReplicaSetStatus(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read scale of the specified ReplicationControllerDummy
   * operationId: readExtensionsV1beta1NamespacedReplicationControllerDummyScale
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/replicationcontrollers/{name}/scale
   */
  async readExtensionsV1beta1NamespacedReplicationControllerDummyScale(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/replicationcontrollers/${params.parameter.name}/scale`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace scale of the specified ReplicationControllerDummy
   * operationId: replaceExtensionsV1beta1NamespacedReplicationControllerDummyScale
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/replicationcontrollers/{name}/scale
   */
  async replaceExtensionsV1beta1NamespacedReplicationControllerDummyScale(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/replicationcontrollers/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update scale of the specified ReplicationControllerDummy
   * operationId: patchExtensionsV1beta1NamespacedReplicationControllerDummyScale
   * Request URI: /apis/extensions/v1beta1/namespaces/{namespace}/replicationcontrollers/{name}/scale
   */
  async patchExtensionsV1beta1NamespacedReplicationControllerDummyScale(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/namespaces/${params.parameter.namespace}/replicationcontrollers/${params.parameter.name}/scale`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind NetworkPolicy
   * operationId: listExtensionsV1beta1NetworkPolicyForAllNamespaces
   * Request URI: /apis/extensions/v1beta1/networkpolicies
   */
  async listExtensionsV1beta1NetworkPolicyForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/networkpolicies`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind PodSecurityPolicy
   * operationId: listExtensionsV1beta1PodSecurityPolicy
   * Request URI: /apis/extensions/v1beta1/podsecuritypolicies
   */
  async listExtensionsV1beta1PodSecurityPolicy(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/podsecuritypolicies`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a PodSecurityPolicy
   * operationId: createExtensionsV1beta1PodSecurityPolicy
   * Request URI: /apis/extensions/v1beta1/podsecuritypolicies
   */
  async createExtensionsV1beta1PodSecurityPolicy(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/podsecuritypolicies`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of PodSecurityPolicy
   * operationId: deleteExtensionsV1beta1CollectionPodSecurityPolicy
   * Request URI: /apis/extensions/v1beta1/podsecuritypolicies
   */
  async deleteExtensionsV1beta1CollectionPodSecurityPolicy(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/podsecuritypolicies`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified PodSecurityPolicy
   * operationId: readExtensionsV1beta1PodSecurityPolicy
   * Request URI: /apis/extensions/v1beta1/podsecuritypolicies/{name}
   */
  async readExtensionsV1beta1PodSecurityPolicy(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/podsecuritypolicies/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified PodSecurityPolicy
   * operationId: replaceExtensionsV1beta1PodSecurityPolicy
   * Request URI: /apis/extensions/v1beta1/podsecuritypolicies/{name}
   */
  async replaceExtensionsV1beta1PodSecurityPolicy(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/podsecuritypolicies/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a PodSecurityPolicy
   * operationId: deleteExtensionsV1beta1PodSecurityPolicy
   * Request URI: /apis/extensions/v1beta1/podsecuritypolicies/{name}
   */
  async deleteExtensionsV1beta1PodSecurityPolicy(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/podsecuritypolicies/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified PodSecurityPolicy
   * operationId: patchExtensionsV1beta1PodSecurityPolicy
   * Request URI: /apis/extensions/v1beta1/podsecuritypolicies/{name}
   */
  async patchExtensionsV1beta1PodSecurityPolicy(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/podsecuritypolicies/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind ReplicaSet
   * operationId: listExtensionsV1beta1ReplicaSetForAllNamespaces
   * Request URI: /apis/extensions/v1beta1/replicasets
   */
  async listExtensionsV1beta1ReplicaSetForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/replicasets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of DaemonSet. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchExtensionsV1beta1DaemonSetListForAllNamespaces
   * Request URI: /apis/extensions/v1beta1/watch/daemonsets
   */
  async watchExtensionsV1beta1DaemonSetListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/watch/daemonsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Deployment. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchExtensionsV1beta1DeploymentListForAllNamespaces
   * Request URI: /apis/extensions/v1beta1/watch/deployments
   */
  async watchExtensionsV1beta1DeploymentListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/watch/deployments`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Ingress. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchExtensionsV1beta1IngressListForAllNamespaces
   * Request URI: /apis/extensions/v1beta1/watch/ingresses
   */
  async watchExtensionsV1beta1IngressListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/watch/ingresses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of DaemonSet. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchExtensionsV1beta1NamespacedDaemonSetList
   * Request URI: /apis/extensions/v1beta1/watch/namespaces/{namespace}/daemonsets
   */
  async watchExtensionsV1beta1NamespacedDaemonSetList(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/watch/namespaces/${params.parameter.namespace}/daemonsets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind DaemonSet. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchExtensionsV1beta1NamespacedDaemonSet
   * Request URI: /apis/extensions/v1beta1/watch/namespaces/{namespace}/daemonsets/{name}
   */
  async watchExtensionsV1beta1NamespacedDaemonSet(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/watch/namespaces/${params.parameter.namespace}/daemonsets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Deployment. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchExtensionsV1beta1NamespacedDeploymentList
   * Request URI: /apis/extensions/v1beta1/watch/namespaces/{namespace}/deployments
   */
  async watchExtensionsV1beta1NamespacedDeploymentList(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/watch/namespaces/${params.parameter.namespace}/deployments`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind Deployment. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchExtensionsV1beta1NamespacedDeployment
   * Request URI: /apis/extensions/v1beta1/watch/namespaces/{namespace}/deployments/{name}
   */
  async watchExtensionsV1beta1NamespacedDeployment(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/watch/namespaces/${params.parameter.namespace}/deployments/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Ingress. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchExtensionsV1beta1NamespacedIngressList
   * Request URI: /apis/extensions/v1beta1/watch/namespaces/{namespace}/ingresses
   */
  async watchExtensionsV1beta1NamespacedIngressList(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/watch/namespaces/${params.parameter.namespace}/ingresses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind Ingress. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchExtensionsV1beta1NamespacedIngress
   * Request URI: /apis/extensions/v1beta1/watch/namespaces/{namespace}/ingresses/{name}
   */
  async watchExtensionsV1beta1NamespacedIngress(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/watch/namespaces/${params.parameter.namespace}/ingresses/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of NetworkPolicy. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchExtensionsV1beta1NamespacedNetworkPolicyList
   * Request URI: /apis/extensions/v1beta1/watch/namespaces/{namespace}/networkpolicies
   */
  async watchExtensionsV1beta1NamespacedNetworkPolicyList(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/watch/namespaces/${params.parameter.namespace}/networkpolicies`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind NetworkPolicy. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchExtensionsV1beta1NamespacedNetworkPolicy
   * Request URI: /apis/extensions/v1beta1/watch/namespaces/{namespace}/networkpolicies/{name}
   */
  async watchExtensionsV1beta1NamespacedNetworkPolicy(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/watch/namespaces/${params.parameter.namespace}/networkpolicies/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ReplicaSet. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchExtensionsV1beta1NamespacedReplicaSetList
   * Request URI: /apis/extensions/v1beta1/watch/namespaces/{namespace}/replicasets
   */
  async watchExtensionsV1beta1NamespacedReplicaSetList(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/watch/namespaces/${params.parameter.namespace}/replicasets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind ReplicaSet. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchExtensionsV1beta1NamespacedReplicaSet
   * Request URI: /apis/extensions/v1beta1/watch/namespaces/{namespace}/replicasets/{name}
   */
  async watchExtensionsV1beta1NamespacedReplicaSet(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/watch/namespaces/${params.parameter.namespace}/replicasets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of NetworkPolicy. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchExtensionsV1beta1NetworkPolicyListForAllNamespaces
   * Request URI: /apis/extensions/v1beta1/watch/networkpolicies
   */
  async watchExtensionsV1beta1NetworkPolicyListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/watch/networkpolicies`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of PodSecurityPolicy. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchExtensionsV1beta1PodSecurityPolicyList
   * Request URI: /apis/extensions/v1beta1/watch/podsecuritypolicies
   */
  async watchExtensionsV1beta1PodSecurityPolicyList(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/watch/podsecuritypolicies`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind PodSecurityPolicy. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchExtensionsV1beta1PodSecurityPolicy
   * Request URI: /apis/extensions/v1beta1/watch/podsecuritypolicies/{name}
   */
  async watchExtensionsV1beta1PodSecurityPolicy(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/watch/podsecuritypolicies/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ReplicaSet. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchExtensionsV1beta1ReplicaSetListForAllNamespaces
   * Request URI: /apis/extensions/v1beta1/watch/replicasets
   */
  async watchExtensionsV1beta1ReplicaSetListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/extensions/v1beta1/watch/replicasets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get information of a group
   * operationId: getNetworkingAPIGroup
   * Request URI: /apis/networking.k8s.io/
   */
  async getNetworkingAPIGroup(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getNetworkingV1APIResources
   * Request URI: /apis/networking.k8s.io/v1/
   */
  async getNetworkingV1APIResources(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind NetworkPolicy
   * operationId: listNetworkingV1NamespacedNetworkPolicy
   * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies
   */
  async listNetworkingV1NamespacedNetworkPolicy(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1/namespaces/${params.parameter.namespace}/networkpolicies`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a NetworkPolicy
   * operationId: createNetworkingV1NamespacedNetworkPolicy
   * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies
   */
  async createNetworkingV1NamespacedNetworkPolicy(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1/namespaces/${params.parameter.namespace}/networkpolicies`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of NetworkPolicy
   * operationId: deleteNetworkingV1CollectionNamespacedNetworkPolicy
   * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies
   */
  async deleteNetworkingV1CollectionNamespacedNetworkPolicy(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1/namespaces/${params.parameter.namespace}/networkpolicies`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified NetworkPolicy
   * operationId: readNetworkingV1NamespacedNetworkPolicy
   * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies/{name}
   */
  async readNetworkingV1NamespacedNetworkPolicy(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1/namespaces/${params.parameter.namespace}/networkpolicies/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified NetworkPolicy
   * operationId: replaceNetworkingV1NamespacedNetworkPolicy
   * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies/{name}
   */
  async replaceNetworkingV1NamespacedNetworkPolicy(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1/namespaces/${params.parameter.namespace}/networkpolicies/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a NetworkPolicy
   * operationId: deleteNetworkingV1NamespacedNetworkPolicy
   * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies/{name}
   */
  async deleteNetworkingV1NamespacedNetworkPolicy(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1/namespaces/${params.parameter.namespace}/networkpolicies/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified NetworkPolicy
   * operationId: patchNetworkingV1NamespacedNetworkPolicy
   * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies/{name}
   */
  async patchNetworkingV1NamespacedNetworkPolicy(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1/namespaces/${params.parameter.namespace}/networkpolicies/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind NetworkPolicy
   * operationId: listNetworkingV1NetworkPolicyForAllNamespaces
   * Request URI: /apis/networking.k8s.io/v1/networkpolicies
   */
  async listNetworkingV1NetworkPolicyForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1/networkpolicies`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of NetworkPolicy. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchNetworkingV1NamespacedNetworkPolicyList
   * Request URI: /apis/networking.k8s.io/v1/watch/namespaces/{namespace}/networkpolicies
   */
  async watchNetworkingV1NamespacedNetworkPolicyList(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1/watch/namespaces/${params.parameter.namespace}/networkpolicies`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind NetworkPolicy. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchNetworkingV1NamespacedNetworkPolicy
   * Request URI: /apis/networking.k8s.io/v1/watch/namespaces/{namespace}/networkpolicies/{name}
   */
  async watchNetworkingV1NamespacedNetworkPolicy(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1/watch/namespaces/${params.parameter.namespace}/networkpolicies/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of NetworkPolicy. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchNetworkingV1NetworkPolicyListForAllNamespaces
   * Request URI: /apis/networking.k8s.io/v1/watch/networkpolicies
   */
  async watchNetworkingV1NetworkPolicyListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1/watch/networkpolicies`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getNetworkingV1beta1APIResources
   * Request URI: /apis/networking.k8s.io/v1beta1/
   */
  async getNetworkingV1beta1APIResources(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1beta1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind Ingress
   * operationId: listNetworkingV1beta1IngressForAllNamespaces
   * Request URI: /apis/networking.k8s.io/v1beta1/ingresses
   */
  async listNetworkingV1beta1IngressForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1beta1/ingresses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Ingress
   * operationId: listNetworkingV1beta1NamespacedIngress
   * Request URI: /apis/networking.k8s.io/v1beta1/namespaces/{namespace}/ingresses
   */
  async listNetworkingV1beta1NamespacedIngress(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/ingresses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create an Ingress
   * operationId: createNetworkingV1beta1NamespacedIngress
   * Request URI: /apis/networking.k8s.io/v1beta1/namespaces/{namespace}/ingresses
   */
  async createNetworkingV1beta1NamespacedIngress(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/ingresses`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of Ingress
   * operationId: deleteNetworkingV1beta1CollectionNamespacedIngress
   * Request URI: /apis/networking.k8s.io/v1beta1/namespaces/{namespace}/ingresses
   */
  async deleteNetworkingV1beta1CollectionNamespacedIngress(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/ingresses`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified Ingress
   * operationId: readNetworkingV1beta1NamespacedIngress
   * Request URI: /apis/networking.k8s.io/v1beta1/namespaces/{namespace}/ingresses/{name}
   */
  async readNetworkingV1beta1NamespacedIngress(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/ingresses/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified Ingress
   * operationId: replaceNetworkingV1beta1NamespacedIngress
   * Request URI: /apis/networking.k8s.io/v1beta1/namespaces/{namespace}/ingresses/{name}
   */
  async replaceNetworkingV1beta1NamespacedIngress(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/ingresses/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete an Ingress
   * operationId: deleteNetworkingV1beta1NamespacedIngress
   * Request URI: /apis/networking.k8s.io/v1beta1/namespaces/{namespace}/ingresses/{name}
   */
  async deleteNetworkingV1beta1NamespacedIngress(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/ingresses/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified Ingress
   * operationId: patchNetworkingV1beta1NamespacedIngress
   * Request URI: /apis/networking.k8s.io/v1beta1/namespaces/{namespace}/ingresses/{name}
   */
  async patchNetworkingV1beta1NamespacedIngress(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/ingresses/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified Ingress
   * operationId: readNetworkingV1beta1NamespacedIngressStatus
   * Request URI: /apis/networking.k8s.io/v1beta1/namespaces/{namespace}/ingresses/{name}/status
   */
  async readNetworkingV1beta1NamespacedIngressStatus(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/ingresses/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified Ingress
   * operationId: replaceNetworkingV1beta1NamespacedIngressStatus
   * Request URI: /apis/networking.k8s.io/v1beta1/namespaces/{namespace}/ingresses/{name}/status
   */
  async replaceNetworkingV1beta1NamespacedIngressStatus(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/ingresses/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified Ingress
   * operationId: patchNetworkingV1beta1NamespacedIngressStatus
   * Request URI: /apis/networking.k8s.io/v1beta1/namespaces/{namespace}/ingresses/{name}/status
   */
  async patchNetworkingV1beta1NamespacedIngressStatus(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/ingresses/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Ingress. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchNetworkingV1beta1IngressListForAllNamespaces
   * Request URI: /apis/networking.k8s.io/v1beta1/watch/ingresses
   */
  async watchNetworkingV1beta1IngressListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1beta1/watch/ingresses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Ingress. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchNetworkingV1beta1NamespacedIngressList
   * Request URI: /apis/networking.k8s.io/v1beta1/watch/namespaces/{namespace}/ingresses
   */
  async watchNetworkingV1beta1NamespacedIngressList(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1beta1/watch/namespaces/${params.parameter.namespace}/ingresses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind Ingress. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchNetworkingV1beta1NamespacedIngress
   * Request URI: /apis/networking.k8s.io/v1beta1/watch/namespaces/{namespace}/ingresses/{name}
   */
  async watchNetworkingV1beta1NamespacedIngress(params, option) {
    const url = this.baseUrl + `/apis/networking.k8s.io/v1beta1/watch/namespaces/${params.parameter.namespace}/ingresses/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get information of a group
   * operationId: getNodeAPIGroup
   * Request URI: /apis/node.k8s.io/
   */
  async getNodeAPIGroup(params, option) {
    const url = this.baseUrl + `/apis/node.k8s.io/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getNodeV1alpha1APIResources
   * Request URI: /apis/node.k8s.io/v1alpha1/
   */
  async getNodeV1alpha1APIResources(params, option) {
    const url = this.baseUrl + `/apis/node.k8s.io/v1alpha1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind RuntimeClass
   * operationId: listNodeV1alpha1RuntimeClass
   * Request URI: /apis/node.k8s.io/v1alpha1/runtimeclasses
   */
  async listNodeV1alpha1RuntimeClass(params, option) {
    const url = this.baseUrl + `/apis/node.k8s.io/v1alpha1/runtimeclasses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a RuntimeClass
   * operationId: createNodeV1alpha1RuntimeClass
   * Request URI: /apis/node.k8s.io/v1alpha1/runtimeclasses
   */
  async createNodeV1alpha1RuntimeClass(params, option) {
    const url = this.baseUrl + `/apis/node.k8s.io/v1alpha1/runtimeclasses`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of RuntimeClass
   * operationId: deleteNodeV1alpha1CollectionRuntimeClass
   * Request URI: /apis/node.k8s.io/v1alpha1/runtimeclasses
   */
  async deleteNodeV1alpha1CollectionRuntimeClass(params, option) {
    const url = this.baseUrl + `/apis/node.k8s.io/v1alpha1/runtimeclasses`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified RuntimeClass
   * operationId: readNodeV1alpha1RuntimeClass
   * Request URI: /apis/node.k8s.io/v1alpha1/runtimeclasses/{name}
   */
  async readNodeV1alpha1RuntimeClass(params, option) {
    const url = this.baseUrl + `/apis/node.k8s.io/v1alpha1/runtimeclasses/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified RuntimeClass
   * operationId: replaceNodeV1alpha1RuntimeClass
   * Request URI: /apis/node.k8s.io/v1alpha1/runtimeclasses/{name}
   */
  async replaceNodeV1alpha1RuntimeClass(params, option) {
    const url = this.baseUrl + `/apis/node.k8s.io/v1alpha1/runtimeclasses/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a RuntimeClass
   * operationId: deleteNodeV1alpha1RuntimeClass
   * Request URI: /apis/node.k8s.io/v1alpha1/runtimeclasses/{name}
   */
  async deleteNodeV1alpha1RuntimeClass(params, option) {
    const url = this.baseUrl + `/apis/node.k8s.io/v1alpha1/runtimeclasses/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified RuntimeClass
   * operationId: patchNodeV1alpha1RuntimeClass
   * Request URI: /apis/node.k8s.io/v1alpha1/runtimeclasses/{name}
   */
  async patchNodeV1alpha1RuntimeClass(params, option) {
    const url = this.baseUrl + `/apis/node.k8s.io/v1alpha1/runtimeclasses/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of RuntimeClass. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchNodeV1alpha1RuntimeClassList
   * Request URI: /apis/node.k8s.io/v1alpha1/watch/runtimeclasses
   */
  async watchNodeV1alpha1RuntimeClassList(params, option) {
    const url = this.baseUrl + `/apis/node.k8s.io/v1alpha1/watch/runtimeclasses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind RuntimeClass. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchNodeV1alpha1RuntimeClass
   * Request URI: /apis/node.k8s.io/v1alpha1/watch/runtimeclasses/{name}
   */
  async watchNodeV1alpha1RuntimeClass(params, option) {
    const url = this.baseUrl + `/apis/node.k8s.io/v1alpha1/watch/runtimeclasses/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getNodeV1beta1APIResources
   * Request URI: /apis/node.k8s.io/v1beta1/
   */
  async getNodeV1beta1APIResources(params, option) {
    const url = this.baseUrl + `/apis/node.k8s.io/v1beta1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind RuntimeClass
   * operationId: listNodeV1beta1RuntimeClass
   * Request URI: /apis/node.k8s.io/v1beta1/runtimeclasses
   */
  async listNodeV1beta1RuntimeClass(params, option) {
    const url = this.baseUrl + `/apis/node.k8s.io/v1beta1/runtimeclasses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a RuntimeClass
   * operationId: createNodeV1beta1RuntimeClass
   * Request URI: /apis/node.k8s.io/v1beta1/runtimeclasses
   */
  async createNodeV1beta1RuntimeClass(params, option) {
    const url = this.baseUrl + `/apis/node.k8s.io/v1beta1/runtimeclasses`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of RuntimeClass
   * operationId: deleteNodeV1beta1CollectionRuntimeClass
   * Request URI: /apis/node.k8s.io/v1beta1/runtimeclasses
   */
  async deleteNodeV1beta1CollectionRuntimeClass(params, option) {
    const url = this.baseUrl + `/apis/node.k8s.io/v1beta1/runtimeclasses`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified RuntimeClass
   * operationId: readNodeV1beta1RuntimeClass
   * Request URI: /apis/node.k8s.io/v1beta1/runtimeclasses/{name}
   */
  async readNodeV1beta1RuntimeClass(params, option) {
    const url = this.baseUrl + `/apis/node.k8s.io/v1beta1/runtimeclasses/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified RuntimeClass
   * operationId: replaceNodeV1beta1RuntimeClass
   * Request URI: /apis/node.k8s.io/v1beta1/runtimeclasses/{name}
   */
  async replaceNodeV1beta1RuntimeClass(params, option) {
    const url = this.baseUrl + `/apis/node.k8s.io/v1beta1/runtimeclasses/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a RuntimeClass
   * operationId: deleteNodeV1beta1RuntimeClass
   * Request URI: /apis/node.k8s.io/v1beta1/runtimeclasses/{name}
   */
  async deleteNodeV1beta1RuntimeClass(params, option) {
    const url = this.baseUrl + `/apis/node.k8s.io/v1beta1/runtimeclasses/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified RuntimeClass
   * operationId: patchNodeV1beta1RuntimeClass
   * Request URI: /apis/node.k8s.io/v1beta1/runtimeclasses/{name}
   */
  async patchNodeV1beta1RuntimeClass(params, option) {
    const url = this.baseUrl + `/apis/node.k8s.io/v1beta1/runtimeclasses/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of RuntimeClass. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchNodeV1beta1RuntimeClassList
   * Request URI: /apis/node.k8s.io/v1beta1/watch/runtimeclasses
   */
  async watchNodeV1beta1RuntimeClassList(params, option) {
    const url = this.baseUrl + `/apis/node.k8s.io/v1beta1/watch/runtimeclasses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind RuntimeClass. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchNodeV1beta1RuntimeClass
   * Request URI: /apis/node.k8s.io/v1beta1/watch/runtimeclasses/{name}
   */
  async watchNodeV1beta1RuntimeClass(params, option) {
    const url = this.baseUrl + `/apis/node.k8s.io/v1beta1/watch/runtimeclasses/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get information of a group
   * operationId: getPolicyAPIGroup
   * Request URI: /apis/policy/
   */
  async getPolicyAPIGroup(params, option) {
    const url = this.baseUrl + `/apis/policy/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getPolicyV1beta1APIResources
   * Request URI: /apis/policy/v1beta1/
   */
  async getPolicyV1beta1APIResources(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind PodDisruptionBudget
   * operationId: listPolicyV1beta1NamespacedPodDisruptionBudget
   * Request URI: /apis/policy/v1beta1/namespaces/{namespace}/poddisruptionbudgets
   */
  async listPolicyV1beta1NamespacedPodDisruptionBudget(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/namespaces/${params.parameter.namespace}/poddisruptionbudgets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a PodDisruptionBudget
   * operationId: createPolicyV1beta1NamespacedPodDisruptionBudget
   * Request URI: /apis/policy/v1beta1/namespaces/{namespace}/poddisruptionbudgets
   */
  async createPolicyV1beta1NamespacedPodDisruptionBudget(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/namespaces/${params.parameter.namespace}/poddisruptionbudgets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of PodDisruptionBudget
   * operationId: deletePolicyV1beta1CollectionNamespacedPodDisruptionBudget
   * Request URI: /apis/policy/v1beta1/namespaces/{namespace}/poddisruptionbudgets
   */
  async deletePolicyV1beta1CollectionNamespacedPodDisruptionBudget(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/namespaces/${params.parameter.namespace}/poddisruptionbudgets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified PodDisruptionBudget
   * operationId: readPolicyV1beta1NamespacedPodDisruptionBudget
   * Request URI: /apis/policy/v1beta1/namespaces/{namespace}/poddisruptionbudgets/{name}
   */
  async readPolicyV1beta1NamespacedPodDisruptionBudget(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/namespaces/${params.parameter.namespace}/poddisruptionbudgets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified PodDisruptionBudget
   * operationId: replacePolicyV1beta1NamespacedPodDisruptionBudget
   * Request URI: /apis/policy/v1beta1/namespaces/{namespace}/poddisruptionbudgets/{name}
   */
  async replacePolicyV1beta1NamespacedPodDisruptionBudget(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/namespaces/${params.parameter.namespace}/poddisruptionbudgets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a PodDisruptionBudget
   * operationId: deletePolicyV1beta1NamespacedPodDisruptionBudget
   * Request URI: /apis/policy/v1beta1/namespaces/{namespace}/poddisruptionbudgets/{name}
   */
  async deletePolicyV1beta1NamespacedPodDisruptionBudget(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/namespaces/${params.parameter.namespace}/poddisruptionbudgets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified PodDisruptionBudget
   * operationId: patchPolicyV1beta1NamespacedPodDisruptionBudget
   * Request URI: /apis/policy/v1beta1/namespaces/{namespace}/poddisruptionbudgets/{name}
   */
  async patchPolicyV1beta1NamespacedPodDisruptionBudget(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/namespaces/${params.parameter.namespace}/poddisruptionbudgets/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified PodDisruptionBudget
   * operationId: readPolicyV1beta1NamespacedPodDisruptionBudgetStatus
   * Request URI: /apis/policy/v1beta1/namespaces/{namespace}/poddisruptionbudgets/{name}/status
   */
  async readPolicyV1beta1NamespacedPodDisruptionBudgetStatus(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/namespaces/${params.parameter.namespace}/poddisruptionbudgets/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified PodDisruptionBudget
   * operationId: replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus
   * Request URI: /apis/policy/v1beta1/namespaces/{namespace}/poddisruptionbudgets/{name}/status
   */
  async replacePolicyV1beta1NamespacedPodDisruptionBudgetStatus(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/namespaces/${params.parameter.namespace}/poddisruptionbudgets/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified PodDisruptionBudget
   * operationId: patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus
   * Request URI: /apis/policy/v1beta1/namespaces/{namespace}/poddisruptionbudgets/{name}/status
   */
  async patchPolicyV1beta1NamespacedPodDisruptionBudgetStatus(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/namespaces/${params.parameter.namespace}/poddisruptionbudgets/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind PodDisruptionBudget
   * operationId: listPolicyV1beta1PodDisruptionBudgetForAllNamespaces
   * Request URI: /apis/policy/v1beta1/poddisruptionbudgets
   */
  async listPolicyV1beta1PodDisruptionBudgetForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/poddisruptionbudgets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind PodSecurityPolicy
   * operationId: listPolicyV1beta1PodSecurityPolicy
   * Request URI: /apis/policy/v1beta1/podsecuritypolicies
   */
  async listPolicyV1beta1PodSecurityPolicy(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/podsecuritypolicies`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a PodSecurityPolicy
   * operationId: createPolicyV1beta1PodSecurityPolicy
   * Request URI: /apis/policy/v1beta1/podsecuritypolicies
   */
  async createPolicyV1beta1PodSecurityPolicy(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/podsecuritypolicies`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of PodSecurityPolicy
   * operationId: deletePolicyV1beta1CollectionPodSecurityPolicy
   * Request URI: /apis/policy/v1beta1/podsecuritypolicies
   */
  async deletePolicyV1beta1CollectionPodSecurityPolicy(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/podsecuritypolicies`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified PodSecurityPolicy
   * operationId: readPolicyV1beta1PodSecurityPolicy
   * Request URI: /apis/policy/v1beta1/podsecuritypolicies/{name}
   */
  async readPolicyV1beta1PodSecurityPolicy(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/podsecuritypolicies/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified PodSecurityPolicy
   * operationId: replacePolicyV1beta1PodSecurityPolicy
   * Request URI: /apis/policy/v1beta1/podsecuritypolicies/{name}
   */
  async replacePolicyV1beta1PodSecurityPolicy(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/podsecuritypolicies/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a PodSecurityPolicy
   * operationId: deletePolicyV1beta1PodSecurityPolicy
   * Request URI: /apis/policy/v1beta1/podsecuritypolicies/{name}
   */
  async deletePolicyV1beta1PodSecurityPolicy(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/podsecuritypolicies/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified PodSecurityPolicy
   * operationId: patchPolicyV1beta1PodSecurityPolicy
   * Request URI: /apis/policy/v1beta1/podsecuritypolicies/{name}
   */
  async patchPolicyV1beta1PodSecurityPolicy(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/podsecuritypolicies/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of PodDisruptionBudget. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchPolicyV1beta1NamespacedPodDisruptionBudgetList
   * Request URI: /apis/policy/v1beta1/watch/namespaces/{namespace}/poddisruptionbudgets
   */
  async watchPolicyV1beta1NamespacedPodDisruptionBudgetList(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/watch/namespaces/${params.parameter.namespace}/poddisruptionbudgets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind PodDisruptionBudget. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchPolicyV1beta1NamespacedPodDisruptionBudget
   * Request URI: /apis/policy/v1beta1/watch/namespaces/{namespace}/poddisruptionbudgets/{name}
   */
  async watchPolicyV1beta1NamespacedPodDisruptionBudget(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/watch/namespaces/${params.parameter.namespace}/poddisruptionbudgets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of PodDisruptionBudget. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchPolicyV1beta1PodDisruptionBudgetListForAllNamespaces
   * Request URI: /apis/policy/v1beta1/watch/poddisruptionbudgets
   */
  async watchPolicyV1beta1PodDisruptionBudgetListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/watch/poddisruptionbudgets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of PodSecurityPolicy. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchPolicyV1beta1PodSecurityPolicyList
   * Request URI: /apis/policy/v1beta1/watch/podsecuritypolicies
   */
  async watchPolicyV1beta1PodSecurityPolicyList(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/watch/podsecuritypolicies`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind PodSecurityPolicy. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchPolicyV1beta1PodSecurityPolicy
   * Request URI: /apis/policy/v1beta1/watch/podsecuritypolicies/{name}
   */
  async watchPolicyV1beta1PodSecurityPolicy(params, option) {
    const url = this.baseUrl + `/apis/policy/v1beta1/watch/podsecuritypolicies/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get information of a group
   * operationId: getRbacAuthorizationAPIGroup
   * Request URI: /apis/rbac.authorization.k8s.io/
   */
  async getRbacAuthorizationAPIGroup(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getRbacAuthorizationV1APIResources
   * Request URI: /apis/rbac.authorization.k8s.io/v1/
   */
  async getRbacAuthorizationV1APIResources(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind ClusterRoleBinding
   * operationId: listRbacAuthorizationV1ClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterrolebindings
   */
  async listRbacAuthorizationV1ClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/clusterrolebindings`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a ClusterRoleBinding
   * operationId: createRbacAuthorizationV1ClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterrolebindings
   */
  async createRbacAuthorizationV1ClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/clusterrolebindings`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of ClusterRoleBinding
   * operationId: deleteRbacAuthorizationV1CollectionClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterrolebindings
   */
  async deleteRbacAuthorizationV1CollectionClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/clusterrolebindings`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified ClusterRoleBinding
   * operationId: readRbacAuthorizationV1ClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterrolebindings/{name}
   */
  async readRbacAuthorizationV1ClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/clusterrolebindings/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified ClusterRoleBinding
   * operationId: replaceRbacAuthorizationV1ClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterrolebindings/{name}
   */
  async replaceRbacAuthorizationV1ClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/clusterrolebindings/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a ClusterRoleBinding
   * operationId: deleteRbacAuthorizationV1ClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterrolebindings/{name}
   */
  async deleteRbacAuthorizationV1ClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/clusterrolebindings/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified ClusterRoleBinding
   * operationId: patchRbacAuthorizationV1ClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterrolebindings/{name}
   */
  async patchRbacAuthorizationV1ClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/clusterrolebindings/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind ClusterRole
   * operationId: listRbacAuthorizationV1ClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterroles
   */
  async listRbacAuthorizationV1ClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/clusterroles`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a ClusterRole
   * operationId: createRbacAuthorizationV1ClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterroles
   */
  async createRbacAuthorizationV1ClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/clusterroles`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of ClusterRole
   * operationId: deleteRbacAuthorizationV1CollectionClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterroles
   */
  async deleteRbacAuthorizationV1CollectionClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/clusterroles`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified ClusterRole
   * operationId: readRbacAuthorizationV1ClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterroles/{name}
   */
  async readRbacAuthorizationV1ClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/clusterroles/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified ClusterRole
   * operationId: replaceRbacAuthorizationV1ClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterroles/{name}
   */
  async replaceRbacAuthorizationV1ClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/clusterroles/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a ClusterRole
   * operationId: deleteRbacAuthorizationV1ClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterroles/{name}
   */
  async deleteRbacAuthorizationV1ClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/clusterroles/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified ClusterRole
   * operationId: patchRbacAuthorizationV1ClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterroles/{name}
   */
  async patchRbacAuthorizationV1ClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/clusterroles/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind RoleBinding
   * operationId: listRbacAuthorizationV1NamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/rolebindings
   */
  async listRbacAuthorizationV1NamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/namespaces/${params.parameter.namespace}/rolebindings`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a RoleBinding
   * operationId: createRbacAuthorizationV1NamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/rolebindings
   */
  async createRbacAuthorizationV1NamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/namespaces/${params.parameter.namespace}/rolebindings`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of RoleBinding
   * operationId: deleteRbacAuthorizationV1CollectionNamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/rolebindings
   */
  async deleteRbacAuthorizationV1CollectionNamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/namespaces/${params.parameter.namespace}/rolebindings`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified RoleBinding
   * operationId: readRbacAuthorizationV1NamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/rolebindings/{name}
   */
  async readRbacAuthorizationV1NamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/namespaces/${params.parameter.namespace}/rolebindings/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified RoleBinding
   * operationId: replaceRbacAuthorizationV1NamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/rolebindings/{name}
   */
  async replaceRbacAuthorizationV1NamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/namespaces/${params.parameter.namespace}/rolebindings/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a RoleBinding
   * operationId: deleteRbacAuthorizationV1NamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/rolebindings/{name}
   */
  async deleteRbacAuthorizationV1NamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/namespaces/${params.parameter.namespace}/rolebindings/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified RoleBinding
   * operationId: patchRbacAuthorizationV1NamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/rolebindings/{name}
   */
  async patchRbacAuthorizationV1NamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/namespaces/${params.parameter.namespace}/rolebindings/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Role
   * operationId: listRbacAuthorizationV1NamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/roles
   */
  async listRbacAuthorizationV1NamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/namespaces/${params.parameter.namespace}/roles`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a Role
   * operationId: createRbacAuthorizationV1NamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/roles
   */
  async createRbacAuthorizationV1NamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/namespaces/${params.parameter.namespace}/roles`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of Role
   * operationId: deleteRbacAuthorizationV1CollectionNamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/roles
   */
  async deleteRbacAuthorizationV1CollectionNamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/namespaces/${params.parameter.namespace}/roles`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified Role
   * operationId: readRbacAuthorizationV1NamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/roles/{name}
   */
  async readRbacAuthorizationV1NamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/namespaces/${params.parameter.namespace}/roles/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified Role
   * operationId: replaceRbacAuthorizationV1NamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/roles/{name}
   */
  async replaceRbacAuthorizationV1NamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/namespaces/${params.parameter.namespace}/roles/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a Role
   * operationId: deleteRbacAuthorizationV1NamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/roles/{name}
   */
  async deleteRbacAuthorizationV1NamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/namespaces/${params.parameter.namespace}/roles/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified Role
   * operationId: patchRbacAuthorizationV1NamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/roles/{name}
   */
  async patchRbacAuthorizationV1NamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/namespaces/${params.parameter.namespace}/roles/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind RoleBinding
   * operationId: listRbacAuthorizationV1RoleBindingForAllNamespaces
   * Request URI: /apis/rbac.authorization.k8s.io/v1/rolebindings
   */
  async listRbacAuthorizationV1RoleBindingForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/rolebindings`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Role
   * operationId: listRbacAuthorizationV1RoleForAllNamespaces
   * Request URI: /apis/rbac.authorization.k8s.io/v1/roles
   */
  async listRbacAuthorizationV1RoleForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/roles`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ClusterRoleBinding. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchRbacAuthorizationV1ClusterRoleBindingList
   * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/clusterrolebindings
   */
  async watchRbacAuthorizationV1ClusterRoleBindingList(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/watch/clusterrolebindings`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind ClusterRoleBinding. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchRbacAuthorizationV1ClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/clusterrolebindings/{name}
   */
  async watchRbacAuthorizationV1ClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/watch/clusterrolebindings/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ClusterRole. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchRbacAuthorizationV1ClusterRoleList
   * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/clusterroles
   */
  async watchRbacAuthorizationV1ClusterRoleList(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/watch/clusterroles`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind ClusterRole. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchRbacAuthorizationV1ClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/clusterroles/{name}
   */
  async watchRbacAuthorizationV1ClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/watch/clusterroles/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of RoleBinding. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchRbacAuthorizationV1NamespacedRoleBindingList
   * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/namespaces/{namespace}/rolebindings
   */
  async watchRbacAuthorizationV1NamespacedRoleBindingList(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/watch/namespaces/${params.parameter.namespace}/rolebindings`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind RoleBinding. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchRbacAuthorizationV1NamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/namespaces/{namespace}/rolebindings/{name}
   */
  async watchRbacAuthorizationV1NamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/watch/namespaces/${params.parameter.namespace}/rolebindings/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Role. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchRbacAuthorizationV1NamespacedRoleList
   * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/namespaces/{namespace}/roles
   */
  async watchRbacAuthorizationV1NamespacedRoleList(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/watch/namespaces/${params.parameter.namespace}/roles`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind Role. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchRbacAuthorizationV1NamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/namespaces/{namespace}/roles/{name}
   */
  async watchRbacAuthorizationV1NamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/watch/namespaces/${params.parameter.namespace}/roles/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of RoleBinding. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchRbacAuthorizationV1RoleBindingListForAllNamespaces
   * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/rolebindings
   */
  async watchRbacAuthorizationV1RoleBindingListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/watch/rolebindings`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Role. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchRbacAuthorizationV1RoleListForAllNamespaces
   * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/roles
   */
  async watchRbacAuthorizationV1RoleListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1/watch/roles`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getRbacAuthorizationV1alpha1APIResources
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/
   */
  async getRbacAuthorizationV1alpha1APIResources(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind ClusterRoleBinding
   * operationId: listRbacAuthorizationV1alpha1ClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/clusterrolebindings
   */
  async listRbacAuthorizationV1alpha1ClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/clusterrolebindings`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a ClusterRoleBinding
   * operationId: createRbacAuthorizationV1alpha1ClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/clusterrolebindings
   */
  async createRbacAuthorizationV1alpha1ClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/clusterrolebindings`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of ClusterRoleBinding
   * operationId: deleteRbacAuthorizationV1alpha1CollectionClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/clusterrolebindings
   */
  async deleteRbacAuthorizationV1alpha1CollectionClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/clusterrolebindings`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified ClusterRoleBinding
   * operationId: readRbacAuthorizationV1alpha1ClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/clusterrolebindings/{name}
   */
  async readRbacAuthorizationV1alpha1ClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/clusterrolebindings/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified ClusterRoleBinding
   * operationId: replaceRbacAuthorizationV1alpha1ClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/clusterrolebindings/{name}
   */
  async replaceRbacAuthorizationV1alpha1ClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/clusterrolebindings/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a ClusterRoleBinding
   * operationId: deleteRbacAuthorizationV1alpha1ClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/clusterrolebindings/{name}
   */
  async deleteRbacAuthorizationV1alpha1ClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/clusterrolebindings/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified ClusterRoleBinding
   * operationId: patchRbacAuthorizationV1alpha1ClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/clusterrolebindings/{name}
   */
  async patchRbacAuthorizationV1alpha1ClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/clusterrolebindings/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind ClusterRole
   * operationId: listRbacAuthorizationV1alpha1ClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/clusterroles
   */
  async listRbacAuthorizationV1alpha1ClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/clusterroles`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a ClusterRole
   * operationId: createRbacAuthorizationV1alpha1ClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/clusterroles
   */
  async createRbacAuthorizationV1alpha1ClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/clusterroles`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of ClusterRole
   * operationId: deleteRbacAuthorizationV1alpha1CollectionClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/clusterroles
   */
  async deleteRbacAuthorizationV1alpha1CollectionClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/clusterroles`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified ClusterRole
   * operationId: readRbacAuthorizationV1alpha1ClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/clusterroles/{name}
   */
  async readRbacAuthorizationV1alpha1ClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/clusterroles/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified ClusterRole
   * operationId: replaceRbacAuthorizationV1alpha1ClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/clusterroles/{name}
   */
  async replaceRbacAuthorizationV1alpha1ClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/clusterroles/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a ClusterRole
   * operationId: deleteRbacAuthorizationV1alpha1ClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/clusterroles/{name}
   */
  async deleteRbacAuthorizationV1alpha1ClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/clusterroles/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified ClusterRole
   * operationId: patchRbacAuthorizationV1alpha1ClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/clusterroles/{name}
   */
  async patchRbacAuthorizationV1alpha1ClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/clusterroles/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind RoleBinding
   * operationId: listRbacAuthorizationV1alpha1NamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/namespaces/{namespace}/rolebindings
   */
  async listRbacAuthorizationV1alpha1NamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/rolebindings`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a RoleBinding
   * operationId: createRbacAuthorizationV1alpha1NamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/namespaces/{namespace}/rolebindings
   */
  async createRbacAuthorizationV1alpha1NamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/rolebindings`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of RoleBinding
   * operationId: deleteRbacAuthorizationV1alpha1CollectionNamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/namespaces/{namespace}/rolebindings
   */
  async deleteRbacAuthorizationV1alpha1CollectionNamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/rolebindings`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified RoleBinding
   * operationId: readRbacAuthorizationV1alpha1NamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/namespaces/{namespace}/rolebindings/{name}
   */
  async readRbacAuthorizationV1alpha1NamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/rolebindings/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified RoleBinding
   * operationId: replaceRbacAuthorizationV1alpha1NamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/namespaces/{namespace}/rolebindings/{name}
   */
  async replaceRbacAuthorizationV1alpha1NamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/rolebindings/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a RoleBinding
   * operationId: deleteRbacAuthorizationV1alpha1NamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/namespaces/{namespace}/rolebindings/{name}
   */
  async deleteRbacAuthorizationV1alpha1NamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/rolebindings/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified RoleBinding
   * operationId: patchRbacAuthorizationV1alpha1NamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/namespaces/{namespace}/rolebindings/{name}
   */
  async patchRbacAuthorizationV1alpha1NamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/rolebindings/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Role
   * operationId: listRbacAuthorizationV1alpha1NamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/namespaces/{namespace}/roles
   */
  async listRbacAuthorizationV1alpha1NamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/roles`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a Role
   * operationId: createRbacAuthorizationV1alpha1NamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/namespaces/{namespace}/roles
   */
  async createRbacAuthorizationV1alpha1NamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/roles`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of Role
   * operationId: deleteRbacAuthorizationV1alpha1CollectionNamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/namespaces/{namespace}/roles
   */
  async deleteRbacAuthorizationV1alpha1CollectionNamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/roles`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified Role
   * operationId: readRbacAuthorizationV1alpha1NamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/namespaces/{namespace}/roles/{name}
   */
  async readRbacAuthorizationV1alpha1NamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/roles/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified Role
   * operationId: replaceRbacAuthorizationV1alpha1NamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/namespaces/{namespace}/roles/{name}
   */
  async replaceRbacAuthorizationV1alpha1NamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/roles/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a Role
   * operationId: deleteRbacAuthorizationV1alpha1NamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/namespaces/{namespace}/roles/{name}
   */
  async deleteRbacAuthorizationV1alpha1NamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/roles/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified Role
   * operationId: patchRbacAuthorizationV1alpha1NamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/namespaces/{namespace}/roles/{name}
   */
  async patchRbacAuthorizationV1alpha1NamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/roles/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind RoleBinding
   * operationId: listRbacAuthorizationV1alpha1RoleBindingForAllNamespaces
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/rolebindings
   */
  async listRbacAuthorizationV1alpha1RoleBindingForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/rolebindings`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Role
   * operationId: listRbacAuthorizationV1alpha1RoleForAllNamespaces
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/roles
   */
  async listRbacAuthorizationV1alpha1RoleForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/roles`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ClusterRoleBinding. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchRbacAuthorizationV1alpha1ClusterRoleBindingList
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/watch/clusterrolebindings
   */
  async watchRbacAuthorizationV1alpha1ClusterRoleBindingList(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/watch/clusterrolebindings`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind ClusterRoleBinding. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchRbacAuthorizationV1alpha1ClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/watch/clusterrolebindings/{name}
   */
  async watchRbacAuthorizationV1alpha1ClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/watch/clusterrolebindings/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ClusterRole. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchRbacAuthorizationV1alpha1ClusterRoleList
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/watch/clusterroles
   */
  async watchRbacAuthorizationV1alpha1ClusterRoleList(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/watch/clusterroles`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind ClusterRole. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchRbacAuthorizationV1alpha1ClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/watch/clusterroles/{name}
   */
  async watchRbacAuthorizationV1alpha1ClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/watch/clusterroles/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of RoleBinding. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchRbacAuthorizationV1alpha1NamespacedRoleBindingList
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/watch/namespaces/{namespace}/rolebindings
   */
  async watchRbacAuthorizationV1alpha1NamespacedRoleBindingList(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/watch/namespaces/${params.parameter.namespace}/rolebindings`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind RoleBinding. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchRbacAuthorizationV1alpha1NamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/watch/namespaces/{namespace}/rolebindings/{name}
   */
  async watchRbacAuthorizationV1alpha1NamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/watch/namespaces/${params.parameter.namespace}/rolebindings/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Role. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchRbacAuthorizationV1alpha1NamespacedRoleList
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/watch/namespaces/{namespace}/roles
   */
  async watchRbacAuthorizationV1alpha1NamespacedRoleList(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/watch/namespaces/${params.parameter.namespace}/roles`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind Role. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchRbacAuthorizationV1alpha1NamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/watch/namespaces/{namespace}/roles/{name}
   */
  async watchRbacAuthorizationV1alpha1NamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/watch/namespaces/${params.parameter.namespace}/roles/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of RoleBinding. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchRbacAuthorizationV1alpha1RoleBindingListForAllNamespaces
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/watch/rolebindings
   */
  async watchRbacAuthorizationV1alpha1RoleBindingListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/watch/rolebindings`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Role. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchRbacAuthorizationV1alpha1RoleListForAllNamespaces
   * Request URI: /apis/rbac.authorization.k8s.io/v1alpha1/watch/roles
   */
  async watchRbacAuthorizationV1alpha1RoleListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1alpha1/watch/roles`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getRbacAuthorizationV1beta1APIResources
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/
   */
  async getRbacAuthorizationV1beta1APIResources(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind ClusterRoleBinding
   * operationId: listRbacAuthorizationV1beta1ClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/clusterrolebindings
   */
  async listRbacAuthorizationV1beta1ClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/clusterrolebindings`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a ClusterRoleBinding
   * operationId: createRbacAuthorizationV1beta1ClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/clusterrolebindings
   */
  async createRbacAuthorizationV1beta1ClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/clusterrolebindings`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of ClusterRoleBinding
   * operationId: deleteRbacAuthorizationV1beta1CollectionClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/clusterrolebindings
   */
  async deleteRbacAuthorizationV1beta1CollectionClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/clusterrolebindings`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified ClusterRoleBinding
   * operationId: readRbacAuthorizationV1beta1ClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/clusterrolebindings/{name}
   */
  async readRbacAuthorizationV1beta1ClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/clusterrolebindings/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified ClusterRoleBinding
   * operationId: replaceRbacAuthorizationV1beta1ClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/clusterrolebindings/{name}
   */
  async replaceRbacAuthorizationV1beta1ClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/clusterrolebindings/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a ClusterRoleBinding
   * operationId: deleteRbacAuthorizationV1beta1ClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/clusterrolebindings/{name}
   */
  async deleteRbacAuthorizationV1beta1ClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/clusterrolebindings/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified ClusterRoleBinding
   * operationId: patchRbacAuthorizationV1beta1ClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/clusterrolebindings/{name}
   */
  async patchRbacAuthorizationV1beta1ClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/clusterrolebindings/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind ClusterRole
   * operationId: listRbacAuthorizationV1beta1ClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/clusterroles
   */
  async listRbacAuthorizationV1beta1ClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/clusterroles`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a ClusterRole
   * operationId: createRbacAuthorizationV1beta1ClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/clusterroles
   */
  async createRbacAuthorizationV1beta1ClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/clusterroles`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of ClusterRole
   * operationId: deleteRbacAuthorizationV1beta1CollectionClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/clusterroles
   */
  async deleteRbacAuthorizationV1beta1CollectionClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/clusterroles`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified ClusterRole
   * operationId: readRbacAuthorizationV1beta1ClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/clusterroles/{name}
   */
  async readRbacAuthorizationV1beta1ClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/clusterroles/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified ClusterRole
   * operationId: replaceRbacAuthorizationV1beta1ClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/clusterroles/{name}
   */
  async replaceRbacAuthorizationV1beta1ClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/clusterroles/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a ClusterRole
   * operationId: deleteRbacAuthorizationV1beta1ClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/clusterroles/{name}
   */
  async deleteRbacAuthorizationV1beta1ClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/clusterroles/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified ClusterRole
   * operationId: patchRbacAuthorizationV1beta1ClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/clusterroles/{name}
   */
  async patchRbacAuthorizationV1beta1ClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/clusterroles/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind RoleBinding
   * operationId: listRbacAuthorizationV1beta1NamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/namespaces/{namespace}/rolebindings
   */
  async listRbacAuthorizationV1beta1NamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/rolebindings`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a RoleBinding
   * operationId: createRbacAuthorizationV1beta1NamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/namespaces/{namespace}/rolebindings
   */
  async createRbacAuthorizationV1beta1NamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/rolebindings`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of RoleBinding
   * operationId: deleteRbacAuthorizationV1beta1CollectionNamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/namespaces/{namespace}/rolebindings
   */
  async deleteRbacAuthorizationV1beta1CollectionNamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/rolebindings`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified RoleBinding
   * operationId: readRbacAuthorizationV1beta1NamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/namespaces/{namespace}/rolebindings/{name}
   */
  async readRbacAuthorizationV1beta1NamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/rolebindings/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified RoleBinding
   * operationId: replaceRbacAuthorizationV1beta1NamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/namespaces/{namespace}/rolebindings/{name}
   */
  async replaceRbacAuthorizationV1beta1NamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/rolebindings/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a RoleBinding
   * operationId: deleteRbacAuthorizationV1beta1NamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/namespaces/{namespace}/rolebindings/{name}
   */
  async deleteRbacAuthorizationV1beta1NamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/rolebindings/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified RoleBinding
   * operationId: patchRbacAuthorizationV1beta1NamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/namespaces/{namespace}/rolebindings/{name}
   */
  async patchRbacAuthorizationV1beta1NamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/rolebindings/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Role
   * operationId: listRbacAuthorizationV1beta1NamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/namespaces/{namespace}/roles
   */
  async listRbacAuthorizationV1beta1NamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/roles`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a Role
   * operationId: createRbacAuthorizationV1beta1NamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/namespaces/{namespace}/roles
   */
  async createRbacAuthorizationV1beta1NamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/roles`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of Role
   * operationId: deleteRbacAuthorizationV1beta1CollectionNamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/namespaces/{namespace}/roles
   */
  async deleteRbacAuthorizationV1beta1CollectionNamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/roles`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified Role
   * operationId: readRbacAuthorizationV1beta1NamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/namespaces/{namespace}/roles/{name}
   */
  async readRbacAuthorizationV1beta1NamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/roles/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified Role
   * operationId: replaceRbacAuthorizationV1beta1NamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/namespaces/{namespace}/roles/{name}
   */
  async replaceRbacAuthorizationV1beta1NamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/roles/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a Role
   * operationId: deleteRbacAuthorizationV1beta1NamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/namespaces/{namespace}/roles/{name}
   */
  async deleteRbacAuthorizationV1beta1NamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/roles/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified Role
   * operationId: patchRbacAuthorizationV1beta1NamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/namespaces/{namespace}/roles/{name}
   */
  async patchRbacAuthorizationV1beta1NamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/namespaces/${params.parameter.namespace}/roles/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind RoleBinding
   * operationId: listRbacAuthorizationV1beta1RoleBindingForAllNamespaces
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/rolebindings
   */
  async listRbacAuthorizationV1beta1RoleBindingForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/rolebindings`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind Role
   * operationId: listRbacAuthorizationV1beta1RoleForAllNamespaces
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/roles
   */
  async listRbacAuthorizationV1beta1RoleForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/roles`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ClusterRoleBinding. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchRbacAuthorizationV1beta1ClusterRoleBindingList
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/watch/clusterrolebindings
   */
  async watchRbacAuthorizationV1beta1ClusterRoleBindingList(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/watch/clusterrolebindings`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind ClusterRoleBinding. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchRbacAuthorizationV1beta1ClusterRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/watch/clusterrolebindings/{name}
   */
  async watchRbacAuthorizationV1beta1ClusterRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/watch/clusterrolebindings/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of ClusterRole. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchRbacAuthorizationV1beta1ClusterRoleList
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/watch/clusterroles
   */
  async watchRbacAuthorizationV1beta1ClusterRoleList(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/watch/clusterroles`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind ClusterRole. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchRbacAuthorizationV1beta1ClusterRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/watch/clusterroles/{name}
   */
  async watchRbacAuthorizationV1beta1ClusterRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/watch/clusterroles/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of RoleBinding. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchRbacAuthorizationV1beta1NamespacedRoleBindingList
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/watch/namespaces/{namespace}/rolebindings
   */
  async watchRbacAuthorizationV1beta1NamespacedRoleBindingList(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/watch/namespaces/${params.parameter.namespace}/rolebindings`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind RoleBinding. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchRbacAuthorizationV1beta1NamespacedRoleBinding
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/watch/namespaces/{namespace}/rolebindings/{name}
   */
  async watchRbacAuthorizationV1beta1NamespacedRoleBinding(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/watch/namespaces/${params.parameter.namespace}/rolebindings/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Role. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchRbacAuthorizationV1beta1NamespacedRoleList
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/watch/namespaces/{namespace}/roles
   */
  async watchRbacAuthorizationV1beta1NamespacedRoleList(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/watch/namespaces/${params.parameter.namespace}/roles`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind Role. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchRbacAuthorizationV1beta1NamespacedRole
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/watch/namespaces/{namespace}/roles/{name}
   */
  async watchRbacAuthorizationV1beta1NamespacedRole(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/watch/namespaces/${params.parameter.namespace}/roles/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of RoleBinding. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchRbacAuthorizationV1beta1RoleBindingListForAllNamespaces
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/watch/rolebindings
   */
  async watchRbacAuthorizationV1beta1RoleBindingListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/watch/rolebindings`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of Role. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchRbacAuthorizationV1beta1RoleListForAllNamespaces
   * Request URI: /apis/rbac.authorization.k8s.io/v1beta1/watch/roles
   */
  async watchRbacAuthorizationV1beta1RoleListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/rbac.authorization.k8s.io/v1beta1/watch/roles`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get information of a group
   * operationId: getSchedulingAPIGroup
   * Request URI: /apis/scheduling.k8s.io/
   */
  async getSchedulingAPIGroup(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getSchedulingV1APIResources
   * Request URI: /apis/scheduling.k8s.io/v1/
   */
  async getSchedulingV1APIResources(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind PriorityClass
   * operationId: listSchedulingV1PriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1/priorityclasses
   */
  async listSchedulingV1PriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1/priorityclasses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a PriorityClass
   * operationId: createSchedulingV1PriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1/priorityclasses
   */
  async createSchedulingV1PriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1/priorityclasses`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of PriorityClass
   * operationId: deleteSchedulingV1CollectionPriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1/priorityclasses
   */
  async deleteSchedulingV1CollectionPriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1/priorityclasses`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified PriorityClass
   * operationId: readSchedulingV1PriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1/priorityclasses/{name}
   */
  async readSchedulingV1PriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1/priorityclasses/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified PriorityClass
   * operationId: replaceSchedulingV1PriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1/priorityclasses/{name}
   */
  async replaceSchedulingV1PriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1/priorityclasses/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a PriorityClass
   * operationId: deleteSchedulingV1PriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1/priorityclasses/{name}
   */
  async deleteSchedulingV1PriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1/priorityclasses/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified PriorityClass
   * operationId: patchSchedulingV1PriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1/priorityclasses/{name}
   */
  async patchSchedulingV1PriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1/priorityclasses/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of PriorityClass. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchSchedulingV1PriorityClassList
   * Request URI: /apis/scheduling.k8s.io/v1/watch/priorityclasses
   */
  async watchSchedulingV1PriorityClassList(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1/watch/priorityclasses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind PriorityClass. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchSchedulingV1PriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1/watch/priorityclasses/{name}
   */
  async watchSchedulingV1PriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1/watch/priorityclasses/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getSchedulingV1alpha1APIResources
   * Request URI: /apis/scheduling.k8s.io/v1alpha1/
   */
  async getSchedulingV1alpha1APIResources(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1alpha1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind PriorityClass
   * operationId: listSchedulingV1alpha1PriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1alpha1/priorityclasses
   */
  async listSchedulingV1alpha1PriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1alpha1/priorityclasses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a PriorityClass
   * operationId: createSchedulingV1alpha1PriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1alpha1/priorityclasses
   */
  async createSchedulingV1alpha1PriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1alpha1/priorityclasses`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of PriorityClass
   * operationId: deleteSchedulingV1alpha1CollectionPriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1alpha1/priorityclasses
   */
  async deleteSchedulingV1alpha1CollectionPriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1alpha1/priorityclasses`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified PriorityClass
   * operationId: readSchedulingV1alpha1PriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1alpha1/priorityclasses/{name}
   */
  async readSchedulingV1alpha1PriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1alpha1/priorityclasses/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified PriorityClass
   * operationId: replaceSchedulingV1alpha1PriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1alpha1/priorityclasses/{name}
   */
  async replaceSchedulingV1alpha1PriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1alpha1/priorityclasses/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a PriorityClass
   * operationId: deleteSchedulingV1alpha1PriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1alpha1/priorityclasses/{name}
   */
  async deleteSchedulingV1alpha1PriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1alpha1/priorityclasses/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified PriorityClass
   * operationId: patchSchedulingV1alpha1PriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1alpha1/priorityclasses/{name}
   */
  async patchSchedulingV1alpha1PriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1alpha1/priorityclasses/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of PriorityClass. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchSchedulingV1alpha1PriorityClassList
   * Request URI: /apis/scheduling.k8s.io/v1alpha1/watch/priorityclasses
   */
  async watchSchedulingV1alpha1PriorityClassList(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1alpha1/watch/priorityclasses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind PriorityClass. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchSchedulingV1alpha1PriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1alpha1/watch/priorityclasses/{name}
   */
  async watchSchedulingV1alpha1PriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1alpha1/watch/priorityclasses/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getSchedulingV1beta1APIResources
   * Request URI: /apis/scheduling.k8s.io/v1beta1/
   */
  async getSchedulingV1beta1APIResources(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1beta1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind PriorityClass
   * operationId: listSchedulingV1beta1PriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1beta1/priorityclasses
   */
  async listSchedulingV1beta1PriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1beta1/priorityclasses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a PriorityClass
   * operationId: createSchedulingV1beta1PriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1beta1/priorityclasses
   */
  async createSchedulingV1beta1PriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1beta1/priorityclasses`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of PriorityClass
   * operationId: deleteSchedulingV1beta1CollectionPriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1beta1/priorityclasses
   */
  async deleteSchedulingV1beta1CollectionPriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1beta1/priorityclasses`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified PriorityClass
   * operationId: readSchedulingV1beta1PriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1beta1/priorityclasses/{name}
   */
  async readSchedulingV1beta1PriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1beta1/priorityclasses/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified PriorityClass
   * operationId: replaceSchedulingV1beta1PriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1beta1/priorityclasses/{name}
   */
  async replaceSchedulingV1beta1PriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1beta1/priorityclasses/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a PriorityClass
   * operationId: deleteSchedulingV1beta1PriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1beta1/priorityclasses/{name}
   */
  async deleteSchedulingV1beta1PriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1beta1/priorityclasses/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified PriorityClass
   * operationId: patchSchedulingV1beta1PriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1beta1/priorityclasses/{name}
   */
  async patchSchedulingV1beta1PriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1beta1/priorityclasses/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of PriorityClass. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchSchedulingV1beta1PriorityClassList
   * Request URI: /apis/scheduling.k8s.io/v1beta1/watch/priorityclasses
   */
  async watchSchedulingV1beta1PriorityClassList(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1beta1/watch/priorityclasses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind PriorityClass. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchSchedulingV1beta1PriorityClass
   * Request URI: /apis/scheduling.k8s.io/v1beta1/watch/priorityclasses/{name}
   */
  async watchSchedulingV1beta1PriorityClass(params, option) {
    const url = this.baseUrl + `/apis/scheduling.k8s.io/v1beta1/watch/priorityclasses/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get information of a group
   * operationId: getSettingsAPIGroup
   * Request URI: /apis/settings.k8s.io/
   */
  async getSettingsAPIGroup(params, option) {
    const url = this.baseUrl + `/apis/settings.k8s.io/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getSettingsV1alpha1APIResources
   * Request URI: /apis/settings.k8s.io/v1alpha1/
   */
  async getSettingsV1alpha1APIResources(params, option) {
    const url = this.baseUrl + `/apis/settings.k8s.io/v1alpha1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind PodPreset
   * operationId: listSettingsV1alpha1NamespacedPodPreset
   * Request URI: /apis/settings.k8s.io/v1alpha1/namespaces/{namespace}/podpresets
   */
  async listSettingsV1alpha1NamespacedPodPreset(params, option) {
    const url = this.baseUrl + `/apis/settings.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/podpresets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a PodPreset
   * operationId: createSettingsV1alpha1NamespacedPodPreset
   * Request URI: /apis/settings.k8s.io/v1alpha1/namespaces/{namespace}/podpresets
   */
  async createSettingsV1alpha1NamespacedPodPreset(params, option) {
    const url = this.baseUrl + `/apis/settings.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/podpresets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of PodPreset
   * operationId: deleteSettingsV1alpha1CollectionNamespacedPodPreset
   * Request URI: /apis/settings.k8s.io/v1alpha1/namespaces/{namespace}/podpresets
   */
  async deleteSettingsV1alpha1CollectionNamespacedPodPreset(params, option) {
    const url = this.baseUrl + `/apis/settings.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/podpresets`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified PodPreset
   * operationId: readSettingsV1alpha1NamespacedPodPreset
   * Request URI: /apis/settings.k8s.io/v1alpha1/namespaces/{namespace}/podpresets/{name}
   */
  async readSettingsV1alpha1NamespacedPodPreset(params, option) {
    const url = this.baseUrl + `/apis/settings.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/podpresets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified PodPreset
   * operationId: replaceSettingsV1alpha1NamespacedPodPreset
   * Request URI: /apis/settings.k8s.io/v1alpha1/namespaces/{namespace}/podpresets/{name}
   */
  async replaceSettingsV1alpha1NamespacedPodPreset(params, option) {
    const url = this.baseUrl + `/apis/settings.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/podpresets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a PodPreset
   * operationId: deleteSettingsV1alpha1NamespacedPodPreset
   * Request URI: /apis/settings.k8s.io/v1alpha1/namespaces/{namespace}/podpresets/{name}
   */
  async deleteSettingsV1alpha1NamespacedPodPreset(params, option) {
    const url = this.baseUrl + `/apis/settings.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/podpresets/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified PodPreset
   * operationId: patchSettingsV1alpha1NamespacedPodPreset
   * Request URI: /apis/settings.k8s.io/v1alpha1/namespaces/{namespace}/podpresets/{name}
   */
  async patchSettingsV1alpha1NamespacedPodPreset(params, option) {
    const url = this.baseUrl + `/apis/settings.k8s.io/v1alpha1/namespaces/${params.parameter.namespace}/podpresets/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind PodPreset
   * operationId: listSettingsV1alpha1PodPresetForAllNamespaces
   * Request URI: /apis/settings.k8s.io/v1alpha1/podpresets
   */
  async listSettingsV1alpha1PodPresetForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/settings.k8s.io/v1alpha1/podpresets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of PodPreset. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchSettingsV1alpha1NamespacedPodPresetList
   * Request URI: /apis/settings.k8s.io/v1alpha1/watch/namespaces/{namespace}/podpresets
   */
  async watchSettingsV1alpha1NamespacedPodPresetList(params, option) {
    const url = this.baseUrl + `/apis/settings.k8s.io/v1alpha1/watch/namespaces/${params.parameter.namespace}/podpresets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind PodPreset. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchSettingsV1alpha1NamespacedPodPreset
   * Request URI: /apis/settings.k8s.io/v1alpha1/watch/namespaces/{namespace}/podpresets/{name}
   */
  async watchSettingsV1alpha1NamespacedPodPreset(params, option) {
    const url = this.baseUrl + `/apis/settings.k8s.io/v1alpha1/watch/namespaces/${params.parameter.namespace}/podpresets/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of PodPreset. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchSettingsV1alpha1PodPresetListForAllNamespaces
   * Request URI: /apis/settings.k8s.io/v1alpha1/watch/podpresets
   */
  async watchSettingsV1alpha1PodPresetListForAllNamespaces(params, option) {
    const url = this.baseUrl + `/apis/settings.k8s.io/v1alpha1/watch/podpresets`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get information of a group
   * operationId: getStorageAPIGroup
   * Request URI: /apis/storage.k8s.io/
   */
  async getStorageAPIGroup(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getStorageV1APIResources
   * Request URI: /apis/storage.k8s.io/v1/
   */
  async getStorageV1APIResources(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind StorageClass
   * operationId: listStorageV1StorageClass
   * Request URI: /apis/storage.k8s.io/v1/storageclasses
   */
  async listStorageV1StorageClass(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1/storageclasses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a StorageClass
   * operationId: createStorageV1StorageClass
   * Request URI: /apis/storage.k8s.io/v1/storageclasses
   */
  async createStorageV1StorageClass(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1/storageclasses`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of StorageClass
   * operationId: deleteStorageV1CollectionStorageClass
   * Request URI: /apis/storage.k8s.io/v1/storageclasses
   */
  async deleteStorageV1CollectionStorageClass(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1/storageclasses`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified StorageClass
   * operationId: readStorageV1StorageClass
   * Request URI: /apis/storage.k8s.io/v1/storageclasses/{name}
   */
  async readStorageV1StorageClass(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1/storageclasses/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified StorageClass
   * operationId: replaceStorageV1StorageClass
   * Request URI: /apis/storage.k8s.io/v1/storageclasses/{name}
   */
  async replaceStorageV1StorageClass(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1/storageclasses/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a StorageClass
   * operationId: deleteStorageV1StorageClass
   * Request URI: /apis/storage.k8s.io/v1/storageclasses/{name}
   */
  async deleteStorageV1StorageClass(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1/storageclasses/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified StorageClass
   * operationId: patchStorageV1StorageClass
   * Request URI: /apis/storage.k8s.io/v1/storageclasses/{name}
   */
  async patchStorageV1StorageClass(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1/storageclasses/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind VolumeAttachment
   * operationId: listStorageV1VolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1/volumeattachments
   */
  async listStorageV1VolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1/volumeattachments`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a VolumeAttachment
   * operationId: createStorageV1VolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1/volumeattachments
   */
  async createStorageV1VolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1/volumeattachments`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of VolumeAttachment
   * operationId: deleteStorageV1CollectionVolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1/volumeattachments
   */
  async deleteStorageV1CollectionVolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1/volumeattachments`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified VolumeAttachment
   * operationId: readStorageV1VolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1/volumeattachments/{name}
   */
  async readStorageV1VolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1/volumeattachments/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified VolumeAttachment
   * operationId: replaceStorageV1VolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1/volumeattachments/{name}
   */
  async replaceStorageV1VolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1/volumeattachments/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a VolumeAttachment
   * operationId: deleteStorageV1VolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1/volumeattachments/{name}
   */
  async deleteStorageV1VolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1/volumeattachments/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified VolumeAttachment
   * operationId: patchStorageV1VolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1/volumeattachments/{name}
   */
  async patchStorageV1VolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1/volumeattachments/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read status of the specified VolumeAttachment
   * operationId: readStorageV1VolumeAttachmentStatus
   * Request URI: /apis/storage.k8s.io/v1/volumeattachments/{name}/status
   */
  async readStorageV1VolumeAttachmentStatus(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1/volumeattachments/${params.parameter.name}/status`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace status of the specified VolumeAttachment
   * operationId: replaceStorageV1VolumeAttachmentStatus
   * Request URI: /apis/storage.k8s.io/v1/volumeattachments/{name}/status
   */
  async replaceStorageV1VolumeAttachmentStatus(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1/volumeattachments/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update status of the specified VolumeAttachment
   * operationId: patchStorageV1VolumeAttachmentStatus
   * Request URI: /apis/storage.k8s.io/v1/volumeattachments/{name}/status
   */
  async patchStorageV1VolumeAttachmentStatus(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1/volumeattachments/${params.parameter.name}/status`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of StorageClass. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchStorageV1StorageClassList
   * Request URI: /apis/storage.k8s.io/v1/watch/storageclasses
   */
  async watchStorageV1StorageClassList(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1/watch/storageclasses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind StorageClass. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchStorageV1StorageClass
   * Request URI: /apis/storage.k8s.io/v1/watch/storageclasses/{name}
   */
  async watchStorageV1StorageClass(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1/watch/storageclasses/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of VolumeAttachment. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchStorageV1VolumeAttachmentList
   * Request URI: /apis/storage.k8s.io/v1/watch/volumeattachments
   */
  async watchStorageV1VolumeAttachmentList(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1/watch/volumeattachments`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind VolumeAttachment. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchStorageV1VolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1/watch/volumeattachments/{name}
   */
  async watchStorageV1VolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1/watch/volumeattachments/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getStorageV1alpha1APIResources
   * Request URI: /apis/storage.k8s.io/v1alpha1/
   */
  async getStorageV1alpha1APIResources(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1alpha1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind VolumeAttachment
   * operationId: listStorageV1alpha1VolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1alpha1/volumeattachments
   */
  async listStorageV1alpha1VolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1alpha1/volumeattachments`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a VolumeAttachment
   * operationId: createStorageV1alpha1VolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1alpha1/volumeattachments
   */
  async createStorageV1alpha1VolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1alpha1/volumeattachments`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of VolumeAttachment
   * operationId: deleteStorageV1alpha1CollectionVolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1alpha1/volumeattachments
   */
  async deleteStorageV1alpha1CollectionVolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1alpha1/volumeattachments`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified VolumeAttachment
   * operationId: readStorageV1alpha1VolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1alpha1/volumeattachments/{name}
   */
  async readStorageV1alpha1VolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1alpha1/volumeattachments/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified VolumeAttachment
   * operationId: replaceStorageV1alpha1VolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1alpha1/volumeattachments/{name}
   */
  async replaceStorageV1alpha1VolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1alpha1/volumeattachments/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a VolumeAttachment
   * operationId: deleteStorageV1alpha1VolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1alpha1/volumeattachments/{name}
   */
  async deleteStorageV1alpha1VolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1alpha1/volumeattachments/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified VolumeAttachment
   * operationId: patchStorageV1alpha1VolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1alpha1/volumeattachments/{name}
   */
  async patchStorageV1alpha1VolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1alpha1/volumeattachments/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of VolumeAttachment. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchStorageV1alpha1VolumeAttachmentList
   * Request URI: /apis/storage.k8s.io/v1alpha1/watch/volumeattachments
   */
  async watchStorageV1alpha1VolumeAttachmentList(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1alpha1/watch/volumeattachments`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind VolumeAttachment. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchStorageV1alpha1VolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1alpha1/watch/volumeattachments/{name}
   */
  async watchStorageV1alpha1VolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1alpha1/watch/volumeattachments/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * get available resources
   * operationId: getStorageV1beta1APIResources
   * Request URI: /apis/storage.k8s.io/v1beta1/
   */
  async getStorageV1beta1APIResources(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/`;
    const headers = {
      Accept: params.headers.Accept
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * list or watch objects of kind CSIDriver
   * operationId: listStorageV1beta1CSIDriver
   * Request URI: /apis/storage.k8s.io/v1beta1/csidrivers
   */
  async listStorageV1beta1CSIDriver(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/csidrivers`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a CSIDriver
   * operationId: createStorageV1beta1CSIDriver
   * Request URI: /apis/storage.k8s.io/v1beta1/csidrivers
   */
  async createStorageV1beta1CSIDriver(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/csidrivers`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of CSIDriver
   * operationId: deleteStorageV1beta1CollectionCSIDriver
   * Request URI: /apis/storage.k8s.io/v1beta1/csidrivers
   */
  async deleteStorageV1beta1CollectionCSIDriver(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/csidrivers`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified CSIDriver
   * operationId: readStorageV1beta1CSIDriver
   * Request URI: /apis/storage.k8s.io/v1beta1/csidrivers/{name}
   */
  async readStorageV1beta1CSIDriver(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/csidrivers/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified CSIDriver
   * operationId: replaceStorageV1beta1CSIDriver
   * Request URI: /apis/storage.k8s.io/v1beta1/csidrivers/{name}
   */
  async replaceStorageV1beta1CSIDriver(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/csidrivers/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a CSIDriver
   * operationId: deleteStorageV1beta1CSIDriver
   * Request URI: /apis/storage.k8s.io/v1beta1/csidrivers/{name}
   */
  async deleteStorageV1beta1CSIDriver(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/csidrivers/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified CSIDriver
   * operationId: patchStorageV1beta1CSIDriver
   * Request URI: /apis/storage.k8s.io/v1beta1/csidrivers/{name}
   */
  async patchStorageV1beta1CSIDriver(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/csidrivers/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind CSINode
   * operationId: listStorageV1beta1CSINode
   * Request URI: /apis/storage.k8s.io/v1beta1/csinodes
   */
  async listStorageV1beta1CSINode(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/csinodes`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a CSINode
   * operationId: createStorageV1beta1CSINode
   * Request URI: /apis/storage.k8s.io/v1beta1/csinodes
   */
  async createStorageV1beta1CSINode(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/csinodes`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of CSINode
   * operationId: deleteStorageV1beta1CollectionCSINode
   * Request URI: /apis/storage.k8s.io/v1beta1/csinodes
   */
  async deleteStorageV1beta1CollectionCSINode(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/csinodes`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified CSINode
   * operationId: readStorageV1beta1CSINode
   * Request URI: /apis/storage.k8s.io/v1beta1/csinodes/{name}
   */
  async readStorageV1beta1CSINode(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/csinodes/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified CSINode
   * operationId: replaceStorageV1beta1CSINode
   * Request URI: /apis/storage.k8s.io/v1beta1/csinodes/{name}
   */
  async replaceStorageV1beta1CSINode(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/csinodes/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a CSINode
   * operationId: deleteStorageV1beta1CSINode
   * Request URI: /apis/storage.k8s.io/v1beta1/csinodes/{name}
   */
  async deleteStorageV1beta1CSINode(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/csinodes/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified CSINode
   * operationId: patchStorageV1beta1CSINode
   * Request URI: /apis/storage.k8s.io/v1beta1/csinodes/{name}
   */
  async patchStorageV1beta1CSINode(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/csinodes/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind StorageClass
   * operationId: listStorageV1beta1StorageClass
   * Request URI: /apis/storage.k8s.io/v1beta1/storageclasses
   */
  async listStorageV1beta1StorageClass(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/storageclasses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a StorageClass
   * operationId: createStorageV1beta1StorageClass
   * Request URI: /apis/storage.k8s.io/v1beta1/storageclasses
   */
  async createStorageV1beta1StorageClass(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/storageclasses`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of StorageClass
   * operationId: deleteStorageV1beta1CollectionStorageClass
   * Request URI: /apis/storage.k8s.io/v1beta1/storageclasses
   */
  async deleteStorageV1beta1CollectionStorageClass(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/storageclasses`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified StorageClass
   * operationId: readStorageV1beta1StorageClass
   * Request URI: /apis/storage.k8s.io/v1beta1/storageclasses/{name}
   */
  async readStorageV1beta1StorageClass(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/storageclasses/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified StorageClass
   * operationId: replaceStorageV1beta1StorageClass
   * Request URI: /apis/storage.k8s.io/v1beta1/storageclasses/{name}
   */
  async replaceStorageV1beta1StorageClass(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/storageclasses/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a StorageClass
   * operationId: deleteStorageV1beta1StorageClass
   * Request URI: /apis/storage.k8s.io/v1beta1/storageclasses/{name}
   */
  async deleteStorageV1beta1StorageClass(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/storageclasses/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified StorageClass
   * operationId: patchStorageV1beta1StorageClass
   * Request URI: /apis/storage.k8s.io/v1beta1/storageclasses/{name}
   */
  async patchStorageV1beta1StorageClass(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/storageclasses/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * list or watch objects of kind VolumeAttachment
   * operationId: listStorageV1beta1VolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1beta1/volumeattachments
   */
  async listStorageV1beta1VolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/volumeattachments`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * create a VolumeAttachment
   * operationId: createStorageV1beta1VolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1beta1/volumeattachments
   */
  async createStorageV1beta1VolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/volumeattachments`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "POST",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete collection of VolumeAttachment
   * operationId: deleteStorageV1beta1CollectionVolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1beta1/volumeattachments
   */
  async deleteStorageV1beta1CollectionVolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/volumeattachments`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * read the specified VolumeAttachment
   * operationId: readStorageV1beta1VolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1beta1/volumeattachments/{name}
   */
  async readStorageV1beta1VolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/volumeattachments/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      exact: { value: params.parameter.exact, explode: false },
      export: { value: params.parameter.export, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * replace the specified VolumeAttachment
   * operationId: replaceStorageV1beta1VolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1beta1/volumeattachments/{name}
   */
  async replaceStorageV1beta1VolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/volumeattachments/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PUT",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * delete a VolumeAttachment
   * operationId: deleteStorageV1beta1VolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1beta1/volumeattachments/{name}
   */
  async deleteStorageV1beta1VolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/volumeattachments/${params.parameter.name}`;
    const headers = {
      "Content-Type": "*/*",
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      gracePeriodSeconds: { value: params.parameter.gracePeriodSeconds, explode: false },
      orphanDependents: { value: params.parameter.orphanDependents, explode: false },
      propagationPolicy: { value: params.parameter.propagationPolicy, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "DELETE",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * partially update the specified VolumeAttachment
   * operationId: patchStorageV1beta1VolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1beta1/volumeattachments/{name}
   */
  async patchStorageV1beta1VolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/volumeattachments/${params.parameter.name}`;
    const headers = {
      "Content-Type": params.headers["Content-Type"],
      Accept: params.headers.Accept
    };
    const queryParameters = {
      pretty: { value: params.parameter.pretty, explode: false },
      dryRun: { value: params.parameter.dryRun, explode: false },
      fieldManager: { value: params.parameter.fieldManager, explode: false },
      force: { value: params.parameter.force, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "PATCH",
        url,
        headers,
        requestBody: params.requestBody,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of CSIDriver. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchStorageV1beta1CSIDriverList
   * Request URI: /apis/storage.k8s.io/v1beta1/watch/csidrivers
   */
  async watchStorageV1beta1CSIDriverList(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/watch/csidrivers`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind CSIDriver. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchStorageV1beta1CSIDriver
   * Request URI: /apis/storage.k8s.io/v1beta1/watch/csidrivers/{name}
   */
  async watchStorageV1beta1CSIDriver(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/watch/csidrivers/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of CSINode. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchStorageV1beta1CSINodeList
   * Request URI: /apis/storage.k8s.io/v1beta1/watch/csinodes
   */
  async watchStorageV1beta1CSINodeList(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/watch/csinodes`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind CSINode. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchStorageV1beta1CSINode
   * Request URI: /apis/storage.k8s.io/v1beta1/watch/csinodes/{name}
   */
  async watchStorageV1beta1CSINode(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/watch/csinodes/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of StorageClass. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchStorageV1beta1StorageClassList
   * Request URI: /apis/storage.k8s.io/v1beta1/watch/storageclasses
   */
  async watchStorageV1beta1StorageClassList(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/watch/storageclasses`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind StorageClass. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchStorageV1beta1StorageClass
   * Request URI: /apis/storage.k8s.io/v1beta1/watch/storageclasses/{name}
   */
  async watchStorageV1beta1StorageClass(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/watch/storageclasses/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch individual changes to a list of VolumeAttachment. deprecated: use the 'watch' parameter with a list operation instead.
   * operationId: watchStorageV1beta1VolumeAttachmentList
   * Request URI: /apis/storage.k8s.io/v1beta1/watch/volumeattachments
   */
  async watchStorageV1beta1VolumeAttachmentList(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/watch/volumeattachments`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * watch changes to an object of kind VolumeAttachment. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
   * operationId: watchStorageV1beta1VolumeAttachment
   * Request URI: /apis/storage.k8s.io/v1beta1/watch/volumeattachments/{name}
   */
  async watchStorageV1beta1VolumeAttachment(params, option) {
    const url = this.baseUrl + `/apis/storage.k8s.io/v1beta1/watch/volumeattachments/${params.parameter.name}`;
    const headers = {
      Accept: params.headers.Accept
    };
    const queryParameters = {
      allowWatchBookmarks: { value: params.parameter.allowWatchBookmarks, explode: false },
      continue: { value: params.parameter.continue, explode: false },
      fieldSelector: { value: params.parameter.fieldSelector, explode: false },
      labelSelector: { value: params.parameter.labelSelector, explode: false },
      limit: { value: params.parameter.limit, explode: false },
      pretty: { value: params.parameter.pretty, explode: false },
      resourceVersion: { value: params.parameter.resourceVersion, explode: false },
      timeoutSeconds: { value: params.parameter.timeoutSeconds, explode: false },
      watch: { value: params.parameter.watch, explode: false }
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers,
        queryParameters
      },
      option
    );
  }
  /**
   * operationId: logFileListHandler
   * Request URI: /logs/
   */
  async logFileListHandler(option) {
    const url = this.baseUrl + `/logs/`;
    const headers = {};
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * operationId: logFileHandler
   * Request URI: /logs/{logpath}
   */
  async logFileHandler(params, option) {
    const url = this.baseUrl + `/logs/${params.parameter.logpath}`;
    const headers = {};
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
  /**
   * get the code version
   * operationId: getCodeVersion
   * Request URI: /version/
   */
  async getCodeVersion(option) {
    const url = this.baseUrl + `/version/`;
    const headers = {
      Accept: "application/json"
    };
    return this.apiClient.request(
      {
        httpMethod: "GET",
        url,
        headers
      },
      option
    );
  }
};
export {
  Client
};
