declare namespace Schemas {
    /** MatchCondition represents a condition which must by fulfilled for a request to be sent to a webhook. */
    interface io$k8s$api$admissionregistration$v1$MatchCondition {
        /**
         * Expression represents the expression which will be evaluated by CEL. Must evaluate to bool. CEL expressions have access to the contents of the AdmissionRequest and Authorizer, organized into CEL variables:
         *
         * 'object' - The object from the incoming request. The value is null for DELETE requests. 'oldObject' - The existing object. The value is null for CREATE requests. 'request' - Attributes of the admission request(/pkg/apis/admission/types.go#AdmissionRequest). 'authorizer' - A CEL Authorizer. May be used to perform authorization checks for the principal (user or service account) of the request.
         *   See https://pkg.go.dev/k8s.io/apiserver/pkg/cel/library#Authz
         * 'authorizer.requestResource' - A CEL ResourceCheck constructed from the 'authorizer' and configured with the
         *   request resource.
         * Documentation on CEL: https://kubernetes.io/docs/reference/using-api/cel/
         *
         * Required.
         */
        expression: string;
        /**
         * Name is an identifier for this match condition, used for strategic merging of MatchConditions, as well as providing an identifier for logging purposes. A good name should be descriptive of the associated expression. Name must be a qualified name consisting of alphanumeric characters, '-', '_' or '.', and must start and end with an alphanumeric character (e.g. 'MyName',  or 'my.name',  or '123-abc', regex used for validation is '([A-Za-z0-9][-A-Za-z0-9_.]*)?[A-Za-z0-9]') with an optional DNS subdomain prefix and '/' (e.g. 'example.com/MyName')
         *
         * Required.
         */
        name: string;
    }
    /** MutatingWebhook describes an admission webhook and the resources and operations it applies to. */
    interface io$k8s$api$admissionregistration$v1$MutatingWebhook {
        /** AdmissionReviewVersions is an ordered list of preferred `AdmissionReview` versions the Webhook expects. API server will try to use first version in the list which it supports. If none of the versions specified in this list supported by API server, validation will fail for this object. If a persisted webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail and be subject to the failure policy. */
        admissionReviewVersions: string[];
        clientConfig: Schemas.io$k8s$api$admissionregistration$v1$WebhookClientConfig;
        /** FailurePolicy defines how unrecognized errors from the admission endpoint are handled - allowed values are Ignore or Fail. Defaults to Fail. */
        failurePolicy?: string;
        /**
         * MatchConditions is a list of conditions that must be met for a request to be sent to this webhook. Match conditions filter requests that have already been matched by the rules, namespaceSelector, and objectSelector. An empty list of matchConditions matches all requests. There are a maximum of 64 match conditions allowed.
         *
         * The exact matching logic is (in order):
         *   1. If ANY matchCondition evaluates to FALSE, the webhook is skipped.
         *   2. If ALL matchConditions evaluate to TRUE, the webhook is called.
         *   3. If any matchCondition evaluates to an error (but none are FALSE):
         *      - If failurePolicy=Fail, reject the request
         *      - If failurePolicy=Ignore, the error is ignored and the webhook is skipped
         *
         * This is an alpha feature and managed by the AdmissionWebhookMatchConditions feature gate.
         */
        matchConditions?: Schemas.io$k8s$api$admissionregistration$v1$MatchCondition[];
        /**
         * matchPolicy defines how the "rules" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".
         *
         * - Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would not be sent to the webhook.
         *
         * - Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would be converted to apps/v1 and sent to the webhook.
         *
         * Defaults to "Equivalent"
         */
        matchPolicy?: string;
        /** The name of the admission webhook. Name should be fully qualified, e.g., imagepolicy.kubernetes.io, where "imagepolicy" is the name of the webhook, and kubernetes.io is the name of the organization. Required. */
        name: string;
        namespaceSelector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        objectSelector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        /**
         * reinvocationPolicy indicates whether this webhook should be called multiple times as part of a single admission evaluation. Allowed values are "Never" and "IfNeeded".
         *
         * Never: the webhook will not be called more than once in a single admission evaluation.
         *
         * IfNeeded: the webhook will be called at least one additional time as part of the admission evaluation if the object being admitted is modified by other admission plugins after the initial webhook call. Webhooks that specify this option *must* be idempotent, able to process objects they previously admitted. Note: * the number of additional invocations is not guaranteed to be exactly one. * if additional invocations result in further modifications to the object, webhooks are not guaranteed to be invoked again. * webhooks that use this option may be reordered to minimize the number of additional invocations. * to validate an object after all mutations are guaranteed complete, use a validating admission webhook instead.
         *
         * Defaults to "Never".
         */
        reinvocationPolicy?: string;
        /** Rules describes what operations on what resources/subresources the webhook cares about. The webhook cares about an operation if it matches _any_ Rule. However, in order to prevent ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks from putting the cluster in a state which cannot be recovered from without completely disabling the plugin, ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks are never called on admission requests for ValidatingWebhookConfiguration and MutatingWebhookConfiguration objects. */
        rules?: Schemas.io$k8s$api$admissionregistration$v1$RuleWithOperations[];
        /** SideEffects states whether this webhook has side effects. Acceptable values are: None, NoneOnDryRun (webhooks created via v1beta1 may also specify Some or Unknown). Webhooks with side effects MUST implement a reconciliation system, since a request may be rejected by a future step in the admission chain and the side effects therefore need to be undone. Requests with the dryRun attribute will be auto-rejected if they match a webhook with sideEffects == Unknown or Some. */
        sideEffects: string;
        /** TimeoutSeconds specifies the timeout for this webhook. After the timeout passes, the webhook call will be ignored or the API call will fail based on the failure policy. The timeout value must be between 1 and 30 seconds. Default to 10 seconds. */
        timeoutSeconds?: number;
    }
    /** MutatingWebhookConfiguration describes the configuration of and admission webhook that accept or reject and may change the object. */
    interface io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** Webhooks is a list of webhooks and the affected resources and operations. */
        webhooks?: Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhook[];
    }
    /** MutatingWebhookConfigurationList is a list of MutatingWebhookConfiguration. */
    interface io$k8s$api$admissionregistration$v1$MutatingWebhookConfigurationList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of MutatingWebhookConfiguration. */
        items: Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** RuleWithOperations is a tuple of Operations and Resources. It is recommended to make sure that all the tuple expansions are valid. */
    interface io$k8s$api$admissionregistration$v1$RuleWithOperations {
        /** APIGroups is the API groups the resources belong to. '*' is all groups. If '*' is present, the length of the slice must be one. Required. */
        apiGroups?: string[];
        /** APIVersions is the API versions the resources belong to. '*' is all versions. If '*' is present, the length of the slice must be one. Required. */
        apiVersions?: string[];
        /** Operations is the operations the admission hook cares about - CREATE, UPDATE, DELETE, CONNECT or * for all of those operations and any future admission operations that are added. If '*' is present, the length of the slice must be one. Required. */
        operations?: string[];
        /**
         * Resources is a list of resources this rule applies to.
         *
         * For example: 'pods' means pods. 'pods/log' means the log subresource of pods. '*' means all resources, but not subresources. 'pods/\\*' means all subresources of pods. '\*\\/scale' means all scale subresources. '\*\/\*' means all resources and their subresources.
         *
         * If wildcard is present, the validation rule will ensure resources do not overlap with each other.
         *
         * Depending on the enclosing object, subresources might not be allowed. Required.
         */
        resources?: string[];
        /** scope specifies the scope of this rule. Valid values are "Cluster", "Namespaced", and "*" "Cluster" means that only cluster-scoped resources will match this rule. Namespace API objects are cluster-scoped. "Namespaced" means that only namespaced resources will match this rule. "*" means that there are no scope restrictions. Subresources match the scope of their parent resource. Default is "*". */
        scope?: string;
    }
    /** ServiceReference holds a reference to Service.legacy.k8s.io */
    interface io$k8s$api$admissionregistration$v1$ServiceReference {
        /** `name` is the name of the service. Required */
        name: string;
        /** `namespace` is the namespace of the service. Required */
        namespace: string;
        /** `path` is an optional URL path which will be sent in any request to this service. */
        path?: string;
        /** If specified, the port on the service that hosting webhook. Default to 443 for backward compatibility. `port` should be a valid port number (1-65535, inclusive). */
        port?: number;
    }
    /** ValidatingWebhook describes an admission webhook and the resources and operations it applies to. */
    interface io$k8s$api$admissionregistration$v1$ValidatingWebhook {
        /** AdmissionReviewVersions is an ordered list of preferred `AdmissionReview` versions the Webhook expects. API server will try to use first version in the list which it supports. If none of the versions specified in this list supported by API server, validation will fail for this object. If a persisted webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail and be subject to the failure policy. */
        admissionReviewVersions: string[];
        clientConfig: Schemas.io$k8s$api$admissionregistration$v1$WebhookClientConfig;
        /** FailurePolicy defines how unrecognized errors from the admission endpoint are handled - allowed values are Ignore or Fail. Defaults to Fail. */
        failurePolicy?: string;
        /**
         * MatchConditions is a list of conditions that must be met for a request to be sent to this webhook. Match conditions filter requests that have already been matched by the rules, namespaceSelector, and objectSelector. An empty list of matchConditions matches all requests. There are a maximum of 64 match conditions allowed.
         *
         * The exact matching logic is (in order):
         *   1. If ANY matchCondition evaluates to FALSE, the webhook is skipped.
         *   2. If ALL matchConditions evaluate to TRUE, the webhook is called.
         *   3. If any matchCondition evaluates to an error (but none are FALSE):
         *      - If failurePolicy=Fail, reject the request
         *      - If failurePolicy=Ignore, the error is ignored and the webhook is skipped
         *
         * This is an alpha feature and managed by the AdmissionWebhookMatchConditions feature gate.
         */
        matchConditions?: Schemas.io$k8s$api$admissionregistration$v1$MatchCondition[];
        /**
         * matchPolicy defines how the "rules" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".
         *
         * - Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would not be sent to the webhook.
         *
         * - Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would be converted to apps/v1 and sent to the webhook.
         *
         * Defaults to "Equivalent"
         */
        matchPolicy?: string;
        /** The name of the admission webhook. Name should be fully qualified, e.g., imagepolicy.kubernetes.io, where "imagepolicy" is the name of the webhook, and kubernetes.io is the name of the organization. Required. */
        name: string;
        namespaceSelector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        objectSelector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        /** Rules describes what operations on what resources/subresources the webhook cares about. The webhook cares about an operation if it matches _any_ Rule. However, in order to prevent ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks from putting the cluster in a state which cannot be recovered from without completely disabling the plugin, ValidatingAdmissionWebhooks and MutatingAdmissionWebhooks are never called on admission requests for ValidatingWebhookConfiguration and MutatingWebhookConfiguration objects. */
        rules?: Schemas.io$k8s$api$admissionregistration$v1$RuleWithOperations[];
        /** SideEffects states whether this webhook has side effects. Acceptable values are: None, NoneOnDryRun (webhooks created via v1beta1 may also specify Some or Unknown). Webhooks with side effects MUST implement a reconciliation system, since a request may be rejected by a future step in the admission chain and the side effects therefore need to be undone. Requests with the dryRun attribute will be auto-rejected if they match a webhook with sideEffects == Unknown or Some. */
        sideEffects: string;
        /** TimeoutSeconds specifies the timeout for this webhook. After the timeout passes, the webhook call will be ignored or the API call will fail based on the failure policy. The timeout value must be between 1 and 30 seconds. Default to 10 seconds. */
        timeoutSeconds?: number;
    }
    /** ValidatingWebhookConfiguration describes the configuration of and admission webhook that accept or reject and object without changing it. */
    interface io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** Webhooks is a list of webhooks and the affected resources and operations. */
        webhooks?: Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhook[];
    }
    /** ValidatingWebhookConfigurationList is a list of ValidatingWebhookConfiguration. */
    interface io$k8s$api$admissionregistration$v1$ValidatingWebhookConfigurationList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of ValidatingWebhookConfiguration. */
        items: Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** WebhookClientConfig contains the information to make a TLS connection with the webhook */
    interface io$k8s$api$admissionregistration$v1$WebhookClientConfig {
        /** `caBundle` is a PEM encoded CA bundle which will be used to validate the webhook's server certificate. If unspecified, system trust roots on the apiserver are used. */
        caBundle?: Blob;
        service?: Schemas.io$k8s$api$admissionregistration$v1$ServiceReference;
        /**
         * `url` gives the location of the webhook, in standard URL form (`scheme://host:port/path`). Exactly one of `url` or `service` must be specified.
         *
         * The `host` should not refer to a service running in the cluster; use the `service` field instead. The host might be resolved via external DNS in some apiservers (e.g., `kube-apiserver` cannot resolve in-cluster DNS as that would be a layering violation). `host` may also be an IP address.
         *
         * Please note that using `localhost` or `127.0.0.1` as a `host` is risky unless you take great care to run this webhook on all hosts which run an apiserver which might need to make calls to this webhook. Such installs are likely to be non-portable, i.e., not easy to turn up in a new cluster.
         *
         * The scheme must be "https"; the URL must begin with "https://".
         *
         * A path is optional, and if present may be any string permissible in a URL. You may use the path to pass an arbitrary string to the webhook, for example, a cluster identifier.
         *
         * Attempting to use a user or basic auth e.g. "user:password@" is not allowed. Fragments ("#...") and query parameters ("?...") are not allowed, either.
         */
        url?: string;
    }
    /** AuditAnnotation describes how to produce an audit annotation for an API request. */
    interface io$k8s$api$admissionregistration$v1alpha1$AuditAnnotation {
        /**
         * key specifies the audit annotation key. The audit annotation keys of a ValidatingAdmissionPolicy must be unique. The key must be a qualified name ([A-Za-z0-9][-A-Za-z0-9_.]*) no more than 63 bytes in length.
         *
         * The key is combined with the resource name of the ValidatingAdmissionPolicy to construct an audit annotation key: "{ValidatingAdmissionPolicy name}/{key}".
         *
         * If an admission webhook uses the same resource name as this ValidatingAdmissionPolicy and the same audit annotation key, the annotation key will be identical. In this case, the first annotation written with the key will be included in the audit event and all subsequent annotations with the same key will be discarded.
         *
         * Required.
         */
        key: string;
        /**
         * valueExpression represents the expression which is evaluated by CEL to produce an audit annotation value. The expression must evaluate to either a string or null value. If the expression evaluates to a string, the audit annotation is included with the string value. If the expression evaluates to null or empty string the audit annotation will be omitted. The valueExpression may be no longer than 5kb in length. If the result of the valueExpression is more than 10kb in length, it will be truncated to 10kb.
         *
         * If multiple ValidatingAdmissionPolicyBinding resources match an API request, then the valueExpression will be evaluated for each binding. All unique values produced by the valueExpressions will be joined together in a comma-separated list.
         *
         * Required.
         */
        valueExpression: string;
    }
    /** ExpressionWarning is a warning information that targets a specific expression. */
    interface io$k8s$api$admissionregistration$v1alpha1$ExpressionWarning {
        /** The path to the field that refers the expression. For example, the reference to the expression of the first item of validations is "spec.validations[0].expression" */
        fieldRef: string;
        /** The content of type checking information in a human-readable form. Each line of the warning contains the type that the expression is checked against, followed by the type check error from the compiler. */
        warning: string;
    }
    interface io$k8s$api$admissionregistration$v1alpha1$MatchCondition {
        /**
         * Expression represents the expression which will be evaluated by CEL. Must evaluate to bool. CEL expressions have access to the contents of the AdmissionRequest and Authorizer, organized into CEL variables:
         *
         * 'object' - The object from the incoming request. The value is null for DELETE requests. 'oldObject' - The existing object. The value is null for CREATE requests. 'request' - Attributes of the admission request(/pkg/apis/admission/types.go#AdmissionRequest). 'authorizer' - A CEL Authorizer. May be used to perform authorization checks for the principal (user or service account) of the request.
         *   See https://pkg.go.dev/k8s.io/apiserver/pkg/cel/library#Authz
         * 'authorizer.requestResource' - A CEL ResourceCheck constructed from the 'authorizer' and configured with the
         *   request resource.
         * Documentation on CEL: https://kubernetes.io/docs/reference/using-api/cel/
         *
         * Required.
         */
        expression: string;
        /**
         * Name is an identifier for this match condition, used for strategic merging of MatchConditions, as well as providing an identifier for logging purposes. A good name should be descriptive of the associated expression. Name must be a qualified name consisting of alphanumeric characters, '-', '_' or '.', and must start and end with an alphanumeric character (e.g. 'MyName',  or 'my.name',  or '123-abc', regex used for validation is '([A-Za-z0-9][-A-Za-z0-9_.]*)?[A-Za-z0-9]') with an optional DNS subdomain prefix and '/' (e.g. 'example.com/MyName')
         *
         * Required.
         */
        name: string;
    }
    /** MatchResources decides whether to run the admission control policy on an object based on whether it meets the match criteria. The exclude rules take precedence over include rules (if a resource matches both, it is excluded) */
    interface io$k8s$api$admissionregistration$v1alpha1$MatchResources {
        /** ExcludeResourceRules describes what operations on what resources/subresources the ValidatingAdmissionPolicy should not care about. The exclude rules take precedence over include rules (if a resource matches both, it is excluded) */
        excludeResourceRules?: Schemas.io$k8s$api$admissionregistration$v1alpha1$NamedRuleWithOperations[];
        /**
         * matchPolicy defines how the "MatchResources" list is used to match incoming requests. Allowed values are "Exact" or "Equivalent".
         *
         * - Exact: match a request only if it exactly matches a specified rule. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, but "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would not be sent to the ValidatingAdmissionPolicy.
         *
         * - Equivalent: match a request if modifies a resource listed in rules, even via another API group or version. For example, if deployments can be modified via apps/v1, apps/v1beta1, and extensions/v1beta1, and "rules" only included `apiGroups:["apps"], apiVersions:["v1"], resources: ["deployments"]`, a request to apps/v1beta1 or extensions/v1beta1 would be converted to apps/v1 and sent to the ValidatingAdmissionPolicy.
         *
         * Defaults to "Equivalent"
         */
        matchPolicy?: string;
        namespaceSelector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        objectSelector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        /** ResourceRules describes what operations on what resources/subresources the ValidatingAdmissionPolicy matches. The policy cares about an operation if it matches _any_ Rule. */
        resourceRules?: Schemas.io$k8s$api$admissionregistration$v1alpha1$NamedRuleWithOperations[];
    }
    /** NamedRuleWithOperations is a tuple of Operations and Resources with ResourceNames. */
    interface io$k8s$api$admissionregistration$v1alpha1$NamedRuleWithOperations {
        /** APIGroups is the API groups the resources belong to. '*' is all groups. If '*' is present, the length of the slice must be one. Required. */
        apiGroups?: string[];
        /** APIVersions is the API versions the resources belong to. '*' is all versions. If '*' is present, the length of the slice must be one. Required. */
        apiVersions?: string[];
        /** Operations is the operations the admission hook cares about - CREATE, UPDATE, DELETE, CONNECT or * for all of those operations and any future admission operations that are added. If '*' is present, the length of the slice must be one. Required. */
        operations?: string[];
        /** ResourceNames is an optional white list of names that the rule applies to.  An empty set means that everything is allowed. */
        resourceNames?: string[];
        /**
         * Resources is a list of resources this rule applies to.
         *
         * For example: 'pods' means pods. 'pods/log' means the log subresource of pods. '*' means all resources, but not subresources. 'pods/\\*' means all subresources of pods. '\*\\/scale' means all scale subresources. '\*\/\*' means all resources and their subresources.
         *
         * If wildcard is present, the validation rule will ensure resources do not overlap with each other.
         *
         * Depending on the enclosing object, subresources might not be allowed. Required.
         */
        resources?: string[];
        /** scope specifies the scope of this rule. Valid values are "Cluster", "Namespaced", and "*" "Cluster" means that only cluster-scoped resources will match this rule. Namespace API objects are cluster-scoped. "Namespaced" means that only namespaced resources will match this rule. "*" means that there are no scope restrictions. Subresources match the scope of their parent resource. Default is "*". */
        scope?: string;
    }
    /** ParamKind is a tuple of Group Kind and Version. */
    interface io$k8s$api$admissionregistration$v1alpha1$ParamKind {
        /** APIVersion is the API group version the resources belong to. In format of "group/version". Required. */
        apiVersion?: string;
        /** Kind is the API kind the resources belong to. Required. */
        kind?: string;
    }
    /** ParamRef references a parameter resource */
    interface io$k8s$api$admissionregistration$v1alpha1$ParamRef {
        /** Name of the resource being referenced. */
        name?: string;
        /** Namespace of the referenced resource. Should be empty for the cluster-scoped resources */
        namespace?: string;
    }
    /** TypeChecking contains results of type checking the expressions in the ValidatingAdmissionPolicy */
    interface io$k8s$api$admissionregistration$v1alpha1$TypeChecking {
        /** The type checking warnings for each expression. */
        expressionWarnings?: Schemas.io$k8s$api$admissionregistration$v1alpha1$ExpressionWarning[];
    }
    /** ValidatingAdmissionPolicy describes the definition of an admission validation policy that accepts or rejects an object without changing it. */
    interface io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicySpec;
        status?: Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyStatus;
    }
    /** ValidatingAdmissionPolicyBinding binds the ValidatingAdmissionPolicy with paramerized resources. ValidatingAdmissionPolicyBinding and parameter CRDs together define how cluster administrators configure policies for clusters. */
    interface io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBindingSpec;
    }
    /** ValidatingAdmissionPolicyBindingList is a list of ValidatingAdmissionPolicyBinding. */
    interface io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBindingList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of PolicyBinding. */
        items?: Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ValidatingAdmissionPolicyBindingSpec is the specification of the ValidatingAdmissionPolicyBinding. */
    interface io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBindingSpec {
        matchResources?: Schemas.io$k8s$api$admissionregistration$v1alpha1$MatchResources;
        paramRef?: Schemas.io$k8s$api$admissionregistration$v1alpha1$ParamRef;
        /** PolicyName references a ValidatingAdmissionPolicy name which the ValidatingAdmissionPolicyBinding binds to. If the referenced resource does not exist, this binding is considered invalid and will be ignored Required. */
        policyName?: string;
        /**
         * validationActions declares how Validations of the referenced ValidatingAdmissionPolicy are enforced. If a validation evaluates to false it is always enforced according to these actions.
         *
         * Failures defined by the ValidatingAdmissionPolicy's FailurePolicy are enforced according to these actions only if the FailurePolicy is set to Fail, otherwise the failures are ignored. This includes compilation errors, runtime errors and misconfigurations of the policy.
         *
         * validationActions is declared as a set of action values. Order does not matter. validationActions may not contain duplicates of the same action.
         *
         * The supported actions values are:
         *
         * "Deny" specifies that a validation failure results in a denied request.
         *
         * "Warn" specifies that a validation failure is reported to the request client in HTTP Warning headers, with a warning code of 299. Warnings can be sent both for allowed or denied admission responses.
         *
         * "Audit" specifies that a validation failure is included in the published audit event for the request. The audit event will contain a `validation.policy.admission.k8s.io/validation_failure` audit annotation with a value containing the details of the validation failures, formatted as a JSON list of objects, each with the following fields: - message: The validation failure message string - policy: The resource name of the ValidatingAdmissionPolicy - binding: The resource name of the ValidatingAdmissionPolicyBinding - expressionIndex: The index of the failed validations in the ValidatingAdmissionPolicy - validationActions: The enforcement actions enacted for the validation failure Example audit annotation: `"validation.policy.admission.k8s.io/validation_failure": "[{"message": "Invalid value", {"policy": "policy.example.com", {"binding": "policybinding.example.com", {"expressionIndex": "1", {"validationActions": ["Audit"]}]"`
         *
         * Clients should expect to handle additional values by ignoring any values not recognized.
         *
         * "Deny" and "Warn" may not be used together since this combination needlessly duplicates the validation failure both in the API response body and the HTTP warning headers.
         *
         * Required.
         */
        validationActions?: string[];
    }
    /** ValidatingAdmissionPolicyList is a list of ValidatingAdmissionPolicy. */
    interface io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of ValidatingAdmissionPolicy. */
        items?: Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ValidatingAdmissionPolicySpec is the specification of the desired behavior of the AdmissionPolicy. */
    interface io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicySpec {
        /** auditAnnotations contains CEL expressions which are used to produce audit annotations for the audit event of the API request. validations and auditAnnotations may not both be empty; a least one of validations or auditAnnotations is required. */
        auditAnnotations?: Schemas.io$k8s$api$admissionregistration$v1alpha1$AuditAnnotation[];
        /**
         * failurePolicy defines how to handle failures for the admission policy. Failures can occur from CEL expression parse errors, type check errors, runtime errors and invalid or mis-configured policy definitions or bindings.
         *
         * A policy is invalid if spec.paramKind refers to a non-existent Kind. A binding is invalid if spec.paramRef.name refers to a non-existent resource.
         *
         * failurePolicy does not define how validations that evaluate to false are handled.
         *
         * When failurePolicy is set to Fail, ValidatingAdmissionPolicyBinding validationActions define how failures are enforced.
         *
         * Allowed values are Ignore or Fail. Defaults to Fail.
         */
        failurePolicy?: string;
        /**
         * MatchConditions is a list of conditions that must be met for a request to be validated. Match conditions filter requests that have already been matched by the rules, namespaceSelector, and objectSelector. An empty list of matchConditions matches all requests. There are a maximum of 64 match conditions allowed.
         *
         * If a parameter object is provided, it can be accessed via the `params` handle in the same manner as validation expressions.
         *
         * The exact matching logic is (in order):
         *   1. If ANY matchCondition evaluates to FALSE, the policy is skipped.
         *   2. If ALL matchConditions evaluate to TRUE, the policy is evaluated.
         *   3. If any matchCondition evaluates to an error (but none are FALSE):
         *      - If failurePolicy=Fail, reject the request
         *      - If failurePolicy=Ignore, the policy is skipped
         */
        matchConditions?: Schemas.io$k8s$api$admissionregistration$v1alpha1$MatchCondition[];
        matchConstraints?: Schemas.io$k8s$api$admissionregistration$v1alpha1$MatchResources;
        paramKind?: Schemas.io$k8s$api$admissionregistration$v1alpha1$ParamKind;
        /** Validations contain CEL expressions which is used to apply the validation. Validations and AuditAnnotations may not both be empty; a minimum of one Validations or AuditAnnotations is required. */
        validations?: Schemas.io$k8s$api$admissionregistration$v1alpha1$Validation[];
    }
    /** ValidatingAdmissionPolicyStatus represents the status of a ValidatingAdmissionPolicy. */
    interface io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyStatus {
        /** The conditions represent the latest available observations of a policy's current state. */
        conditions?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Condition[];
        /** The generation observed by the controller. */
        observedGeneration?: number;
        typeChecking?: Schemas.io$k8s$api$admissionregistration$v1alpha1$TypeChecking;
    }
    /** Validation specifies the CEL expression which is used to apply the validation. */
    interface io$k8s$api$admissionregistration$v1alpha1$Validation {
        /**
         * Expression represents the expression which will be evaluated by CEL. ref: https://github.com/google/cel-spec CEL expressions have access to the contents of the API request/response, organized into CEL variables as well as some other useful variables:
         *
         * - 'object' - The object from the incoming request. The value is null for DELETE requests. - 'oldObject' - The existing object. The value is null for CREATE requests. - 'request' - Attributes of the API request([ref](/pkg/apis/admission/types.go#AdmissionRequest)). - 'params' - Parameter resource referred to by the policy binding being evaluated. Only populated if the policy has a ParamKind. - 'authorizer' - A CEL Authorizer. May be used to perform authorization checks for the principal (user or service account) of the request.
         *   See https://pkg.go.dev/k8s.io/apiserver/pkg/cel/library#Authz
         * - 'authorizer.requestResource' - A CEL ResourceCheck constructed from the 'authorizer' and configured with the
         *   request resource.
         *
         * The `apiVersion`, `kind`, `metadata.name` and `metadata.generateName` are always accessible from the root of the object. No other metadata properties are accessible.
         *
         * Only property names of the form `[a-zA-Z_.-/][a-zA-Z0-9_.-/]*` are accessible. Accessible property names are escaped according to the following rules when accessed in the expression: - '__' escapes to '__underscores__' - '.' escapes to '__dot__' - '-' escapes to '__dash__' - '/' escapes to '__slash__' - Property names that exactly match a CEL RESERVED keyword escape to '__{keyword}__'. The keywords are:
         * 	  "true", "false", "null", "in", "as", "break", "const", "continue", "else", "for", "function", "if",
         * 	  "import", "let", "loop", "package", "namespace", "return".
         * Examples:
         *   - Expression accessing a property named "namespace": {"Expression": "object.__namespace__ > 0"}
         *   - Expression accessing a property named "x-prop": {"Expression": "object.x__dash__prop > 0"}
         *   - Expression accessing a property named "redact__d": {"Expression": "object.redact__underscores__d > 0"}
         *
         * Equality on arrays with list type of 'set' or 'map' ignores element order, i.e. [1, 2] == [2, 1]. Concatenation on arrays with x-kubernetes-list-type use the semantics of the list type:
         *   - 'set': `X + Y` performs a union where the array positions of all elements in `X` are preserved and
         *     non-intersecting elements in `Y` are appended, retaining their partial order.
         *   - 'map': `X + Y` performs a merge where the array positions of all keys in `X` are preserved but the values
         *     are overwritten by values in `Y` when the key sets of `X` and `Y` intersect. Elements in `Y` with
         *     non-intersecting keys are appended, retaining their partial order.
         * Required.
         */
        expression: string;
        /** Message represents the message displayed when validation fails. The message is required if the Expression contains line breaks. The message must not contain line breaks. If unset, the message is "failed rule: {Rule}". e.g. "must be a URL with the host matching spec.host" If the Expression contains line breaks. Message is required. The message must not contain line breaks. If unset, the message is "failed Expression: {Expression}". */
        message?: string;
        /** messageExpression declares a CEL expression that evaluates to the validation failure message that is returned when this rule fails. Since messageExpression is used as a failure message, it must evaluate to a string. If both message and messageExpression are present on a validation, then messageExpression will be used if validation fails. If messageExpression results in a runtime error, the runtime error is logged, and the validation failure message is produced as if the messageExpression field were unset. If messageExpression evaluates to an empty string, a string with only spaces, or a string that contains line breaks, then the validation failure message will also be produced as if the messageExpression field were unset, and the fact that messageExpression produced an empty string/string with only spaces/string with line breaks will be logged. messageExpression has access to all the same variables as the `expression` except for 'authorizer' and 'authorizer.requestResource'. Example: "object.x must be less than max ("+string(params.max)+")" */
        messageExpression?: string;
        /** Reason represents a machine-readable description of why this validation failed. If this is the first validation in the list to fail, this reason, as well as the corresponding HTTP response code, are used in the HTTP response to the client. The currently supported reasons are: "Unauthorized", "Forbidden", "Invalid", "RequestEntityTooLarge". If not set, StatusReasonInvalid is used in the response to the client. */
        reason?: string;
    }
    /** An API server instance reports the version it can decode and the version it encodes objects to when persisting objects in the backend. */
    interface io$k8s$api$apiserverinternal$v1alpha1$ServerStorageVersion {
        /** The ID of the reporting API server. */
        apiServerID?: string;
        /** The API server can decode objects encoded in these versions. The encodingVersion must be included in the decodableVersions. */
        decodableVersions?: string[];
        /** The API server encodes the object to this version when persisting it in the backend (e.g., etcd). */
        encodingVersion?: string;
    }
    /** Storage version of a specific resource. */
    interface io$k8s$api$apiserverinternal$v1alpha1$StorageVersion {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersionSpec;
        status: Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersionStatus;
    }
    /** Describes the state of the storageVersion at a certain point. */
    interface io$k8s$api$apiserverinternal$v1alpha1$StorageVersionCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** A human readable message indicating details about the transition. */
        message?: string;
        /** If set, this represents the .metadata.generation that the condition was set based upon. */
        observedGeneration?: number;
        /** The reason for the condition's last transition. */
        reason: string;
        /** Status of the condition, one of True, False, Unknown. */
        status: string;
        /** Type of the condition. */
        type: string;
    }
    /** A list of StorageVersions. */
    interface io$k8s$api$apiserverinternal$v1alpha1$StorageVersionList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items holds a list of StorageVersion */
        items: Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** StorageVersionSpec is an empty spec. */
    type io$k8s$api$apiserverinternal$v1alpha1$StorageVersionSpec = {};
    /** API server instances report the versions they can decode and the version they encode objects to when persisting objects in the backend. */
    interface io$k8s$api$apiserverinternal$v1alpha1$StorageVersionStatus {
        /** If all API server instances agree on the same encoding storage version, then this field is set to that version. Otherwise this field is left empty. API servers should finish updating its storageVersionStatus entry before serving write operations, so that this field will be in sync with the reality. */
        commonEncodingVersion?: string;
        /** The latest available observations of the storageVersion's state. */
        conditions?: Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersionCondition[];
        /** The reported versions per API server instance. */
        storageVersions?: Schemas.io$k8s$api$apiserverinternal$v1alpha1$ServerStorageVersion[];
    }
    /** ControllerRevision implements an immutable snapshot of state data. Clients are responsible for serializing and deserializing the objects that contain their internal state. Once a ControllerRevision has been successfully created, it can not be updated. The API Server will fail validation of all requests that attempt to mutate the Data field. ControllerRevisions may, however, be deleted. Note that, due to its use by both the DaemonSet and StatefulSet controllers for update and rollback, this object is beta. However, it may be subject to name and representation changes in future releases, and clients should not depend on its stability. It is primarily for internal use by controllers. */
    interface io$k8s$api$apps$v1$ControllerRevision {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        data?: Schemas.io$k8s$apimachinery$pkg$runtime$RawExtension;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** Revision indicates the revision of the state represented by Data. */
        revision: number;
    }
    /** ControllerRevisionList is a resource containing a list of ControllerRevision objects. */
    interface io$k8s$api$apps$v1$ControllerRevisionList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is the list of ControllerRevisions */
        items: Schemas.io$k8s$api$apps$v1$ControllerRevision[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** DaemonSet represents the configuration of a daemon set. */
    interface io$k8s$api$apps$v1$DaemonSet {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$apps$v1$DaemonSetSpec;
        status?: Schemas.io$k8s$api$apps$v1$DaemonSetStatus;
    }
    /** DaemonSetCondition describes the state of a DaemonSet at a certain point. */
    interface io$k8s$api$apps$v1$DaemonSetCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** A human readable message indicating details about the transition. */
        message?: string;
        /** The reason for the condition's last transition. */
        reason?: string;
        /** Status of the condition, one of True, False, Unknown. */
        status: string;
        /** Type of DaemonSet condition. */
        type: string;
    }
    /** DaemonSetList is a collection of daemon sets. */
    interface io$k8s$api$apps$v1$DaemonSetList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** A list of daemon sets. */
        items: Schemas.io$k8s$api$apps$v1$DaemonSet[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** DaemonSetSpec is the specification of a daemon set. */
    interface io$k8s$api$apps$v1$DaemonSetSpec {
        /** The minimum number of seconds for which a newly created DaemonSet pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready). */
        minReadySeconds?: number;
        /** The number of old history to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. Defaults to 10. */
        revisionHistoryLimit?: number;
        selector: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        template: Schemas.io$k8s$api$core$v1$PodTemplateSpec;
        updateStrategy?: Schemas.io$k8s$api$apps$v1$DaemonSetUpdateStrategy;
    }
    /** DaemonSetStatus represents the current status of a daemon set. */
    interface io$k8s$api$apps$v1$DaemonSetStatus {
        /** Count of hash collisions for the DaemonSet. The DaemonSet controller uses this field as a collision avoidance mechanism when it needs to create the name for the newest ControllerRevision. */
        collisionCount?: number;
        /** Represents the latest available observations of a DaemonSet's current state. */
        conditions?: Schemas.io$k8s$api$apps$v1$DaemonSetCondition[];
        /** The number of nodes that are running at least 1 daemon pod and are supposed to run the daemon pod. More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/ */
        currentNumberScheduled: number;
        /** The total number of nodes that should be running the daemon pod (including nodes correctly running the daemon pod). More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/ */
        desiredNumberScheduled: number;
        /** The number of nodes that should be running the daemon pod and have one or more of the daemon pod running and available (ready for at least spec.minReadySeconds) */
        numberAvailable?: number;
        /** The number of nodes that are running the daemon pod, but are not supposed to run the daemon pod. More info: https://kubernetes.io/docs/concepts/workloads/controllers/daemonset/ */
        numberMisscheduled: number;
        /** numberReady is the number of nodes that should be running the daemon pod and have one or more of the daemon pod running with a Ready Condition. */
        numberReady: number;
        /** The number of nodes that should be running the daemon pod and have none of the daemon pod running and available (ready for at least spec.minReadySeconds) */
        numberUnavailable?: number;
        /** The most recent generation observed by the daemon set controller. */
        observedGeneration?: number;
        /** The total number of nodes that are running updated daemon pod */
        updatedNumberScheduled?: number;
    }
    /** DaemonSetUpdateStrategy is a struct used to control the update strategy for a DaemonSet. */
    interface io$k8s$api$apps$v1$DaemonSetUpdateStrategy {
        rollingUpdate?: Schemas.io$k8s$api$apps$v1$RollingUpdateDaemonSet;
        /** Type of daemon set update. Can be "RollingUpdate" or "OnDelete". Default is RollingUpdate. */
        type?: string;
    }
    /** Deployment enables declarative updates for Pods and ReplicaSets. */
    interface io$k8s$api$apps$v1$Deployment {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$apps$v1$DeploymentSpec;
        status?: Schemas.io$k8s$api$apps$v1$DeploymentStatus;
    }
    /** DeploymentCondition describes the state of a deployment at a certain point. */
    interface io$k8s$api$apps$v1$DeploymentCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        lastUpdateTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** A human readable message indicating details about the transition. */
        message?: string;
        /** The reason for the condition's last transition. */
        reason?: string;
        /** Status of the condition, one of True, False, Unknown. */
        status: string;
        /** Type of deployment condition. */
        type: string;
    }
    /** DeploymentList is a list of Deployments. */
    interface io$k8s$api$apps$v1$DeploymentList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is the list of Deployments. */
        items: Schemas.io$k8s$api$apps$v1$Deployment[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** DeploymentSpec is the specification of the desired behavior of the Deployment. */
    interface io$k8s$api$apps$v1$DeploymentSpec {
        /** Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready) */
        minReadySeconds?: number;
        /** Indicates that the deployment is paused. */
        paused?: boolean;
        /** The maximum time in seconds for a deployment to make progress before it is considered to be failed. The deployment controller will continue to process failed deployments and a condition with a ProgressDeadlineExceeded reason will be surfaced in the deployment status. Note that progress will not be estimated during the time a deployment is paused. Defaults to 600s. */
        progressDeadlineSeconds?: number;
        /** Number of desired pods. This is a pointer to distinguish between explicit zero and not specified. Defaults to 1. */
        replicas?: number;
        /** The number of old ReplicaSets to retain to allow rollback. This is a pointer to distinguish between explicit zero and not specified. Defaults to 10. */
        revisionHistoryLimit?: number;
        selector: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        strategy?: Schemas.io$k8s$api$apps$v1$DeploymentStrategy;
        template: Schemas.io$k8s$api$core$v1$PodTemplateSpec;
    }
    /** DeploymentStatus is the most recently observed status of the Deployment. */
    interface io$k8s$api$apps$v1$DeploymentStatus {
        /** Total number of available pods (ready for at least minReadySeconds) targeted by this deployment. */
        availableReplicas?: number;
        /** Count of hash collisions for the Deployment. The Deployment controller uses this field as a collision avoidance mechanism when it needs to create the name for the newest ReplicaSet. */
        collisionCount?: number;
        /** Represents the latest available observations of a deployment's current state. */
        conditions?: Schemas.io$k8s$api$apps$v1$DeploymentCondition[];
        /** The generation observed by the deployment controller. */
        observedGeneration?: number;
        /** readyReplicas is the number of pods targeted by this Deployment with a Ready Condition. */
        readyReplicas?: number;
        /** Total number of non-terminated pods targeted by this deployment (their labels match the selector). */
        replicas?: number;
        /** Total number of unavailable pods targeted by this deployment. This is the total number of pods that are still required for the deployment to have 100% available capacity. They may either be pods that are running but not yet available or pods that still have not been created. */
        unavailableReplicas?: number;
        /** Total number of non-terminated pods targeted by this deployment that have the desired template spec. */
        updatedReplicas?: number;
    }
    /** DeploymentStrategy describes how to replace existing pods with new ones. */
    interface io$k8s$api$apps$v1$DeploymentStrategy {
        rollingUpdate?: Schemas.io$k8s$api$apps$v1$RollingUpdateDeployment;
        /** Type of deployment. Can be "Recreate" or "RollingUpdate". Default is RollingUpdate. */
        type?: string;
    }
    /** ReplicaSet ensures that a specified number of pod replicas are running at any given time. */
    interface io$k8s$api$apps$v1$ReplicaSet {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$apps$v1$ReplicaSetSpec;
        status?: Schemas.io$k8s$api$apps$v1$ReplicaSetStatus;
    }
    /** ReplicaSetCondition describes the state of a replica set at a certain point. */
    interface io$k8s$api$apps$v1$ReplicaSetCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** A human readable message indicating details about the transition. */
        message?: string;
        /** The reason for the condition's last transition. */
        reason?: string;
        /** Status of the condition, one of True, False, Unknown. */
        status: string;
        /** Type of replica set condition. */
        type: string;
    }
    /** ReplicaSetList is a collection of ReplicaSets. */
    interface io$k8s$api$apps$v1$ReplicaSetList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of ReplicaSets. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller */
        items: Schemas.io$k8s$api$apps$v1$ReplicaSet[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ReplicaSetSpec is the specification of a ReplicaSet. */
    interface io$k8s$api$apps$v1$ReplicaSetSpec {
        /** Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready) */
        minReadySeconds?: number;
        /** Replicas is the number of desired replicas. This is a pointer to distinguish between explicit zero and unspecified. Defaults to 1. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller/#what-is-a-replicationcontroller */
        replicas?: number;
        selector: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        template?: Schemas.io$k8s$api$core$v1$PodTemplateSpec;
    }
    /** ReplicaSetStatus represents the current status of a ReplicaSet. */
    interface io$k8s$api$apps$v1$ReplicaSetStatus {
        /** The number of available replicas (ready for at least minReadySeconds) for this replica set. */
        availableReplicas?: number;
        /** Represents the latest available observations of a replica set's current state. */
        conditions?: Schemas.io$k8s$api$apps$v1$ReplicaSetCondition[];
        /** The number of pods that have labels matching the labels of the pod template of the replicaset. */
        fullyLabeledReplicas?: number;
        /** ObservedGeneration reflects the generation of the most recently observed ReplicaSet. */
        observedGeneration?: number;
        /** readyReplicas is the number of pods targeted by this ReplicaSet with a Ready Condition. */
        readyReplicas?: number;
        /** Replicas is the most recently observed number of replicas. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller/#what-is-a-replicationcontroller */
        replicas: number;
    }
    /** Spec to control the desired behavior of daemon set rolling update. */
    interface io$k8s$api$apps$v1$RollingUpdateDaemonSet {
        maxSurge?: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
        maxUnavailable?: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
    }
    /** Spec to control the desired behavior of rolling update. */
    interface io$k8s$api$apps$v1$RollingUpdateDeployment {
        maxSurge?: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
        maxUnavailable?: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
    }
    /** RollingUpdateStatefulSetStrategy is used to communicate parameter for RollingUpdateStatefulSetStrategyType. */
    interface io$k8s$api$apps$v1$RollingUpdateStatefulSetStrategy {
        maxUnavailable?: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
        /** Partition indicates the ordinal at which the StatefulSet should be partitioned for updates. During a rolling update, all pods from ordinal Replicas-1 to Partition are updated. All pods from ordinal Partition-1 to 0 remain untouched. This is helpful in being able to do a canary based deployment. The default value is 0. */
        partition?: number;
    }
    /**
     * StatefulSet represents a set of pods with consistent identities. Identities are defined as:
     *   - Network: A single stable DNS and hostname.
     *   - Storage: As many VolumeClaims as requested.
     *
     * The StatefulSet guarantees that a given network identity will always map to the same storage identity.
     */
    interface io$k8s$api$apps$v1$StatefulSet {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$apps$v1$StatefulSetSpec;
        status?: Schemas.io$k8s$api$apps$v1$StatefulSetStatus;
    }
    /** StatefulSetCondition describes the state of a statefulset at a certain point. */
    interface io$k8s$api$apps$v1$StatefulSetCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** A human readable message indicating details about the transition. */
        message?: string;
        /** The reason for the condition's last transition. */
        reason?: string;
        /** Status of the condition, one of True, False, Unknown. */
        status: string;
        /** Type of statefulset condition. */
        type: string;
    }
    /** StatefulSetList is a collection of StatefulSets. */
    interface io$k8s$api$apps$v1$StatefulSetList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is the list of stateful sets. */
        items: Schemas.io$k8s$api$apps$v1$StatefulSet[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** StatefulSetOrdinals describes the policy used for replica ordinal assignment in this StatefulSet. */
    interface io$k8s$api$apps$v1$StatefulSetOrdinals {
        /**
         * start is the number representing the first replica's index. It may be used to number replicas from an alternate index (eg: 1-indexed) over the default 0-indexed names, or to orchestrate progressive movement of replicas from one StatefulSet to another. If set, replica indices will be in the range:
         *   [.spec.ordinals.start, .spec.ordinals.start + .spec.replicas).
         * If unset, defaults to 0. Replica indices will be in the range:
         *   [0, .spec.replicas).
         */
        start?: number;
    }
    /** StatefulSetPersistentVolumeClaimRetentionPolicy describes the policy used for PVCs created from the StatefulSet VolumeClaimTemplates. */
    interface io$k8s$api$apps$v1$StatefulSetPersistentVolumeClaimRetentionPolicy {
        /** WhenDeleted specifies what happens to PVCs created from StatefulSet VolumeClaimTemplates when the StatefulSet is deleted. The default policy of `Retain` causes PVCs to not be affected by StatefulSet deletion. The `Delete` policy causes those PVCs to be deleted. */
        whenDeleted?: string;
        /** WhenScaled specifies what happens to PVCs created from StatefulSet VolumeClaimTemplates when the StatefulSet is scaled down. The default policy of `Retain` causes PVCs to not be affected by a scaledown. The `Delete` policy causes the associated PVCs for any excess pods above the replica count to be deleted. */
        whenScaled?: string;
    }
    /** A StatefulSetSpec is the specification of a StatefulSet. */
    interface io$k8s$api$apps$v1$StatefulSetSpec {
        /** Minimum number of seconds for which a newly created pod should be ready without any of its container crashing for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready) */
        minReadySeconds?: number;
        ordinals?: Schemas.io$k8s$api$apps$v1$StatefulSetOrdinals;
        persistentVolumeClaimRetentionPolicy?: Schemas.io$k8s$api$apps$v1$StatefulSetPersistentVolumeClaimRetentionPolicy;
        /** podManagementPolicy controls how pods are created during initial scale up, when replacing pods on nodes, or when scaling down. The default policy is `OrderedReady`, where pods are created in increasing order (pod-0, then pod-1, etc) and the controller will wait until each pod is ready before continuing. When scaling down, the pods are removed in the opposite order. The alternative policy is `Parallel` which will create pods in parallel to match the desired scale without waiting, and on scale down will delete all pods at once. */
        podManagementPolicy?: string;
        /** replicas is the desired number of replicas of the given Template. These are replicas in the sense that they are instantiations of the same Template, but individual replicas also have a consistent identity. If unspecified, defaults to 1. */
        replicas?: number;
        /** revisionHistoryLimit is the maximum number of revisions that will be maintained in the StatefulSet's revision history. The revision history consists of all revisions not represented by a currently applied StatefulSetSpec version. The default value is 10. */
        revisionHistoryLimit?: number;
        selector: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        /** serviceName is the name of the service that governs this StatefulSet. This service must exist before the StatefulSet, and is responsible for the network identity of the set. Pods get DNS/hostnames that follow the pattern: pod-specific-string.serviceName.default.svc.cluster.local where "pod-specific-string" is managed by the StatefulSet controller. */
        serviceName: string;
        template: Schemas.io$k8s$api$core$v1$PodTemplateSpec;
        updateStrategy?: Schemas.io$k8s$api$apps$v1$StatefulSetUpdateStrategy;
        /** volumeClaimTemplates is a list of claims that pods are allowed to reference. The StatefulSet controller is responsible for mapping network identities to claims in a way that maintains the identity of a pod. Every claim in this list must have at least one matching (by name) volumeMount in one container in the template. A claim in this list takes precedence over any volumes in the template, with the same name. */
        volumeClaimTemplates?: Schemas.io$k8s$api$core$v1$PersistentVolumeClaim[];
    }
    /** StatefulSetStatus represents the current state of a StatefulSet. */
    interface io$k8s$api$apps$v1$StatefulSetStatus {
        /** Total number of available pods (ready for at least minReadySeconds) targeted by this statefulset. */
        availableReplicas?: number;
        /** collisionCount is the count of hash collisions for the StatefulSet. The StatefulSet controller uses this field as a collision avoidance mechanism when it needs to create the name for the newest ControllerRevision. */
        collisionCount?: number;
        /** Represents the latest available observations of a statefulset's current state. */
        conditions?: Schemas.io$k8s$api$apps$v1$StatefulSetCondition[];
        /** currentReplicas is the number of Pods created by the StatefulSet controller from the StatefulSet version indicated by currentRevision. */
        currentReplicas?: number;
        /** currentRevision, if not empty, indicates the version of the StatefulSet used to generate Pods in the sequence [0,currentReplicas). */
        currentRevision?: string;
        /** observedGeneration is the most recent generation observed for this StatefulSet. It corresponds to the StatefulSet's generation, which is updated on mutation by the API Server. */
        observedGeneration?: number;
        /** readyReplicas is the number of pods created for this StatefulSet with a Ready Condition. */
        readyReplicas?: number;
        /** replicas is the number of Pods created by the StatefulSet controller. */
        replicas: number;
        /** updateRevision, if not empty, indicates the version of the StatefulSet used to generate Pods in the sequence [replicas-updatedReplicas,replicas) */
        updateRevision?: string;
        /** updatedReplicas is the number of Pods created by the StatefulSet controller from the StatefulSet version indicated by updateRevision. */
        updatedReplicas?: number;
    }
    /** StatefulSetUpdateStrategy indicates the strategy that the StatefulSet controller will use to perform updates. It includes any additional parameters necessary to perform the update for the indicated strategy. */
    interface io$k8s$api$apps$v1$StatefulSetUpdateStrategy {
        rollingUpdate?: Schemas.io$k8s$api$apps$v1$RollingUpdateStatefulSetStrategy;
        /** Type indicates the type of the StatefulSetUpdateStrategy. Default is RollingUpdate. */
        type?: string;
    }
    /** BoundObjectReference is a reference to an object that a token is bound to. */
    interface io$k8s$api$authentication$v1$BoundObjectReference {
        /** API version of the referent. */
        apiVersion?: string;
        /** Kind of the referent. Valid kinds are 'Pod' and 'Secret'. */
        kind?: string;
        /** Name of the referent. */
        name?: string;
        /** UID of the referent. */
        uid?: string;
    }
    /** TokenRequest requests a token for a given service account. */
    interface io$k8s$api$authentication$v1$TokenRequest {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$authentication$v1$TokenRequestSpec;
        status?: Schemas.io$k8s$api$authentication$v1$TokenRequestStatus;
    }
    /** TokenRequestSpec contains client provided parameters of a token request. */
    interface io$k8s$api$authentication$v1$TokenRequestSpec {
        /** Audiences are the intendend audiences of the token. A recipient of a token must identify themself with an identifier in the list of audiences of the token, and otherwise should reject the token. A token issued for multiple audiences may be used to authenticate against any of the audiences listed but implies a high degree of trust between the target audiences. */
        audiences: string[];
        boundObjectRef?: Schemas.io$k8s$api$authentication$v1$BoundObjectReference;
        /** ExpirationSeconds is the requested duration of validity of the request. The token issuer may return a token with a different validity duration so a client needs to check the 'expiration' field in a response. */
        expirationSeconds?: number;
    }
    /** TokenRequestStatus is the result of a token request. */
    interface io$k8s$api$authentication$v1$TokenRequestStatus {
        expirationTimestamp: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** Token is the opaque bearer token. */
        token: string;
    }
    /** TokenReview attempts to authenticate a token to a known user. Note: TokenReview requests may be cached by the webhook token authenticator plugin in the kube-apiserver. */
    interface io$k8s$api$authentication$v1$TokenReview {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$authentication$v1$TokenReviewSpec;
        status?: Schemas.io$k8s$api$authentication$v1$TokenReviewStatus;
    }
    /** TokenReviewSpec is a description of the token authentication request. */
    interface io$k8s$api$authentication$v1$TokenReviewSpec {
        /** Audiences is a list of the identifiers that the resource server presented with the token identifies as. Audience-aware token authenticators will verify that the token was intended for at least one of the audiences in this list. If no audiences are provided, the audience will default to the audience of the Kubernetes apiserver. */
        audiences?: string[];
        /** Token is the opaque bearer token. */
        token?: string;
    }
    /** TokenReviewStatus is the result of the token authentication request. */
    interface io$k8s$api$authentication$v1$TokenReviewStatus {
        /** Audiences are audience identifiers chosen by the authenticator that are compatible with both the TokenReview and token. An identifier is any identifier in the intersection of the TokenReviewSpec audiences and the token's audiences. A client of the TokenReview API that sets the spec.audiences field should validate that a compatible audience identifier is returned in the status.audiences field to ensure that the TokenReview server is audience aware. If a TokenReview returns an empty status.audience field where status.authenticated is "true", the token is valid against the audience of the Kubernetes API server. */
        audiences?: string[];
        /** Authenticated indicates that the token was associated with a known user. */
        authenticated?: boolean;
        /** Error indicates that the token couldn't be checked */
        error?: string;
        user?: Schemas.io$k8s$api$authentication$v1$UserInfo;
    }
    /** UserInfo holds the information about the user needed to implement the user.Info interface. */
    interface io$k8s$api$authentication$v1$UserInfo {
        /** Any additional information provided by the authenticator. */
        extra?: {
            [key: string]: string[];
        };
        /** The names of groups this user is a part of. */
        groups?: string[];
        /** A unique value that identifies this user across time. If this user is deleted and another user by the same name is added, they will have different UIDs. */
        uid?: string;
        /** The name that uniquely identifies this user among all active users. */
        username?: string;
    }
    /** SelfSubjectReview contains the user information that the kube-apiserver has about the user making this request. When using impersonation, users will receive the user info of the user being impersonated.  If impersonation or request header authentication is used, any extra keys will have their case ignored and returned as lowercase. */
    interface io$k8s$api$authentication$v1alpha1$SelfSubjectReview {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        status?: Schemas.io$k8s$api$authentication$v1alpha1$SelfSubjectReviewStatus;
    }
    /** SelfSubjectReviewStatus is filled by the kube-apiserver and sent back to a user. */
    interface io$k8s$api$authentication$v1alpha1$SelfSubjectReviewStatus {
        userInfo?: Schemas.io$k8s$api$authentication$v1$UserInfo;
    }
    /** SelfSubjectReview contains the user information that the kube-apiserver has about the user making this request. When using impersonation, users will receive the user info of the user being impersonated.  If impersonation or request header authentication is used, any extra keys will have their case ignored and returned as lowercase. */
    interface io$k8s$api$authentication$v1beta1$SelfSubjectReview {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        status?: Schemas.io$k8s$api$authentication$v1beta1$SelfSubjectReviewStatus;
    }
    /** SelfSubjectReviewStatus is filled by the kube-apiserver and sent back to a user. */
    interface io$k8s$api$authentication$v1beta1$SelfSubjectReviewStatus {
        userInfo?: Schemas.io$k8s$api$authentication$v1$UserInfo;
    }
    /** LocalSubjectAccessReview checks whether or not a user or group can perform an action in a given namespace. Having a namespace scoped resource makes it much easier to grant namespace scoped policy that includes permissions checking. */
    interface io$k8s$api$authorization$v1$LocalSubjectAccessReview {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$authorization$v1$SubjectAccessReviewSpec;
        status?: Schemas.io$k8s$api$authorization$v1$SubjectAccessReviewStatus;
    }
    /** NonResourceAttributes includes the authorization attributes available for non-resource requests to the Authorizer interface */
    interface io$k8s$api$authorization$v1$NonResourceAttributes {
        /** Path is the URL path of the request */
        path?: string;
        /** Verb is the standard HTTP verb */
        verb?: string;
    }
    /** NonResourceRule holds information that describes a rule for the non-resource */
    interface io$k8s$api$authorization$v1$NonResourceRule {
        /** NonResourceURLs is a set of partial urls that a user should have access to.  *s are allowed, but only as the full, final step in the path.  "*" means all. */
        nonResourceURLs?: string[];
        /** Verb is a list of kubernetes non-resource API verbs, like: get, post, put, delete, patch, head, options.  "*" means all. */
        verbs: string[];
    }
    /** ResourceAttributes includes the authorization attributes available for resource requests to the Authorizer interface */
    interface io$k8s$api$authorization$v1$ResourceAttributes {
        /** Group is the API Group of the Resource.  "*" means all. */
        group?: string;
        /** Name is the name of the resource being requested for a "get" or deleted for a "delete". "" (empty) means all. */
        name?: string;
        /** Namespace is the namespace of the action being requested.  Currently, there is no distinction between no namespace and all namespaces "" (empty) is defaulted for LocalSubjectAccessReviews "" (empty) is empty for cluster-scoped resources "" (empty) means "all" for namespace scoped resources from a SubjectAccessReview or SelfSubjectAccessReview */
        namespace?: string;
        /** Resource is one of the existing resource types.  "*" means all. */
        resource?: string;
        /** Subresource is one of the existing resource types.  "" means none. */
        subresource?: string;
        /** Verb is a kubernetes resource API verb, like: get, list, watch, create, update, delete, proxy.  "*" means all. */
        verb?: string;
        /** Version is the API Version of the Resource.  "*" means all. */
        version?: string;
    }
    /** ResourceRule is the list of actions the subject is allowed to perform on resources. The list ordering isn't significant, may contain duplicates, and possibly be incomplete. */
    interface io$k8s$api$authorization$v1$ResourceRule {
        /** APIGroups is the name of the APIGroup that contains the resources.  If multiple API groups are specified, any action requested against one of the enumerated resources in any API group will be allowed.  "*" means all. */
        apiGroups?: string[];
        /** ResourceNames is an optional white list of names that the rule applies to.  An empty set means that everything is allowed.  "*" means all. */
        resourceNames?: string[];
        /**
         * Resources is a list of resources this rule applies to.  "*" means all in the specified apiGroups.
         *  "\*\\/foo" represents the subresource 'foo' for all resources in the specified apiGroups.
         */
        resources?: string[];
        /** Verb is a list of kubernetes resource API verbs, like: get, list, watch, create, update, delete, proxy.  "*" means all. */
        verbs: string[];
    }
    /** SelfSubjectAccessReview checks whether or the current user can perform an action.  Not filling in a spec.namespace means "in all namespaces".  Self is a special case, because users should always be able to check whether they can perform an action */
    interface io$k8s$api$authorization$v1$SelfSubjectAccessReview {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$authorization$v1$SelfSubjectAccessReviewSpec;
        status?: Schemas.io$k8s$api$authorization$v1$SubjectAccessReviewStatus;
    }
    /** SelfSubjectAccessReviewSpec is a description of the access request.  Exactly one of ResourceAuthorizationAttributes and NonResourceAuthorizationAttributes must be set */
    interface io$k8s$api$authorization$v1$SelfSubjectAccessReviewSpec {
        nonResourceAttributes?: Schemas.io$k8s$api$authorization$v1$NonResourceAttributes;
        resourceAttributes?: Schemas.io$k8s$api$authorization$v1$ResourceAttributes;
    }
    /** SelfSubjectRulesReview enumerates the set of actions the current user can perform within a namespace. The returned list of actions may be incomplete depending on the server's authorization mode, and any errors experienced during the evaluation. SelfSubjectRulesReview should be used by UIs to show/hide actions, or to quickly let an end user reason about their permissions. It should NOT Be used by external systems to drive authorization decisions as this raises confused deputy, cache lifetime/revocation, and correctness concerns. SubjectAccessReview, and LocalAccessReview are the correct way to defer authorization decisions to the API server. */
    interface io$k8s$api$authorization$v1$SelfSubjectRulesReview {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$authorization$v1$SelfSubjectRulesReviewSpec;
        status?: Schemas.io$k8s$api$authorization$v1$SubjectRulesReviewStatus;
    }
    /** SelfSubjectRulesReviewSpec defines the specification for SelfSubjectRulesReview. */
    interface io$k8s$api$authorization$v1$SelfSubjectRulesReviewSpec {
        /** Namespace to evaluate rules for. Required. */
        namespace?: string;
    }
    /** SubjectAccessReview checks whether or not a user or group can perform an action. */
    interface io$k8s$api$authorization$v1$SubjectAccessReview {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$authorization$v1$SubjectAccessReviewSpec;
        status?: Schemas.io$k8s$api$authorization$v1$SubjectAccessReviewStatus;
    }
    /** SubjectAccessReviewSpec is a description of the access request.  Exactly one of ResourceAuthorizationAttributes and NonResourceAuthorizationAttributes must be set */
    interface io$k8s$api$authorization$v1$SubjectAccessReviewSpec {
        /** Extra corresponds to the user.Info.GetExtra() method from the authenticator.  Since that is input to the authorizer it needs a reflection here. */
        extra?: {
            [key: string]: string[];
        };
        /** Groups is the groups you're testing for. */
        groups?: string[];
        nonResourceAttributes?: Schemas.io$k8s$api$authorization$v1$NonResourceAttributes;
        resourceAttributes?: Schemas.io$k8s$api$authorization$v1$ResourceAttributes;
        /** UID information about the requesting user. */
        uid?: string;
        /** User is the user you're testing for. If you specify "User" but not "Groups", then is it interpreted as "What if User were not a member of any groups */
        user?: string;
    }
    /** SubjectAccessReviewStatus */
    interface io$k8s$api$authorization$v1$SubjectAccessReviewStatus {
        /** Allowed is required. True if the action would be allowed, false otherwise. */
        allowed: boolean;
        /** Denied is optional. True if the action would be denied, otherwise false. If both allowed is false and denied is false, then the authorizer has no opinion on whether to authorize the action. Denied may not be true if Allowed is true. */
        denied?: boolean;
        /** EvaluationError is an indication that some error occurred during the authorization check. It is entirely possible to get an error and be able to continue determine authorization status in spite of it. For instance, RBAC can be missing a role, but enough roles are still present and bound to reason about the request. */
        evaluationError?: string;
        /** Reason is optional.  It indicates why a request was allowed or denied. */
        reason?: string;
    }
    /** SubjectRulesReviewStatus contains the result of a rules check. This check can be incomplete depending on the set of authorizers the server is configured with and any errors experienced during evaluation. Because authorization rules are additive, if a rule appears in a list it's safe to assume the subject has that permission, even if that list is incomplete. */
    interface io$k8s$api$authorization$v1$SubjectRulesReviewStatus {
        /** EvaluationError can appear in combination with Rules. It indicates an error occurred during rule evaluation, such as an authorizer that doesn't support rule evaluation, and that ResourceRules and/or NonResourceRules may be incomplete. */
        evaluationError?: string;
        /** Incomplete is true when the rules returned by this call are incomplete. This is most commonly encountered when an authorizer, such as an external authorizer, doesn't support rules evaluation. */
        incomplete: boolean;
        /** NonResourceRules is the list of actions the subject is allowed to perform on non-resources. The list ordering isn't significant, may contain duplicates, and possibly be incomplete. */
        nonResourceRules: Schemas.io$k8s$api$authorization$v1$NonResourceRule[];
        /** ResourceRules is the list of actions the subject is allowed to perform on resources. The list ordering isn't significant, may contain duplicates, and possibly be incomplete. */
        resourceRules: Schemas.io$k8s$api$authorization$v1$ResourceRule[];
    }
    /** CrossVersionObjectReference contains enough information to let you identify the referred resource. */
    interface io$k8s$api$autoscaling$v1$CrossVersionObjectReference {
        /** apiVersion is the API version of the referent */
        apiVersion?: string;
        /** kind is the kind of the referent; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind: string;
        /** name is the name of the referent; More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names */
        name: string;
    }
    /** configuration of a horizontal pod autoscaler. */
    interface io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerSpec;
        status?: Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerStatus;
    }
    /** list of horizontal pod autoscaler objects. */
    interface io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of horizontal pod autoscaler objects. */
        items: Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** specification of a horizontal pod autoscaler. */
    interface io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerSpec {
        /** maxReplicas is the upper limit for the number of pods that can be set by the autoscaler; cannot be smaller than MinReplicas. */
        maxReplicas: number;
        /** minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down.  It defaults to 1 pod.  minReplicas is allowed to be 0 if the alpha feature gate HPAScaleToZero is enabled and at least one Object or External metric is configured.  Scaling is active as long as at least one metric value is available. */
        minReplicas?: number;
        scaleTargetRef: Schemas.io$k8s$api$autoscaling$v1$CrossVersionObjectReference;
        /** targetCPUUtilizationPercentage is the target average CPU utilization (represented as a percentage of requested CPU) over all the pods; if not specified the default autoscaling policy will be used. */
        targetCPUUtilizationPercentage?: number;
    }
    /** current status of a horizontal pod autoscaler */
    interface io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerStatus {
        /** currentCPUUtilizationPercentage is the current average CPU utilization over all pods, represented as a percentage of requested CPU, e.g. 70 means that an average pod is using now 70% of its requested CPU. */
        currentCPUUtilizationPercentage?: number;
        /** currentReplicas is the current number of replicas of pods managed by this autoscaler. */
        currentReplicas: number;
        /** desiredReplicas is the  desired number of replicas of pods managed by this autoscaler. */
        desiredReplicas: number;
        lastScaleTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** observedGeneration is the most recent generation observed by this autoscaler. */
        observedGeneration?: number;
    }
    /** Scale represents a scaling request for a resource. */
    interface io$k8s$api$autoscaling$v1$Scale {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$autoscaling$v1$ScaleSpec;
        status?: Schemas.io$k8s$api$autoscaling$v1$ScaleStatus;
    }
    /** ScaleSpec describes the attributes of a scale subresource. */
    interface io$k8s$api$autoscaling$v1$ScaleSpec {
        /** replicas is the desired number of instances for the scaled object. */
        replicas?: number;
    }
    /** ScaleStatus represents the current status of a scale subresource. */
    interface io$k8s$api$autoscaling$v1$ScaleStatus {
        /** replicas is the actual number of observed instances of the scaled object. */
        replicas: number;
        /** selector is the label query over pods that should match the replicas count. This is same as the label selector but in the string format to avoid introspection by clients. The string will be in the same format as the query-param syntax. More info about label selectors: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/ */
        selector?: string;
    }
    /** ContainerResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set. */
    interface io$k8s$api$autoscaling$v2$ContainerResourceMetricSource {
        /** container is the name of the container in the pods of the scaling target */
        container: string;
        /** name is the name of the resource in question. */
        name: string;
        target: Schemas.io$k8s$api$autoscaling$v2$MetricTarget;
    }
    /** ContainerResourceMetricStatus indicates the current value of a resource metric known to Kubernetes, as specified in requests and limits, describing a single container in each pod in the current scale target (e.g. CPU or memory).  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source. */
    interface io$k8s$api$autoscaling$v2$ContainerResourceMetricStatus {
        /** container is the name of the container in the pods of the scaling target */
        container: string;
        current: Schemas.io$k8s$api$autoscaling$v2$MetricValueStatus;
        /** name is the name of the resource in question. */
        name: string;
    }
    /** CrossVersionObjectReference contains enough information to let you identify the referred resource. */
    interface io$k8s$api$autoscaling$v2$CrossVersionObjectReference {
        /** apiVersion is the API version of the referent */
        apiVersion?: string;
        /** kind is the kind of the referent; More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind: string;
        /** name is the name of the referent; More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names */
        name: string;
    }
    /** ExternalMetricSource indicates how to scale on a metric not associated with any Kubernetes object (for example length of queue in cloud messaging service, or QPS from loadbalancer running outside of cluster). */
    interface io$k8s$api$autoscaling$v2$ExternalMetricSource {
        metric: Schemas.io$k8s$api$autoscaling$v2$MetricIdentifier;
        target: Schemas.io$k8s$api$autoscaling$v2$MetricTarget;
    }
    /** ExternalMetricStatus indicates the current value of a global metric not associated with any Kubernetes object. */
    interface io$k8s$api$autoscaling$v2$ExternalMetricStatus {
        current: Schemas.io$k8s$api$autoscaling$v2$MetricValueStatus;
        metric: Schemas.io$k8s$api$autoscaling$v2$MetricIdentifier;
    }
    /** HPAScalingPolicy is a single policy which must hold true for a specified past interval. */
    interface io$k8s$api$autoscaling$v2$HPAScalingPolicy {
        /** periodSeconds specifies the window of time for which the policy should hold true. PeriodSeconds must be greater than zero and less than or equal to 1800 (30 min). */
        periodSeconds: number;
        /** type is used to specify the scaling policy. */
        type: string;
        /** value contains the amount of change which is permitted by the policy. It must be greater than zero */
        value: number;
    }
    /** HPAScalingRules configures the scaling behavior for one direction. These Rules are applied after calculating DesiredReplicas from metrics for the HPA. They can limit the scaling velocity by specifying scaling policies. They can prevent flapping by specifying the stabilization window, so that the number of replicas is not set instantly, instead, the safest value from the stabilization window is chosen. */
    interface io$k8s$api$autoscaling$v2$HPAScalingRules {
        /** policies is a list of potential scaling polices which can be used during scaling. At least one policy must be specified, otherwise the HPAScalingRules will be discarded as invalid */
        policies?: Schemas.io$k8s$api$autoscaling$v2$HPAScalingPolicy[];
        /** selectPolicy is used to specify which policy should be used. If not set, the default value Max is used. */
        selectPolicy?: string;
        /** stabilizationWindowSeconds is the number of seconds for which past recommendations should be considered while scaling up or scaling down. StabilizationWindowSeconds must be greater than or equal to zero and less than or equal to 3600 (one hour). If not set, use the default values: - For scale up: 0 (i.e. no stabilization is done). - For scale down: 300 (i.e. the stabilization window is 300 seconds long). */
        stabilizationWindowSeconds?: number;
    }
    /** HorizontalPodAutoscaler is the configuration for a horizontal pod autoscaler, which automatically manages the replica count of any resource implementing the scale subresource based on the metrics specified. */
    interface io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerSpec;
        status?: Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerStatus;
    }
    /** HorizontalPodAutoscalerBehavior configures the scaling behavior of the target in both Up and Down directions (scaleUp and scaleDown fields respectively). */
    interface io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerBehavior {
        scaleDown?: Schemas.io$k8s$api$autoscaling$v2$HPAScalingRules;
        scaleUp?: Schemas.io$k8s$api$autoscaling$v2$HPAScalingRules;
    }
    /** HorizontalPodAutoscalerCondition describes the state of a HorizontalPodAutoscaler at a certain point. */
    interface io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** message is a human-readable explanation containing details about the transition */
        message?: string;
        /** reason is the reason for the condition's last transition. */
        reason?: string;
        /** status is the status of the condition (True, False, Unknown) */
        status: string;
        /** type describes the current condition */
        type: string;
    }
    /** HorizontalPodAutoscalerList is a list of horizontal pod autoscaler objects. */
    interface io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of horizontal pod autoscaler objects. */
        items: Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** HorizontalPodAutoscalerSpec describes the desired functionality of the HorizontalPodAutoscaler. */
    interface io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerSpec {
        behavior?: Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerBehavior;
        /** maxReplicas is the upper limit for the number of replicas to which the autoscaler can scale up. It cannot be less that minReplicas. */
        maxReplicas: number;
        /** metrics contains the specifications for which to use to calculate the desired replica count (the maximum replica count across all metrics will be used).  The desired replica count is calculated multiplying the ratio between the target value and the current value by the current number of pods.  Ergo, metrics used must decrease as the pod count is increased, and vice-versa.  See the individual metric source types for more information about how each type of metric must respond. If not set, the default metric will be set to 80% average CPU utilization. */
        metrics?: Schemas.io$k8s$api$autoscaling$v2$MetricSpec[];
        /** minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down.  It defaults to 1 pod.  minReplicas is allowed to be 0 if the alpha feature gate HPAScaleToZero is enabled and at least one Object or External metric is configured.  Scaling is active as long as at least one metric value is available. */
        minReplicas?: number;
        scaleTargetRef: Schemas.io$k8s$api$autoscaling$v2$CrossVersionObjectReference;
    }
    /** HorizontalPodAutoscalerStatus describes the current status of a horizontal pod autoscaler. */
    interface io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerStatus {
        /** conditions is the set of conditions required for this autoscaler to scale its target, and indicates whether or not those conditions are met. */
        conditions?: Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerCondition[];
        /** currentMetrics is the last read state of the metrics used by this autoscaler. */
        currentMetrics?: Schemas.io$k8s$api$autoscaling$v2$MetricStatus[];
        /** currentReplicas is current number of replicas of pods managed by this autoscaler, as last seen by the autoscaler. */
        currentReplicas?: number;
        /** desiredReplicas is the desired number of replicas of pods managed by this autoscaler, as last calculated by the autoscaler. */
        desiredReplicas: number;
        lastScaleTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** observedGeneration is the most recent generation observed by this autoscaler. */
        observedGeneration?: number;
    }
    /** MetricIdentifier defines the name and optionally selector for a metric */
    interface io$k8s$api$autoscaling$v2$MetricIdentifier {
        /** name is the name of the given metric */
        name: string;
        selector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
    }
    /** MetricSpec specifies how to scale based on a single metric (only `type` and one other matching field should be set at once). */
    interface io$k8s$api$autoscaling$v2$MetricSpec {
        containerResource?: Schemas.io$k8s$api$autoscaling$v2$ContainerResourceMetricSource;
        external?: Schemas.io$k8s$api$autoscaling$v2$ExternalMetricSource;
        object?: Schemas.io$k8s$api$autoscaling$v2$ObjectMetricSource;
        pods?: Schemas.io$k8s$api$autoscaling$v2$PodsMetricSource;
        resource?: Schemas.io$k8s$api$autoscaling$v2$ResourceMetricSource;
        /** type is the type of metric source.  It should be one of "ContainerResource", "External", "Object", "Pods" or "Resource", each mapping to a matching field in the object. Note: "ContainerResource" type is available on when the feature-gate HPAContainerMetrics is enabled */
        type: string;
    }
    /** MetricStatus describes the last-read state of a single metric. */
    interface io$k8s$api$autoscaling$v2$MetricStatus {
        containerResource?: Schemas.io$k8s$api$autoscaling$v2$ContainerResourceMetricStatus;
        external?: Schemas.io$k8s$api$autoscaling$v2$ExternalMetricStatus;
        object?: Schemas.io$k8s$api$autoscaling$v2$ObjectMetricStatus;
        pods?: Schemas.io$k8s$api$autoscaling$v2$PodsMetricStatus;
        resource?: Schemas.io$k8s$api$autoscaling$v2$ResourceMetricStatus;
        /** type is the type of metric source.  It will be one of "ContainerResource", "External", "Object", "Pods" or "Resource", each corresponds to a matching field in the object. Note: "ContainerResource" type is available on when the feature-gate HPAContainerMetrics is enabled */
        type: string;
    }
    /** MetricTarget defines the target value, average value, or average utilization of a specific metric */
    interface io$k8s$api$autoscaling$v2$MetricTarget {
        /** averageUtilization is the target value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods. Currently only valid for Resource metric source type */
        averageUtilization?: number;
        averageValue?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        /** type represents whether the metric type is Utilization, Value, or AverageValue */
        type: string;
        value?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
    }
    /** MetricValueStatus holds the current value for a metric */
    interface io$k8s$api$autoscaling$v2$MetricValueStatus {
        /** currentAverageUtilization is the current value of the average of the resource metric across all relevant pods, represented as a percentage of the requested value of the resource for the pods. */
        averageUtilization?: number;
        averageValue?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        value?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
    }
    /** ObjectMetricSource indicates how to scale on a metric describing a kubernetes object (for example, hits-per-second on an Ingress object). */
    interface io$k8s$api$autoscaling$v2$ObjectMetricSource {
        describedObject: Schemas.io$k8s$api$autoscaling$v2$CrossVersionObjectReference;
        metric: Schemas.io$k8s$api$autoscaling$v2$MetricIdentifier;
        target: Schemas.io$k8s$api$autoscaling$v2$MetricTarget;
    }
    /** ObjectMetricStatus indicates the current value of a metric describing a kubernetes object (for example, hits-per-second on an Ingress object). */
    interface io$k8s$api$autoscaling$v2$ObjectMetricStatus {
        current: Schemas.io$k8s$api$autoscaling$v2$MetricValueStatus;
        describedObject: Schemas.io$k8s$api$autoscaling$v2$CrossVersionObjectReference;
        metric: Schemas.io$k8s$api$autoscaling$v2$MetricIdentifier;
    }
    /** PodsMetricSource indicates how to scale on a metric describing each pod in the current scale target (for example, transactions-processed-per-second). The values will be averaged together before being compared to the target value. */
    interface io$k8s$api$autoscaling$v2$PodsMetricSource {
        metric: Schemas.io$k8s$api$autoscaling$v2$MetricIdentifier;
        target: Schemas.io$k8s$api$autoscaling$v2$MetricTarget;
    }
    /** PodsMetricStatus indicates the current value of a metric describing each pod in the current scale target (for example, transactions-processed-per-second). */
    interface io$k8s$api$autoscaling$v2$PodsMetricStatus {
        current: Schemas.io$k8s$api$autoscaling$v2$MetricValueStatus;
        metric: Schemas.io$k8s$api$autoscaling$v2$MetricIdentifier;
    }
    /** ResourceMetricSource indicates how to scale on a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  The values will be averaged together before being compared to the target.  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source.  Only one "target" type should be set. */
    interface io$k8s$api$autoscaling$v2$ResourceMetricSource {
        /** name is the name of the resource in question. */
        name: string;
        target: Schemas.io$k8s$api$autoscaling$v2$MetricTarget;
    }
    /** ResourceMetricStatus indicates the current value of a resource metric known to Kubernetes, as specified in requests and limits, describing each pod in the current scale target (e.g. CPU or memory).  Such metrics are built in to Kubernetes, and have special scaling options on top of those available to normal per-pod metrics using the "pods" source. */
    interface io$k8s$api$autoscaling$v2$ResourceMetricStatus {
        current: Schemas.io$k8s$api$autoscaling$v2$MetricValueStatus;
        /** name is the name of the resource in question. */
        name: string;
    }
    /** CronJob represents the configuration of a single cron job. */
    interface io$k8s$api$batch$v1$CronJob {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$batch$v1$CronJobSpec;
        status?: Schemas.io$k8s$api$batch$v1$CronJobStatus;
    }
    /** CronJobList is a collection of cron jobs. */
    interface io$k8s$api$batch$v1$CronJobList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of CronJobs. */
        items: Schemas.io$k8s$api$batch$v1$CronJob[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** CronJobSpec describes how the job execution will look like and when it will actually run. */
    interface io$k8s$api$batch$v1$CronJobSpec {
        /**
         * Specifies how to treat concurrent executions of a Job. Valid values are:
         *
         * - "Allow" (default): allows CronJobs to run concurrently; - "Forbid": forbids concurrent runs, skipping next run if previous run hasn't finished yet; - "Replace": cancels currently running job and replaces it with a new one
         */
        concurrencyPolicy?: string;
        /** The number of failed finished jobs to retain. Value must be non-negative integer. Defaults to 1. */
        failedJobsHistoryLimit?: number;
        jobTemplate: Schemas.io$k8s$api$batch$v1$JobTemplateSpec;
        /** The schedule in Cron format, see https://en.wikipedia.org/wiki/Cron. */
        schedule: string;
        /** Optional deadline in seconds for starting the job if it misses scheduled time for any reason.  Missed jobs executions will be counted as failed ones. */
        startingDeadlineSeconds?: number;
        /** The number of successful finished jobs to retain. Value must be non-negative integer. Defaults to 3. */
        successfulJobsHistoryLimit?: number;
        /** This flag tells the controller to suspend subsequent executions, it does not apply to already started executions.  Defaults to false. */
        suspend?: boolean;
        /** The time zone name for the given schedule, see https://en.wikipedia.org/wiki/List_of_tz_database_time_zones. If not specified, this will default to the time zone of the kube-controller-manager process. The set of valid time zone names and the time zone offset is loaded from the system-wide time zone database by the API server during CronJob validation and the controller manager during execution. If no system-wide time zone database can be found a bundled version of the database is used instead. If the time zone name becomes invalid during the lifetime of a CronJob or due to a change in host configuration, the controller will stop creating new new Jobs and will create a system event with the reason UnknownTimeZone. More information can be found in https://kubernetes.io/docs/concepts/workloads/controllers/cron-jobs/#time-zones */
        timeZone?: string;
    }
    /** CronJobStatus represents the current state of a cron job. */
    interface io$k8s$api$batch$v1$CronJobStatus {
        /** A list of pointers to currently running jobs. */
        active?: Schemas.io$k8s$api$core$v1$ObjectReference[];
        lastScheduleTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        lastSuccessfulTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
    }
    /** Job represents the configuration of a single job. */
    interface io$k8s$api$batch$v1$Job {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$batch$v1$JobSpec;
        status?: Schemas.io$k8s$api$batch$v1$JobStatus;
    }
    /** JobCondition describes current state of a job. */
    interface io$k8s$api$batch$v1$JobCondition {
        lastProbeTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** Human readable message indicating details about last transition. */
        message?: string;
        /** (brief) reason for the condition's last transition. */
        reason?: string;
        /** Status of the condition, one of True, False, Unknown. */
        status: string;
        /** Type of job condition, Complete or Failed. */
        type: string;
    }
    /** JobList is a collection of jobs. */
    interface io$k8s$api$batch$v1$JobList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of Jobs. */
        items: Schemas.io$k8s$api$batch$v1$Job[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** JobSpec describes how the job execution will look like. */
    interface io$k8s$api$batch$v1$JobSpec {
        /** Specifies the duration in seconds relative to the startTime that the job may be continuously active before the system tries to terminate it; value must be positive integer. If a Job is suspended (at creation or through an update), this timer will effectively be stopped and reset when the Job is resumed again. */
        activeDeadlineSeconds?: number;
        /** Specifies the number of retries before marking this job failed. Defaults to 6 */
        backoffLimit?: number;
        /**
         * completionMode specifies how Pod completions are tracked. It can be `NonIndexed` (default) or `Indexed`.
         *
         * `NonIndexed` means that the Job is considered complete when there have been .spec.completions successfully completed Pods. Each Pod completion is homologous to each other.
         *
         * `Indexed` means that the Pods of a Job get an associated completion index from 0 to (.spec.completions - 1), available in the annotation batch.kubernetes.io/job-completion-index. The Job is considered complete when there is one successfully completed Pod for each index. When value is `Indexed`, .spec.completions must be specified and `.spec.parallelism` must be less than or equal to 10^5. In addition, The Pod name takes the form `$(job-name)-$(index)-$(random-string)`, the Pod hostname takes the form `$(job-name)-$(index)`.
         *
         * More completion modes can be added in the future. If the Job controller observes a mode that it doesn't recognize, which is possible during upgrades due to version skew, the controller skips updates for the Job.
         */
        completionMode?: string;
        /** Specifies the desired number of successfully finished pods the job should be run with.  Setting to null means that the success of any pod signals the success of all pods, and allows parallelism to have any positive value.  Setting to 1 means that parallelism is limited to 1 and the success of that pod signals the success of the job. More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/ */
        completions?: number;
        /** manualSelector controls generation of pod labels and pod selectors. Leave `manualSelector` unset unless you are certain what you are doing. When false or unset, the system pick labels unique to this job and appends those labels to the pod template.  When true, the user is responsible for picking unique labels and specifying the selector.  Failure to pick a unique label may cause this and other jobs to not function correctly.  However, You may see `manualSelector=true` in jobs that were created with the old `extensions/v1beta1` API. More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/#specifying-your-own-pod-selector */
        manualSelector?: boolean;
        /** Specifies the maximum desired number of pods the job should run at any given time. The actual number of pods running in steady state will be less than this number when ((.spec.completions - .status.successful) < .spec.parallelism), i.e. when the work left to do is less than max parallelism. More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/ */
        parallelism?: number;
        podFailurePolicy?: Schemas.io$k8s$api$batch$v1$PodFailurePolicy;
        selector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        /** suspend specifies whether the Job controller should create Pods or not. If a Job is created with suspend set to true, no Pods are created by the Job controller. If a Job is suspended after creation (i.e. the flag goes from false to true), the Job controller will delete all active Pods associated with this Job. Users must design their workload to gracefully handle this. Suspending a Job will reset the StartTime field of the Job, effectively resetting the ActiveDeadlineSeconds timer too. Defaults to false. */
        suspend?: boolean;
        template: Schemas.io$k8s$api$core$v1$PodTemplateSpec;
        /** ttlSecondsAfterFinished limits the lifetime of a Job that has finished execution (either Complete or Failed). If this field is set, ttlSecondsAfterFinished after the Job finishes, it is eligible to be automatically deleted. When the Job is being deleted, its lifecycle guarantees (e.g. finalizers) will be honored. If this field is unset, the Job won't be automatically deleted. If this field is set to zero, the Job becomes eligible to be deleted immediately after it finishes. */
        ttlSecondsAfterFinished?: number;
    }
    /** JobStatus represents the current state of a Job. */
    interface io$k8s$api$batch$v1$JobStatus {
        /** The number of pending and running pods. */
        active?: number;
        /** completedIndexes holds the completed indexes when .spec.completionMode = "Indexed" in a text format. The indexes are represented as decimal integers separated by commas. The numbers are listed in increasing order. Three or more consecutive numbers are compressed and represented by the first and last element of the series, separated by a hyphen. For example, if the completed indexes are 1, 3, 4, 5 and 7, they are represented as "1,3-5,7". */
        completedIndexes?: string;
        completionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** The latest available observations of an object's current state. When a Job fails, one of the conditions will have type "Failed" and status true. When a Job is suspended, one of the conditions will have type "Suspended" and status true; when the Job is resumed, the status of this condition will become false. When a Job is completed, one of the conditions will have type "Complete" and status true. More info: https://kubernetes.io/docs/concepts/workloads/controllers/jobs-run-to-completion/ */
        conditions?: Schemas.io$k8s$api$batch$v1$JobCondition[];
        /** The number of pods which reached phase Failed. */
        failed?: number;
        /**
         * The number of pods which have a Ready condition.
         *
         * This field is beta-level. The job controller populates the field when the feature gate JobReadyPods is enabled (enabled by default).
         */
        ready?: number;
        startTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** The number of pods which reached phase Succeeded. */
        succeeded?: number;
        uncountedTerminatedPods?: Schemas.io$k8s$api$batch$v1$UncountedTerminatedPods;
    }
    /** JobTemplateSpec describes the data a Job should have when created from a template */
    interface io$k8s$api$batch$v1$JobTemplateSpec {
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$batch$v1$JobSpec;
    }
    /** PodFailurePolicy describes how failed pods influence the backoffLimit. */
    interface io$k8s$api$batch$v1$PodFailurePolicy {
        /** A list of pod failure policy rules. The rules are evaluated in order. Once a rule matches a Pod failure, the remaining of the rules are ignored. When no rule matches the Pod failure, the default handling applies - the counter of pod failures is incremented and it is checked against the backoffLimit. At most 20 elements are allowed. */
        rules: Schemas.io$k8s$api$batch$v1$PodFailurePolicyRule[];
    }
    /** PodFailurePolicyOnExitCodesRequirement describes the requirement for handling a failed pod based on its container exit codes. In particular, it lookups the .state.terminated.exitCode for each app container and init container status, represented by the .status.containerStatuses and .status.initContainerStatuses fields in the Pod status, respectively. Containers completed with success (exit code 0) are excluded from the requirement check. */
    interface io$k8s$api$batch$v1$PodFailurePolicyOnExitCodesRequirement {
        /** Restricts the check for exit codes to the container with the specified name. When null, the rule applies to all containers. When specified, it should match one the container or initContainer names in the pod template. */
        containerName?: string;
        /**
         * Represents the relationship between the container exit code(s) and the specified values. Containers completed with success (exit code 0) are excluded from the requirement check. Possible values are:
         *
         * - In: the requirement is satisfied if at least one container exit code
         *   (might be multiple if there are multiple containers not restricted
         *   by the 'containerName' field) is in the set of specified values.
         * - NotIn: the requirement is satisfied if at least one container exit code
         *   (might be multiple if there are multiple containers not restricted
         *   by the 'containerName' field) is not in the set of specified values.
         * Additional values are considered to be added in the future. Clients should react to an unknown operator by assuming the requirement is not satisfied.
         */
        operator: string;
        /** Specifies the set of values. Each returned container exit code (might be multiple in case of multiple containers) is checked against this set of values with respect to the operator. The list of values must be ordered and must not contain duplicates. Value '0' cannot be used for the In operator. At least one element is required. At most 255 elements are allowed. */
        values: number[];
    }
    /** PodFailurePolicyOnPodConditionsPattern describes a pattern for matching an actual pod condition type. */
    interface io$k8s$api$batch$v1$PodFailurePolicyOnPodConditionsPattern {
        /** Specifies the required Pod condition status. To match a pod condition it is required that the specified status equals the pod condition status. Defaults to True. */
        status: string;
        /** Specifies the required Pod condition type. To match a pod condition it is required that specified type equals the pod condition type. */
        type: string;
    }
    /** PodFailurePolicyRule describes how a pod failure is handled when the requirements are met. One of onExitCodes and onPodConditions, but not both, can be used in each rule. */
    interface io$k8s$api$batch$v1$PodFailurePolicyRule {
        /**
         * Specifies the action taken on a pod failure when the requirements are satisfied. Possible values are:
         *
         * - FailJob: indicates that the pod's job is marked as Failed and all
         *   running pods are terminated.
         * - Ignore: indicates that the counter towards the .backoffLimit is not
         *   incremented and a replacement pod is created.
         * - Count: indicates that the pod is handled in the default way - the
         *   counter towards the .backoffLimit is incremented.
         * Additional values are considered to be added in the future. Clients should react to an unknown action by skipping the rule.
         */
        action: string;
        onExitCodes?: Schemas.io$k8s$api$batch$v1$PodFailurePolicyOnExitCodesRequirement;
        /** Represents the requirement on the pod conditions. The requirement is represented as a list of pod condition patterns. The requirement is satisfied if at least one pattern matches an actual pod condition. At most 20 elements are allowed. */
        onPodConditions?: Schemas.io$k8s$api$batch$v1$PodFailurePolicyOnPodConditionsPattern[];
    }
    /** UncountedTerminatedPods holds UIDs of Pods that have terminated but haven't been accounted in Job status counters. */
    interface io$k8s$api$batch$v1$UncountedTerminatedPods {
        /** failed holds UIDs of failed Pods. */
        failed?: string[];
        /** succeeded holds UIDs of succeeded Pods. */
        succeeded?: string[];
    }
    /**
     * CertificateSigningRequest objects provide a mechanism to obtain x509 certificates by submitting a certificate signing request, and having it asynchronously approved and issued.
     *
     * Kubelets use this API to obtain:
     *  1. client certificates to authenticate to kube-apiserver (with the "kubernetes.io/kube-apiserver-client-kubelet" signerName).
     *  2. serving certificates for TLS endpoints kube-apiserver can connect to securely (with the "kubernetes.io/kubelet-serving" signerName).
     *
     * This API can be used to request client certificates to authenticate to kube-apiserver (with the "kubernetes.io/kube-apiserver-client" signerName), or to obtain certificates from custom non-Kubernetes signers.
     */
    interface io$k8s$api$certificates$v1$CertificateSigningRequest {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$certificates$v1$CertificateSigningRequestSpec;
        status?: Schemas.io$k8s$api$certificates$v1$CertificateSigningRequestStatus;
    }
    /** CertificateSigningRequestCondition describes a condition of a CertificateSigningRequest object */
    interface io$k8s$api$certificates$v1$CertificateSigningRequestCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        lastUpdateTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** message contains a human readable message with details about the request state */
        message?: string;
        /** reason indicates a brief reason for the request state */
        reason?: string;
        /** status of the condition, one of True, False, Unknown. Approved, Denied, and Failed conditions may not be "False" or "Unknown". */
        status: string;
        /**
         * type of the condition. Known conditions are "Approved", "Denied", and "Failed".
         *
         * An "Approved" condition is added via the /approval subresource, indicating the request was approved and should be issued by the signer.
         *
         * A "Denied" condition is added via the /approval subresource, indicating the request was denied and should not be issued by the signer.
         *
         * A "Failed" condition is added via the /status subresource, indicating the signer failed to issue the certificate.
         *
         * Approved and Denied conditions are mutually exclusive. Approved, Denied, and Failed conditions cannot be removed once added.
         *
         * Only one condition of a given type is allowed.
         */
        type: string;
    }
    /** CertificateSigningRequestList is a collection of CertificateSigningRequest objects */
    interface io$k8s$api$certificates$v1$CertificateSigningRequestList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is a collection of CertificateSigningRequest objects */
        items: Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** CertificateSigningRequestSpec contains the certificate request. */
    interface io$k8s$api$certificates$v1$CertificateSigningRequestSpec {
        /**
         * expirationSeconds is the requested duration of validity of the issued certificate. The certificate signer may issue a certificate with a different validity duration so a client must check the delta between the notBefore and and notAfter fields in the issued certificate to determine the actual duration.
         *
         * The v1.22+ in-tree implementations of the well-known Kubernetes signers will honor this field as long as the requested duration is not greater than the maximum duration they will honor per the --cluster-signing-duration CLI flag to the Kubernetes controller manager.
         *
         * Certificate signers may not honor this field for various reasons:
         *
         *   1. Old signer that is unaware of the field (such as the in-tree
         *      implementations prior to v1.22)
         *   2. Signer whose configured maximum is shorter than the requested duration
         *   3. Signer whose configured minimum is longer than the requested duration
         *
         * The minimum valid value for expirationSeconds is 600, i.e. 10 minutes.
         */
        expirationSeconds?: number;
        /** extra contains extra attributes of the user that created the CertificateSigningRequest. Populated by the API server on creation and immutable. */
        extra?: {
            [key: string]: string[];
        };
        /** groups contains group membership of the user that created the CertificateSigningRequest. Populated by the API server on creation and immutable. */
        groups?: string[];
        /** request contains an x509 certificate signing request encoded in a "CERTIFICATE REQUEST" PEM block. When serialized as JSON or YAML, the data is additionally base64-encoded. */
        request: Blob;
        /**
         * signerName indicates the requested signer, and is a qualified name.
         *
         * List/watch requests for CertificateSigningRequests can filter on this field using a "spec.signerName=NAME" fieldSelector.
         *
         * Well-known Kubernetes signers are:
         *  1. "kubernetes.io/kube-apiserver-client": issues client certificates that can be used to authenticate to kube-apiserver.
         *   Requests for this signer are never auto-approved by kube-controller-manager, can be issued by the "csrsigning" controller in kube-controller-manager.
         *  2. "kubernetes.io/kube-apiserver-client-kubelet": issues client certificates that kubelets use to authenticate to kube-apiserver.
         *   Requests for this signer can be auto-approved by the "csrapproving" controller in kube-controller-manager, and can be issued by the "csrsigning" controller in kube-controller-manager.
         *  3. "kubernetes.io/kubelet-serving" issues serving certificates that kubelets use to serve TLS endpoints, which kube-apiserver can connect to securely.
         *   Requests for this signer are never auto-approved by kube-controller-manager, and can be issued by the "csrsigning" controller in kube-controller-manager.
         *
         * More details are available at https://k8s.io/docs/reference/access-authn-authz/certificate-signing-requests/#kubernetes-signers
         *
         * Custom signerNames can also be specified. The signer defines:
         *  1. Trust distribution: how trust (CA bundles) are distributed.
         *  2. Permitted subjects: and behavior when a disallowed subject is requested.
         *  3. Required, permitted, or forbidden x509 extensions in the request (including whether subjectAltNames are allowed, which types, restrictions on allowed values) and behavior when a disallowed extension is requested.
         *  4. Required, permitted, or forbidden key usages / extended key usages.
         *  5. Expiration/certificate lifetime: whether it is fixed by the signer, configurable by the admin.
         *  6. Whether or not requests for CA certificates are allowed.
         */
        signerName: string;
        /** uid contains the uid of the user that created the CertificateSigningRequest. Populated by the API server on creation and immutable. */
        uid?: string;
        /**
         * usages specifies a set of key usages requested in the issued certificate.
         *
         * Requests for TLS client certificates typically request: "digital signature", "key encipherment", "client auth".
         *
         * Requests for TLS serving certificates typically request: "key encipherment", "digital signature", "server auth".
         *
         * Valid values are:
         *  "signing", "digital signature", "content commitment",
         *  "key encipherment", "key agreement", "data encipherment",
         *  "cert sign", "crl sign", "encipher only", "decipher only", "any",
         *  "server auth", "client auth",
         *  "code signing", "email protection", "s/mime",
         *  "ipsec end system", "ipsec tunnel", "ipsec user",
         *  "timestamping", "ocsp signing", "microsoft sgc", "netscape sgc"
         */
        usages?: string[];
        /** username contains the name of the user that created the CertificateSigningRequest. Populated by the API server on creation and immutable. */
        username?: string;
    }
    /** CertificateSigningRequestStatus contains conditions used to indicate approved/denied/failed status of the request, and the issued certificate. */
    interface io$k8s$api$certificates$v1$CertificateSigningRequestStatus {
        /**
         * certificate is populated with an issued certificate by the signer after an Approved condition is present. This field is set via the /status subresource. Once populated, this field is immutable.
         *
         * If the certificate signing request is denied, a condition of type "Denied" is added and this field remains empty. If the signer cannot issue the certificate, a condition of type "Failed" is added and this field remains empty.
         *
         * Validation requirements:
         *  1. certificate must contain one or more PEM blocks.
         *  2. All PEM blocks must have the "CERTIFICATE" label, contain no headers, and the encoded data
         *   must be a BER-encoded ASN.1 Certificate structure as described in section 4 of RFC5280.
         *  3. Non-PEM content may appear before or after the "CERTIFICATE" PEM blocks and is unvalidated,
         *   to allow for explanatory text as described in section 5.2 of RFC7468.
         *
         * If more than one PEM block is present, and the definition of the requested spec.signerName does not indicate otherwise, the first block is the issued certificate, and subsequent blocks should be treated as intermediate certificates and presented in TLS handshakes.
         *
         * The certificate is encoded in PEM format.
         *
         * When serialized as JSON or YAML, the data is additionally base64-encoded, so it consists of:
         *
         *     base64(
         *     -----BEGIN CERTIFICATE-----
         *     ...
         *     -----END CERTIFICATE-----
         *     )
         */
        certificate?: Blob;
        /** conditions applied to the request. Known conditions are "Approved", "Denied", and "Failed". */
        conditions?: Schemas.io$k8s$api$certificates$v1$CertificateSigningRequestCondition[];
    }
    /**
     * ClusterTrustBundle is a cluster-scoped container for X.509 trust anchors (root certificates).
     *
     * ClusterTrustBundle objects are considered to be readable by any authenticated user in the cluster, because they can be mounted by pods using the `clusterTrustBundle` projection.  All service accounts have read access to ClusterTrustBundles by default.  Users who only have namespace-level access to a cluster can read ClusterTrustBundles by impersonating a serviceaccount that they have access to.
     *
     * It can be optionally associated with a particular assigner, in which case it contains one valid set of trust anchors for that signer. Signers may have multiple associated ClusterTrustBundles; each is an independent set of trust anchors for that signer. Admission control is used to enforce that only users with permissions on the signer can create or modify the corresponding bundle.
     */
    interface io$k8s$api$certificates$v1alpha1$ClusterTrustBundle {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundleSpec;
    }
    /** ClusterTrustBundleList is a collection of ClusterTrustBundle objects */
    interface io$k8s$api$certificates$v1alpha1$ClusterTrustBundleList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is a collection of ClusterTrustBundle objects */
        items: Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ClusterTrustBundleSpec contains the signer and trust anchors. */
    interface io$k8s$api$certificates$v1alpha1$ClusterTrustBundleSpec {
        /**
         * signerName indicates the associated signer, if any.
         *
         * In order to create or update a ClusterTrustBundle that sets signerName, you must have the following cluster-scoped permission: group=certificates.k8s.io resource=signers resourceName=<the signer name> verb=attest.
         *
         * If signerName is not empty, then the ClusterTrustBundle object must be named with the signer name as a prefix (translating slashes to colons). For example, for the signer name `example.com/foo`, valid ClusterTrustBundle object names include `example.com:foo:abc` and `example.com:foo:v1`.
         *
         * If signerName is empty, then the ClusterTrustBundle object's name must not have such a prefix.
         *
         * List/watch requests for ClusterTrustBundles can filter on this field using a `spec.signerName=NAME` field selector.
         */
        signerName?: string;
        /**
         * trustBundle contains the individual X.509 trust anchors for this bundle, as PEM bundle of PEM-wrapped, DER-formatted X.509 certificates.
         *
         * The data must consist only of PEM certificate blocks that parse as valid X.509 certificates.  Each certificate must include a basic constraints extension with the CA bit set.  The API server will reject objects that contain duplicate certificates, or that use PEM block headers.
         *
         * Users of ClusterTrustBundles, including Kubelet, are free to reorder and deduplicate certificate blocks in this file according to their own logic, as well as to drop PEM block headers and inter-block data.
         */
        trustBundle: string;
    }
    /** Lease defines a lease concept. */
    interface io$k8s$api$coordination$v1$Lease {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$coordination$v1$LeaseSpec;
    }
    /** LeaseList is a list of Lease objects. */
    interface io$k8s$api$coordination$v1$LeaseList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is a list of schema objects. */
        items: Schemas.io$k8s$api$coordination$v1$Lease[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** LeaseSpec is a specification of a Lease. */
    interface io$k8s$api$coordination$v1$LeaseSpec {
        acquireTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$MicroTime;
        /** holderIdentity contains the identity of the holder of a current lease. */
        holderIdentity?: string;
        /** leaseDurationSeconds is a duration that candidates for a lease need to wait to force acquire it. This is measure against time of last observed renewTime. */
        leaseDurationSeconds?: number;
        /** leaseTransitions is the number of transitions of a lease between holders. */
        leaseTransitions?: number;
        renewTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$MicroTime;
    }
    /**
     * Represents a Persistent Disk resource in AWS.
     *
     * An AWS EBS disk must exist before mounting to a container. The disk must also be in the same AWS zone as the kubelet. An AWS EBS disk can only be mounted as read/write once. AWS EBS volumes support ownership management and SELinux relabeling.
     */
    interface io$k8s$api$core$v1$AWSElasticBlockStoreVolumeSource {
        /** fsType is the filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#awselasticblockstore */
        fsType?: string;
        /** partition is the partition in the volume that you want to mount. If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty). */
        partition?: number;
        /** readOnly value true will force the readOnly setting in VolumeMounts. More info: https://kubernetes.io/docs/concepts/storage/volumes#awselasticblockstore */
        readOnly?: boolean;
        /** volumeID is unique ID of the persistent disk resource in AWS (Amazon EBS volume). More info: https://kubernetes.io/docs/concepts/storage/volumes#awselasticblockstore */
        volumeID: string;
    }
    /** Affinity is a group of affinity scheduling rules. */
    interface io$k8s$api$core$v1$Affinity {
        nodeAffinity?: Schemas.io$k8s$api$core$v1$NodeAffinity;
        podAffinity?: Schemas.io$k8s$api$core$v1$PodAffinity;
        podAntiAffinity?: Schemas.io$k8s$api$core$v1$PodAntiAffinity;
    }
    /** AttachedVolume describes a volume attached to a node */
    interface io$k8s$api$core$v1$AttachedVolume {
        /** DevicePath represents the device path where the volume should be available */
        devicePath: string;
        /** Name of the attached volume */
        name: string;
    }
    /** AzureDisk represents an Azure Data Disk mount on the host and bind mount to the pod. */
    interface io$k8s$api$core$v1$AzureDiskVolumeSource {
        /** cachingMode is the Host Caching mode: None, Read Only, Read Write. */
        cachingMode?: string;
        /** diskName is the Name of the data disk in the blob storage */
        diskName: string;
        /** diskURI is the URI of data disk in the blob storage */
        diskURI: string;
        /** fsType is Filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. */
        fsType?: string;
        /** kind expected values are Shared: multiple blob disks per storage account  Dedicated: single blob disk per storage account  Managed: azure managed data disk (only in managed availability set). defaults to shared */
        kind?: string;
        /** readOnly Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. */
        readOnly?: boolean;
    }
    /** AzureFile represents an Azure File Service mount on the host and bind mount to the pod. */
    interface io$k8s$api$core$v1$AzureFilePersistentVolumeSource {
        /** readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. */
        readOnly?: boolean;
        /** secretName is the name of secret that contains Azure Storage Account Name and Key */
        secretName: string;
        /** secretNamespace is the namespace of the secret that contains Azure Storage Account Name and Key default is the same as the Pod */
        secretNamespace?: string;
        /** shareName is the azure Share Name */
        shareName: string;
    }
    /** AzureFile represents an Azure File Service mount on the host and bind mount to the pod. */
    interface io$k8s$api$core$v1$AzureFileVolumeSource {
        /** readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. */
        readOnly?: boolean;
        /** secretName is the  name of secret that contains Azure Storage Account Name and Key */
        secretName: string;
        /** shareName is the azure share Name */
        shareName: string;
    }
    /** Binding ties one object to another; for example, a pod is bound to a node by a scheduler. Deprecated in 1.7, please use the bindings subresource of pods instead. */
    interface io$k8s$api$core$v1$Binding {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        target: Schemas.io$k8s$api$core$v1$ObjectReference;
    }
    /** Represents storage that is managed by an external CSI volume driver (Beta feature) */
    interface io$k8s$api$core$v1$CSIPersistentVolumeSource {
        controllerExpandSecretRef?: Schemas.io$k8s$api$core$v1$SecretReference;
        controllerPublishSecretRef?: Schemas.io$k8s$api$core$v1$SecretReference;
        /** driver is the name of the driver to use for this volume. Required. */
        driver: string;
        /** fsType to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". */
        fsType?: string;
        nodeExpandSecretRef?: Schemas.io$k8s$api$core$v1$SecretReference;
        nodePublishSecretRef?: Schemas.io$k8s$api$core$v1$SecretReference;
        nodeStageSecretRef?: Schemas.io$k8s$api$core$v1$SecretReference;
        /** readOnly value to pass to ControllerPublishVolumeRequest. Defaults to false (read/write). */
        readOnly?: boolean;
        /** volumeAttributes of the volume to publish. */
        volumeAttributes?: {
            [key: string]: string;
        };
        /** volumeHandle is the unique volume name returned by the CSI volume plugin’s CreateVolume to refer to the volume on all subsequent calls. Required. */
        volumeHandle: string;
    }
    /** Represents a source location of a volume to mount, managed by an external CSI driver */
    interface io$k8s$api$core$v1$CSIVolumeSource {
        /** driver is the name of the CSI driver that handles this volume. Consult with your admin for the correct name as registered in the cluster. */
        driver: string;
        /** fsType to mount. Ex. "ext4", "xfs", "ntfs". If not provided, the empty value is passed to the associated CSI driver which will determine the default filesystem to apply. */
        fsType?: string;
        nodePublishSecretRef?: Schemas.io$k8s$api$core$v1$LocalObjectReference;
        /** readOnly specifies a read-only configuration for the volume. Defaults to false (read/write). */
        readOnly?: boolean;
        /** volumeAttributes stores driver-specific properties that are passed to the CSI driver. Consult your driver's documentation for supported values. */
        volumeAttributes?: {
            [key: string]: string;
        };
    }
    /** Adds and removes POSIX capabilities from running containers. */
    interface io$k8s$api$core$v1$Capabilities {
        /** Added capabilities */
        add?: string[];
        /** Removed capabilities */
        drop?: string[];
    }
    /** Represents a Ceph Filesystem mount that lasts the lifetime of a pod Cephfs volumes do not support ownership management or SELinux relabeling. */
    interface io$k8s$api$core$v1$CephFSPersistentVolumeSource {
        /** monitors is Required: Monitors is a collection of Ceph monitors More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it */
        monitors: string[];
        /** path is Optional: Used as the mounted root, rather than the full Ceph tree, default is / */
        path?: string;
        /** readOnly is Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it */
        readOnly?: boolean;
        /** secretFile is Optional: SecretFile is the path to key ring for User, default is /etc/ceph/user.secret More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it */
        secretFile?: string;
        secretRef?: Schemas.io$k8s$api$core$v1$SecretReference;
        /** user is Optional: User is the rados user name, default is admin More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it */
        user?: string;
    }
    /** Represents a Ceph Filesystem mount that lasts the lifetime of a pod Cephfs volumes do not support ownership management or SELinux relabeling. */
    interface io$k8s$api$core$v1$CephFSVolumeSource {
        /** monitors is Required: Monitors is a collection of Ceph monitors More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it */
        monitors: string[];
        /** path is Optional: Used as the mounted root, rather than the full Ceph tree, default is / */
        path?: string;
        /** readOnly is Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it */
        readOnly?: boolean;
        /** secretFile is Optional: SecretFile is the path to key ring for User, default is /etc/ceph/user.secret More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it */
        secretFile?: string;
        secretRef?: Schemas.io$k8s$api$core$v1$LocalObjectReference;
        /** user is optional: User is the rados user name, default is admin More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it */
        user?: string;
    }
    /** Represents a cinder volume resource in Openstack. A Cinder volume must exist before mounting to a container. The volume must also be in the same region as the kubelet. Cinder volumes support ownership management and SELinux relabeling. */
    interface io$k8s$api$core$v1$CinderPersistentVolumeSource {
        /** fsType Filesystem type to mount. Must be a filesystem type supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://examples.k8s.io/mysql-cinder-pd/README.md */
        fsType?: string;
        /** readOnly is Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/mysql-cinder-pd/README.md */
        readOnly?: boolean;
        secretRef?: Schemas.io$k8s$api$core$v1$SecretReference;
        /** volumeID used to identify the volume in cinder. More info: https://examples.k8s.io/mysql-cinder-pd/README.md */
        volumeID: string;
    }
    /** Represents a cinder volume resource in Openstack. A Cinder volume must exist before mounting to a container. The volume must also be in the same region as the kubelet. Cinder volumes support ownership management and SELinux relabeling. */
    interface io$k8s$api$core$v1$CinderVolumeSource {
        /** fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://examples.k8s.io/mysql-cinder-pd/README.md */
        fsType?: string;
        /** readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/mysql-cinder-pd/README.md */
        readOnly?: boolean;
        secretRef?: Schemas.io$k8s$api$core$v1$LocalObjectReference;
        /** volumeID used to identify the volume in cinder. More info: https://examples.k8s.io/mysql-cinder-pd/README.md */
        volumeID: string;
    }
    /**
     * ClaimSource describes a reference to a ResourceClaim.
     *
     * Exactly one of these fields should be set.  Consumers of this type must treat an empty object as if it has an unknown value.
     */
    interface io$k8s$api$core$v1$ClaimSource {
        /** ResourceClaimName is the name of a ResourceClaim object in the same namespace as this pod. */
        resourceClaimName?: string;
        /**
         * ResourceClaimTemplateName is the name of a ResourceClaimTemplate object in the same namespace as this pod.
         *
         * The template will be used to create a new ResourceClaim, which will be bound to this pod. When this pod is deleted, the ResourceClaim will also be deleted. The name of the ResourceClaim will be <pod name>-<resource name>, where <resource name> is the PodResourceClaim.Name. Pod validation will reject the pod if the concatenated name is not valid for a ResourceClaim (e.g. too long).
         *
         * An existing ResourceClaim with that name that is not owned by the pod will not be used for the pod to avoid using an unrelated resource by mistake. Scheduling and pod startup are then blocked until the unrelated ResourceClaim is removed.
         *
         * This field is immutable and no changes will be made to the corresponding ResourceClaim by the control plane after creating the ResourceClaim.
         */
        resourceClaimTemplateName?: string;
    }
    /** ClientIPConfig represents the configurations of Client IP based session affinity. */
    interface io$k8s$api$core$v1$ClientIPConfig {
        /** timeoutSeconds specifies the seconds of ClientIP type session sticky time. The value must be >0 && <=86400(for 1 day) if ServiceAffinity == "ClientIP". Default value is 10800(for 3 hours). */
        timeoutSeconds?: number;
    }
    /** Information about the condition of a component. */
    interface io$k8s$api$core$v1$ComponentCondition {
        /** Condition error code for a component. For example, a health check error code. */
        error?: string;
        /** Message about the condition for a component. For example, information about a health check. */
        message?: string;
        /** Status of the condition for a component. Valid values for "Healthy": "True", "False", or "Unknown". */
        status: string;
        /** Type of condition for a component. Valid value: "Healthy" */
        type: string;
    }
    /** ComponentStatus (and ComponentStatusList) holds the cluster validation info. Deprecated: This API is deprecated in v1.19+ */
    interface io$k8s$api$core$v1$ComponentStatus {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of component conditions observed */
        conditions?: Schemas.io$k8s$api$core$v1$ComponentCondition[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
    }
    /** Status of all the conditions for the component as a list of ComponentStatus objects. Deprecated: This API is deprecated in v1.19+ */
    interface io$k8s$api$core$v1$ComponentStatusList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of ComponentStatus objects. */
        items: Schemas.io$k8s$api$core$v1$ComponentStatus[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ConfigMap holds configuration data for pods to consume. */
    interface io$k8s$api$core$v1$ConfigMap {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** BinaryData contains the binary data. Each key must consist of alphanumeric characters, '-', '_' or '.'. BinaryData can contain byte sequences that are not in the UTF-8 range. The keys stored in BinaryData must not overlap with the ones in the Data field, this is enforced during validation process. Using this field will require 1.10+ apiserver and kubelet. */
        binaryData?: {
            [key: string]: Blob;
        };
        /** Data contains the configuration data. Each key must consist of alphanumeric characters, '-', '_' or '.'. Values with non-UTF-8 byte sequences must use the BinaryData field. The keys stored in Data must not overlap with the keys in the BinaryData field, this is enforced during validation process. */
        data?: {
            [key: string]: string;
        };
        /** Immutable, if set to true, ensures that data stored in the ConfigMap cannot be updated (only object metadata can be modified). If not set to true, the field can be modified at any time. Defaulted to nil. */
        immutable?: boolean;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
    }
    /**
     * ConfigMapEnvSource selects a ConfigMap to populate the environment variables with.
     *
     * The contents of the target ConfigMap's Data field will represent the key-value pairs as environment variables.
     */
    interface io$k8s$api$core$v1$ConfigMapEnvSource {
        /** Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names */
        name?: string;
        /** Specify whether the ConfigMap must be defined */
        optional?: boolean;
    }
    /** Selects a key from a ConfigMap. */
    interface io$k8s$api$core$v1$ConfigMapKeySelector {
        /** The key to select. */
        key: string;
        /** Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names */
        name?: string;
        /** Specify whether the ConfigMap or its key must be defined */
        optional?: boolean;
    }
    /** ConfigMapList is a resource containing a list of ConfigMap objects. */
    interface io$k8s$api$core$v1$ConfigMapList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is the list of ConfigMaps. */
        items: Schemas.io$k8s$api$core$v1$ConfigMap[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ConfigMapNodeConfigSource contains the information to reference a ConfigMap as a config source for the Node. This API is deprecated since 1.22: https://git.k8s.io/enhancements/keps/sig-node/281-dynamic-kubelet-configuration */
    interface io$k8s$api$core$v1$ConfigMapNodeConfigSource {
        /** KubeletConfigKey declares which key of the referenced ConfigMap corresponds to the KubeletConfiguration structure This field is required in all cases. */
        kubeletConfigKey: string;
        /** Name is the metadata.name of the referenced ConfigMap. This field is required in all cases. */
        name: string;
        /** Namespace is the metadata.namespace of the referenced ConfigMap. This field is required in all cases. */
        namespace: string;
        /** ResourceVersion is the metadata.ResourceVersion of the referenced ConfigMap. This field is forbidden in Node.Spec, and required in Node.Status. */
        resourceVersion?: string;
        /** UID is the metadata.UID of the referenced ConfigMap. This field is forbidden in Node.Spec, and required in Node.Status. */
        uid?: string;
    }
    /**
     * Adapts a ConfigMap into a projected volume.
     *
     * The contents of the target ConfigMap's Data field will be presented in a projected volume as files using the keys in the Data field as the file names, unless the items element is populated with specific mappings of keys to paths. Note that this is identical to a configmap volume source without the default mode.
     */
    interface io$k8s$api$core$v1$ConfigMapProjection {
        /** items if unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the ConfigMap, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'. */
        items?: Schemas.io$k8s$api$core$v1$KeyToPath[];
        /** Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names */
        name?: string;
        /** optional specify whether the ConfigMap or its keys must be defined */
        optional?: boolean;
    }
    /**
     * Adapts a ConfigMap into a volume.
     *
     * The contents of the target ConfigMap's Data field will be presented in a volume as files using the keys in the Data field as the file names, unless the items element is populated with specific mappings of keys to paths. ConfigMap volumes support ownership management and SELinux relabeling.
     */
    interface io$k8s$api$core$v1$ConfigMapVolumeSource {
        /** defaultMode is optional: mode bits used to set permissions on created files by default. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set. */
        defaultMode?: number;
        /** items if unspecified, each key-value pair in the Data field of the referenced ConfigMap will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the ConfigMap, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'. */
        items?: Schemas.io$k8s$api$core$v1$KeyToPath[];
        /** Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names */
        name?: string;
        /** optional specify whether the ConfigMap or its keys must be defined */
        optional?: boolean;
    }
    /** A single application container that you want to run within a pod. */
    interface io$k8s$api$core$v1$Container {
        /** Arguments to the entrypoint. The container image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell */
        args?: string[];
        /** Entrypoint array. Not executed within a shell. The container image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell */
        command?: string[];
        /** List of environment variables to set in the container. Cannot be updated. */
        env?: Schemas.io$k8s$api$core$v1$EnvVar[];
        /** List of sources to populate environment variables in the container. The keys defined within a source must be a C_IDENTIFIER. All invalid keys will be reported as an event when the container is starting. When a key exists in multiple sources, the value associated with the last source will take precedence. Values defined by an Env with a duplicate key will take precedence. Cannot be updated. */
        envFrom?: Schemas.io$k8s$api$core$v1$EnvFromSource[];
        /** Container image name. More info: https://kubernetes.io/docs/concepts/containers/images This field is optional to allow higher level config management to default or override container images in workload controllers like Deployments and StatefulSets. */
        image?: string;
        /** Image pull policy. One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: https://kubernetes.io/docs/concepts/containers/images#updating-images */
        imagePullPolicy?: string;
        lifecycle?: Schemas.io$k8s$api$core$v1$Lifecycle;
        livenessProbe?: Schemas.io$k8s$api$core$v1$Probe;
        /** Name of the container specified as a DNS_LABEL. Each container in a pod must have a unique name (DNS_LABEL). Cannot be updated. */
        name: string;
        /** List of ports to expose from the container. Not specifying a port here DOES NOT prevent that port from being exposed. Any port which is listening on the default "0.0.0.0" address inside a container will be accessible from the network. Modifying this array with strategic merge patch may corrupt the data. For more information See https://github.com/kubernetes/kubernetes/issues/108255. Cannot be updated. */
        ports?: Schemas.io$k8s$api$core$v1$ContainerPort[];
        readinessProbe?: Schemas.io$k8s$api$core$v1$Probe;
        /** Resources resize policy for the container. */
        resizePolicy?: Schemas.io$k8s$api$core$v1$ContainerResizePolicy[];
        resources?: Schemas.io$k8s$api$core$v1$ResourceRequirements;
        securityContext?: Schemas.io$k8s$api$core$v1$SecurityContext;
        startupProbe?: Schemas.io$k8s$api$core$v1$Probe;
        /** Whether this container should allocate a buffer for stdin in the container runtime. If this is not set, reads from stdin in the container will always result in EOF. Default is false. */
        stdin?: boolean;
        /** Whether the container runtime should close the stdin channel after it has been opened by a single attach. When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF. Default is false */
        stdinOnce?: boolean;
        /** Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem. Message written is intended to be brief final status, such as an assertion failure message. Will be truncated by the node if greater than 4096 bytes. The total message length across all containers will be limited to 12kb. Defaults to /dev/termination-log. Cannot be updated. */
        terminationMessagePath?: string;
        /** Indicate how the termination message should be populated. File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated. */
        terminationMessagePolicy?: string;
        /** Whether this container should allocate a TTY for itself, also requires 'stdin' to be true. Default is false. */
        tty?: boolean;
        /** volumeDevices is the list of block devices to be used by the container. */
        volumeDevices?: Schemas.io$k8s$api$core$v1$VolumeDevice[];
        /** Pod volumes to mount into the container's filesystem. Cannot be updated. */
        volumeMounts?: Schemas.io$k8s$api$core$v1$VolumeMount[];
        /** Container's working directory. If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated. */
        workingDir?: string;
    }
    /** Describe a container image */
    interface io$k8s$api$core$v1$ContainerImage {
        /** Names by which this image is known. e.g. ["kubernetes.example/hyperkube:v1.0.7", "cloud-vendor.registry.example/cloud-vendor/hyperkube:v1.0.7"] */
        names?: string[];
        /** The size of the image in bytes. */
        sizeBytes?: number;
    }
    /** ContainerPort represents a network port in a single container. */
    interface io$k8s$api$core$v1$ContainerPort {
        /** Number of port to expose on the pod's IP address. This must be a valid port number, 0 < x < 65536. */
        containerPort: number;
        /** What host IP to bind the external port to. */
        hostIP?: string;
        /** Number of port to expose on the host. If specified, this must be a valid port number, 0 < x < 65536. If HostNetwork is specified, this must match ContainerPort. Most containers do not need this. */
        hostPort?: number;
        /** If specified, this must be an IANA_SVC_NAME and unique within the pod. Each named port in a pod must have a unique name. Name for the port that can be referred to by services. */
        name?: string;
        /** Protocol for port. Must be UDP, TCP, or SCTP. Defaults to "TCP". */
        protocol?: string;
    }
    /** ContainerResizePolicy represents resource resize policy for the container. */
    interface io$k8s$api$core$v1$ContainerResizePolicy {
        /** Name of the resource to which this resource resize policy applies. Supported values: cpu, memory. */
        resourceName: string;
        /** Restart policy to apply when specified resource is resized. If not specified, it defaults to NotRequired. */
        restartPolicy: string;
    }
    /** ContainerState holds a possible state of container. Only one of its members may be specified. If none of them is specified, the default one is ContainerStateWaiting. */
    interface io$k8s$api$core$v1$ContainerState {
        running?: Schemas.io$k8s$api$core$v1$ContainerStateRunning;
        terminated?: Schemas.io$k8s$api$core$v1$ContainerStateTerminated;
        waiting?: Schemas.io$k8s$api$core$v1$ContainerStateWaiting;
    }
    /** ContainerStateRunning is a running state of a container. */
    interface io$k8s$api$core$v1$ContainerStateRunning {
        startedAt?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
    }
    /** ContainerStateTerminated is a terminated state of a container. */
    interface io$k8s$api$core$v1$ContainerStateTerminated {
        /** Container's ID in the format '<type>://<container_id>' */
        containerID?: string;
        /** Exit status from the last termination of the container */
        exitCode: number;
        finishedAt?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** Message regarding the last termination of the container */
        message?: string;
        /** (brief) reason from the last termination of the container */
        reason?: string;
        /** Signal from the last termination of the container */
        signal?: number;
        startedAt?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
    }
    /** ContainerStateWaiting is a waiting state of a container. */
    interface io$k8s$api$core$v1$ContainerStateWaiting {
        /** Message regarding why the container is not yet running. */
        message?: string;
        /** (brief) reason the container is not yet running. */
        reason?: string;
    }
    /** ContainerStatus contains details for the current status of this container. */
    interface io$k8s$api$core$v1$ContainerStatus {
        /** AllocatedResources represents the compute resources allocated for this container by the node. Kubelet sets this value to Container.Resources.Requests upon successful pod admission and after successfully admitting desired pod resize. */
        allocatedResources?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** ContainerID is the ID of the container in the format '<type>://<container_id>'. Where type is a container runtime identifier, returned from Version call of CRI API (for example "containerd"). */
        containerID?: string;
        /** Image is the name of container image that the container is running. The container image may not match the image used in the PodSpec, as it may have been resolved by the runtime. More info: https://kubernetes.io/docs/concepts/containers/images. */
        image: string;
        /** ImageID is the image ID of the container's image. The image ID may not match the image ID of the image used in the PodSpec, as it may have been resolved by the runtime. */
        imageID: string;
        lastState?: Schemas.io$k8s$api$core$v1$ContainerState;
        /** Name is a DNS_LABEL representing the unique name of the container. Each container in a pod must have a unique name across all container types. Cannot be updated. */
        name: string;
        /**
         * Ready specifies whether the container is currently passing its readiness check. The value will change as readiness probes keep executing. If no readiness probes are specified, this field defaults to true once the container is fully started (see Started field).
         *
         * The value is typically used to determine whether a container is ready to accept traffic.
         */
        ready: boolean;
        resources?: Schemas.io$k8s$api$core$v1$ResourceRequirements;
        /** RestartCount holds the number of times the container has been restarted. Kubelet makes an effort to always increment the value, but there are cases when the state may be lost due to node restarts and then the value may be reset to 0. The value is never negative. */
        restartCount: number;
        /** Started indicates whether the container has finished its postStart lifecycle hook and passed its startup probe. Initialized as false, becomes true after startupProbe is considered successful. Resets to false when the container is restarted, or if kubelet loses state temporarily. In both cases, startup probes will run again. Is always true when no startupProbe is defined and container is running and has passed the postStart lifecycle hook. The null value must be treated the same as false. */
        started?: boolean;
        state?: Schemas.io$k8s$api$core$v1$ContainerState;
    }
    /** DaemonEndpoint contains information about a single Daemon endpoint. */
    interface io$k8s$api$core$v1$DaemonEndpoint {
        /** Port number of the given endpoint. */
        Port: number;
    }
    /** Represents downward API info for projecting into a projected volume. Note that this is identical to a downwardAPI volume source without the default mode. */
    interface io$k8s$api$core$v1$DownwardAPIProjection {
        /** Items is a list of DownwardAPIVolume file */
        items?: Schemas.io$k8s$api$core$v1$DownwardAPIVolumeFile[];
    }
    /** DownwardAPIVolumeFile represents information to create the file containing the pod field */
    interface io$k8s$api$core$v1$DownwardAPIVolumeFile {
        fieldRef?: Schemas.io$k8s$api$core$v1$ObjectFieldSelector;
        /** Optional: mode bits used to set permissions on this file, must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set. */
        mode?: number;
        /** Required: Path is  the relative path name of the file to be created. Must not be absolute or contain the '..' path. Must be utf-8 encoded. The first item of the relative path must not start with '..' */
        path: string;
        resourceFieldRef?: Schemas.io$k8s$api$core$v1$ResourceFieldSelector;
    }
    /** DownwardAPIVolumeSource represents a volume containing downward API info. Downward API volumes support ownership management and SELinux relabeling. */
    interface io$k8s$api$core$v1$DownwardAPIVolumeSource {
        /** Optional: mode bits to use on created files by default. Must be a Optional: mode bits used to set permissions on created files by default. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set. */
        defaultMode?: number;
        /** Items is a list of downward API volume file */
        items?: Schemas.io$k8s$api$core$v1$DownwardAPIVolumeFile[];
    }
    /** Represents an empty directory for a pod. Empty directory volumes support ownership management and SELinux relabeling. */
    interface io$k8s$api$core$v1$EmptyDirVolumeSource {
        /** medium represents what type of storage medium should back this directory. The default is "" which means to use the node's default medium. Must be an empty string (default) or Memory. More info: https://kubernetes.io/docs/concepts/storage/volumes#emptydir */
        medium?: string;
        sizeLimit?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
    }
    /** EndpointAddress is a tuple that describes single IP address. */
    interface io$k8s$api$core$v1$EndpointAddress {
        /** The Hostname of this endpoint */
        hostname?: string;
        /** The IP of this endpoint. May not be loopback (127.0.0.0/8 or ::1), link-local (169.254.0.0/16 or fe80::/10), or link-local multicast (224.0.0.0/24 or ff02::/16). */
        ip: string;
        /** Optional: Node hosting this endpoint. This can be used to determine endpoints local to a node. */
        nodeName?: string;
        targetRef?: Schemas.io$k8s$api$core$v1$ObjectReference;
    }
    /** EndpointPort is a tuple that describes a single port. */
    interface io$k8s$api$core$v1$EndpointPort {
        /**
         * The application protocol for this port. This is used as a hint for implementations to offer richer behavior for protocols that they understand. This field follows standard Kubernetes label syntax. Valid values are either:
         *
         * * Un-prefixed protocol names - reserved for IANA standard service names (as per RFC-6335 and https://www.iana.org/assignments/service-names).
         *
         * * Kubernetes-defined prefixed names:
         *   * 'kubernetes.io/h2c' - HTTP/2 over cleartext as described in https://www.rfc-editor.org/rfc/rfc7540
         *
         * * Other protocols should use implementation-defined prefixed names such as mycompany.com/my-custom-protocol.
         */
        appProtocol?: string;
        /** The name of this port.  This must match the 'name' field in the corresponding ServicePort. Must be a DNS_LABEL. Optional only if one port is defined. */
        name?: string;
        /** The port number of the endpoint. */
        port: number;
        /** The IP protocol for this port. Must be UDP, TCP, or SCTP. Default is TCP. */
        protocol?: string;
    }
    /**
     * EndpointSubset is a group of addresses with a common set of ports. The expanded set of endpoints is the Cartesian product of Addresses x Ports. For example, given:
     *
     * 	{
     * 	  Addresses: [{"ip": "10.10.1.1"}, {"ip": "10.10.2.2"}],
     * 	  Ports:     [{"name": "a", "port": 8675}, {"name": "b", "port": 309}]
     * 	}
     *
     * The resulting set of endpoints can be viewed as:
     *
     * 	a: [ 10.10.1.1:8675, 10.10.2.2:8675 ],
     * 	b: [ 10.10.1.1:309, 10.10.2.2:309 ]
     */
    interface io$k8s$api$core$v1$EndpointSubset {
        /** IP addresses which offer the related ports that are marked as ready. These endpoints should be considered safe for load balancers and clients to utilize. */
        addresses?: Schemas.io$k8s$api$core$v1$EndpointAddress[];
        /** IP addresses which offer the related ports but are not currently marked as ready because they have not yet finished starting, have recently failed a readiness check, or have recently failed a liveness check. */
        notReadyAddresses?: Schemas.io$k8s$api$core$v1$EndpointAddress[];
        /** Port numbers available on the related IP addresses. */
        ports?: Schemas.io$k8s$api$core$v1$EndpointPort[];
    }
    /**
     * Endpoints is a collection of endpoints that implement the actual service. Example:
     *
     * 	 Name: "mysvc",
     * 	 Subsets: [
     * 	   {
     * 	     Addresses: [{"ip": "10.10.1.1"}, {"ip": "10.10.2.2"}],
     * 	     Ports: [{"name": "a", "port": 8675}, {"name": "b", "port": 309}]
     * 	   },
     * 	   {
     * 	     Addresses: [{"ip": "10.10.3.3"}],
     * 	     Ports: [{"name": "a", "port": 93}, {"name": "b", "port": 76}]
     * 	   },
     * 	]
     */
    interface io$k8s$api$core$v1$Endpoints {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** The set of all endpoints is the union of all subsets. Addresses are placed into subsets according to the IPs they share. A single address with multiple ports, some of which are ready and some of which are not (because they come from different containers) will result in the address being displayed in different subsets for the different ports. No address will appear in both Addresses and NotReadyAddresses in the same subset. Sets of addresses and ports that comprise a service. */
        subsets?: Schemas.io$k8s$api$core$v1$EndpointSubset[];
    }
    /** EndpointsList is a list of endpoints. */
    interface io$k8s$api$core$v1$EndpointsList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of endpoints. */
        items: Schemas.io$k8s$api$core$v1$Endpoints[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** EnvFromSource represents the source of a set of ConfigMaps */
    interface io$k8s$api$core$v1$EnvFromSource {
        configMapRef?: Schemas.io$k8s$api$core$v1$ConfigMapEnvSource;
        /** An optional identifier to prepend to each key in the ConfigMap. Must be a C_IDENTIFIER. */
        prefix?: string;
        secretRef?: Schemas.io$k8s$api$core$v1$SecretEnvSource;
    }
    /** EnvVar represents an environment variable present in a Container. */
    interface io$k8s$api$core$v1$EnvVar {
        /** Name of the environment variable. Must be a C_IDENTIFIER. */
        name: string;
        /** Variable references $(VAR_NAME) are expanded using the previously defined environment variables in the container and any service environment variables. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Defaults to "". */
        value?: string;
        valueFrom?: Schemas.io$k8s$api$core$v1$EnvVarSource;
    }
    /** EnvVarSource represents a source for the value of an EnvVar. */
    interface io$k8s$api$core$v1$EnvVarSource {
        configMapKeyRef?: Schemas.io$k8s$api$core$v1$ConfigMapKeySelector;
        fieldRef?: Schemas.io$k8s$api$core$v1$ObjectFieldSelector;
        resourceFieldRef?: Schemas.io$k8s$api$core$v1$ResourceFieldSelector;
        secretKeyRef?: Schemas.io$k8s$api$core$v1$SecretKeySelector;
    }
    /**
     * An EphemeralContainer is a temporary container that you may add to an existing Pod for user-initiated activities such as debugging. Ephemeral containers have no resource or scheduling guarantees, and they will not be restarted when they exit or when a Pod is removed or restarted. The kubelet may evict a Pod if an ephemeral container causes the Pod to exceed its resource allocation.
     *
     * To add an ephemeral container, use the ephemeralcontainers subresource of an existing Pod. Ephemeral containers may not be removed or restarted.
     */
    interface io$k8s$api$core$v1$EphemeralContainer {
        /** Arguments to the entrypoint. The image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell */
        args?: string[];
        /** Entrypoint array. Not executed within a shell. The image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. "$$(VAR_NAME)" will produce the string literal "$(VAR_NAME)". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell */
        command?: string[];
        /** List of environment variables to set in the container. Cannot be updated. */
        env?: Schemas.io$k8s$api$core$v1$EnvVar[];
        /** List of sources to populate environment variables in the container. The keys defined within a source must be a C_IDENTIFIER. All invalid keys will be reported as an event when the container is starting. When a key exists in multiple sources, the value associated with the last source will take precedence. Values defined by an Env with a duplicate key will take precedence. Cannot be updated. */
        envFrom?: Schemas.io$k8s$api$core$v1$EnvFromSource[];
        /** Container image name. More info: https://kubernetes.io/docs/concepts/containers/images */
        image?: string;
        /** Image pull policy. One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: https://kubernetes.io/docs/concepts/containers/images#updating-images */
        imagePullPolicy?: string;
        lifecycle?: Schemas.io$k8s$api$core$v1$Lifecycle;
        livenessProbe?: Schemas.io$k8s$api$core$v1$Probe;
        /** Name of the ephemeral container specified as a DNS_LABEL. This name must be unique among all containers, init containers and ephemeral containers. */
        name: string;
        /** Ports are not allowed for ephemeral containers. */
        ports?: Schemas.io$k8s$api$core$v1$ContainerPort[];
        readinessProbe?: Schemas.io$k8s$api$core$v1$Probe;
        /** Resources resize policy for the container. */
        resizePolicy?: Schemas.io$k8s$api$core$v1$ContainerResizePolicy[];
        resources?: Schemas.io$k8s$api$core$v1$ResourceRequirements;
        securityContext?: Schemas.io$k8s$api$core$v1$SecurityContext;
        startupProbe?: Schemas.io$k8s$api$core$v1$Probe;
        /** Whether this container should allocate a buffer for stdin in the container runtime. If this is not set, reads from stdin in the container will always result in EOF. Default is false. */
        stdin?: boolean;
        /** Whether the container runtime should close the stdin channel after it has been opened by a single attach. When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF. Default is false */
        stdinOnce?: boolean;
        /**
         * If set, the name of the container from PodSpec that this ephemeral container targets. The ephemeral container will be run in the namespaces (IPC, PID, etc) of this container. If not set then the ephemeral container uses the namespaces configured in the Pod spec.
         *
         * The container runtime must implement support for this feature. If the runtime does not support namespace targeting then the result of setting this field is undefined.
         */
        targetContainerName?: string;
        /** Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem. Message written is intended to be brief final status, such as an assertion failure message. Will be truncated by the node if greater than 4096 bytes. The total message length across all containers will be limited to 12kb. Defaults to /dev/termination-log. Cannot be updated. */
        terminationMessagePath?: string;
        /** Indicate how the termination message should be populated. File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated. */
        terminationMessagePolicy?: string;
        /** Whether this container should allocate a TTY for itself, also requires 'stdin' to be true. Default is false. */
        tty?: boolean;
        /** volumeDevices is the list of block devices to be used by the container. */
        volumeDevices?: Schemas.io$k8s$api$core$v1$VolumeDevice[];
        /** Pod volumes to mount into the container's filesystem. Subpath mounts are not allowed for ephemeral containers. Cannot be updated. */
        volumeMounts?: Schemas.io$k8s$api$core$v1$VolumeMount[];
        /** Container's working directory. If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated. */
        workingDir?: string;
    }
    /** Represents an ephemeral volume that is handled by a normal storage driver. */
    interface io$k8s$api$core$v1$EphemeralVolumeSource {
        volumeClaimTemplate?: Schemas.io$k8s$api$core$v1$PersistentVolumeClaimTemplate;
    }
    /** Event is a report of an event somewhere in the cluster.  Events have a limited retention time and triggers and messages may evolve with time.  Event consumers should not rely on the timing of an event with a given Reason reflecting a consistent underlying trigger, or the continued existence of events with that Reason.  Events should be treated as informative, best-effort, supplemental data. */
    interface io$k8s$api$core$v1$Event {
        /** What action was taken/failed regarding to the Regarding object. */
        action?: string;
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** The number of times this event has occurred. */
        count?: number;
        eventTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$MicroTime;
        firstTimestamp?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        involvedObject: Schemas.io$k8s$api$core$v1$ObjectReference;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        lastTimestamp?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** A human-readable description of the status of this operation. */
        message?: string;
        metadata: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** This should be a short, machine understandable string that gives the reason for the transition into the object's current status. */
        reason?: string;
        related?: Schemas.io$k8s$api$core$v1$ObjectReference;
        /** Name of the controller that emitted this Event, e.g. `kubernetes.io/kubelet`. */
        reportingComponent?: string;
        /** ID of the controller instance, e.g. `kubelet-xyzf`. */
        reportingInstance?: string;
        series?: Schemas.io$k8s$api$core$v1$EventSeries;
        source?: Schemas.io$k8s$api$core$v1$EventSource;
        /** Type of this event (Normal, Warning), new types could be added in the future */
        type?: string;
    }
    /** EventList is a list of events. */
    interface io$k8s$api$core$v1$EventList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of events */
        items: Schemas.io$k8s$api$core$v1$Event[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** EventSeries contain information on series of events, i.e. thing that was/is happening continuously for some time. */
    interface io$k8s$api$core$v1$EventSeries {
        /** Number of occurrences in this series up to the last heartbeat time */
        count?: number;
        lastObservedTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$MicroTime;
    }
    /** EventSource contains information for an event. */
    interface io$k8s$api$core$v1$EventSource {
        /** Component from which the event is generated. */
        component?: string;
        /** Node name on which the event is generated. */
        host?: string;
    }
    /** ExecAction describes a "run in container" action. */
    interface io$k8s$api$core$v1$ExecAction {
        /** Command is the command line to execute inside the container, the working directory for the command  is root ('/') in the container's filesystem. The command is simply exec'd, it is not run inside a shell, so traditional shell instructions ('|', etc) won't work. To use a shell, you need to explicitly call out to that shell. Exit status of 0 is treated as live/healthy and non-zero is unhealthy. */
        command?: string[];
    }
    /** Represents a Fibre Channel volume. Fibre Channel volumes can only be mounted as read/write once. Fibre Channel volumes support ownership management and SELinux relabeling. */
    interface io$k8s$api$core$v1$FCVolumeSource {
        /** fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. */
        fsType?: string;
        /** lun is Optional: FC target lun number */
        lun?: number;
        /** readOnly is Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. */
        readOnly?: boolean;
        /** targetWWNs is Optional: FC target worldwide names (WWNs) */
        targetWWNs?: string[];
        /** wwids Optional: FC volume world wide identifiers (wwids) Either wwids or combination of targetWWNs and lun must be set, but not both simultaneously. */
        wwids?: string[];
    }
    /** FlexPersistentVolumeSource represents a generic persistent volume resource that is provisioned/attached using an exec based plugin. */
    interface io$k8s$api$core$v1$FlexPersistentVolumeSource {
        /** driver is the name of the driver to use for this volume. */
        driver: string;
        /** fsType is the Filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default filesystem depends on FlexVolume script. */
        fsType?: string;
        /** options is Optional: this field holds extra command options if any. */
        options?: {
            [key: string]: string;
        };
        /** readOnly is Optional: defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. */
        readOnly?: boolean;
        secretRef?: Schemas.io$k8s$api$core$v1$SecretReference;
    }
    /** FlexVolume represents a generic volume resource that is provisioned/attached using an exec based plugin. */
    interface io$k8s$api$core$v1$FlexVolumeSource {
        /** driver is the name of the driver to use for this volume. */
        driver: string;
        /** fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default filesystem depends on FlexVolume script. */
        fsType?: string;
        /** options is Optional: this field holds extra command options if any. */
        options?: {
            [key: string]: string;
        };
        /** readOnly is Optional: defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. */
        readOnly?: boolean;
        secretRef?: Schemas.io$k8s$api$core$v1$LocalObjectReference;
    }
    /** Represents a Flocker volume mounted by the Flocker agent. One and only one of datasetName and datasetUUID should be set. Flocker volumes do not support ownership management or SELinux relabeling. */
    interface io$k8s$api$core$v1$FlockerVolumeSource {
        /** datasetName is Name of the dataset stored as metadata -> name on the dataset for Flocker should be considered as deprecated */
        datasetName?: string;
        /** datasetUUID is the UUID of the dataset. This is unique identifier of a Flocker dataset */
        datasetUUID?: string;
    }
    /**
     * Represents a Persistent Disk resource in Google Compute Engine.
     *
     * A GCE PD must exist before mounting to a container. The disk must also be in the same GCE project and zone as the kubelet. A GCE PD can only be mounted as read/write once or read-only many times. GCE PDs support ownership management and SELinux relabeling.
     */
    interface io$k8s$api$core$v1$GCEPersistentDiskVolumeSource {
        /** fsType is filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk */
        fsType?: string;
        /** partition is the partition in the volume that you want to mount. If omitted, the default is to mount by volume name. Examples: For volume /dev/sda1, you specify the partition as "1". Similarly, the volume partition for /dev/sda is "0" (or you can leave the property empty). More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk */
        partition?: number;
        /** pdName is unique name of the PD resource in GCE. Used to identify the disk in GCE. More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk */
        pdName: string;
        /** readOnly here will force the ReadOnly setting in VolumeMounts. Defaults to false. More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk */
        readOnly?: boolean;
    }
    interface io$k8s$api$core$v1$GRPCAction {
        /** Port number of the gRPC service. Number must be in the range 1 to 65535. */
        port: number;
        /**
         * Service is the name of the service to place in the gRPC HealthCheckRequest (see https://github.com/grpc/grpc/blob/master/doc/health-checking.md).
         *
         * If this is not specified, the default behavior is defined by gRPC.
         */
        service?: string;
    }
    /**
     * Represents a volume that is populated with the contents of a git repository. Git repo volumes do not support ownership management. Git repo volumes support SELinux relabeling.
     *
     * DEPRECATED: GitRepo is deprecated. To provision a container with a git repo, mount an EmptyDir into an InitContainer that clones the repo using git, then mount the EmptyDir into the Pod's container.
     */
    interface io$k8s$api$core$v1$GitRepoVolumeSource {
        /** directory is the target directory name. Must not contain or start with '..'.  If '.' is supplied, the volume directory will be the git repository.  Otherwise, if specified, the volume will contain the git repository in the subdirectory with the given name. */
        directory?: string;
        /** repository is the URL */
        repository: string;
        /** revision is the commit hash for the specified revision. */
        revision?: string;
    }
    /** Represents a Glusterfs mount that lasts the lifetime of a pod. Glusterfs volumes do not support ownership management or SELinux relabeling. */
    interface io$k8s$api$core$v1$GlusterfsPersistentVolumeSource {
        /** endpoints is the endpoint name that details Glusterfs topology. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod */
        endpoints: string;
        /** endpointsNamespace is the namespace that contains Glusterfs endpoint. If this field is empty, the EndpointNamespace defaults to the same namespace as the bound PVC. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod */
        endpointsNamespace?: string;
        /** path is the Glusterfs volume path. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod */
        path: string;
        /** readOnly here will force the Glusterfs volume to be mounted with read-only permissions. Defaults to false. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod */
        readOnly?: boolean;
    }
    /** Represents a Glusterfs mount that lasts the lifetime of a pod. Glusterfs volumes do not support ownership management or SELinux relabeling. */
    interface io$k8s$api$core$v1$GlusterfsVolumeSource {
        /** endpoints is the endpoint name that details Glusterfs topology. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod */
        endpoints: string;
        /** path is the Glusterfs volume path. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod */
        path: string;
        /** readOnly here will force the Glusterfs volume to be mounted with read-only permissions. Defaults to false. More info: https://examples.k8s.io/volumes/glusterfs/README.md#create-a-pod */
        readOnly?: boolean;
    }
    /** HTTPGetAction describes an action based on HTTP Get requests. */
    interface io$k8s$api$core$v1$HTTPGetAction {
        /** Host name to connect to, defaults to the pod IP. You probably want to set "Host" in httpHeaders instead. */
        host?: string;
        /** Custom headers to set in the request. HTTP allows repeated headers. */
        httpHeaders?: Schemas.io$k8s$api$core$v1$HTTPHeader[];
        /** Path to access on the HTTP server. */
        path?: string;
        port: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
        /** Scheme to use for connecting to the host. Defaults to HTTP. */
        scheme?: string;
    }
    /** HTTPHeader describes a custom header to be used in HTTP probes */
    interface io$k8s$api$core$v1$HTTPHeader {
        /** The header field name. This will be canonicalized upon output, so case-variant names will be understood as the same header. */
        name: string;
        /** The header field value */
        value: string;
    }
    /** HostAlias holds the mapping between IP and hostnames that will be injected as an entry in the pod's hosts file. */
    interface io$k8s$api$core$v1$HostAlias {
        /** Hostnames for the above IP address. */
        hostnames?: string[];
        /** IP address of the host file entry. */
        ip?: string;
    }
    /** Represents a host path mapped into a pod. Host path volumes do not support ownership management or SELinux relabeling. */
    interface io$k8s$api$core$v1$HostPathVolumeSource {
        /** path of the directory on the host. If the path is a symlink, it will follow the link to the real path. More info: https://kubernetes.io/docs/concepts/storage/volumes#hostpath */
        path: string;
        /** type for HostPath Volume Defaults to "" More info: https://kubernetes.io/docs/concepts/storage/volumes#hostpath */
        type?: string;
    }
    /** ISCSIPersistentVolumeSource represents an ISCSI disk. ISCSI volumes can only be mounted as read/write once. ISCSI volumes support ownership management and SELinux relabeling. */
    interface io$k8s$api$core$v1$ISCSIPersistentVolumeSource {
        /** chapAuthDiscovery defines whether support iSCSI Discovery CHAP authentication */
        chapAuthDiscovery?: boolean;
        /** chapAuthSession defines whether support iSCSI Session CHAP authentication */
        chapAuthSession?: boolean;
        /** fsType is the filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#iscsi */
        fsType?: string;
        /** initiatorName is the custom iSCSI Initiator Name. If initiatorName is specified with iscsiInterface simultaneously, new iSCSI interface <target portal>:<volume name> will be created for the connection. */
        initiatorName?: string;
        /** iqn is Target iSCSI Qualified Name. */
        iqn: string;
        /** iscsiInterface is the interface Name that uses an iSCSI transport. Defaults to 'default' (tcp). */
        iscsiInterface?: string;
        /** lun is iSCSI Target Lun number. */
        lun: number;
        /** portals is the iSCSI Target Portal List. The Portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260). */
        portals?: string[];
        /** readOnly here will force the ReadOnly setting in VolumeMounts. Defaults to false. */
        readOnly?: boolean;
        secretRef?: Schemas.io$k8s$api$core$v1$SecretReference;
        /** targetPortal is iSCSI Target Portal. The Portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260). */
        targetPortal: string;
    }
    /** Represents an ISCSI disk. ISCSI volumes can only be mounted as read/write once. ISCSI volumes support ownership management and SELinux relabeling. */
    interface io$k8s$api$core$v1$ISCSIVolumeSource {
        /** chapAuthDiscovery defines whether support iSCSI Discovery CHAP authentication */
        chapAuthDiscovery?: boolean;
        /** chapAuthSession defines whether support iSCSI Session CHAP authentication */
        chapAuthSession?: boolean;
        /** fsType is the filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#iscsi */
        fsType?: string;
        /** initiatorName is the custom iSCSI Initiator Name. If initiatorName is specified with iscsiInterface simultaneously, new iSCSI interface <target portal>:<volume name> will be created for the connection. */
        initiatorName?: string;
        /** iqn is the target iSCSI Qualified Name. */
        iqn: string;
        /** iscsiInterface is the interface Name that uses an iSCSI transport. Defaults to 'default' (tcp). */
        iscsiInterface?: string;
        /** lun represents iSCSI Target Lun number. */
        lun: number;
        /** portals is the iSCSI Target Portal List. The portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260). */
        portals?: string[];
        /** readOnly here will force the ReadOnly setting in VolumeMounts. Defaults to false. */
        readOnly?: boolean;
        secretRef?: Schemas.io$k8s$api$core$v1$LocalObjectReference;
        /** targetPortal is iSCSI Target Portal. The Portal is either an IP or ip_addr:port if the port is other than default (typically TCP ports 860 and 3260). */
        targetPortal: string;
    }
    /** Maps a string key to a path within a volume. */
    interface io$k8s$api$core$v1$KeyToPath {
        /** key is the key to project. */
        key: string;
        /** mode is Optional: mode bits used to set permissions on this file. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. If not specified, the volume defaultMode will be used. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set. */
        mode?: number;
        /** path is the relative path of the file to map the key to. May not be an absolute path. May not contain the path element '..'. May not start with the string '..'. */
        path: string;
    }
    /** Lifecycle describes actions that the management system should take in response to container lifecycle events. For the PostStart and PreStop lifecycle handlers, management of the container blocks until the action is complete, unless the container process fails, in which case the handler is aborted. */
    interface io$k8s$api$core$v1$Lifecycle {
        postStart?: Schemas.io$k8s$api$core$v1$LifecycleHandler;
        preStop?: Schemas.io$k8s$api$core$v1$LifecycleHandler;
    }
    /** LifecycleHandler defines a specific action that should be taken in a lifecycle hook. One and only one of the fields, except TCPSocket must be specified. */
    interface io$k8s$api$core$v1$LifecycleHandler {
        exec?: Schemas.io$k8s$api$core$v1$ExecAction;
        httpGet?: Schemas.io$k8s$api$core$v1$HTTPGetAction;
        tcpSocket?: Schemas.io$k8s$api$core$v1$TCPSocketAction;
    }
    /** LimitRange sets resource usage limits for each kind of resource in a Namespace. */
    interface io$k8s$api$core$v1$LimitRange {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$core$v1$LimitRangeSpec;
    }
    /** LimitRangeItem defines a min/max usage limit for any resource that matches on kind. */
    interface io$k8s$api$core$v1$LimitRangeItem {
        /** Default resource requirement limit value by resource name if resource limit is omitted. */
        default?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** DefaultRequest is the default resource requirement request value by resource name if resource request is omitted. */
        defaultRequest?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** Max usage constraints on this kind by resource name. */
        max?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** MaxLimitRequestRatio if specified, the named resource must have a request and limit that are both non-zero where limit divided by request is less than or equal to the enumerated value; this represents the max burst for the named resource. */
        maxLimitRequestRatio?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** Min usage constraints on this kind by resource name. */
        min?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** Type of resource that this limit applies to. */
        type: string;
    }
    /** LimitRangeList is a list of LimitRange items. */
    interface io$k8s$api$core$v1$LimitRangeList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is a list of LimitRange objects. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/ */
        items: Schemas.io$k8s$api$core$v1$LimitRange[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** LimitRangeSpec defines a min/max usage limit for resources that match on kind. */
    interface io$k8s$api$core$v1$LimitRangeSpec {
        /** Limits is the list of LimitRangeItem objects that are enforced. */
        limits: Schemas.io$k8s$api$core$v1$LimitRangeItem[];
    }
    /** LoadBalancerIngress represents the status of a load-balancer ingress point: traffic intended for the service should be sent to an ingress point. */
    interface io$k8s$api$core$v1$LoadBalancerIngress {
        /** Hostname is set for load-balancer ingress points that are DNS based (typically AWS load-balancers) */
        hostname?: string;
        /** IP is set for load-balancer ingress points that are IP based (typically GCE or OpenStack load-balancers) */
        ip?: string;
        /** Ports is a list of records of service ports If used, every port defined in the service should have an entry in it */
        ports?: Schemas.io$k8s$api$core$v1$PortStatus[];
    }
    /** LoadBalancerStatus represents the status of a load-balancer. */
    interface io$k8s$api$core$v1$LoadBalancerStatus {
        /** Ingress is a list containing ingress points for the load-balancer. Traffic intended for the service should be sent to these ingress points. */
        ingress?: Schemas.io$k8s$api$core$v1$LoadBalancerIngress[];
    }
    /** LocalObjectReference contains enough information to let you locate the referenced object inside the same namespace. */
    interface io$k8s$api$core$v1$LocalObjectReference {
        /** Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names */
        name?: string;
    }
    /** Local represents directly-attached storage with node affinity (Beta feature) */
    interface io$k8s$api$core$v1$LocalVolumeSource {
        /** fsType is the filesystem type to mount. It applies only when the Path is a block device. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". The default value is to auto-select a filesystem if unspecified. */
        fsType?: string;
        /** path of the full path to the volume on the node. It can be either a directory or block device (disk, partition, ...). */
        path: string;
    }
    /** Represents an NFS mount that lasts the lifetime of a pod. NFS volumes do not support ownership management or SELinux relabeling. */
    interface io$k8s$api$core$v1$NFSVolumeSource {
        /** path that is exported by the NFS server. More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs */
        path: string;
        /** readOnly here will force the NFS export to be mounted with read-only permissions. Defaults to false. More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs */
        readOnly?: boolean;
        /** server is the hostname or IP address of the NFS server. More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs */
        server: string;
    }
    /** Namespace provides a scope for Names. Use of multiple namespaces is optional. */
    interface io$k8s$api$core$v1$Namespace {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$core$v1$NamespaceSpec;
        status?: Schemas.io$k8s$api$core$v1$NamespaceStatus;
    }
    /** NamespaceCondition contains details about state of namespace. */
    interface io$k8s$api$core$v1$NamespaceCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        message?: string;
        reason?: string;
        /** Status of the condition, one of True, False, Unknown. */
        status: string;
        /** Type of namespace controller condition. */
        type: string;
    }
    /** NamespaceList is a list of Namespaces. */
    interface io$k8s$api$core$v1$NamespaceList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is the list of Namespace objects in the list. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/namespaces/ */
        items: Schemas.io$k8s$api$core$v1$Namespace[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** NamespaceSpec describes the attributes on a Namespace. */
    interface io$k8s$api$core$v1$NamespaceSpec {
        /** Finalizers is an opaque list of values that must be empty to permanently remove object from storage. More info: https://kubernetes.io/docs/tasks/administer-cluster/namespaces/ */
        finalizers?: string[];
    }
    /** NamespaceStatus is information about the current status of a Namespace. */
    interface io$k8s$api$core$v1$NamespaceStatus {
        /** Represents the latest available observations of a namespace's current state. */
        conditions?: Schemas.io$k8s$api$core$v1$NamespaceCondition[];
        /** Phase is the current lifecycle phase of the namespace. More info: https://kubernetes.io/docs/tasks/administer-cluster/namespaces/ */
        phase?: string;
    }
    /** Node is a worker node in Kubernetes. Each node will have a unique identifier in the cache (i.e. in etcd). */
    interface io$k8s$api$core$v1$Node {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$core$v1$NodeSpec;
        status?: Schemas.io$k8s$api$core$v1$NodeStatus;
    }
    /** NodeAddress contains information for the node's address. */
    interface io$k8s$api$core$v1$NodeAddress {
        /** The node address. */
        address: string;
        /** Node address type, one of Hostname, ExternalIP or InternalIP. */
        type: string;
    }
    /** Node affinity is a group of node affinity scheduling rules. */
    interface io$k8s$api$core$v1$NodeAffinity {
        /** The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node matches the corresponding matchExpressions; the node(s) with the highest sum are the most preferred. */
        preferredDuringSchedulingIgnoredDuringExecution?: Schemas.io$k8s$api$core$v1$PreferredSchedulingTerm[];
        requiredDuringSchedulingIgnoredDuringExecution?: Schemas.io$k8s$api$core$v1$NodeSelector;
    }
    /** NodeCondition contains condition information for a node. */
    interface io$k8s$api$core$v1$NodeCondition {
        lastHeartbeatTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** Human readable message indicating details about last transition. */
        message?: string;
        /** (brief) reason for the condition's last transition. */
        reason?: string;
        /** Status of the condition, one of True, False, Unknown. */
        status: string;
        /** Type of node condition. */
        type: string;
    }
    /** NodeConfigSource specifies a source of node configuration. Exactly one subfield (excluding metadata) must be non-nil. This API is deprecated since 1.22 */
    interface io$k8s$api$core$v1$NodeConfigSource {
        configMap?: Schemas.io$k8s$api$core$v1$ConfigMapNodeConfigSource;
    }
    /** NodeConfigStatus describes the status of the config assigned by Node.Spec.ConfigSource. */
    interface io$k8s$api$core$v1$NodeConfigStatus {
        active?: Schemas.io$k8s$api$core$v1$NodeConfigSource;
        assigned?: Schemas.io$k8s$api$core$v1$NodeConfigSource;
        /** Error describes any problems reconciling the Spec.ConfigSource to the Active config. Errors may occur, for example, attempting to checkpoint Spec.ConfigSource to the local Assigned record, attempting to checkpoint the payload associated with Spec.ConfigSource, attempting to load or validate the Assigned config, etc. Errors may occur at different points while syncing config. Earlier errors (e.g. download or checkpointing errors) will not result in a rollback to LastKnownGood, and may resolve across Kubelet retries. Later errors (e.g. loading or validating a checkpointed config) will result in a rollback to LastKnownGood. In the latter case, it is usually possible to resolve the error by fixing the config assigned in Spec.ConfigSource. You can find additional information for debugging by searching the error message in the Kubelet log. Error is a human-readable description of the error state; machines can check whether or not Error is empty, but should not rely on the stability of the Error text across Kubelet versions. */
        error?: string;
        lastKnownGood?: Schemas.io$k8s$api$core$v1$NodeConfigSource;
    }
    /** NodeDaemonEndpoints lists ports opened by daemons running on the Node. */
    interface io$k8s$api$core$v1$NodeDaemonEndpoints {
        kubeletEndpoint?: Schemas.io$k8s$api$core$v1$DaemonEndpoint;
    }
    /** NodeList is the whole list of all Nodes which have been registered with master. */
    interface io$k8s$api$core$v1$NodeList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of nodes */
        items: Schemas.io$k8s$api$core$v1$Node[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** A node selector represents the union of the results of one or more label queries over a set of nodes; that is, it represents the OR of the selectors represented by the node selector terms. */
    interface io$k8s$api$core$v1$NodeSelector {
        /** Required. A list of node selector terms. The terms are ORed. */
        nodeSelectorTerms: Schemas.io$k8s$api$core$v1$NodeSelectorTerm[];
    }
    /** A node selector requirement is a selector that contains values, a key, and an operator that relates the key and values. */
    interface io$k8s$api$core$v1$NodeSelectorRequirement {
        /** The label key that the selector applies to. */
        key: string;
        /** Represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. Gt, and Lt. */
        operator: string;
        /** An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. If the operator is Gt or Lt, the values array must have a single element, which will be interpreted as an integer. This array is replaced during a strategic merge patch. */
        values?: string[];
    }
    /** A null or empty node selector term matches no objects. The requirements of them are ANDed. The TopologySelectorTerm type implements a subset of the NodeSelectorTerm. */
    interface io$k8s$api$core$v1$NodeSelectorTerm {
        /** A list of node selector requirements by node's labels. */
        matchExpressions?: Schemas.io$k8s$api$core$v1$NodeSelectorRequirement[];
        /** A list of node selector requirements by node's fields. */
        matchFields?: Schemas.io$k8s$api$core$v1$NodeSelectorRequirement[];
    }
    /** NodeSpec describes the attributes that a node is created with. */
    interface io$k8s$api$core$v1$NodeSpec {
        configSource?: Schemas.io$k8s$api$core$v1$NodeConfigSource;
        /** Deprecated. Not all kubelets will set this field. Remove field after 1.13. see: https://issues.k8s.io/61966 */
        externalID?: string;
        /** PodCIDR represents the pod IP range assigned to the node. */
        podCIDR?: string;
        /** podCIDRs represents the IP ranges assigned to the node for usage by Pods on that node. If this field is specified, the 0th entry must match the podCIDR field. It may contain at most 1 value for each of IPv4 and IPv6. */
        podCIDRs?: string[];
        /** ID of the node assigned by the cloud provider in the format: <ProviderName>://<ProviderSpecificNodeID> */
        providerID?: string;
        /** If specified, the node's taints. */
        taints?: Schemas.io$k8s$api$core$v1$Taint[];
        /** Unschedulable controls node schedulability of new pods. By default, node is schedulable. More info: https://kubernetes.io/docs/concepts/nodes/node/#manual-node-administration */
        unschedulable?: boolean;
    }
    /** NodeStatus is information about the current status of a node. */
    interface io$k8s$api$core$v1$NodeStatus {
        /** List of addresses reachable to the node. Queried from cloud provider, if available. More info: https://kubernetes.io/docs/concepts/nodes/node/#addresses Note: This field is declared as mergeable, but the merge key is not sufficiently unique, which can cause data corruption when it is merged. Callers should instead use a full-replacement patch. See https://pr.k8s.io/79391 for an example. Consumers should assume that addresses can change during the lifetime of a Node. However, there are some exceptions where this may not be possible, such as Pods that inherit a Node's address in its own status or consumers of the downward API (status.hostIP). */
        addresses?: Schemas.io$k8s$api$core$v1$NodeAddress[];
        /** Allocatable represents the resources of a node that are available for scheduling. Defaults to Capacity. */
        allocatable?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** Capacity represents the total resources of a node. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#capacity */
        capacity?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** Conditions is an array of current observed node conditions. More info: https://kubernetes.io/docs/concepts/nodes/node/#condition */
        conditions?: Schemas.io$k8s$api$core$v1$NodeCondition[];
        config?: Schemas.io$k8s$api$core$v1$NodeConfigStatus;
        daemonEndpoints?: Schemas.io$k8s$api$core$v1$NodeDaemonEndpoints;
        /** List of container images on this node */
        images?: Schemas.io$k8s$api$core$v1$ContainerImage[];
        nodeInfo?: Schemas.io$k8s$api$core$v1$NodeSystemInfo;
        /** NodePhase is the recently observed lifecycle phase of the node. More info: https://kubernetes.io/docs/concepts/nodes/node/#phase The field is never populated, and now is deprecated. */
        phase?: string;
        /** List of volumes that are attached to the node. */
        volumesAttached?: Schemas.io$k8s$api$core$v1$AttachedVolume[];
        /** List of attachable volumes in use (mounted) by the node. */
        volumesInUse?: string[];
    }
    /** NodeSystemInfo is a set of ids/uuids to uniquely identify the node. */
    interface io$k8s$api$core$v1$NodeSystemInfo {
        /** The Architecture reported by the node */
        architecture: string;
        /** Boot ID reported by the node. */
        bootID: string;
        /** ContainerRuntime Version reported by the node through runtime remote API (e.g. containerd://1.4.2). */
        containerRuntimeVersion: string;
        /** Kernel Version reported by the node from 'uname -r' (e.g. 3.16.0-0.bpo.4-amd64). */
        kernelVersion: string;
        /** KubeProxy Version reported by the node. */
        kubeProxyVersion: string;
        /** Kubelet Version reported by the node. */
        kubeletVersion: string;
        /** MachineID reported by the node. For unique machine identification in the cluster this field is preferred. Learn more from man(5) machine-id: http://man7.org/linux/man-pages/man5/machine-id.5.html */
        machineID: string;
        /** The Operating System reported by the node */
        operatingSystem: string;
        /** OS Image reported by the node from /etc/os-release (e.g. Debian GNU/Linux 7 (wheezy)). */
        osImage: string;
        /** SystemUUID reported by the node. For unique machine identification MachineID is preferred. This field is specific to Red Hat hosts https://access.redhat.com/documentation/en-us/red_hat_subscription_management/1/html/rhsm/uuid */
        systemUUID: string;
    }
    /** ObjectFieldSelector selects an APIVersioned field of an object. */
    interface io$k8s$api$core$v1$ObjectFieldSelector {
        /** Version of the schema the FieldPath is written in terms of, defaults to "v1". */
        apiVersion?: string;
        /** Path of the field to select in the specified API version. */
        fieldPath: string;
    }
    /** ObjectReference contains enough information to let you inspect or modify the referred object. */
    interface io$k8s$api$core$v1$ObjectReference {
        /** API version of the referent. */
        apiVersion?: string;
        /** If referring to a piece of an object instead of an entire object, this string should contain a valid JSON/Go field access statement, such as desiredState.manifest.containers[2]. For example, if the object reference is to a container within a pod, this would take on a value like: "spec.containers{name}" (where "name" refers to the name of the container that triggered the event) or if no container name is specified "spec.containers[2]" (container with index 2 in this pod). This syntax is chosen only to have some well-defined way of referencing a part of an object. */
        fieldPath?: string;
        /** Kind of the referent. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        /** Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names */
        name?: string;
        /** Namespace of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/namespaces/ */
        namespace?: string;
        /** Specific resourceVersion to which this reference is made, if any. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#concurrency-control-and-consistency */
        resourceVersion?: string;
        /** UID of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#uids */
        uid?: string;
    }
    /** PersistentVolume (PV) is a storage resource provisioned by an administrator. It is analogous to a node. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes */
    interface io$k8s$api$core$v1$PersistentVolume {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$core$v1$PersistentVolumeSpec;
        status?: Schemas.io$k8s$api$core$v1$PersistentVolumeStatus;
    }
    /** PersistentVolumeClaim is a user's request for and claim to a persistent volume */
    interface io$k8s$api$core$v1$PersistentVolumeClaim {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$core$v1$PersistentVolumeClaimSpec;
        status?: Schemas.io$k8s$api$core$v1$PersistentVolumeClaimStatus;
    }
    /** PersistentVolumeClaimCondition contains details about state of pvc */
    interface io$k8s$api$core$v1$PersistentVolumeClaimCondition {
        lastProbeTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** message is the human-readable message indicating details about last transition. */
        message?: string;
        /** reason is a unique, this should be a short, machine understandable string that gives the reason for condition's last transition. If it reports "ResizeStarted" that means the underlying persistent volume is being resized. */
        reason?: string;
        status: string;
        type: string;
    }
    /** PersistentVolumeClaimList is a list of PersistentVolumeClaim items. */
    interface io$k8s$api$core$v1$PersistentVolumeClaimList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is a list of persistent volume claims. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistentvolumeclaims */
        items: Schemas.io$k8s$api$core$v1$PersistentVolumeClaim[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** PersistentVolumeClaimSpec describes the common attributes of storage devices and allows a Source for provider-specific attributes */
    interface io$k8s$api$core$v1$PersistentVolumeClaimSpec {
        /** accessModes contains the desired access modes the volume should have. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes-1 */
        accessModes?: string[];
        dataSource?: Schemas.io$k8s$api$core$v1$TypedLocalObjectReference;
        dataSourceRef?: Schemas.io$k8s$api$core$v1$TypedObjectReference;
        resources?: Schemas.io$k8s$api$core$v1$ResourceRequirements;
        selector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        /** storageClassName is the name of the StorageClass required by the claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#class-1 */
        storageClassName?: string;
        /** volumeMode defines what type of volume is required by the claim. Value of Filesystem is implied when not included in claim spec. */
        volumeMode?: string;
        /** volumeName is the binding reference to the PersistentVolume backing this claim. */
        volumeName?: string;
    }
    /** PersistentVolumeClaimStatus is the current status of a persistent volume claim. */
    interface io$k8s$api$core$v1$PersistentVolumeClaimStatus {
        /** accessModes contains the actual access modes the volume backing the PVC has. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes-1 */
        accessModes?: string[];
        /** allocatedResources is the storage resource within AllocatedResources tracks the capacity allocated to a PVC. It may be larger than the actual capacity when a volume expansion operation is requested. For storage quota, the larger value from allocatedResources and PVC.spec.resources is used. If allocatedResources is not set, PVC.spec.resources alone is used for quota calculation. If a volume expansion capacity request is lowered, allocatedResources is only lowered if there are no expansion operations in progress and if the actual volume capacity is equal or lower than the requested capacity. This is an alpha field and requires enabling RecoverVolumeExpansionFailure feature. */
        allocatedResources?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** capacity represents the actual resources of the underlying volume. */
        capacity?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** conditions is the current Condition of persistent volume claim. If underlying persistent volume is being resized then the Condition will be set to 'ResizeStarted'. */
        conditions?: Schemas.io$k8s$api$core$v1$PersistentVolumeClaimCondition[];
        /** phase represents the current phase of PersistentVolumeClaim. */
        phase?: string;
        /** resizeStatus stores status of resize operation. ResizeStatus is not set by default but when expansion is complete resizeStatus is set to empty string by resize controller or kubelet. This is an alpha field and requires enabling RecoverVolumeExpansionFailure feature. */
        resizeStatus?: string;
    }
    /** PersistentVolumeClaimTemplate is used to produce PersistentVolumeClaim objects as part of an EphemeralVolumeSource. */
    interface io$k8s$api$core$v1$PersistentVolumeClaimTemplate {
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$core$v1$PersistentVolumeClaimSpec;
    }
    /** PersistentVolumeClaimVolumeSource references the user's PVC in the same namespace. This volume finds the bound PV and mounts that volume for the pod. A PersistentVolumeClaimVolumeSource is, essentially, a wrapper around another type of volume that is owned by someone else (the system). */
    interface io$k8s$api$core$v1$PersistentVolumeClaimVolumeSource {
        /** claimName is the name of a PersistentVolumeClaim in the same namespace as the pod using this volume. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#persistentvolumeclaims */
        claimName: string;
        /** readOnly Will force the ReadOnly setting in VolumeMounts. Default false. */
        readOnly?: boolean;
    }
    /** PersistentVolumeList is a list of PersistentVolume items. */
    interface io$k8s$api$core$v1$PersistentVolumeList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is a list of persistent volumes. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes */
        items: Schemas.io$k8s$api$core$v1$PersistentVolume[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** PersistentVolumeSpec is the specification of a persistent volume. */
    interface io$k8s$api$core$v1$PersistentVolumeSpec {
        /** accessModes contains all ways the volume can be mounted. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#access-modes */
        accessModes?: string[];
        awsElasticBlockStore?: Schemas.io$k8s$api$core$v1$AWSElasticBlockStoreVolumeSource;
        azureDisk?: Schemas.io$k8s$api$core$v1$AzureDiskVolumeSource;
        azureFile?: Schemas.io$k8s$api$core$v1$AzureFilePersistentVolumeSource;
        /** capacity is the description of the persistent volume's resources and capacity. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#capacity */
        capacity?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        cephfs?: Schemas.io$k8s$api$core$v1$CephFSPersistentVolumeSource;
        cinder?: Schemas.io$k8s$api$core$v1$CinderPersistentVolumeSource;
        claimRef?: Schemas.io$k8s$api$core$v1$ObjectReference;
        csi?: Schemas.io$k8s$api$core$v1$CSIPersistentVolumeSource;
        fc?: Schemas.io$k8s$api$core$v1$FCVolumeSource;
        flexVolume?: Schemas.io$k8s$api$core$v1$FlexPersistentVolumeSource;
        flocker?: Schemas.io$k8s$api$core$v1$FlockerVolumeSource;
        gcePersistentDisk?: Schemas.io$k8s$api$core$v1$GCEPersistentDiskVolumeSource;
        glusterfs?: Schemas.io$k8s$api$core$v1$GlusterfsPersistentVolumeSource;
        hostPath?: Schemas.io$k8s$api$core$v1$HostPathVolumeSource;
        iscsi?: Schemas.io$k8s$api$core$v1$ISCSIPersistentVolumeSource;
        local?: Schemas.io$k8s$api$core$v1$LocalVolumeSource;
        /** mountOptions is the list of mount options, e.g. ["ro", "soft"]. Not validated - mount will simply fail if one is invalid. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes/#mount-options */
        mountOptions?: string[];
        nfs?: Schemas.io$k8s$api$core$v1$NFSVolumeSource;
        nodeAffinity?: Schemas.io$k8s$api$core$v1$VolumeNodeAffinity;
        /** persistentVolumeReclaimPolicy defines what happens to a persistent volume when released from its claim. Valid options are Retain (default for manually created PersistentVolumes), Delete (default for dynamically provisioned PersistentVolumes), and Recycle (deprecated). Recycle must be supported by the volume plugin underlying this PersistentVolume. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#reclaiming */
        persistentVolumeReclaimPolicy?: string;
        photonPersistentDisk?: Schemas.io$k8s$api$core$v1$PhotonPersistentDiskVolumeSource;
        portworxVolume?: Schemas.io$k8s$api$core$v1$PortworxVolumeSource;
        quobyte?: Schemas.io$k8s$api$core$v1$QuobyteVolumeSource;
        rbd?: Schemas.io$k8s$api$core$v1$RBDPersistentVolumeSource;
        scaleIO?: Schemas.io$k8s$api$core$v1$ScaleIOPersistentVolumeSource;
        /** storageClassName is the name of StorageClass to which this persistent volume belongs. Empty value means that this volume does not belong to any StorageClass. */
        storageClassName?: string;
        storageos?: Schemas.io$k8s$api$core$v1$StorageOSPersistentVolumeSource;
        /** volumeMode defines if a volume is intended to be used with a formatted filesystem or to remain in raw block state. Value of Filesystem is implied when not included in spec. */
        volumeMode?: string;
        vsphereVolume?: Schemas.io$k8s$api$core$v1$VsphereVirtualDiskVolumeSource;
    }
    /** PersistentVolumeStatus is the current status of a persistent volume. */
    interface io$k8s$api$core$v1$PersistentVolumeStatus {
        /** message is a human-readable message indicating details about why the volume is in this state. */
        message?: string;
        /** phase indicates if a volume is available, bound to a claim, or released by a claim. More info: https://kubernetes.io/docs/concepts/storage/persistent-volumes#phase */
        phase?: string;
        /** reason is a brief CamelCase string that describes any failure and is meant for machine parsing and tidy display in the CLI. */
        reason?: string;
    }
    /** Represents a Photon Controller persistent disk resource. */
    interface io$k8s$api$core$v1$PhotonPersistentDiskVolumeSource {
        /** fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. */
        fsType?: string;
        /** pdID is the ID that identifies Photon Controller persistent disk */
        pdID: string;
    }
    /** Pod is a collection of containers that can run on a host. This resource is created by clients and scheduled onto hosts. */
    interface io$k8s$api$core$v1$Pod {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$core$v1$PodSpec;
        status?: Schemas.io$k8s$api$core$v1$PodStatus;
    }
    /** Pod affinity is a group of inter pod affinity scheduling rules. */
    interface io$k8s$api$core$v1$PodAffinity {
        /** The scheduler will prefer to schedule pods to nodes that satisfy the affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred. */
        preferredDuringSchedulingIgnoredDuringExecution?: Schemas.io$k8s$api$core$v1$WeightedPodAffinityTerm[];
        /** If the affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied. */
        requiredDuringSchedulingIgnoredDuringExecution?: Schemas.io$k8s$api$core$v1$PodAffinityTerm[];
    }
    /** Defines a set of pods (namely those matching the labelSelector relative to the given namespace(s)) that this pod should be co-located (affinity) or not co-located (anti-affinity) with, where co-located is defined as running on a node whose value of the label with key <topologyKey> matches that of any node on which a pod of the set of pods is running */
    interface io$k8s$api$core$v1$PodAffinityTerm {
        labelSelector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        namespaceSelector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        /** namespaces specifies a static list of namespace names that the term applies to. The term is applied to the union of the namespaces listed in this field and the ones selected by namespaceSelector. null or empty namespaces list and null namespaceSelector means "this pod's namespace". */
        namespaces?: string[];
        /** This pod should be co-located (affinity) or not co-located (anti-affinity) with the pods matching the labelSelector in the specified namespaces, where co-located is defined as running on a node whose value of the label with key topologyKey matches that of any node on which any of the selected pods is running. Empty topologyKey is not allowed. */
        topologyKey: string;
    }
    /** Pod anti affinity is a group of inter pod anti affinity scheduling rules. */
    interface io$k8s$api$core$v1$PodAntiAffinity {
        /** The scheduler will prefer to schedule pods to nodes that satisfy the anti-affinity expressions specified by this field, but it may choose a node that violates one or more of the expressions. The node that is most preferred is the one with the greatest sum of weights, i.e. for each node that meets all of the scheduling requirements (resource request, requiredDuringScheduling anti-affinity expressions, etc.), compute a sum by iterating through the elements of this field and adding "weight" to the sum if the node has pods which matches the corresponding podAffinityTerm; the node(s) with the highest sum are the most preferred. */
        preferredDuringSchedulingIgnoredDuringExecution?: Schemas.io$k8s$api$core$v1$WeightedPodAffinityTerm[];
        /** If the anti-affinity requirements specified by this field are not met at scheduling time, the pod will not be scheduled onto the node. If the anti-affinity requirements specified by this field cease to be met at some point during pod execution (e.g. due to a pod label update), the system may or may not try to eventually evict the pod from its node. When there are multiple elements, the lists of nodes corresponding to each podAffinityTerm are intersected, i.e. all terms must be satisfied. */
        requiredDuringSchedulingIgnoredDuringExecution?: Schemas.io$k8s$api$core$v1$PodAffinityTerm[];
    }
    /** PodCondition contains details for the current condition of this pod. */
    interface io$k8s$api$core$v1$PodCondition {
        lastProbeTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** Human-readable message indicating details about last transition. */
        message?: string;
        /** Unique, one-word, CamelCase reason for the condition's last transition. */
        reason?: string;
        /** Status is the status of the condition. Can be True, False, Unknown. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-conditions */
        status: string;
        /** Type is the type of the condition. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-conditions */
        type: string;
    }
    /** PodDNSConfig defines the DNS parameters of a pod in addition to those generated from DNSPolicy. */
    interface io$k8s$api$core$v1$PodDNSConfig {
        /** A list of DNS name server IP addresses. This will be appended to the base nameservers generated from DNSPolicy. Duplicated nameservers will be removed. */
        nameservers?: string[];
        /** A list of DNS resolver options. This will be merged with the base options generated from DNSPolicy. Duplicated entries will be removed. Resolution options given in Options will override those that appear in the base DNSPolicy. */
        options?: Schemas.io$k8s$api$core$v1$PodDNSConfigOption[];
        /** A list of DNS search domains for host-name lookup. This will be appended to the base search paths generated from DNSPolicy. Duplicated search paths will be removed. */
        searches?: string[];
    }
    /** PodDNSConfigOption defines DNS resolver options of a pod. */
    interface io$k8s$api$core$v1$PodDNSConfigOption {
        /** Required. */
        name?: string;
        value?: string;
    }
    /**
     * IP address information for entries in the (plural) PodIPs field. Each entry includes:
     *
     * 	IP: An IP address allocated to the pod. Routable at least within the cluster.
     */
    interface io$k8s$api$core$v1$PodIP {
        /** ip is an IP address (IPv4 or IPv6) assigned to the pod */
        ip?: string;
    }
    /** PodList is a list of Pods. */
    interface io$k8s$api$core$v1$PodList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of pods. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md */
        items: Schemas.io$k8s$api$core$v1$Pod[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** PodOS defines the OS parameters of a pod. */
    interface io$k8s$api$core$v1$PodOS {
        /** Name is the name of the operating system. The currently supported values are linux and windows. Additional value may be defined in future and can be one of: https://github.com/opencontainers/runtime-spec/blob/master/config.md#platform-specific-configuration Clients should expect to handle additional values and treat unrecognized values in this field as os: null */
        name: string;
    }
    /** PodReadinessGate contains the reference to a pod condition */
    interface io$k8s$api$core$v1$PodReadinessGate {
        /** ConditionType refers to a condition in the pod's condition list with matching type. */
        conditionType: string;
    }
    /** PodResourceClaim references exactly one ResourceClaim through a ClaimSource. It adds a name to it that uniquely identifies the ResourceClaim inside the Pod. Containers that need access to the ResourceClaim reference it with this name. */
    interface io$k8s$api$core$v1$PodResourceClaim {
        /** Name uniquely identifies this resource claim inside the pod. This must be a DNS_LABEL. */
        name: string;
        source?: Schemas.io$k8s$api$core$v1$ClaimSource;
    }
    /** PodSchedulingGate is associated to a Pod to guard its scheduling. */
    interface io$k8s$api$core$v1$PodSchedulingGate {
        /** Name of the scheduling gate. Each scheduling gate must have a unique name field. */
        name: string;
    }
    /** PodSecurityContext holds pod-level security attributes and common container settings. Some fields are also present in container.securityContext.  Field values of container.securityContext take precedence over field values of PodSecurityContext. */
    interface io$k8s$api$core$v1$PodSecurityContext {
        /**
         * A special supplemental group that applies to all containers in a pod. Some volume types allow the Kubelet to change the ownership of that volume to be owned by the pod:
         *
         * 1. The owning GID will be the FSGroup 2. The setgid bit is set (new files created in the volume will be owned by FSGroup) 3. The permission bits are OR'd with rw-rw----
         *
         * If unset, the Kubelet will not modify the ownership and permissions of any volume. Note that this field cannot be set when spec.os.name is windows.
         */
        fsGroup?: number;
        /** fsGroupChangePolicy defines behavior of changing ownership and permission of the volume before being exposed inside Pod. This field will only apply to volume types which support fsGroup based ownership(and permissions). It will have no effect on ephemeral volume types such as: secret, configmaps and emptydir. Valid values are "OnRootMismatch" and "Always". If not specified, "Always" is used. Note that this field cannot be set when spec.os.name is windows. */
        fsGroupChangePolicy?: string;
        /** The GID to run the entrypoint of the container process. Uses runtime default if unset. May also be set in SecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container. Note that this field cannot be set when spec.os.name is windows. */
        runAsGroup?: number;
        /** Indicates that the container must run as a non-root user. If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in SecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. */
        runAsNonRoot?: boolean;
        /** The UID to run the entrypoint of the container process. Defaults to user specified in image metadata if unspecified. May also be set in SecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence for that container. Note that this field cannot be set when spec.os.name is windows. */
        runAsUser?: number;
        seLinuxOptions?: Schemas.io$k8s$api$core$v1$SELinuxOptions;
        seccompProfile?: Schemas.io$k8s$api$core$v1$SeccompProfile;
        /** A list of groups applied to the first process run in each container, in addition to the container's primary GID, the fsGroup (if specified), and group memberships defined in the container image for the uid of the container process. If unspecified, no additional groups are added to any container. Note that group memberships defined in the container image for the uid of the container process are still effective, even if they are not included in this list. Note that this field cannot be set when spec.os.name is windows. */
        supplementalGroups?: number[];
        /** Sysctls hold a list of namespaced sysctls used for the pod. Pods with unsupported sysctls (by the container runtime) might fail to launch. Note that this field cannot be set when spec.os.name is windows. */
        sysctls?: Schemas.io$k8s$api$core$v1$Sysctl[];
        windowsOptions?: Schemas.io$k8s$api$core$v1$WindowsSecurityContextOptions;
    }
    /** PodSpec is a description of a pod. */
    interface io$k8s$api$core$v1$PodSpec {
        /** Optional duration in seconds the pod may be active on the node relative to StartTime before the system will actively try to mark it failed and kill associated containers. Value must be a positive integer. */
        activeDeadlineSeconds?: number;
        affinity?: Schemas.io$k8s$api$core$v1$Affinity;
        /** AutomountServiceAccountToken indicates whether a service account token should be automatically mounted. */
        automountServiceAccountToken?: boolean;
        /** List of containers belonging to the pod. Containers cannot currently be added or removed. There must be at least one container in a Pod. Cannot be updated. */
        containers: Schemas.io$k8s$api$core$v1$Container[];
        dnsConfig?: Schemas.io$k8s$api$core$v1$PodDNSConfig;
        /** Set DNS policy for the pod. Defaults to "ClusterFirst". Valid values are 'ClusterFirstWithHostNet', 'ClusterFirst', 'Default' or 'None'. DNS parameters given in DNSConfig will be merged with the policy selected with DNSPolicy. To have DNS options set along with hostNetwork, you have to specify DNS policy explicitly to 'ClusterFirstWithHostNet'. */
        dnsPolicy?: string;
        /** EnableServiceLinks indicates whether information about services should be injected into pod's environment variables, matching the syntax of Docker links. Optional: Defaults to true. */
        enableServiceLinks?: boolean;
        /** List of ephemeral containers run in this pod. Ephemeral containers may be run in an existing pod to perform user-initiated actions such as debugging. This list cannot be specified when creating a pod, and it cannot be modified by updating the pod spec. In order to add an ephemeral container to an existing pod, use the pod's ephemeralcontainers subresource. */
        ephemeralContainers?: Schemas.io$k8s$api$core$v1$EphemeralContainer[];
        /** HostAliases is an optional list of hosts and IPs that will be injected into the pod's hosts file if specified. This is only valid for non-hostNetwork pods. */
        hostAliases?: Schemas.io$k8s$api$core$v1$HostAlias[];
        /** Use the host's ipc namespace. Optional: Default to false. */
        hostIPC?: boolean;
        /** Host networking requested for this pod. Use the host's network namespace. If this option is set, the ports that will be used must be specified. Default to false. */
        hostNetwork?: boolean;
        /** Use the host's pid namespace. Optional: Default to false. */
        hostPID?: boolean;
        /** Use the host's user namespace. Optional: Default to true. If set to true or not present, the pod will be run in the host user namespace, useful for when the pod needs a feature only available to the host user namespace, such as loading a kernel module with CAP_SYS_MODULE. When set to false, a new userns is created for the pod. Setting false is useful for mitigating container breakout vulnerabilities even allowing users to run their containers as root without actually having root privileges on the host. This field is alpha-level and is only honored by servers that enable the UserNamespacesSupport feature. */
        hostUsers?: boolean;
        /** Specifies the hostname of the Pod If not specified, the pod's hostname will be set to a system-defined value. */
        hostname?: string;
        /** ImagePullSecrets is an optional list of references to secrets in the same namespace to use for pulling any of the images used by this PodSpec. If specified, these secrets will be passed to individual puller implementations for them to use. More info: https://kubernetes.io/docs/concepts/containers/images#specifying-imagepullsecrets-on-a-pod */
        imagePullSecrets?: Schemas.io$k8s$api$core$v1$LocalObjectReference[];
        /** List of initialization containers belonging to the pod. Init containers are executed in order prior to containers being started. If any init container fails, the pod is considered to have failed and is handled according to its restartPolicy. The name for an init container or normal container must be unique among all containers. Init containers may not have Lifecycle actions, Readiness probes, Liveness probes, or Startup probes. The resourceRequirements of an init container are taken into account during scheduling by finding the highest request/limit for each resource type, and then using the max of of that value or the sum of the normal containers. Limits are applied to init containers in a similar fashion. Init containers cannot currently be added or removed. Cannot be updated. More info: https://kubernetes.io/docs/concepts/workloads/pods/init-containers/ */
        initContainers?: Schemas.io$k8s$api$core$v1$Container[];
        /** NodeName is a request to schedule this pod onto a specific node. If it is non-empty, the scheduler simply schedules this pod onto that node, assuming that it fits resource requirements. */
        nodeName?: string;
        /** NodeSelector is a selector which must be true for the pod to fit on a node. Selector which must match a node's labels for the pod to be scheduled on that node. More info: https://kubernetes.io/docs/concepts/configuration/assign-pod-node/ */
        nodeSelector?: {
            [key: string]: string;
        };
        os?: Schemas.io$k8s$api$core$v1$PodOS;
        /** Overhead represents the resource overhead associated with running a pod for a given RuntimeClass. This field will be autopopulated at admission time by the RuntimeClass admission controller. If the RuntimeClass admission controller is enabled, overhead must not be set in Pod create requests. The RuntimeClass admission controller will reject Pod create requests which have the overhead already set. If RuntimeClass is configured and selected in the PodSpec, Overhead will be set to the value defined in the corresponding RuntimeClass, otherwise it will remain unset and treated as zero. More info: https://git.k8s.io/enhancements/keps/sig-node/688-pod-overhead/README.md */
        overhead?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** PreemptionPolicy is the Policy for preempting pods with lower priority. One of Never, PreemptLowerPriority. Defaults to PreemptLowerPriority if unset. */
        preemptionPolicy?: string;
        /** The priority value. Various system components use this field to find the priority of the pod. When Priority Admission Controller is enabled, it prevents users from setting this field. The admission controller populates this field from PriorityClassName. The higher the value, the higher the priority. */
        priority?: number;
        /** If specified, indicates the pod's priority. "system-node-critical" and "system-cluster-critical" are two special keywords which indicate the highest priorities with the former being the highest priority. Any other name must be defined by creating a PriorityClass object with that name. If not specified, the pod priority will be default or zero if there is no default. */
        priorityClassName?: string;
        /** If specified, all readiness gates will be evaluated for pod readiness. A pod is ready when all its containers are ready AND all conditions specified in the readiness gates have status equal to "True" More info: https://git.k8s.io/enhancements/keps/sig-network/580-pod-readiness-gates */
        readinessGates?: Schemas.io$k8s$api$core$v1$PodReadinessGate[];
        /**
         * ResourceClaims defines which ResourceClaims must be allocated and reserved before the Pod is allowed to start. The resources will be made available to those containers which consume them by name.
         *
         * This is an alpha field and requires enabling the DynamicResourceAllocation feature gate.
         *
         * This field is immutable.
         */
        resourceClaims?: Schemas.io$k8s$api$core$v1$PodResourceClaim[];
        /** Restart policy for all containers within the pod. One of Always, OnFailure, Never. In some contexts, only a subset of those values may be permitted. Default to Always. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle/#restart-policy */
        restartPolicy?: string;
        /** RuntimeClassName refers to a RuntimeClass object in the node.k8s.io group, which should be used to run this pod.  If no RuntimeClass resource matches the named class, the pod will not be run. If unset or empty, the "legacy" RuntimeClass will be used, which is an implicit class with an empty definition that uses the default runtime handler. More info: https://git.k8s.io/enhancements/keps/sig-node/585-runtime-class */
        runtimeClassName?: string;
        /** If specified, the pod will be dispatched by specified scheduler. If not specified, the pod will be dispatched by default scheduler. */
        schedulerName?: string;
        /**
         * SchedulingGates is an opaque list of values that if specified will block scheduling the pod. If schedulingGates is not empty, the pod will stay in the SchedulingGated state and the scheduler will not attempt to schedule the pod.
         *
         * SchedulingGates can only be set at pod creation time, and be removed only afterwards.
         *
         * This is a beta feature enabled by the PodSchedulingReadiness feature gate.
         */
        schedulingGates?: Schemas.io$k8s$api$core$v1$PodSchedulingGate[];
        securityContext?: Schemas.io$k8s$api$core$v1$PodSecurityContext;
        /** DeprecatedServiceAccount is a depreciated alias for ServiceAccountName. Deprecated: Use serviceAccountName instead. */
        serviceAccount?: string;
        /** ServiceAccountName is the name of the ServiceAccount to use to run this pod. More info: https://kubernetes.io/docs/tasks/configure-pod-container/configure-service-account/ */
        serviceAccountName?: string;
        /** If true the pod's hostname will be configured as the pod's FQDN, rather than the leaf name (the default). In Linux containers, this means setting the FQDN in the hostname field of the kernel (the nodename field of struct utsname). In Windows containers, this means setting the registry value of hostname for the registry key HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\Tcpip\Parameters to FQDN. If a pod does not have FQDN, this has no effect. Default to false. */
        setHostnameAsFQDN?: boolean;
        /** Share a single process namespace between all of the containers in a pod. When this is set containers will be able to view and signal processes from other containers in the same pod, and the first process in each container will not be assigned PID 1. HostPID and ShareProcessNamespace cannot both be set. Optional: Default to false. */
        shareProcessNamespace?: boolean;
        /** If specified, the fully qualified Pod hostname will be "<hostname>.<subdomain>.<pod namespace>.svc.<cluster domain>". If not specified, the pod will not have a domainname at all. */
        subdomain?: string;
        /** Optional duration in seconds the pod needs to terminate gracefully. May be decreased in delete request. Value must be non-negative integer. The value zero indicates stop immediately via the kill signal (no opportunity to shut down). If this value is nil, the default grace period will be used instead. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process. Defaults to 30 seconds. */
        terminationGracePeriodSeconds?: number;
        /** If specified, the pod's tolerations. */
        tolerations?: Schemas.io$k8s$api$core$v1$Toleration[];
        /** TopologySpreadConstraints describes how a group of pods ought to spread across topology domains. Scheduler will schedule pods in a way which abides by the constraints. All topologySpreadConstraints are ANDed. */
        topologySpreadConstraints?: Schemas.io$k8s$api$core$v1$TopologySpreadConstraint[];
        /** List of volumes that can be mounted by containers belonging to the pod. More info: https://kubernetes.io/docs/concepts/storage/volumes */
        volumes?: Schemas.io$k8s$api$core$v1$Volume[];
    }
    /** PodStatus represents information about the status of a pod. Status may trail the actual state of a system, especially if the node that hosts the pod cannot contact the control plane. */
    interface io$k8s$api$core$v1$PodStatus {
        /** Current service state of pod. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-conditions */
        conditions?: Schemas.io$k8s$api$core$v1$PodCondition[];
        /** The list has one entry per container in the manifest. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-and-container-status */
        containerStatuses?: Schemas.io$k8s$api$core$v1$ContainerStatus[];
        /** Status for any ephemeral containers that have run in this pod. */
        ephemeralContainerStatuses?: Schemas.io$k8s$api$core$v1$ContainerStatus[];
        /** IP address of the host to which the pod is assigned. Empty if not yet scheduled. */
        hostIP?: string;
        /** The list has one entry per init container in the manifest. The most recent successful init container will have ready = true, the most recently started container will have startTime set. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-and-container-status */
        initContainerStatuses?: Schemas.io$k8s$api$core$v1$ContainerStatus[];
        /** A human readable message indicating details about why the pod is in this condition. */
        message?: string;
        /** nominatedNodeName is set only when this pod preempts other pods on the node, but it cannot be scheduled right away as preemption victims receive their graceful termination periods. This field does not guarantee that the pod will be scheduled on this node. Scheduler may decide to place the pod elsewhere if other nodes become available sooner. Scheduler may also decide to give the resources on this node to a higher priority pod that is created after preemption. As a result, this field may be different than PodSpec.nodeName when the pod is scheduled. */
        nominatedNodeName?: string;
        /**
         * The phase of a Pod is a simple, high-level summary of where the Pod is in its lifecycle. The conditions array, the reason and message fields, and the individual container status arrays contain more detail about the pod's status. There are five possible phase values:
         *
         * Pending: The pod has been accepted by the Kubernetes system, but one or more of the container images has not been created. This includes time before being scheduled as well as time spent downloading images over the network, which could take a while. Running: The pod has been bound to a node, and all of the containers have been created. At least one container is still running, or is in the process of starting or restarting. Succeeded: All containers in the pod have terminated in success, and will not be restarted. Failed: All containers in the pod have terminated, and at least one container has terminated in failure. The container either exited with non-zero status or was terminated by the system. Unknown: For some reason the state of the pod could not be obtained, typically due to an error in communicating with the host of the pod.
         *
         * More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#pod-phase
         */
        phase?: string;
        /** IP address allocated to the pod. Routable at least within the cluster. Empty if not yet allocated. */
        podIP?: string;
        /** podIPs holds the IP addresses allocated to the pod. If this field is specified, the 0th entry must match the podIP field. Pods may be allocated at most 1 value for each of IPv4 and IPv6. This list is empty if no IPs have been allocated yet. */
        podIPs?: Schemas.io$k8s$api$core$v1$PodIP[];
        /** The Quality of Service (QOS) classification assigned to the pod based on resource requirements See PodQOSClass type for available QOS classes More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-qos/#quality-of-service-classes */
        qosClass?: string;
        /** A brief CamelCase message indicating details about why the pod is in this state. e.g. 'Evicted' */
        reason?: string;
        /** Status of resources resize desired for pod's containers. It is empty if no resources resize is pending. Any changes to container resources will automatically set this to "Proposed" */
        resize?: string;
        startTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
    }
    /** PodTemplate describes a template for creating copies of a predefined pod. */
    interface io$k8s$api$core$v1$PodTemplate {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        template?: Schemas.io$k8s$api$core$v1$PodTemplateSpec;
    }
    /** PodTemplateList is a list of PodTemplates. */
    interface io$k8s$api$core$v1$PodTemplateList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of pod templates */
        items: Schemas.io$k8s$api$core$v1$PodTemplate[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** PodTemplateSpec describes the data a pod should have when created from a template */
    interface io$k8s$api$core$v1$PodTemplateSpec {
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$core$v1$PodSpec;
    }
    interface io$k8s$api$core$v1$PortStatus {
        /**
         * Error is to record the problem with the service port The format of the error shall comply with the following rules: - built-in error values shall be specified in this file and those shall use
         *   CamelCase names
         * - cloud provider specific error values must have names that comply with the
         *   format foo.example.com/CamelCase.
         */
        error?: string;
        /** Port is the port number of the service port of which status is recorded here */
        port: number;
        /** Protocol is the protocol of the service port of which status is recorded here The supported values are: "TCP", "UDP", "SCTP" */
        protocol: string;
    }
    /** PortworxVolumeSource represents a Portworx volume resource. */
    interface io$k8s$api$core$v1$PortworxVolumeSource {
        /** fSType represents the filesystem type to mount Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs". Implicitly inferred to be "ext4" if unspecified. */
        fsType?: string;
        /** readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. */
        readOnly?: boolean;
        /** volumeID uniquely identifies a Portworx volume */
        volumeID: string;
    }
    /** An empty preferred scheduling term matches all objects with implicit weight 0 (i.e. it's a no-op). A null preferred scheduling term matches no objects (i.e. is also a no-op). */
    interface io$k8s$api$core$v1$PreferredSchedulingTerm {
        preference: Schemas.io$k8s$api$core$v1$NodeSelectorTerm;
        /** Weight associated with matching the corresponding nodeSelectorTerm, in the range 1-100. */
        weight: number;
    }
    /** Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic. */
    interface io$k8s$api$core$v1$Probe {
        exec?: Schemas.io$k8s$api$core$v1$ExecAction;
        /** Minimum consecutive failures for the probe to be considered failed after having succeeded. Defaults to 3. Minimum value is 1. */
        failureThreshold?: number;
        grpc?: Schemas.io$k8s$api$core$v1$GRPCAction;
        httpGet?: Schemas.io$k8s$api$core$v1$HTTPGetAction;
        /** Number of seconds after the container has started before liveness probes are initiated. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes */
        initialDelaySeconds?: number;
        /** How often (in seconds) to perform the probe. Default to 10 seconds. Minimum value is 1. */
        periodSeconds?: number;
        /** Minimum consecutive successes for the probe to be considered successful after having failed. Defaults to 1. Must be 1 for liveness and startup. Minimum value is 1. */
        successThreshold?: number;
        tcpSocket?: Schemas.io$k8s$api$core$v1$TCPSocketAction;
        /** Optional duration in seconds the pod needs to terminate gracefully upon probe failure. The grace period is the duration in seconds after the processes running in the pod are sent a termination signal and the time when the processes are forcibly halted with a kill signal. Set this value longer than the expected cleanup time for your process. If this value is nil, the pod's terminationGracePeriodSeconds will be used. Otherwise, this value overrides the value provided by the pod spec. Value must be non-negative integer. The value zero indicates stop immediately via the kill signal (no opportunity to shut down). This is a beta field and requires enabling ProbeTerminationGracePeriod feature gate. Minimum value is 1. spec.terminationGracePeriodSeconds is used if unset. */
        terminationGracePeriodSeconds?: number;
        /** Number of seconds after which the probe times out. Defaults to 1 second. Minimum value is 1. More info: https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle#container-probes */
        timeoutSeconds?: number;
    }
    /** Represents a projected volume source */
    interface io$k8s$api$core$v1$ProjectedVolumeSource {
        /** defaultMode are the mode bits used to set permissions on created files by default. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set. */
        defaultMode?: number;
        /** sources is the list of volume projections */
        sources?: Schemas.io$k8s$api$core$v1$VolumeProjection[];
    }
    /** Represents a Quobyte mount that lasts the lifetime of a pod. Quobyte volumes do not support ownership management or SELinux relabeling. */
    interface io$k8s$api$core$v1$QuobyteVolumeSource {
        /** group to map volume access to Default is no group */
        group?: string;
        /** readOnly here will force the Quobyte volume to be mounted with read-only permissions. Defaults to false. */
        readOnly?: boolean;
        /** registry represents a single or multiple Quobyte Registry services specified as a string as host:port pair (multiple entries are separated with commas) which acts as the central registry for volumes */
        registry: string;
        /** tenant owning the given Quobyte volume in the Backend Used with dynamically provisioned Quobyte volumes, value is set by the plugin */
        tenant?: string;
        /** user to map volume access to Defaults to serivceaccount user */
        user?: string;
        /** volume is a string that references an already created Quobyte volume by name. */
        volume: string;
    }
    /** Represents a Rados Block Device mount that lasts the lifetime of a pod. RBD volumes support ownership management and SELinux relabeling. */
    interface io$k8s$api$core$v1$RBDPersistentVolumeSource {
        /** fsType is the filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#rbd */
        fsType?: string;
        /** image is the rados image name. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        image: string;
        /** keyring is the path to key ring for RBDUser. Default is /etc/ceph/keyring. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        keyring?: string;
        /** monitors is a collection of Ceph monitors. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        monitors: string[];
        /** pool is the rados pool name. Default is rbd. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        pool?: string;
        /** readOnly here will force the ReadOnly setting in VolumeMounts. Defaults to false. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        readOnly?: boolean;
        secretRef?: Schemas.io$k8s$api$core$v1$SecretReference;
        /** user is the rados user name. Default is admin. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        user?: string;
    }
    /** Represents a Rados Block Device mount that lasts the lifetime of a pod. RBD volumes support ownership management and SELinux relabeling. */
    interface io$k8s$api$core$v1$RBDVolumeSource {
        /** fsType is the filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#rbd */
        fsType?: string;
        /** image is the rados image name. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        image: string;
        /** keyring is the path to key ring for RBDUser. Default is /etc/ceph/keyring. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        keyring?: string;
        /** monitors is a collection of Ceph monitors. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        monitors: string[];
        /** pool is the rados pool name. Default is rbd. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        pool?: string;
        /** readOnly here will force the ReadOnly setting in VolumeMounts. Defaults to false. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        readOnly?: boolean;
        secretRef?: Schemas.io$k8s$api$core$v1$LocalObjectReference;
        /** user is the rados user name. Default is admin. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it */
        user?: string;
    }
    /** ReplicationController represents the configuration of a replication controller. */
    interface io$k8s$api$core$v1$ReplicationController {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$core$v1$ReplicationControllerSpec;
        status?: Schemas.io$k8s$api$core$v1$ReplicationControllerStatus;
    }
    /** ReplicationControllerCondition describes the state of a replication controller at a certain point. */
    interface io$k8s$api$core$v1$ReplicationControllerCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** A human readable message indicating details about the transition. */
        message?: string;
        /** The reason for the condition's last transition. */
        reason?: string;
        /** Status of the condition, one of True, False, Unknown. */
        status: string;
        /** Type of replication controller condition. */
        type: string;
    }
    /** ReplicationControllerList is a collection of replication controllers. */
    interface io$k8s$api$core$v1$ReplicationControllerList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of replication controllers. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller */
        items: Schemas.io$k8s$api$core$v1$ReplicationController[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ReplicationControllerSpec is the specification of a replication controller. */
    interface io$k8s$api$core$v1$ReplicationControllerSpec {
        /** Minimum number of seconds for which a newly created pod should be ready without any of its container crashing, for it to be considered available. Defaults to 0 (pod will be considered available as soon as it is ready) */
        minReadySeconds?: number;
        /** Replicas is the number of desired replicas. This is a pointer to distinguish between explicit zero and unspecified. Defaults to 1. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#what-is-a-replicationcontroller */
        replicas?: number;
        /** Selector is a label query over pods that should match the Replicas count. If Selector is empty, it is defaulted to the labels present on the Pod template. Label keys and values that must match in order to be controlled by this replication controller, if empty defaulted to labels on Pod template. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels/#label-selectors */
        selector?: {
            [key: string]: string;
        };
        template?: Schemas.io$k8s$api$core$v1$PodTemplateSpec;
    }
    /** ReplicationControllerStatus represents the current status of a replication controller. */
    interface io$k8s$api$core$v1$ReplicationControllerStatus {
        /** The number of available replicas (ready for at least minReadySeconds) for this replication controller. */
        availableReplicas?: number;
        /** Represents the latest available observations of a replication controller's current state. */
        conditions?: Schemas.io$k8s$api$core$v1$ReplicationControllerCondition[];
        /** The number of pods that have labels matching the labels of the pod template of the replication controller. */
        fullyLabeledReplicas?: number;
        /** ObservedGeneration reflects the generation of the most recently observed replication controller. */
        observedGeneration?: number;
        /** The number of ready replicas for this replication controller. */
        readyReplicas?: number;
        /** Replicas is the most recently observed number of replicas. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#what-is-a-replicationcontroller */
        replicas: number;
    }
    /** ResourceClaim references one entry in PodSpec.ResourceClaims. */
    interface io$k8s$api$core$v1$ResourceClaim {
        /** Name must match the name of one entry in pod.spec.resourceClaims of the Pod where this field is used. It makes that resource available inside a container. */
        name: string;
    }
    /** ResourceFieldSelector represents container resources (cpu, memory) and their output format */
    interface io$k8s$api$core$v1$ResourceFieldSelector {
        /** Container name: required for volumes, optional for env vars */
        containerName?: string;
        divisor?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        /** Required: resource to select */
        resource: string;
    }
    /** ResourceQuota sets aggregate quota restrictions enforced per namespace */
    interface io$k8s$api$core$v1$ResourceQuota {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$core$v1$ResourceQuotaSpec;
        status?: Schemas.io$k8s$api$core$v1$ResourceQuotaStatus;
    }
    /** ResourceQuotaList is a list of ResourceQuota items. */
    interface io$k8s$api$core$v1$ResourceQuotaList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is a list of ResourceQuota objects. More info: https://kubernetes.io/docs/concepts/policy/resource-quotas/ */
        items: Schemas.io$k8s$api$core$v1$ResourceQuota[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ResourceQuotaSpec defines the desired hard limits to enforce for Quota. */
    interface io$k8s$api$core$v1$ResourceQuotaSpec {
        /** hard is the set of desired hard limits for each named resource. More info: https://kubernetes.io/docs/concepts/policy/resource-quotas/ */
        hard?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        scopeSelector?: Schemas.io$k8s$api$core$v1$ScopeSelector;
        /** A collection of filters that must match each object tracked by a quota. If not specified, the quota matches all objects. */
        scopes?: string[];
    }
    /** ResourceQuotaStatus defines the enforced hard limits and observed use. */
    interface io$k8s$api$core$v1$ResourceQuotaStatus {
        /** Hard is the set of enforced hard limits for each named resource. More info: https://kubernetes.io/docs/concepts/policy/resource-quotas/ */
        hard?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** Used is the current observed total usage of the resource in the namespace. */
        used?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
    }
    /** ResourceRequirements describes the compute resource requirements. */
    interface io$k8s$api$core$v1$ResourceRequirements {
        /**
         * Claims lists the names of resources, defined in spec.resourceClaims, that are used by this container.
         *
         * This is an alpha field and requires enabling the DynamicResourceAllocation feature gate.
         *
         * This field is immutable. It can only be set for containers.
         */
        claims?: Schemas.io$k8s$api$core$v1$ResourceClaim[];
        /** Limits describes the maximum amount of compute resources allowed. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/ */
        limits?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
        /** Requests describes the minimum amount of compute resources required. If Requests is omitted for a container, it defaults to Limits if that is explicitly specified, otherwise to an implementation-defined value. Requests cannot exceed Limits. More info: https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/ */
        requests?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
    }
    /** SELinuxOptions are the labels to be applied to the container */
    interface io$k8s$api$core$v1$SELinuxOptions {
        /** Level is SELinux level label that applies to the container. */
        level?: string;
        /** Role is a SELinux role label that applies to the container. */
        role?: string;
        /** Type is a SELinux type label that applies to the container. */
        type?: string;
        /** User is a SELinux user label that applies to the container. */
        user?: string;
    }
    /** ScaleIOPersistentVolumeSource represents a persistent ScaleIO volume */
    interface io$k8s$api$core$v1$ScaleIOPersistentVolumeSource {
        /** fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Default is "xfs" */
        fsType?: string;
        /** gateway is the host address of the ScaleIO API Gateway. */
        gateway: string;
        /** protectionDomain is the name of the ScaleIO Protection Domain for the configured storage. */
        protectionDomain?: string;
        /** readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. */
        readOnly?: boolean;
        secretRef: Schemas.io$k8s$api$core$v1$SecretReference;
        /** sslEnabled is the flag to enable/disable SSL communication with Gateway, default false */
        sslEnabled?: boolean;
        /** storageMode indicates whether the storage for a volume should be ThickProvisioned or ThinProvisioned. Default is ThinProvisioned. */
        storageMode?: string;
        /** storagePool is the ScaleIO Storage Pool associated with the protection domain. */
        storagePool?: string;
        /** system is the name of the storage system as configured in ScaleIO. */
        system: string;
        /** volumeName is the name of a volume already created in the ScaleIO system that is associated with this volume source. */
        volumeName?: string;
    }
    /** ScaleIOVolumeSource represents a persistent ScaleIO volume */
    interface io$k8s$api$core$v1$ScaleIOVolumeSource {
        /** fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Default is "xfs". */
        fsType?: string;
        /** gateway is the host address of the ScaleIO API Gateway. */
        gateway: string;
        /** protectionDomain is the name of the ScaleIO Protection Domain for the configured storage. */
        protectionDomain?: string;
        /** readOnly Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. */
        readOnly?: boolean;
        secretRef: Schemas.io$k8s$api$core$v1$LocalObjectReference;
        /** sslEnabled Flag enable/disable SSL communication with Gateway, default false */
        sslEnabled?: boolean;
        /** storageMode indicates whether the storage for a volume should be ThickProvisioned or ThinProvisioned. Default is ThinProvisioned. */
        storageMode?: string;
        /** storagePool is the ScaleIO Storage Pool associated with the protection domain. */
        storagePool?: string;
        /** system is the name of the storage system as configured in ScaleIO. */
        system: string;
        /** volumeName is the name of a volume already created in the ScaleIO system that is associated with this volume source. */
        volumeName?: string;
    }
    /** A scope selector represents the AND of the selectors represented by the scoped-resource selector requirements. */
    interface io$k8s$api$core$v1$ScopeSelector {
        /** A list of scope selector requirements by scope of the resources. */
        matchExpressions?: Schemas.io$k8s$api$core$v1$ScopedResourceSelectorRequirement[];
    }
    /** A scoped-resource selector requirement is a selector that contains values, a scope name, and an operator that relates the scope name and values. */
    interface io$k8s$api$core$v1$ScopedResourceSelectorRequirement {
        /** Represents a scope's relationship to a set of values. Valid operators are In, NotIn, Exists, DoesNotExist. */
        operator: string;
        /** The name of the scope that the selector applies to. */
        scopeName: string;
        /** An array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch. */
        values?: string[];
    }
    /** SeccompProfile defines a pod/container's seccomp profile settings. Only one profile source may be set. */
    interface io$k8s$api$core$v1$SeccompProfile {
        /** localhostProfile indicates a profile defined in a file on the node should be used. The profile must be preconfigured on the node to work. Must be a descending path, relative to the kubelet's configured seccomp profile location. Must only be set if type is "Localhost". */
        localhostProfile?: string;
        /**
         * type indicates which kind of seccomp profile will be applied. Valid options are:
         *
         * Localhost - a profile defined in a file on the node should be used. RuntimeDefault - the container runtime default profile should be used. Unconfined - no profile should be applied.
         */
        type: string;
    }
    /** Secret holds secret data of a certain type. The total bytes of the values in the Data field must be less than MaxSecretSize bytes. */
    interface io$k8s$api$core$v1$Secret {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Data contains the secret data. Each key must consist of alphanumeric characters, '-', '_' or '.'. The serialized form of the secret data is a base64 encoded string, representing the arbitrary (possibly non-string) data value here. Described in https://tools.ietf.org/html/rfc4648#section-4 */
        data?: {
            [key: string]: Blob;
        };
        /** Immutable, if set to true, ensures that data stored in the Secret cannot be updated (only object metadata can be modified). If not set to true, the field can be modified at any time. Defaulted to nil. */
        immutable?: boolean;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** stringData allows specifying non-binary secret data in string form. It is provided as a write-only input field for convenience. All keys and values are merged into the data field on write, overwriting any existing values. The stringData field is never output when reading from the API. */
        stringData?: {
            [key: string]: string;
        };
        /** Used to facilitate programmatic handling of secret data. More info: https://kubernetes.io/docs/concepts/configuration/secret/#secret-types */
        type?: string;
    }
    /**
     * SecretEnvSource selects a Secret to populate the environment variables with.
     *
     * The contents of the target Secret's Data field will represent the key-value pairs as environment variables.
     */
    interface io$k8s$api$core$v1$SecretEnvSource {
        /** Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names */
        name?: string;
        /** Specify whether the Secret must be defined */
        optional?: boolean;
    }
    /** SecretKeySelector selects a key of a Secret. */
    interface io$k8s$api$core$v1$SecretKeySelector {
        /** The key of the secret to select from.  Must be a valid secret key. */
        key: string;
        /** Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names */
        name?: string;
        /** Specify whether the Secret or its key must be defined */
        optional?: boolean;
    }
    /** SecretList is a list of Secret. */
    interface io$k8s$api$core$v1$SecretList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is a list of secret objects. More info: https://kubernetes.io/docs/concepts/configuration/secret */
        items: Schemas.io$k8s$api$core$v1$Secret[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /**
     * Adapts a secret into a projected volume.
     *
     * The contents of the target Secret's Data field will be presented in a projected volume as files using the keys in the Data field as the file names. Note that this is identical to a secret volume source without the default mode.
     */
    interface io$k8s$api$core$v1$SecretProjection {
        /** items if unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the Secret, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'. */
        items?: Schemas.io$k8s$api$core$v1$KeyToPath[];
        /** Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names */
        name?: string;
        /** optional field specify whether the Secret or its key must be defined */
        optional?: boolean;
    }
    /** SecretReference represents a Secret Reference. It has enough information to retrieve secret in any namespace */
    interface io$k8s$api$core$v1$SecretReference {
        /** name is unique within a namespace to reference a secret resource. */
        name?: string;
        /** namespace defines the space within which the secret name must be unique. */
        namespace?: string;
    }
    /**
     * Adapts a Secret into a volume.
     *
     * The contents of the target Secret's Data field will be presented in a volume as files using the keys in the Data field as the file names. Secret volumes support ownership management and SELinux relabeling.
     */
    interface io$k8s$api$core$v1$SecretVolumeSource {
        /** defaultMode is Optional: mode bits used to set permissions on created files by default. Must be an octal value between 0000 and 0777 or a decimal value between 0 and 511. YAML accepts both octal and decimal values, JSON requires decimal values for mode bits. Defaults to 0644. Directories within the path are not affected by this setting. This might be in conflict with other options that affect the file mode, like fsGroup, and the result can be other mode bits set. */
        defaultMode?: number;
        /** items If unspecified, each key-value pair in the Data field of the referenced Secret will be projected into the volume as a file whose name is the key and content is the value. If specified, the listed keys will be projected into the specified paths, and unlisted keys will not be present. If a key is specified which is not present in the Secret, the volume setup will error unless it is marked optional. Paths must be relative and may not contain the '..' path or start with '..'. */
        items?: Schemas.io$k8s$api$core$v1$KeyToPath[];
        /** optional field specify whether the Secret or its keys must be defined */
        optional?: boolean;
        /** secretName is the name of the secret in the pod's namespace to use. More info: https://kubernetes.io/docs/concepts/storage/volumes#secret */
        secretName?: string;
    }
    /** SecurityContext holds security configuration that will be applied to a container. Some fields are present in both SecurityContext and PodSecurityContext.  When both are set, the values in SecurityContext take precedence. */
    interface io$k8s$api$core$v1$SecurityContext {
        /** AllowPrivilegeEscalation controls whether a process can gain more privileges than its parent process. This bool directly controls if the no_new_privs flag will be set on the container process. AllowPrivilegeEscalation is true always when the container is: 1) run as Privileged 2) has CAP_SYS_ADMIN Note that this field cannot be set when spec.os.name is windows. */
        allowPrivilegeEscalation?: boolean;
        capabilities?: Schemas.io$k8s$api$core$v1$Capabilities;
        /** Run container in privileged mode. Processes in privileged containers are essentially equivalent to root on the host. Defaults to false. Note that this field cannot be set when spec.os.name is windows. */
        privileged?: boolean;
        /** procMount denotes the type of proc mount to use for the containers. The default is DefaultProcMount which uses the container runtime defaults for readonly paths and masked paths. This requires the ProcMountType feature flag to be enabled. Note that this field cannot be set when spec.os.name is windows. */
        procMount?: string;
        /** Whether this container has a read-only root filesystem. Default is false. Note that this field cannot be set when spec.os.name is windows. */
        readOnlyRootFilesystem?: boolean;
        /** The GID to run the entrypoint of the container process. Uses runtime default if unset. May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is windows. */
        runAsGroup?: number;
        /** Indicates that the container must run as a non-root user. If true, the Kubelet will validate the image at runtime to ensure that it does not run as UID 0 (root) and fail to start the container if it does. If unset or false, no such validation will be performed. May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. */
        runAsNonRoot?: boolean;
        /** The UID to run the entrypoint of the container process. Defaults to user specified in image metadata if unspecified. May also be set in PodSecurityContext.  If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. Note that this field cannot be set when spec.os.name is windows. */
        runAsUser?: number;
        seLinuxOptions?: Schemas.io$k8s$api$core$v1$SELinuxOptions;
        seccompProfile?: Schemas.io$k8s$api$core$v1$SeccompProfile;
        windowsOptions?: Schemas.io$k8s$api$core$v1$WindowsSecurityContextOptions;
    }
    /** Service is a named abstraction of software service (for example, mysql) consisting of local port (for example 3306) that the proxy listens on, and the selector that determines which pods will answer requests sent through the proxy. */
    interface io$k8s$api$core$v1$Service {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$core$v1$ServiceSpec;
        status?: Schemas.io$k8s$api$core$v1$ServiceStatus;
    }
    /** ServiceAccount binds together: * a name, understood by users, and perhaps by peripheral systems, for an identity * a principal that can be authenticated and authorized * a set of secrets */
    interface io$k8s$api$core$v1$ServiceAccount {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** AutomountServiceAccountToken indicates whether pods running as this service account should have an API token automatically mounted. Can be overridden at the pod level. */
        automountServiceAccountToken?: boolean;
        /** ImagePullSecrets is a list of references to secrets in the same namespace to use for pulling any images in pods that reference this ServiceAccount. ImagePullSecrets are distinct from Secrets because Secrets can be mounted in the pod, but ImagePullSecrets are only accessed by the kubelet. More info: https://kubernetes.io/docs/concepts/containers/images/#specifying-imagepullsecrets-on-a-pod */
        imagePullSecrets?: Schemas.io$k8s$api$core$v1$LocalObjectReference[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** Secrets is a list of the secrets in the same namespace that pods running using this ServiceAccount are allowed to use. Pods are only limited to this list if this service account has a "kubernetes.io/enforce-mountable-secrets" annotation set to "true". This field should not be used to find auto-generated service account token secrets for use outside of pods. Instead, tokens can be requested directly using the TokenRequest API, or service account token secrets can be manually created. More info: https://kubernetes.io/docs/concepts/configuration/secret */
        secrets?: Schemas.io$k8s$api$core$v1$ObjectReference[];
    }
    /** ServiceAccountList is a list of ServiceAccount objects */
    interface io$k8s$api$core$v1$ServiceAccountList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of ServiceAccounts. More info: https://kubernetes.io/docs/tasks/configure-pod-container/configure-service-account/ */
        items: Schemas.io$k8s$api$core$v1$ServiceAccount[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ServiceAccountTokenProjection represents a projected service account token volume. This projection can be used to insert a service account token into the pods runtime filesystem for use against APIs (Kubernetes API Server or otherwise). */
    interface io$k8s$api$core$v1$ServiceAccountTokenProjection {
        /** audience is the intended audience of the token. A recipient of a token must identify itself with an identifier specified in the audience of the token, and otherwise should reject the token. The audience defaults to the identifier of the apiserver. */
        audience?: string;
        /** expirationSeconds is the requested duration of validity of the service account token. As the token approaches expiration, the kubelet volume plugin will proactively rotate the service account token. The kubelet will start trying to rotate the token if the token is older than 80 percent of its time to live or if the token is older than 24 hours.Defaults to 1 hour and must be at least 10 minutes. */
        expirationSeconds?: number;
        /** path is the path relative to the mount point of the file to project the token into. */
        path: string;
    }
    /** ServiceList holds a list of services. */
    interface io$k8s$api$core$v1$ServiceList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** List of services */
        items: Schemas.io$k8s$api$core$v1$Service[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ServicePort contains information on service's port. */
    interface io$k8s$api$core$v1$ServicePort {
        /** The application protocol for this port. This field follows standard Kubernetes label syntax. Un-prefixed names are reserved for IANA standard service names (as per RFC-6335 and https://www.iana.org/assignments/service-names). Non-standard protocols should use prefixed names such as mycompany.com/my-custom-protocol. */
        appProtocol?: string;
        /** The name of this port within the service. This must be a DNS_LABEL. All ports within a ServiceSpec must have unique names. When considering the endpoints for a Service, this must match the 'name' field in the EndpointPort. Optional if only one ServicePort is defined on this service. */
        name?: string;
        /** The port on each node on which this service is exposed when type is NodePort or LoadBalancer.  Usually assigned by the system. If a value is specified, in-range, and not in use it will be used, otherwise the operation will fail.  If not specified, a port will be allocated if this Service requires one.  If this field is specified when creating a Service which does not need it, creation will fail. This field will be wiped when updating a Service to no longer need it (e.g. changing type from NodePort to ClusterIP). More info: https://kubernetes.io/docs/concepts/services-networking/service/#type-nodeport */
        nodePort?: number;
        /** The port that will be exposed by this service. */
        port: number;
        /** The IP protocol for this port. Supports "TCP", "UDP", and "SCTP". Default is TCP. */
        protocol?: string;
        targetPort?: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
    }
    /** ServiceSpec describes the attributes that a user creates on a service. */
    interface io$k8s$api$core$v1$ServiceSpec {
        /** allocateLoadBalancerNodePorts defines if NodePorts will be automatically allocated for services with type LoadBalancer.  Default is "true". It may be set to "false" if the cluster load-balancer does not rely on NodePorts.  If the caller requests specific NodePorts (by specifying a value), those requests will be respected, regardless of this field. This field may only be set for services with type LoadBalancer and will be cleared if the type is changed to any other type. */
        allocateLoadBalancerNodePorts?: boolean;
        /** clusterIP is the IP address of the service and is usually assigned randomly. If an address is specified manually, is in-range (as per system configuration), and is not in use, it will be allocated to the service; otherwise creation of the service will fail. This field may not be changed through updates unless the type field is also being changed to ExternalName (which requires this field to be blank) or the type field is being changed from ExternalName (in which case this field may optionally be specified, as describe above).  Valid values are "None", empty string (""), or a valid IP address. Setting this to "None" makes a "headless service" (no virtual IP), which is useful when direct endpoint connections are preferred and proxying is not required.  Only applies to types ClusterIP, NodePort, and LoadBalancer. If this field is specified when creating a Service of type ExternalName, creation will fail. This field will be wiped when updating a Service to type ExternalName. More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies */
        clusterIP?: string;
        /**
         * ClusterIPs is a list of IP addresses assigned to this service, and are usually assigned randomly.  If an address is specified manually, is in-range (as per system configuration), and is not in use, it will be allocated to the service; otherwise creation of the service will fail. This field may not be changed through updates unless the type field is also being changed to ExternalName (which requires this field to be empty) or the type field is being changed from ExternalName (in which case this field may optionally be specified, as describe above).  Valid values are "None", empty string (""), or a valid IP address.  Setting this to "None" makes a "headless service" (no virtual IP), which is useful when direct endpoint connections are preferred and proxying is not required.  Only applies to types ClusterIP, NodePort, and LoadBalancer. If this field is specified when creating a Service of type ExternalName, creation will fail. This field will be wiped when updating a Service to type ExternalName.  If this field is not specified, it will be initialized from the clusterIP field.  If this field is specified, clients must ensure that clusterIPs[0] and clusterIP have the same value.
         *
         * This field may hold a maximum of two entries (dual-stack IPs, in either order). These IPs must correspond to the values of the ipFamilies field. Both clusterIPs and ipFamilies are governed by the ipFamilyPolicy field. More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies
         */
        clusterIPs?: string[];
        /** externalIPs is a list of IP addresses for which nodes in the cluster will also accept traffic for this service.  These IPs are not managed by Kubernetes.  The user is responsible for ensuring that traffic arrives at a node with this IP.  A common example is external load-balancers that are not part of the Kubernetes system. */
        externalIPs?: string[];
        /** externalName is the external reference that discovery mechanisms will return as an alias for this service (e.g. a DNS CNAME record). No proxying will be involved.  Must be a lowercase RFC-1123 hostname (https://tools.ietf.org/html/rfc1123) and requires `type` to be "ExternalName". */
        externalName?: string;
        /** externalTrafficPolicy describes how nodes distribute service traffic they receive on one of the Service's "externally-facing" addresses (NodePorts, ExternalIPs, and LoadBalancer IPs). If set to "Local", the proxy will configure the service in a way that assumes that external load balancers will take care of balancing the service traffic between nodes, and so each node will deliver traffic only to the node-local endpoints of the service, without masquerading the client source IP. (Traffic mistakenly sent to a node with no endpoints will be dropped.) The default value, "Cluster", uses the standard behavior of routing to all endpoints evenly (possibly modified by topology and other features). Note that traffic sent to an External IP or LoadBalancer IP from within the cluster will always get "Cluster" semantics, but clients sending to a NodePort from within the cluster may need to take traffic policy into account when picking a node. */
        externalTrafficPolicy?: string;
        /** healthCheckNodePort specifies the healthcheck nodePort for the service. This only applies when type is set to LoadBalancer and externalTrafficPolicy is set to Local. If a value is specified, is in-range, and is not in use, it will be used.  If not specified, a value will be automatically allocated.  External systems (e.g. load-balancers) can use this port to determine if a given node holds endpoints for this service or not.  If this field is specified when creating a Service which does not need it, creation will fail. This field will be wiped when updating a Service to no longer need it (e.g. changing type). This field cannot be updated once set. */
        healthCheckNodePort?: number;
        /** InternalTrafficPolicy describes how nodes distribute service traffic they receive on the ClusterIP. If set to "Local", the proxy will assume that pods only want to talk to endpoints of the service on the same node as the pod, dropping the traffic if there are no local endpoints. The default value, "Cluster", uses the standard behavior of routing to all endpoints evenly (possibly modified by topology and other features). */
        internalTrafficPolicy?: string;
        /**
         * IPFamilies is a list of IP families (e.g. IPv4, IPv6) assigned to this service. This field is usually assigned automatically based on cluster configuration and the ipFamilyPolicy field. If this field is specified manually, the requested family is available in the cluster, and ipFamilyPolicy allows it, it will be used; otherwise creation of the service will fail. This field is conditionally mutable: it allows for adding or removing a secondary IP family, but it does not allow changing the primary IP family of the Service. Valid values are "IPv4" and "IPv6".  This field only applies to Services of types ClusterIP, NodePort, and LoadBalancer, and does apply to "headless" services. This field will be wiped when updating a Service to type ExternalName.
         *
         * This field may hold a maximum of two entries (dual-stack families, in either order).  These families must correspond to the values of the clusterIPs field, if specified. Both clusterIPs and ipFamilies are governed by the ipFamilyPolicy field.
         */
        ipFamilies?: string[];
        /** IPFamilyPolicy represents the dual-stack-ness requested or required by this Service. If there is no value provided, then this field will be set to SingleStack. Services can be "SingleStack" (a single IP family), "PreferDualStack" (two IP families on dual-stack configured clusters or a single IP family on single-stack clusters), or "RequireDualStack" (two IP families on dual-stack configured clusters, otherwise fail). The ipFamilies and clusterIPs fields depend on the value of this field. This field will be wiped when updating a service to type ExternalName. */
        ipFamilyPolicy?: string;
        /** loadBalancerClass is the class of the load balancer implementation this Service belongs to. If specified, the value of this field must be a label-style identifier, with an optional prefix, e.g. "internal-vip" or "example.com/internal-vip". Unprefixed names are reserved for end-users. This field can only be set when the Service type is 'LoadBalancer'. If not set, the default load balancer implementation is used, today this is typically done through the cloud provider integration, but should apply for any default implementation. If set, it is assumed that a load balancer implementation is watching for Services with a matching class. Any default load balancer implementation (e.g. cloud providers) should ignore Services that set this field. This field can only be set when creating or updating a Service to type 'LoadBalancer'. Once set, it can not be changed. This field will be wiped when a service is updated to a non 'LoadBalancer' type. */
        loadBalancerClass?: string;
        /** Only applies to Service Type: LoadBalancer. This feature depends on whether the underlying cloud-provider supports specifying the loadBalancerIP when a load balancer is created. This field will be ignored if the cloud-provider does not support the feature. Deprecated: This field was under-specified and its meaning varies across implementations, and it cannot support dual-stack. As of Kubernetes v1.24, users are encouraged to use implementation-specific annotations when available. This field may be removed in a future API version. */
        loadBalancerIP?: string;
        /** If specified and supported by the platform, this will restrict traffic through the cloud-provider load-balancer will be restricted to the specified client IPs. This field will be ignored if the cloud-provider does not support the feature." More info: https://kubernetes.io/docs/tasks/access-application-cluster/create-external-load-balancer/ */
        loadBalancerSourceRanges?: string[];
        /** The list of ports that are exposed by this service. More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies */
        ports?: Schemas.io$k8s$api$core$v1$ServicePort[];
        /** publishNotReadyAddresses indicates that any agent which deals with endpoints for this Service should disregard any indications of ready/not-ready. The primary use case for setting this field is for a StatefulSet's Headless Service to propagate SRV DNS records for its Pods for the purpose of peer discovery. The Kubernetes controllers that generate Endpoints and EndpointSlice resources for Services interpret this to mean that all endpoints are considered "ready" even if the Pods themselves are not. Agents which consume only Kubernetes generated endpoints through the Endpoints or EndpointSlice resources can safely assume this behavior. */
        publishNotReadyAddresses?: boolean;
        /** Route service traffic to pods with label keys and values matching this selector. If empty or not present, the service is assumed to have an external process managing its endpoints, which Kubernetes will not modify. Only applies to types ClusterIP, NodePort, and LoadBalancer. Ignored if type is ExternalName. More info: https://kubernetes.io/docs/concepts/services-networking/service/ */
        selector?: {
            [key: string]: string;
        };
        /** Supports "ClientIP" and "None". Used to maintain session affinity. Enable client IP based session affinity. Must be ClientIP or None. Defaults to None. More info: https://kubernetes.io/docs/concepts/services-networking/service/#virtual-ips-and-service-proxies */
        sessionAffinity?: string;
        sessionAffinityConfig?: Schemas.io$k8s$api$core$v1$SessionAffinityConfig;
        /** type determines how the Service is exposed. Defaults to ClusterIP. Valid options are ExternalName, ClusterIP, NodePort, and LoadBalancer. "ClusterIP" allocates a cluster-internal IP address for load-balancing to endpoints. Endpoints are determined by the selector or if that is not specified, by manual construction of an Endpoints object or EndpointSlice objects. If clusterIP is "None", no virtual IP is allocated and the endpoints are published as a set of endpoints rather than a virtual IP. "NodePort" builds on ClusterIP and allocates a port on every node which routes to the same endpoints as the clusterIP. "LoadBalancer" builds on NodePort and creates an external load-balancer (if supported in the current cloud) which routes to the same endpoints as the clusterIP. "ExternalName" aliases this service to the specified externalName. Several other fields do not apply to ExternalName services. More info: https://kubernetes.io/docs/concepts/services-networking/service/#publishing-services-service-types */
        type?: string;
    }
    /** ServiceStatus represents the current status of a service. */
    interface io$k8s$api$core$v1$ServiceStatus {
        /** Current service state */
        conditions?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Condition[];
        loadBalancer?: Schemas.io$k8s$api$core$v1$LoadBalancerStatus;
    }
    /** SessionAffinityConfig represents the configurations of session affinity. */
    interface io$k8s$api$core$v1$SessionAffinityConfig {
        clientIP?: Schemas.io$k8s$api$core$v1$ClientIPConfig;
    }
    /** Represents a StorageOS persistent volume resource. */
    interface io$k8s$api$core$v1$StorageOSPersistentVolumeSource {
        /** fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. */
        fsType?: string;
        /** readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. */
        readOnly?: boolean;
        secretRef?: Schemas.io$k8s$api$core$v1$ObjectReference;
        /** volumeName is the human-readable name of the StorageOS volume.  Volume names are only unique within a namespace. */
        volumeName?: string;
        /** volumeNamespace specifies the scope of the volume within StorageOS.  If no namespace is specified then the Pod's namespace will be used.  This allows the Kubernetes name scoping to be mirrored within StorageOS for tighter integration. Set VolumeName to any name to override the default behaviour. Set to "default" if you are not using namespaces within StorageOS. Namespaces that do not pre-exist within StorageOS will be created. */
        volumeNamespace?: string;
    }
    /** Represents a StorageOS persistent volume resource. */
    interface io$k8s$api$core$v1$StorageOSVolumeSource {
        /** fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. */
        fsType?: string;
        /** readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. */
        readOnly?: boolean;
        secretRef?: Schemas.io$k8s$api$core$v1$LocalObjectReference;
        /** volumeName is the human-readable name of the StorageOS volume.  Volume names are only unique within a namespace. */
        volumeName?: string;
        /** volumeNamespace specifies the scope of the volume within StorageOS.  If no namespace is specified then the Pod's namespace will be used.  This allows the Kubernetes name scoping to be mirrored within StorageOS for tighter integration. Set VolumeName to any name to override the default behaviour. Set to "default" if you are not using namespaces within StorageOS. Namespaces that do not pre-exist within StorageOS will be created. */
        volumeNamespace?: string;
    }
    /** Sysctl defines a kernel parameter to be set */
    interface io$k8s$api$core$v1$Sysctl {
        /** Name of a property to set */
        name: string;
        /** Value of a property to set */
        value: string;
    }
    /** TCPSocketAction describes an action based on opening a socket */
    interface io$k8s$api$core$v1$TCPSocketAction {
        /** Optional: Host name to connect to, defaults to the pod IP. */
        host?: string;
        port: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
    }
    /** The node this Taint is attached to has the "effect" on any pod that does not tolerate the Taint. */
    interface io$k8s$api$core$v1$Taint {
        /** Required. The effect of the taint on pods that do not tolerate the taint. Valid effects are NoSchedule, PreferNoSchedule and NoExecute. */
        effect: string;
        /** Required. The taint key to be applied to a node. */
        key: string;
        timeAdded?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** The taint value corresponding to the taint key. */
        value?: string;
    }
    /** The pod this Toleration is attached to tolerates any taint that matches the triple <key,value,effect> using the matching operator <operator>. */
    interface io$k8s$api$core$v1$Toleration {
        /** Effect indicates the taint effect to match. Empty means match all taint effects. When specified, allowed values are NoSchedule, PreferNoSchedule and NoExecute. */
        effect?: string;
        /** Key is the taint key that the toleration applies to. Empty means match all taint keys. If the key is empty, operator must be Exists; this combination means to match all values and all keys. */
        key?: string;
        /** Operator represents a key's relationship to the value. Valid operators are Exists and Equal. Defaults to Equal. Exists is equivalent to wildcard for value, so that a pod can tolerate all taints of a particular category. */
        operator?: string;
        /** TolerationSeconds represents the period of time the toleration (which must be of effect NoExecute, otherwise this field is ignored) tolerates the taint. By default, it is not set, which means tolerate the taint forever (do not evict). Zero and negative values will be treated as 0 (evict immediately) by the system. */
        tolerationSeconds?: number;
        /** Value is the taint value the toleration matches to. If the operator is Exists, the value should be empty, otherwise just a regular string. */
        value?: string;
    }
    /** A topology selector requirement is a selector that matches given label. This is an alpha feature and may change in the future. */
    interface io$k8s$api$core$v1$TopologySelectorLabelRequirement {
        /** The label key that the selector applies to. */
        key: string;
        /** An array of string values. One value must match the label to be selected. Each entry in Values is ORed. */
        values: string[];
    }
    /** A topology selector term represents the result of label queries. A null or empty topology selector term matches no objects. The requirements of them are ANDed. It provides a subset of functionality as NodeSelectorTerm. This is an alpha feature and may change in the future. */
    interface io$k8s$api$core$v1$TopologySelectorTerm {
        /** A list of topology selector requirements by labels. */
        matchLabelExpressions?: Schemas.io$k8s$api$core$v1$TopologySelectorLabelRequirement[];
    }
    /** TopologySpreadConstraint specifies how to spread matching pods among the given topology. */
    interface io$k8s$api$core$v1$TopologySpreadConstraint {
        labelSelector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        /**
         * MatchLabelKeys is a set of pod label keys to select the pods over which spreading will be calculated. The keys are used to lookup values from the incoming pod labels, those key-value labels are ANDed with labelSelector to select the group of existing pods over which spreading will be calculated for the incoming pod. The same key is forbidden to exist in both MatchLabelKeys and LabelSelector. MatchLabelKeys cannot be set when LabelSelector isn't set. Keys that don't exist in the incoming pod labels will be ignored. A null or empty list means only match against labelSelector.
         *
         * This is a beta field and requires the MatchLabelKeysInPodTopologySpread feature gate to be enabled (enabled by default).
         */
        matchLabelKeys?: string[];
        /** MaxSkew describes the degree to which pods may be unevenly distributed. When `whenUnsatisfiable=DoNotSchedule`, it is the maximum permitted difference between the number of matching pods in the target topology and the global minimum. The global minimum is the minimum number of matching pods in an eligible domain or zero if the number of eligible domains is less than MinDomains. For example, in a 3-zone cluster, MaxSkew is set to 1, and pods with the same labelSelector spread as 2/2/1: In this case, the global minimum is 1. | zone1 | zone2 | zone3 | |  P P  |  P P  |   P   | - if MaxSkew is 1, incoming pod can only be scheduled to zone3 to become 2/2/2; scheduling it onto zone1(zone2) would make the ActualSkew(3-1) on zone1(zone2) violate MaxSkew(1). - if MaxSkew is 2, incoming pod can be scheduled onto any zone. When `whenUnsatisfiable=ScheduleAnyway`, it is used to give higher precedence to topologies that satisfy it. It's a required field. Default value is 1 and 0 is not allowed. */
        maxSkew: number;
        /**
         * MinDomains indicates a minimum number of eligible domains. When the number of eligible domains with matching topology keys is less than minDomains, Pod Topology Spread treats "global minimum" as 0, and then the calculation of Skew is performed. And when the number of eligible domains with matching topology keys equals or greater than minDomains, this value has no effect on scheduling. As a result, when the number of eligible domains is less than minDomains, scheduler won't schedule more than maxSkew Pods to those domains. If value is nil, the constraint behaves as if MinDomains is equal to 1. Valid values are integers greater than 0. When value is not nil, WhenUnsatisfiable must be DoNotSchedule.
         *
         * For example, in a 3-zone cluster, MaxSkew is set to 2, MinDomains is set to 5 and pods with the same labelSelector spread as 2/2/2: | zone1 | zone2 | zone3 | |  P P  |  P P  |  P P  | The number of domains is less than 5(MinDomains), so "global minimum" is treated as 0. In this situation, new pod with the same labelSelector cannot be scheduled, because computed skew will be 3(3 - 0) if new Pod is scheduled to any of the three zones, it will violate MaxSkew.
         *
         * This is a beta field and requires the MinDomainsInPodTopologySpread feature gate to be enabled (enabled by default).
         */
        minDomains?: number;
        /**
         * NodeAffinityPolicy indicates how we will treat Pod's nodeAffinity/nodeSelector when calculating pod topology spread skew. Options are: - Honor: only nodes matching nodeAffinity/nodeSelector are included in the calculations. - Ignore: nodeAffinity/nodeSelector are ignored. All nodes are included in the calculations.
         *
         * If this value is nil, the behavior is equivalent to the Honor policy. This is a beta-level feature default enabled by the NodeInclusionPolicyInPodTopologySpread feature flag.
         */
        nodeAffinityPolicy?: string;
        /**
         * NodeTaintsPolicy indicates how we will treat node taints when calculating pod topology spread skew. Options are: - Honor: nodes without taints, along with tainted nodes for which the incoming pod has a toleration, are included. - Ignore: node taints are ignored. All nodes are included.
         *
         * If this value is nil, the behavior is equivalent to the Ignore policy. This is a beta-level feature default enabled by the NodeInclusionPolicyInPodTopologySpread feature flag.
         */
        nodeTaintsPolicy?: string;
        /** TopologyKey is the key of node labels. Nodes that have a label with this key and identical values are considered to be in the same topology. We consider each <key, value> as a "bucket", and try to put balanced number of pods into each bucket. We define a domain as a particular instance of a topology. Also, we define an eligible domain as a domain whose nodes meet the requirements of nodeAffinityPolicy and nodeTaintsPolicy. e.g. If TopologyKey is "kubernetes.io/hostname", each Node is a domain of that topology. And, if TopologyKey is "topology.kubernetes.io/zone", each zone is a domain of that topology. It's a required field. */
        topologyKey: string;
        /**
         * WhenUnsatisfiable indicates how to deal with a pod if it doesn't satisfy the spread constraint. - DoNotSchedule (default) tells the scheduler not to schedule it. - ScheduleAnyway tells the scheduler to schedule the pod in any location,
         *   but giving higher precedence to topologies that would help reduce the
         *   skew.
         * A constraint is considered "Unsatisfiable" for an incoming pod if and only if every possible node assignment for that pod would violate "MaxSkew" on some topology. For example, in a 3-zone cluster, MaxSkew is set to 1, and pods with the same labelSelector spread as 3/1/1: | zone1 | zone2 | zone3 | | P P P |   P   |   P   | If WhenUnsatisfiable is set to DoNotSchedule, incoming pod can only be scheduled to zone2(zone3) to become 3/2/1(3/1/2) as ActualSkew(2-1) on zone2(zone3) satisfies MaxSkew(1). In other words, the cluster can still be imbalanced, but scheduler won't make it *more* imbalanced. It's a required field.
         */
        whenUnsatisfiable: string;
    }
    /** TypedLocalObjectReference contains enough information to let you locate the typed referenced object inside the same namespace. */
    interface io$k8s$api$core$v1$TypedLocalObjectReference {
        /** APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required. */
        apiGroup?: string;
        /** Kind is the type of resource being referenced */
        kind: string;
        /** Name is the name of resource being referenced */
        name: string;
    }
    interface io$k8s$api$core$v1$TypedObjectReference {
        /** APIGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required. */
        apiGroup?: string;
        /** Kind is the type of resource being referenced */
        kind: string;
        /** Name is the name of resource being referenced */
        name: string;
        /** Namespace is the namespace of resource being referenced Note that when a namespace is specified, a gateway.networking.k8s.io/ReferenceGrant object is required in the referent namespace to allow that namespace's owner to accept the reference. See the ReferenceGrant documentation for details. (Alpha) This field requires the CrossNamespaceVolumeDataSource feature gate to be enabled. */
        namespace?: string;
    }
    /** Volume represents a named volume in a pod that may be accessed by any container in the pod. */
    interface io$k8s$api$core$v1$Volume {
        awsElasticBlockStore?: Schemas.io$k8s$api$core$v1$AWSElasticBlockStoreVolumeSource;
        azureDisk?: Schemas.io$k8s$api$core$v1$AzureDiskVolumeSource;
        azureFile?: Schemas.io$k8s$api$core$v1$AzureFileVolumeSource;
        cephfs?: Schemas.io$k8s$api$core$v1$CephFSVolumeSource;
        cinder?: Schemas.io$k8s$api$core$v1$CinderVolumeSource;
        configMap?: Schemas.io$k8s$api$core$v1$ConfigMapVolumeSource;
        csi?: Schemas.io$k8s$api$core$v1$CSIVolumeSource;
        downwardAPI?: Schemas.io$k8s$api$core$v1$DownwardAPIVolumeSource;
        emptyDir?: Schemas.io$k8s$api$core$v1$EmptyDirVolumeSource;
        ephemeral?: Schemas.io$k8s$api$core$v1$EphemeralVolumeSource;
        fc?: Schemas.io$k8s$api$core$v1$FCVolumeSource;
        flexVolume?: Schemas.io$k8s$api$core$v1$FlexVolumeSource;
        flocker?: Schemas.io$k8s$api$core$v1$FlockerVolumeSource;
        gcePersistentDisk?: Schemas.io$k8s$api$core$v1$GCEPersistentDiskVolumeSource;
        gitRepo?: Schemas.io$k8s$api$core$v1$GitRepoVolumeSource;
        glusterfs?: Schemas.io$k8s$api$core$v1$GlusterfsVolumeSource;
        hostPath?: Schemas.io$k8s$api$core$v1$HostPathVolumeSource;
        iscsi?: Schemas.io$k8s$api$core$v1$ISCSIVolumeSource;
        /** name of the volume. Must be a DNS_LABEL and unique within the pod. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#names */
        name: string;
        nfs?: Schemas.io$k8s$api$core$v1$NFSVolumeSource;
        persistentVolumeClaim?: Schemas.io$k8s$api$core$v1$PersistentVolumeClaimVolumeSource;
        photonPersistentDisk?: Schemas.io$k8s$api$core$v1$PhotonPersistentDiskVolumeSource;
        portworxVolume?: Schemas.io$k8s$api$core$v1$PortworxVolumeSource;
        projected?: Schemas.io$k8s$api$core$v1$ProjectedVolumeSource;
        quobyte?: Schemas.io$k8s$api$core$v1$QuobyteVolumeSource;
        rbd?: Schemas.io$k8s$api$core$v1$RBDVolumeSource;
        scaleIO?: Schemas.io$k8s$api$core$v1$ScaleIOVolumeSource;
        secret?: Schemas.io$k8s$api$core$v1$SecretVolumeSource;
        storageos?: Schemas.io$k8s$api$core$v1$StorageOSVolumeSource;
        vsphereVolume?: Schemas.io$k8s$api$core$v1$VsphereVirtualDiskVolumeSource;
    }
    /** volumeDevice describes a mapping of a raw block device within a container. */
    interface io$k8s$api$core$v1$VolumeDevice {
        /** devicePath is the path inside of the container that the device will be mapped to. */
        devicePath: string;
        /** name must match the name of a persistentVolumeClaim in the pod */
        name: string;
    }
    /** VolumeMount describes a mounting of a Volume within a container. */
    interface io$k8s$api$core$v1$VolumeMount {
        /** Path within the container at which the volume should be mounted.  Must not contain ':'. */
        mountPath: string;
        /** mountPropagation determines how mounts are propagated from the host to container and the other way around. When not set, MountPropagationNone is used. This field is beta in 1.10. */
        mountPropagation?: string;
        /** This must match the Name of a Volume. */
        name: string;
        /** Mounted read-only if true, read-write otherwise (false or unspecified). Defaults to false. */
        readOnly?: boolean;
        /** Path within the volume from which the container's volume should be mounted. Defaults to "" (volume's root). */
        subPath?: string;
        /** Expanded path within the volume from which the container's volume should be mounted. Behaves similarly to SubPath but environment variable references $(VAR_NAME) are expanded using the container's environment. Defaults to "" (volume's root). SubPathExpr and SubPath are mutually exclusive. */
        subPathExpr?: string;
    }
    /** VolumeNodeAffinity defines constraints that limit what nodes this volume can be accessed from. */
    interface io$k8s$api$core$v1$VolumeNodeAffinity {
        required?: Schemas.io$k8s$api$core$v1$NodeSelector;
    }
    /** Projection that may be projected along with other supported volume types */
    interface io$k8s$api$core$v1$VolumeProjection {
        configMap?: Schemas.io$k8s$api$core$v1$ConfigMapProjection;
        downwardAPI?: Schemas.io$k8s$api$core$v1$DownwardAPIProjection;
        secret?: Schemas.io$k8s$api$core$v1$SecretProjection;
        serviceAccountToken?: Schemas.io$k8s$api$core$v1$ServiceAccountTokenProjection;
    }
    /** Represents a vSphere volume resource. */
    interface io$k8s$api$core$v1$VsphereVirtualDiskVolumeSource {
        /** fsType is filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. "ext4", "xfs", "ntfs". Implicitly inferred to be "ext4" if unspecified. */
        fsType?: string;
        /** storagePolicyID is the storage Policy Based Management (SPBM) profile ID associated with the StoragePolicyName. */
        storagePolicyID?: string;
        /** storagePolicyName is the storage Policy Based Management (SPBM) profile name. */
        storagePolicyName?: string;
        /** volumePath is the path that identifies vSphere volume vmdk */
        volumePath: string;
    }
    /** The weights of all of the matched WeightedPodAffinityTerm fields are added per-node to find the most preferred node(s) */
    interface io$k8s$api$core$v1$WeightedPodAffinityTerm {
        podAffinityTerm: Schemas.io$k8s$api$core$v1$PodAffinityTerm;
        /** weight associated with matching the corresponding podAffinityTerm, in the range 1-100. */
        weight: number;
    }
    /** WindowsSecurityContextOptions contain Windows-specific options and credentials. */
    interface io$k8s$api$core$v1$WindowsSecurityContextOptions {
        /** GMSACredentialSpec is where the GMSA admission webhook (https://github.com/kubernetes-sigs/windows-gmsa) inlines the contents of the GMSA credential spec named by the GMSACredentialSpecName field. */
        gmsaCredentialSpec?: string;
        /** GMSACredentialSpecName is the name of the GMSA credential spec to use. */
        gmsaCredentialSpecName?: string;
        /** HostProcess determines if a container should be run as a 'Host Process' container. This field is alpha-level and will only be honored by components that enable the WindowsHostProcessContainers feature flag. Setting this field without the feature flag will result in errors when validating the Pod. All of a Pod's containers must have the same effective HostProcess value (it is not allowed to have a mix of HostProcess containers and non-HostProcess containers).  In addition, if HostProcess is true then HostNetwork must also be set to true. */
        hostProcess?: boolean;
        /** The UserName in Windows to run the entrypoint of the container process. Defaults to the user specified in image metadata if unspecified. May also be set in PodSecurityContext. If set in both SecurityContext and PodSecurityContext, the value specified in SecurityContext takes precedence. */
        runAsUserName?: string;
    }
    /** Endpoint represents a single logical "backend" implementing a service. */
    interface io$k8s$api$discovery$v1$Endpoint {
        /** addresses of this endpoint. The contents of this field are interpreted according to the corresponding EndpointSlice addressType field. Consumers must handle different types of addresses in the context of their own capabilities. This must contain at least one address but no more than 100. These are all assumed to be fungible and clients may choose to only use the first element. Refer to: https://issue.k8s.io/106267 */
        addresses: string[];
        conditions?: Schemas.io$k8s$api$discovery$v1$EndpointConditions;
        /** deprecatedTopology contains topology information part of the v1beta1 API. This field is deprecated, and will be removed when the v1beta1 API is removed (no sooner than kubernetes v1.24).  While this field can hold values, it is not writable through the v1 API, and any attempts to write to it will be silently ignored. Topology information can be found in the zone and nodeName fields instead. */
        deprecatedTopology?: {
            [key: string]: string;
        };
        hints?: Schemas.io$k8s$api$discovery$v1$EndpointHints;
        /** hostname of this endpoint. This field may be used by consumers of endpoints to distinguish endpoints from each other (e.g. in DNS names). Multiple endpoints which use the same hostname should be considered fungible (e.g. multiple A values in DNS). Must be lowercase and pass DNS Label (RFC 1123) validation. */
        hostname?: string;
        /** nodeName represents the name of the Node hosting this endpoint. This can be used to determine endpoints local to a Node. */
        nodeName?: string;
        targetRef?: Schemas.io$k8s$api$core$v1$ObjectReference;
        /** zone is the name of the Zone this endpoint exists in. */
        zone?: string;
    }
    /** EndpointConditions represents the current condition of an endpoint. */
    interface io$k8s$api$discovery$v1$EndpointConditions {
        /** ready indicates that this endpoint is prepared to receive traffic, according to whatever system is managing the endpoint. A nil value indicates an unknown state. In most cases consumers should interpret this unknown state as ready. For compatibility reasons, ready should never be "true" for terminating endpoints, except when the normal readiness behavior is being explicitly overridden, for example when the associated Service has set the publishNotReadyAddresses flag. */
        ready?: boolean;
        /** serving is identical to ready except that it is set regardless of the terminating state of endpoints. This condition should be set to true for a ready endpoint that is terminating. If nil, consumers should defer to the ready condition. */
        serving?: boolean;
        /** terminating indicates that this endpoint is terminating. A nil value indicates an unknown state. Consumers should interpret this unknown state to mean that the endpoint is not terminating. */
        terminating?: boolean;
    }
    /** EndpointHints provides hints describing how an endpoint should be consumed. */
    interface io$k8s$api$discovery$v1$EndpointHints {
        /** forZones indicates the zone(s) this endpoint should be consumed by to enable topology aware routing. */
        forZones?: Schemas.io$k8s$api$discovery$v1$ForZone[];
    }
    /** EndpointPort represents a Port used by an EndpointSlice */
    interface io$k8s$api$discovery$v1$EndpointPort {
        /**
         * The application protocol for this port. This is used as a hint for implementations to offer richer behavior for protocols that they understand. This field follows standard Kubernetes label syntax. Valid values are either:
         *
         * * Un-prefixed protocol names - reserved for IANA standard service names (as per RFC-6335 and https://www.iana.org/assignments/service-names).
         *
         * * Kubernetes-defined prefixed names:
         *   * 'kubernetes.io/h2c' - HTTP/2 over cleartext as described in https://www.rfc-editor.org/rfc/rfc7540
         *
         * * Other protocols should use implementation-defined prefixed names such as mycompany.com/my-custom-protocol.
         */
        appProtocol?: string;
        /** name represents the name of this port. All ports in an EndpointSlice must have a unique name. If the EndpointSlice is dervied from a Kubernetes service, this corresponds to the Service.ports[].name. Name must either be an empty string or pass DNS_LABEL validation: * must be no more than 63 characters long. * must consist of lower case alphanumeric characters or '-'. * must start and end with an alphanumeric character. Default is empty string. */
        name?: string;
        /** port represents the port number of the endpoint. If this is not specified, ports are not restricted and must be interpreted in the context of the specific consumer. */
        port?: number;
        /** protocol represents the IP protocol for this port. Must be UDP, TCP, or SCTP. Default is TCP. */
        protocol?: string;
    }
    /** EndpointSlice represents a subset of the endpoints that implement a service. For a given service there may be multiple EndpointSlice objects, selected by labels, which must be joined to produce the full set of endpoints. */
    interface io$k8s$api$discovery$v1$EndpointSlice {
        /** addressType specifies the type of address carried by this EndpointSlice. All addresses in this slice must be the same type. This field is immutable after creation. The following address types are currently supported: * IPv4: Represents an IPv4 Address. * IPv6: Represents an IPv6 Address. * FQDN: Represents a Fully Qualified Domain Name. */
        addressType: string;
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** endpoints is a list of unique endpoints in this slice. Each slice may include a maximum of 1000 endpoints. */
        endpoints: Schemas.io$k8s$api$discovery$v1$Endpoint[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** ports specifies the list of network ports exposed by each endpoint in this slice. Each port must have a unique name. When ports is empty, it indicates that there are no defined ports. When a port is defined with a nil port value, it indicates "all ports". Each slice may include a maximum of 100 ports. */
        ports?: Schemas.io$k8s$api$discovery$v1$EndpointPort[];
    }
    /** EndpointSliceList represents a list of endpoint slices */
    interface io$k8s$api$discovery$v1$EndpointSliceList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of endpoint slices */
        items: Schemas.io$k8s$api$discovery$v1$EndpointSlice[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ForZone provides information about which zones should consume this endpoint. */
    interface io$k8s$api$discovery$v1$ForZone {
        /** name represents the name of the zone. */
        name: string;
    }
    /** Event is a report of an event somewhere in the cluster. It generally denotes some state change in the system. Events have a limited retention time and triggers and messages may evolve with time.  Event consumers should not rely on the timing of an event with a given Reason reflecting a consistent underlying trigger, or the continued existence of events with that Reason.  Events should be treated as informative, best-effort, supplemental data. */
    interface io$k8s$api$events$v1$Event {
        /** action is what action was taken/failed regarding to the regarding object. It is machine-readable. This field cannot be empty for new Events and it can have at most 128 characters. */
        action?: string;
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** deprecatedCount is the deprecated field assuring backward compatibility with core.v1 Event type. */
        deprecatedCount?: number;
        deprecatedFirstTimestamp?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        deprecatedLastTimestamp?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        deprecatedSource?: Schemas.io$k8s$api$core$v1$EventSource;
        eventTime: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$MicroTime;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** note is a human-readable description of the status of this operation. Maximal length of the note is 1kB, but libraries should be prepared to handle values up to 64kB. */
        note?: string;
        /** reason is why the action was taken. It is human-readable. This field cannot be empty for new Events and it can have at most 128 characters. */
        reason?: string;
        regarding?: Schemas.io$k8s$api$core$v1$ObjectReference;
        related?: Schemas.io$k8s$api$core$v1$ObjectReference;
        /** reportingController is the name of the controller that emitted this Event, e.g. `kubernetes.io/kubelet`. This field cannot be empty for new Events. */
        reportingController?: string;
        /** reportingInstance is the ID of the controller instance, e.g. `kubelet-xyzf`. This field cannot be empty for new Events and it can have at most 128 characters. */
        reportingInstance?: string;
        series?: Schemas.io$k8s$api$events$v1$EventSeries;
        /** type is the type of this event (Normal, Warning), new types could be added in the future. It is machine-readable. This field cannot be empty for new Events. */
        type?: string;
    }
    /** EventList is a list of Event objects. */
    interface io$k8s$api$events$v1$EventList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is a list of schema objects. */
        items: Schemas.io$k8s$api$events$v1$Event[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** EventSeries contain information on series of events, i.e. thing that was/is happening continuously for some time. How often to update the EventSeries is up to the event reporters. The default event reporter in "k8s.io/client-go/tools/events/event_broadcaster.go" shows how this struct is updated on heartbeats and can guide customized reporter implementations. */
    interface io$k8s$api$events$v1$EventSeries {
        /** count is the number of occurrences in this series up to the last heartbeat time. */
        count: number;
        lastObservedTime: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$MicroTime;
    }
    /** FlowDistinguisherMethod specifies the method of a flow distinguisher. */
    interface io$k8s$api$flowcontrol$v1beta2$FlowDistinguisherMethod {
        /** `type` is the type of flow distinguisher method The supported types are "ByUser" and "ByNamespace". Required. */
        type: string;
    }
    /** FlowSchema defines the schema of a group of flows. Note that a flow is made up of a set of inbound API requests with similar attributes and is identified by a pair of strings: the name of the FlowSchema and a "flow distinguisher". */
    interface io$k8s$api$flowcontrol$v1beta2$FlowSchema {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchemaSpec;
        status?: Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchemaStatus;
    }
    /** FlowSchemaCondition describes conditions for a FlowSchema. */
    interface io$k8s$api$flowcontrol$v1beta2$FlowSchemaCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** `message` is a human-readable message indicating details about last transition. */
        message?: string;
        /** `reason` is a unique, one-word, CamelCase reason for the condition's last transition. */
        reason?: string;
        /** `status` is the status of the condition. Can be True, False, Unknown. Required. */
        status?: string;
        /** `type` is the type of the condition. Required. */
        type?: string;
    }
    /** FlowSchemaList is a list of FlowSchema objects. */
    interface io$k8s$api$flowcontrol$v1beta2$FlowSchemaList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** `items` is a list of FlowSchemas. */
        items: Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** FlowSchemaSpec describes how the FlowSchema's specification looks like. */
    interface io$k8s$api$flowcontrol$v1beta2$FlowSchemaSpec {
        distinguisherMethod?: Schemas.io$k8s$api$flowcontrol$v1beta2$FlowDistinguisherMethod;
        /** `matchingPrecedence` is used to choose among the FlowSchemas that match a given request. The chosen FlowSchema is among those with the numerically lowest (which we take to be logically highest) MatchingPrecedence.  Each MatchingPrecedence value must be ranged in [1,10000]. Note that if the precedence is not specified, it will be set to 1000 as default. */
        matchingPrecedence?: number;
        priorityLevelConfiguration: Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationReference;
        /** `rules` describes which requests will match this flow schema. This FlowSchema matches a request if and only if at least one member of rules matches the request. if it is an empty slice, there will be no requests matching the FlowSchema. */
        rules?: Schemas.io$k8s$api$flowcontrol$v1beta2$PolicyRulesWithSubjects[];
    }
    /** FlowSchemaStatus represents the current state of a FlowSchema. */
    interface io$k8s$api$flowcontrol$v1beta2$FlowSchemaStatus {
        /** `conditions` is a list of the current states of FlowSchema. */
        conditions?: Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchemaCondition[];
    }
    /** GroupSubject holds detailed information for group-kind subject. */
    interface io$k8s$api$flowcontrol$v1beta2$GroupSubject {
        /** name is the user group that matches, or "*" to match all user groups. See https://github.com/kubernetes/apiserver/blob/master/pkg/authentication/user/user.go for some well-known group names. Required. */
        name: string;
    }
    /** LimitResponse defines how to handle requests that can not be executed right now. */
    interface io$k8s$api$flowcontrol$v1beta2$LimitResponse {
        queuing?: Schemas.io$k8s$api$flowcontrol$v1beta2$QueuingConfiguration;
        /** `type` is "Queue" or "Reject". "Queue" means that requests that can not be executed upon arrival are held in a queue until they can be executed or a queuing limit is reached. "Reject" means that requests that can not be executed upon arrival are rejected. Required. */
        type: string;
    }
    /**
     * LimitedPriorityLevelConfiguration specifies how to handle requests that are subject to limits. It addresses two issues:
     *   - How are requests for this priority level limited?
     *   - What should be done with requests that exceed the limit?
     */
    interface io$k8s$api$flowcontrol$v1beta2$LimitedPriorityLevelConfiguration {
        /**
         * `assuredConcurrencyShares` (ACS) configures the execution limit, which is a limit on the number of requests of this priority level that may be exeucting at a given time.  ACS must be a positive number. The server's concurrency limit (SCL) is divided among the concurrency-controlled priority levels in proportion to their assured concurrency shares. This produces the assured concurrency value (ACV) --- the number of requests that may be executing at a time --- for each such priority level:
         *
         *             ACV(l) = ceil( SCL * ACS(l) / ( sum[priority levels k] ACS(k) ) )
         *
         * bigger numbers of ACS mean more reserved concurrent requests (at the expense of every other PL). This field has a default value of 30.
         */
        assuredConcurrencyShares?: number;
        /**
         * `borrowingLimitPercent`, if present, configures a limit on how many seats this priority level can borrow from other priority levels. The limit is known as this level's BorrowingConcurrencyLimit (BorrowingCL) and is a limit on the total number of seats that this level may borrow at any one time. This field holds the ratio of that limit to the level's nominal concurrency limit. When this field is non-nil, it must hold a non-negative integer and the limit is calculated as follows.
         *
         * BorrowingCL(i) = round( NominalCL(i) * borrowingLimitPercent(i)/100.0 )
         *
         * The value of this field can be more than 100, implying that this priority level can borrow a number of seats that is greater than its own nominal concurrency limit (NominalCL). When this field is left `nil`, the limit is effectively infinite.
         */
        borrowingLimitPercent?: number;
        /**
         * `lendablePercent` prescribes the fraction of the level's NominalCL that can be borrowed by other priority levels. The value of this field must be between 0 and 100, inclusive, and it defaults to 0. The number of seats that other levels can borrow from this level, known as this level's LendableConcurrencyLimit (LendableCL), is defined as follows.
         *
         * LendableCL(i) = round( NominalCL(i) * lendablePercent(i)/100.0 )
         */
        lendablePercent?: number;
        limitResponse?: Schemas.io$k8s$api$flowcontrol$v1beta2$LimitResponse;
    }
    /** NonResourcePolicyRule is a predicate that matches non-resource requests according to their verb and the target non-resource URL. A NonResourcePolicyRule matches a request if and only if both (a) at least one member of verbs matches the request and (b) at least one member of nonResourceURLs matches the request. */
    interface io$k8s$api$flowcontrol$v1beta2$NonResourcePolicyRule {
        /**
         * `nonResourceURLs` is a set of url prefixes that a user should have access to and may not be empty. For example:
         *   - "/healthz" is legal
         *   - "/hea*" is illegal
         *   - "/hea" is legal but matches nothing
         *   - "/hea/\\*" also matches nothing
         *   - "/healthz/*" matches all per-component health checks.
         * "*" matches all non-resource urls. if it is present, it must be the only entry. Required.
         */
        nonResourceURLs: string[];
        /** `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs. If it is present, it must be the only entry. Required. */
        verbs: string[];
    }
    /** PolicyRulesWithSubjects prescribes a test that applies to a request to an apiserver. The test considers the subject making the request, the verb being requested, and the resource to be acted upon. This PolicyRulesWithSubjects matches a request if and only if both (a) at least one member of subjects matches the request and (b) at least one member of resourceRules or nonResourceRules matches the request. */
    interface io$k8s$api$flowcontrol$v1beta2$PolicyRulesWithSubjects {
        /** `nonResourceRules` is a list of NonResourcePolicyRules that identify matching requests according to their verb and the target non-resource URL. */
        nonResourceRules?: Schemas.io$k8s$api$flowcontrol$v1beta2$NonResourcePolicyRule[];
        /** `resourceRules` is a slice of ResourcePolicyRules that identify matching requests according to their verb and the target resource. At least one of `resourceRules` and `nonResourceRules` has to be non-empty. */
        resourceRules?: Schemas.io$k8s$api$flowcontrol$v1beta2$ResourcePolicyRule[];
        /** subjects is the list of normal user, serviceaccount, or group that this rule cares about. There must be at least one member in this slice. A slice that includes both the system:authenticated and system:unauthenticated user groups matches every request. Required. */
        subjects: Schemas.io$k8s$api$flowcontrol$v1beta2$Subject[];
    }
    /** PriorityLevelConfiguration represents the configuration of a priority level. */
    interface io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationSpec;
        status?: Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationStatus;
    }
    /** PriorityLevelConfigurationCondition defines the condition of priority level. */
    interface io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** `message` is a human-readable message indicating details about last transition. */
        message?: string;
        /** `reason` is a unique, one-word, CamelCase reason for the condition's last transition. */
        reason?: string;
        /** `status` is the status of the condition. Can be True, False, Unknown. Required. */
        status?: string;
        /** `type` is the type of the condition. Required. */
        type?: string;
    }
    /** PriorityLevelConfigurationList is a list of PriorityLevelConfiguration objects. */
    interface io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** `items` is a list of request-priorities. */
        items: Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** PriorityLevelConfigurationReference contains information that points to the "request-priority" being used. */
    interface io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationReference {
        /** `name` is the name of the priority level configuration being referenced Required. */
        name: string;
    }
    /** PriorityLevelConfigurationSpec specifies the configuration of a priority level. */
    interface io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationSpec {
        limited?: Schemas.io$k8s$api$flowcontrol$v1beta2$LimitedPriorityLevelConfiguration;
        /** `type` indicates whether this priority level is subject to limitation on request execution.  A value of `"Exempt"` means that requests of this priority level are not subject to a limit (and thus are never queued) and do not detract from the capacity made available to other priority levels.  A value of `"Limited"` means that (a) requests of this priority level _are_ subject to limits and (b) some of the server's limited capacity is made available exclusively to this priority level. Required. */
        type: string;
    }
    /** PriorityLevelConfigurationStatus represents the current state of a "request-priority". */
    interface io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationStatus {
        /** `conditions` is the current state of "request-priority". */
        conditions?: Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationCondition[];
    }
    /** QueuingConfiguration holds the configuration parameters for queuing */
    interface io$k8s$api$flowcontrol$v1beta2$QueuingConfiguration {
        /** `handSize` is a small positive number that configures the shuffle sharding of requests into queues.  When enqueuing a request at this priority level the request's flow identifier (a string pair) is hashed and the hash value is used to shuffle the list of queues and deal a hand of the size specified here.  The request is put into one of the shortest queues in that hand. `handSize` must be no larger than `queues`, and should be significantly smaller (so that a few heavy flows do not saturate most of the queues).  See the user-facing documentation for more extensive guidance on setting this field.  This field has a default value of 8. */
        handSize?: number;
        /** `queueLengthLimit` is the maximum number of requests allowed to be waiting in a given queue of this priority level at a time; excess requests are rejected.  This value must be positive.  If not specified, it will be defaulted to 50. */
        queueLengthLimit?: number;
        /** `queues` is the number of queues for this priority level. The queues exist independently at each apiserver. The value must be positive.  Setting it to 1 effectively precludes shufflesharding and thus makes the distinguisher method of associated flow schemas irrelevant.  This field has a default value of 64. */
        queues?: number;
    }
    /** ResourcePolicyRule is a predicate that matches some resource requests, testing the request's verb and the target resource. A ResourcePolicyRule matches a resource request if and only if: (a) at least one member of verbs matches the request, (b) at least one member of apiGroups matches the request, (c) at least one member of resources matches the request, and (d) either (d1) the request does not specify a namespace (i.e., `Namespace==""`) and clusterScope is true or (d2) the request specifies a namespace and least one member of namespaces matches the request's namespace. */
    interface io$k8s$api$flowcontrol$v1beta2$ResourcePolicyRule {
        /** `apiGroups` is a list of matching API groups and may not be empty. "*" matches all API groups and, if present, must be the only entry. Required. */
        apiGroups: string[];
        /** `clusterScope` indicates whether to match requests that do not specify a namespace (which happens either because the resource is not namespaced or the request targets all namespaces). If this field is omitted or false then the `namespaces` field must contain a non-empty list. */
        clusterScope?: boolean;
        /** `namespaces` is a list of target namespaces that restricts matches.  A request that specifies a target namespace matches only if either (a) this list contains that target namespace or (b) this list contains "*".  Note that "*" matches any specified namespace but does not match a request that _does not specify_ a namespace (see the `clusterScope` field for that). This list may be empty, but only if `clusterScope` is true. */
        namespaces?: string[];
        /** `resources` is a list of matching resources (i.e., lowercase and plural) with, if desired, subresource.  For example, [ "services", "nodes/status" ].  This list may not be empty. "*" matches all resources and, if present, must be the only entry. Required. */
        resources: string[];
        /** `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs and, if present, must be the only entry. Required. */
        verbs: string[];
    }
    /** ServiceAccountSubject holds detailed information for service-account-kind subject. */
    interface io$k8s$api$flowcontrol$v1beta2$ServiceAccountSubject {
        /** `name` is the name of matching ServiceAccount objects, or "*" to match regardless of name. Required. */
        name: string;
        /** `namespace` is the namespace of matching ServiceAccount objects. Required. */
        namespace: string;
    }
    /** Subject matches the originator of a request, as identified by the request authentication system. There are three ways of matching an originator; by user, group, or service account. */
    interface io$k8s$api$flowcontrol$v1beta2$Subject {
        group?: Schemas.io$k8s$api$flowcontrol$v1beta2$GroupSubject;
        /** `kind` indicates which one of the other fields is non-empty. Required */
        kind: string;
        serviceAccount?: Schemas.io$k8s$api$flowcontrol$v1beta2$ServiceAccountSubject;
        user?: Schemas.io$k8s$api$flowcontrol$v1beta2$UserSubject;
    }
    /** UserSubject holds detailed information for user-kind subject. */
    interface io$k8s$api$flowcontrol$v1beta2$UserSubject {
        /** `name` is the username that matches, or "*" to match all usernames. Required. */
        name: string;
    }
    /** FlowDistinguisherMethod specifies the method of a flow distinguisher. */
    interface io$k8s$api$flowcontrol$v1beta3$FlowDistinguisherMethod {
        /** `type` is the type of flow distinguisher method The supported types are "ByUser" and "ByNamespace". Required. */
        type: string;
    }
    /** FlowSchema defines the schema of a group of flows. Note that a flow is made up of a set of inbound API requests with similar attributes and is identified by a pair of strings: the name of the FlowSchema and a "flow distinguisher". */
    interface io$k8s$api$flowcontrol$v1beta3$FlowSchema {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchemaSpec;
        status?: Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchemaStatus;
    }
    /** FlowSchemaCondition describes conditions for a FlowSchema. */
    interface io$k8s$api$flowcontrol$v1beta3$FlowSchemaCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** `message` is a human-readable message indicating details about last transition. */
        message?: string;
        /** `reason` is a unique, one-word, CamelCase reason for the condition's last transition. */
        reason?: string;
        /** `status` is the status of the condition. Can be True, False, Unknown. Required. */
        status?: string;
        /** `type` is the type of the condition. Required. */
        type?: string;
    }
    /** FlowSchemaList is a list of FlowSchema objects. */
    interface io$k8s$api$flowcontrol$v1beta3$FlowSchemaList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** `items` is a list of FlowSchemas. */
        items: Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** FlowSchemaSpec describes how the FlowSchema's specification looks like. */
    interface io$k8s$api$flowcontrol$v1beta3$FlowSchemaSpec {
        distinguisherMethod?: Schemas.io$k8s$api$flowcontrol$v1beta3$FlowDistinguisherMethod;
        /** `matchingPrecedence` is used to choose among the FlowSchemas that match a given request. The chosen FlowSchema is among those with the numerically lowest (which we take to be logically highest) MatchingPrecedence.  Each MatchingPrecedence value must be ranged in [1,10000]. Note that if the precedence is not specified, it will be set to 1000 as default. */
        matchingPrecedence?: number;
        priorityLevelConfiguration: Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfigurationReference;
        /** `rules` describes which requests will match this flow schema. This FlowSchema matches a request if and only if at least one member of rules matches the request. if it is an empty slice, there will be no requests matching the FlowSchema. */
        rules?: Schemas.io$k8s$api$flowcontrol$v1beta3$PolicyRulesWithSubjects[];
    }
    /** FlowSchemaStatus represents the current state of a FlowSchema. */
    interface io$k8s$api$flowcontrol$v1beta3$FlowSchemaStatus {
        /** `conditions` is a list of the current states of FlowSchema. */
        conditions?: Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchemaCondition[];
    }
    /** GroupSubject holds detailed information for group-kind subject. */
    interface io$k8s$api$flowcontrol$v1beta3$GroupSubject {
        /** name is the user group that matches, or "*" to match all user groups. See https://github.com/kubernetes/apiserver/blob/master/pkg/authentication/user/user.go for some well-known group names. Required. */
        name: string;
    }
    /** LimitResponse defines how to handle requests that can not be executed right now. */
    interface io$k8s$api$flowcontrol$v1beta3$LimitResponse {
        queuing?: Schemas.io$k8s$api$flowcontrol$v1beta3$QueuingConfiguration;
        /** `type` is "Queue" or "Reject". "Queue" means that requests that can not be executed upon arrival are held in a queue until they can be executed or a queuing limit is reached. "Reject" means that requests that can not be executed upon arrival are rejected. Required. */
        type: string;
    }
    /**
     * LimitedPriorityLevelConfiguration specifies how to handle requests that are subject to limits. It addresses two issues:
     *   - How are requests for this priority level limited?
     *   - What should be done with requests that exceed the limit?
     */
    interface io$k8s$api$flowcontrol$v1beta3$LimitedPriorityLevelConfiguration {
        /**
         * `borrowingLimitPercent`, if present, configures a limit on how many seats this priority level can borrow from other priority levels. The limit is known as this level's BorrowingConcurrencyLimit (BorrowingCL) and is a limit on the total number of seats that this level may borrow at any one time. This field holds the ratio of that limit to the level's nominal concurrency limit. When this field is non-nil, it must hold a non-negative integer and the limit is calculated as follows.
         *
         * BorrowingCL(i) = round( NominalCL(i) * borrowingLimitPercent(i)/100.0 )
         *
         * The value of this field can be more than 100, implying that this priority level can borrow a number of seats that is greater than its own nominal concurrency limit (NominalCL). When this field is left `nil`, the limit is effectively infinite.
         */
        borrowingLimitPercent?: number;
        /**
         * `lendablePercent` prescribes the fraction of the level's NominalCL that can be borrowed by other priority levels. The value of this field must be between 0 and 100, inclusive, and it defaults to 0. The number of seats that other levels can borrow from this level, known as this level's LendableConcurrencyLimit (LendableCL), is defined as follows.
         *
         * LendableCL(i) = round( NominalCL(i) * lendablePercent(i)/100.0 )
         */
        lendablePercent?: number;
        limitResponse?: Schemas.io$k8s$api$flowcontrol$v1beta3$LimitResponse;
        /**
         * `nominalConcurrencyShares` (NCS) contributes to the computation of the NominalConcurrencyLimit (NominalCL) of this level. This is the number of execution seats available at this priority level. This is used both for requests dispatched from this priority level as well as requests dispatched from other priority levels borrowing seats from this level. The server's concurrency limit (ServerCL) is divided among the Limited priority levels in proportion to their NCS values:
         *
         * NominalCL(i)  = ceil( ServerCL * NCS(i) / sum_ncs ) sum_ncs = sum[limited priority level k] NCS(k)
         *
         * Bigger numbers mean a larger nominal concurrency limit, at the expense of every other Limited priority level. This field has a default value of 30.
         */
        nominalConcurrencyShares?: number;
    }
    /** NonResourcePolicyRule is a predicate that matches non-resource requests according to their verb and the target non-resource URL. A NonResourcePolicyRule matches a request if and only if both (a) at least one member of verbs matches the request and (b) at least one member of nonResourceURLs matches the request. */
    interface io$k8s$api$flowcontrol$v1beta3$NonResourcePolicyRule {
        /**
         * `nonResourceURLs` is a set of url prefixes that a user should have access to and may not be empty. For example:
         *   - "/healthz" is legal
         *   - "/hea*" is illegal
         *   - "/hea" is legal but matches nothing
         *   - "/hea/\\*" also matches nothing
         *   - "/healthz/*" matches all per-component health checks.
         * "*" matches all non-resource urls. if it is present, it must be the only entry. Required.
         */
        nonResourceURLs: string[];
        /** `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs. If it is present, it must be the only entry. Required. */
        verbs: string[];
    }
    /** PolicyRulesWithSubjects prescribes a test that applies to a request to an apiserver. The test considers the subject making the request, the verb being requested, and the resource to be acted upon. This PolicyRulesWithSubjects matches a request if and only if both (a) at least one member of subjects matches the request and (b) at least one member of resourceRules or nonResourceRules matches the request. */
    interface io$k8s$api$flowcontrol$v1beta3$PolicyRulesWithSubjects {
        /** `nonResourceRules` is a list of NonResourcePolicyRules that identify matching requests according to their verb and the target non-resource URL. */
        nonResourceRules?: Schemas.io$k8s$api$flowcontrol$v1beta3$NonResourcePolicyRule[];
        /** `resourceRules` is a slice of ResourcePolicyRules that identify matching requests according to their verb and the target resource. At least one of `resourceRules` and `nonResourceRules` has to be non-empty. */
        resourceRules?: Schemas.io$k8s$api$flowcontrol$v1beta3$ResourcePolicyRule[];
        /** subjects is the list of normal user, serviceaccount, or group that this rule cares about. There must be at least one member in this slice. A slice that includes both the system:authenticated and system:unauthenticated user groups matches every request. Required. */
        subjects: Schemas.io$k8s$api$flowcontrol$v1beta3$Subject[];
    }
    /** PriorityLevelConfiguration represents the configuration of a priority level. */
    interface io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfigurationSpec;
        status?: Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfigurationStatus;
    }
    /** PriorityLevelConfigurationCondition defines the condition of priority level. */
    interface io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfigurationCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** `message` is a human-readable message indicating details about last transition. */
        message?: string;
        /** `reason` is a unique, one-word, CamelCase reason for the condition's last transition. */
        reason?: string;
        /** `status` is the status of the condition. Can be True, False, Unknown. Required. */
        status?: string;
        /** `type` is the type of the condition. Required. */
        type?: string;
    }
    /** PriorityLevelConfigurationList is a list of PriorityLevelConfiguration objects. */
    interface io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfigurationList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** `items` is a list of request-priorities. */
        items: Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** PriorityLevelConfigurationReference contains information that points to the "request-priority" being used. */
    interface io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfigurationReference {
        /** `name` is the name of the priority level configuration being referenced Required. */
        name: string;
    }
    /** PriorityLevelConfigurationSpec specifies the configuration of a priority level. */
    interface io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfigurationSpec {
        limited?: Schemas.io$k8s$api$flowcontrol$v1beta3$LimitedPriorityLevelConfiguration;
        /** `type` indicates whether this priority level is subject to limitation on request execution.  A value of `"Exempt"` means that requests of this priority level are not subject to a limit (and thus are never queued) and do not detract from the capacity made available to other priority levels.  A value of `"Limited"` means that (a) requests of this priority level _are_ subject to limits and (b) some of the server's limited capacity is made available exclusively to this priority level. Required. */
        type: string;
    }
    /** PriorityLevelConfigurationStatus represents the current state of a "request-priority". */
    interface io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfigurationStatus {
        /** `conditions` is the current state of "request-priority". */
        conditions?: Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfigurationCondition[];
    }
    /** QueuingConfiguration holds the configuration parameters for queuing */
    interface io$k8s$api$flowcontrol$v1beta3$QueuingConfiguration {
        /** `handSize` is a small positive number that configures the shuffle sharding of requests into queues.  When enqueuing a request at this priority level the request's flow identifier (a string pair) is hashed and the hash value is used to shuffle the list of queues and deal a hand of the size specified here.  The request is put into one of the shortest queues in that hand. `handSize` must be no larger than `queues`, and should be significantly smaller (so that a few heavy flows do not saturate most of the queues).  See the user-facing documentation for more extensive guidance on setting this field.  This field has a default value of 8. */
        handSize?: number;
        /** `queueLengthLimit` is the maximum number of requests allowed to be waiting in a given queue of this priority level at a time; excess requests are rejected.  This value must be positive.  If not specified, it will be defaulted to 50. */
        queueLengthLimit?: number;
        /** `queues` is the number of queues for this priority level. The queues exist independently at each apiserver. The value must be positive.  Setting it to 1 effectively precludes shufflesharding and thus makes the distinguisher method of associated flow schemas irrelevant.  This field has a default value of 64. */
        queues?: number;
    }
    /** ResourcePolicyRule is a predicate that matches some resource requests, testing the request's verb and the target resource. A ResourcePolicyRule matches a resource request if and only if: (a) at least one member of verbs matches the request, (b) at least one member of apiGroups matches the request, (c) at least one member of resources matches the request, and (d) either (d1) the request does not specify a namespace (i.e., `Namespace==""`) and clusterScope is true or (d2) the request specifies a namespace and least one member of namespaces matches the request's namespace. */
    interface io$k8s$api$flowcontrol$v1beta3$ResourcePolicyRule {
        /** `apiGroups` is a list of matching API groups and may not be empty. "*" matches all API groups and, if present, must be the only entry. Required. */
        apiGroups: string[];
        /** `clusterScope` indicates whether to match requests that do not specify a namespace (which happens either because the resource is not namespaced or the request targets all namespaces). If this field is omitted or false then the `namespaces` field must contain a non-empty list. */
        clusterScope?: boolean;
        /** `namespaces` is a list of target namespaces that restricts matches.  A request that specifies a target namespace matches only if either (a) this list contains that target namespace or (b) this list contains "*".  Note that "*" matches any specified namespace but does not match a request that _does not specify_ a namespace (see the `clusterScope` field for that). This list may be empty, but only if `clusterScope` is true. */
        namespaces?: string[];
        /** `resources` is a list of matching resources (i.e., lowercase and plural) with, if desired, subresource.  For example, [ "services", "nodes/status" ].  This list may not be empty. "*" matches all resources and, if present, must be the only entry. Required. */
        resources: string[];
        /** `verbs` is a list of matching verbs and may not be empty. "*" matches all verbs and, if present, must be the only entry. Required. */
        verbs: string[];
    }
    /** ServiceAccountSubject holds detailed information for service-account-kind subject. */
    interface io$k8s$api$flowcontrol$v1beta3$ServiceAccountSubject {
        /** `name` is the name of matching ServiceAccount objects, or "*" to match regardless of name. Required. */
        name: string;
        /** `namespace` is the namespace of matching ServiceAccount objects. Required. */
        namespace: string;
    }
    /** Subject matches the originator of a request, as identified by the request authentication system. There are three ways of matching an originator; by user, group, or service account. */
    interface io$k8s$api$flowcontrol$v1beta3$Subject {
        group?: Schemas.io$k8s$api$flowcontrol$v1beta3$GroupSubject;
        /** `kind` indicates which one of the other fields is non-empty. Required */
        kind: string;
        serviceAccount?: Schemas.io$k8s$api$flowcontrol$v1beta3$ServiceAccountSubject;
        user?: Schemas.io$k8s$api$flowcontrol$v1beta3$UserSubject;
    }
    /** UserSubject holds detailed information for user-kind subject. */
    interface io$k8s$api$flowcontrol$v1beta3$UserSubject {
        /** `name` is the username that matches, or "*" to match all usernames. Required. */
        name: string;
    }
    /** HTTPIngressPath associates a path with a backend. Incoming urls matching the path are forwarded to the backend. */
    interface io$k8s$api$networking$v1$HTTPIngressPath {
        backend: Schemas.io$k8s$api$networking$v1$IngressBackend;
        /** path is matched against the path of an incoming request. Currently it can contain characters disallowed from the conventional "path" part of a URL as defined by RFC 3986. Paths must begin with a '/' and must be present when using PathType with value "Exact" or "Prefix". */
        path?: string;
        /**
         * pathType determines the interpretation of the path matching. PathType can be one of the following values: * Exact: Matches the URL path exactly. * Prefix: Matches based on a URL path prefix split by '/'. Matching is
         *   done on a path element by element basis. A path element refers is the
         *   list of labels in the path split by the '/' separator. A request is a
         *   match for path p if every p is an element-wise prefix of p of the
         *   request path. Note that if the last element of the path is a substring
         *   of the last element in request path, it is not a match (e.g. /foo/bar
         *   matches /foo/bar/baz, but does not match /foo/barbaz).
         * * ImplementationSpecific: Interpretation of the Path matching is up to
         *   the IngressClass. Implementations can treat this as a separate PathType
         *   or treat it identically to Prefix or Exact path types.
         * Implementations are required to support all path types.
         */
        pathType: string;
    }
    /** HTTPIngressRuleValue is a list of http selectors pointing to backends. In the example: http://<host>/<path>?<searchpart> -> backend where where parts of the url correspond to RFC 3986, this resource will be used to match against everything after the last '/' and before the first '?' or '#'. */
    interface io$k8s$api$networking$v1$HTTPIngressRuleValue {
        /** paths is a collection of paths that map requests to backends. */
        paths: Schemas.io$k8s$api$networking$v1$HTTPIngressPath[];
    }
    /** IPBlock describes a particular CIDR (Ex. "192.168.1.0/24","2001:db8::/64") that is allowed to the pods matched by a NetworkPolicySpec's podSelector. The except entry describes CIDRs that should not be included within this rule. */
    interface io$k8s$api$networking$v1$IPBlock {
        /** cidr is a string representing the IPBlock Valid examples are "192.168.1.0/24" or "2001:db8::/64" */
        cidr: string;
        /** except is a slice of CIDRs that should not be included within an IPBlock Valid examples are "192.168.1.0/24" or "2001:db8::/64" Except values will be rejected if they are outside the cidr range */
        except?: string[];
    }
    /** Ingress is a collection of rules that allow inbound connections to reach the endpoints defined by a backend. An Ingress can be configured to give services externally-reachable urls, load balance traffic, terminate SSL, offer name based virtual hosting etc. */
    interface io$k8s$api$networking$v1$Ingress {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$networking$v1$IngressSpec;
        status?: Schemas.io$k8s$api$networking$v1$IngressStatus;
    }
    /** IngressBackend describes all endpoints for a given service and port. */
    interface io$k8s$api$networking$v1$IngressBackend {
        resource?: Schemas.io$k8s$api$core$v1$TypedLocalObjectReference;
        service?: Schemas.io$k8s$api$networking$v1$IngressServiceBackend;
    }
    /** IngressClass represents the class of the Ingress, referenced by the Ingress Spec. The `ingressclass.kubernetes.io/is-default-class` annotation can be used to indicate that an IngressClass should be considered default. When a single IngressClass resource has this annotation set to true, new Ingress resources without a class specified will be assigned this default class. */
    interface io$k8s$api$networking$v1$IngressClass {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$networking$v1$IngressClassSpec;
    }
    /** IngressClassList is a collection of IngressClasses. */
    interface io$k8s$api$networking$v1$IngressClassList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of IngressClasses. */
        items: Schemas.io$k8s$api$networking$v1$IngressClass[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** IngressClassParametersReference identifies an API object. This can be used to specify a cluster or namespace-scoped resource. */
    interface io$k8s$api$networking$v1$IngressClassParametersReference {
        /** apiGroup is the group for the resource being referenced. If APIGroup is not specified, the specified Kind must be in the core API group. For any other third-party types, APIGroup is required. */
        apiGroup?: string;
        /** kind is the type of resource being referenced. */
        kind: string;
        /** name is the name of resource being referenced. */
        name: string;
        /** namespace is the namespace of the resource being referenced. This field is required when scope is set to "Namespace" and must be unset when scope is set to "Cluster". */
        namespace?: string;
        /** scope represents if this refers to a cluster or namespace scoped resource. This may be set to "Cluster" (default) or "Namespace". */
        scope?: string;
    }
    /** IngressClassSpec provides information about the class of an Ingress. */
    interface io$k8s$api$networking$v1$IngressClassSpec {
        /** controller refers to the name of the controller that should handle this class. This allows for different "flavors" that are controlled by the same controller. For example, you may have different parameters for the same implementing controller. This should be specified as a domain-prefixed path no more than 250 characters in length, e.g. "acme.io/ingress-controller". This field is immutable. */
        controller?: string;
        parameters?: Schemas.io$k8s$api$networking$v1$IngressClassParametersReference;
    }
    /** IngressList is a collection of Ingress. */
    interface io$k8s$api$networking$v1$IngressList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of Ingress. */
        items: Schemas.io$k8s$api$networking$v1$Ingress[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** IngressLoadBalancerIngress represents the status of a load-balancer ingress point. */
    interface io$k8s$api$networking$v1$IngressLoadBalancerIngress {
        /** hostname is set for load-balancer ingress points that are DNS based. */
        hostname?: string;
        /** ip is set for load-balancer ingress points that are IP based. */
        ip?: string;
        /** ports provides information about the ports exposed by this LoadBalancer. */
        ports?: Schemas.io$k8s$api$networking$v1$IngressPortStatus[];
    }
    /** IngressLoadBalancerStatus represents the status of a load-balancer. */
    interface io$k8s$api$networking$v1$IngressLoadBalancerStatus {
        /** ingress is a list containing ingress points for the load-balancer. */
        ingress?: Schemas.io$k8s$api$networking$v1$IngressLoadBalancerIngress[];
    }
    /** IngressPortStatus represents the error condition of a service port */
    interface io$k8s$api$networking$v1$IngressPortStatus {
        /**
         * error is to record the problem with the service port The format of the error shall comply with the following rules: - built-in error values shall be specified in this file and those shall use
         *   CamelCase names
         * - cloud provider specific error values must have names that comply with the
         *   format foo.example.com/CamelCase.
         */
        error?: string;
        /** port is the port number of the ingress port. */
        port: number;
        /** protocol is the protocol of the ingress port. The supported values are: "TCP", "UDP", "SCTP" */
        protocol: string;
    }
    /** IngressRule represents the rules mapping the paths under a specified host to the related backend services. Incoming requests are first evaluated for a host match, then routed to the backend associated with the matching IngressRuleValue. */
    interface io$k8s$api$networking$v1$IngressRule {
        /**
         * host is the fully qualified domain name of a network host, as defined by RFC 3986. Note the following deviations from the "host" part of the URI as defined in RFC 3986: 1. IPs are not allowed. Currently an IngressRuleValue can only apply to
         *    the IP in the Spec of the parent Ingress.
         * 2. The `:` delimiter is not respected because ports are not allowed.
         * 	  Currently the port of an Ingress is implicitly :80 for http and
         * 	  :443 for https.
         * Both these may change in the future. Incoming requests are matched against the host before the IngressRuleValue. If the host is unspecified, the Ingress routes all traffic based on the specified IngressRuleValue.
         *
         * host can be "precise" which is a domain name without the terminating dot of a network host (e.g. "foo.bar.com") or "wildcard", which is a domain name prefixed with a single wildcard label (e.g. "*.foo.com"). The wildcard character '*' must appear by itself as the first DNS label and matches only a single label. You cannot have a wildcard label by itself (e.g. Host == "*"). Requests will be matched against the Host field in the following way: 1. If host is precise, the request matches this rule if the http host header is equal to Host. 2. If host is a wildcard, then the request matches this rule if the http host header is to equal to the suffix (removing the first label) of the wildcard rule.
         */
        host?: string;
        http?: Schemas.io$k8s$api$networking$v1$HTTPIngressRuleValue;
    }
    /** IngressServiceBackend references a Kubernetes Service as a Backend. */
    interface io$k8s$api$networking$v1$IngressServiceBackend {
        /** name is the referenced service. The service must exist in the same namespace as the Ingress object. */
        name: string;
        port?: Schemas.io$k8s$api$networking$v1$ServiceBackendPort;
    }
    /** IngressSpec describes the Ingress the user wishes to exist. */
    interface io$k8s$api$networking$v1$IngressSpec {
        defaultBackend?: Schemas.io$k8s$api$networking$v1$IngressBackend;
        /** ingressClassName is the name of an IngressClass cluster resource. Ingress controller implementations use this field to know whether they should be serving this Ingress resource, by a transitive connection (controller -> IngressClass -> Ingress resource). Although the `kubernetes.io/ingress.class` annotation (simple constant name) was never formally defined, it was widely supported by Ingress controllers to create a direct binding between Ingress controller and Ingress resources. Newly created Ingress resources should prefer using the field. However, even though the annotation is officially deprecated, for backwards compatibility reasons, ingress controllers should still honor that annotation if present. */
        ingressClassName?: string;
        /** rules is a list of host rules used to configure the Ingress. If unspecified, or no rule matches, all traffic is sent to the default backend. */
        rules?: Schemas.io$k8s$api$networking$v1$IngressRule[];
        /** tls represents the TLS configuration. Currently the Ingress only supports a single TLS port, 443. If multiple members of this list specify different hosts, they will be multiplexed on the same port according to the hostname specified through the SNI TLS extension, if the ingress controller fulfilling the ingress supports SNI. */
        tls?: Schemas.io$k8s$api$networking$v1$IngressTLS[];
    }
    /** IngressStatus describe the current state of the Ingress. */
    interface io$k8s$api$networking$v1$IngressStatus {
        loadBalancer?: Schemas.io$k8s$api$networking$v1$IngressLoadBalancerStatus;
    }
    /** IngressTLS describes the transport layer security associated with an ingress. */
    interface io$k8s$api$networking$v1$IngressTLS {
        /** hosts is a list of hosts included in the TLS certificate. The values in this list must match the name/s used in the tlsSecret. Defaults to the wildcard host setting for the loadbalancer controller fulfilling this Ingress, if left unspecified. */
        hosts?: string[];
        /** secretName is the name of the secret used to terminate TLS traffic on port 443. Field is left optional to allow TLS routing based on SNI hostname alone. If the SNI host in a listener conflicts with the "Host" header field used by an IngressRule, the SNI host is used for termination and value of the "Host" header is used for routing. */
        secretName?: string;
    }
    /** NetworkPolicy describes what network traffic is allowed for a set of Pods */
    interface io$k8s$api$networking$v1$NetworkPolicy {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$networking$v1$NetworkPolicySpec;
        status?: Schemas.io$k8s$api$networking$v1$NetworkPolicyStatus;
    }
    /** NetworkPolicyEgressRule describes a particular set of traffic that is allowed out of pods matched by a NetworkPolicySpec's podSelector. The traffic must match both ports and to. This type is beta-level in 1.8 */
    interface io$k8s$api$networking$v1$NetworkPolicyEgressRule {
        /** ports is a list of destination ports for outgoing traffic. Each item in this list is combined using a logical OR. If this field is empty or missing, this rule matches all ports (traffic not restricted by port). If this field is present and contains at least one item, then this rule allows traffic only if the traffic matches at least one port in the list. */
        ports?: Schemas.io$k8s$api$networking$v1$NetworkPolicyPort[];
        /** to is a list of destinations for outgoing traffic of pods selected for this rule. Items in this list are combined using a logical OR operation. If this field is empty or missing, this rule matches all destinations (traffic not restricted by destination). If this field is present and contains at least one item, this rule allows traffic only if the traffic matches at least one item in the to list. */
        to?: Schemas.io$k8s$api$networking$v1$NetworkPolicyPeer[];
    }
    /** NetworkPolicyIngressRule describes a particular set of traffic that is allowed to the pods matched by a NetworkPolicySpec's podSelector. The traffic must match both ports and from. */
    interface io$k8s$api$networking$v1$NetworkPolicyIngressRule {
        /** from is a list of sources which should be able to access the pods selected for this rule. Items in this list are combined using a logical OR operation. If this field is empty or missing, this rule matches all sources (traffic not restricted by source). If this field is present and contains at least one item, this rule allows traffic only if the traffic matches at least one item in the from list. */
        from?: Schemas.io$k8s$api$networking$v1$NetworkPolicyPeer[];
        /** ports is a list of ports which should be made accessible on the pods selected for this rule. Each item in this list is combined using a logical OR. If this field is empty or missing, this rule matches all ports (traffic not restricted by port). If this field is present and contains at least one item, then this rule allows traffic only if the traffic matches at least one port in the list. */
        ports?: Schemas.io$k8s$api$networking$v1$NetworkPolicyPort[];
    }
    /** NetworkPolicyList is a list of NetworkPolicy objects. */
    interface io$k8s$api$networking$v1$NetworkPolicyList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is a list of schema objects. */
        items: Schemas.io$k8s$api$networking$v1$NetworkPolicy[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** NetworkPolicyPeer describes a peer to allow traffic to/from. Only certain combinations of fields are allowed */
    interface io$k8s$api$networking$v1$NetworkPolicyPeer {
        ipBlock?: Schemas.io$k8s$api$networking$v1$IPBlock;
        namespaceSelector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        podSelector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
    }
    /** NetworkPolicyPort describes a port to allow traffic on */
    interface io$k8s$api$networking$v1$NetworkPolicyPort {
        /** endPort indicates that the range of ports from port to endPort if set, inclusive, should be allowed by the policy. This field cannot be defined if the port field is not defined or if the port field is defined as a named (string) port. The endPort must be equal or greater than port. */
        endPort?: number;
        port?: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
        /** protocol represents the protocol (TCP, UDP, or SCTP) which traffic must match. If not specified, this field defaults to TCP. */
        protocol?: string;
    }
    /** NetworkPolicySpec provides the specification of a NetworkPolicy */
    interface io$k8s$api$networking$v1$NetworkPolicySpec {
        /** egress is a list of egress rules to be applied to the selected pods. Outgoing traffic is allowed if there are no NetworkPolicies selecting the pod (and cluster policy otherwise allows the traffic), OR if the traffic matches at least one egress rule across all of the NetworkPolicy objects whose podSelector matches the pod. If this field is empty then this NetworkPolicy limits all outgoing traffic (and serves solely to ensure that the pods it selects are isolated by default). This field is beta-level in 1.8 */
        egress?: Schemas.io$k8s$api$networking$v1$NetworkPolicyEgressRule[];
        /** ingress is a list of ingress rules to be applied to the selected pods. Traffic is allowed to a pod if there are no NetworkPolicies selecting the pod (and cluster policy otherwise allows the traffic), OR if the traffic source is the pod's local node, OR if the traffic matches at least one ingress rule across all of the NetworkPolicy objects whose podSelector matches the pod. If this field is empty then this NetworkPolicy does not allow any traffic (and serves solely to ensure that the pods it selects are isolated by default) */
        ingress?: Schemas.io$k8s$api$networking$v1$NetworkPolicyIngressRule[];
        podSelector: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        /** policyTypes is a list of rule types that the NetworkPolicy relates to. Valid options are ["Ingress"], ["Egress"], or ["Ingress", "Egress"]. If this field is not specified, it will default based on the existence of ingress or egress rules; policies that contain an egress section are assumed to affect egress, and all policies (whether or not they contain an ingress section) are assumed to affect ingress. If you want to write an egress-only policy, you must explicitly specify policyTypes [ "Egress" ]. Likewise, if you want to write a policy that specifies that no egress is allowed, you must specify a policyTypes value that include "Egress" (since such a policy would not include an egress section and would otherwise default to just [ "Ingress" ]). This field is beta-level in 1.8 */
        policyTypes?: string[];
    }
    /** NetworkPolicyStatus describes the current state of the NetworkPolicy. */
    interface io$k8s$api$networking$v1$NetworkPolicyStatus {
        /** conditions holds an array of metav1.Condition that describe the state of the NetworkPolicy. Current service state */
        conditions?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Condition[];
    }
    /** ServiceBackendPort is the service port being referenced. */
    interface io$k8s$api$networking$v1$ServiceBackendPort {
        /** name is the name of the port on the Service. This is a mutually exclusive setting with "Number". */
        name?: string;
        /** number is the numerical port number (e.g. 80) on the Service. This is a mutually exclusive setting with "Name". */
        number?: number;
    }
    /** ClusterCIDR represents a single configuration for per-Node Pod CIDR allocations when the MultiCIDRRangeAllocator is enabled (see the config for kube-controller-manager).  A cluster may have any number of ClusterCIDR resources, all of which will be considered when allocating a CIDR for a Node.  A ClusterCIDR is eligible to be used for a given Node when the node selector matches the node in question and has free CIDRs to allocate.  In case of multiple matching ClusterCIDR resources, the allocator will attempt to break ties using internal heuristics, but any ClusterCIDR whose node selector matches the Node may be used. */
    interface io$k8s$api$networking$v1alpha1$ClusterCIDR {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDRSpec;
    }
    /** ClusterCIDRList contains a list of ClusterCIDR. */
    interface io$k8s$api$networking$v1alpha1$ClusterCIDRList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of ClusterCIDRs. */
        items: Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ClusterCIDRSpec defines the desired state of ClusterCIDR. */
    interface io$k8s$api$networking$v1alpha1$ClusterCIDRSpec {
        /** ipv4 defines an IPv4 IP block in CIDR notation(e.g. "10.0.0.0/8"). At least one of ipv4 and ipv6 must be specified. This field is immutable. */
        ipv4?: string;
        /** ipv6 defines an IPv6 IP block in CIDR notation(e.g. "2001:db8::/64"). At least one of ipv4 and ipv6 must be specified. This field is immutable. */
        ipv6?: string;
        nodeSelector?: Schemas.io$k8s$api$core$v1$NodeSelector;
        /** perNodeHostBits defines the number of host bits to be configured per node. A subnet mask determines how much of the address is used for network bits and host bits. For example an IPv4 address of 192.168.0.0/24, splits the address into 24 bits for the network portion and 8 bits for the host portion. To allocate 256 IPs, set this field to 8 (a /24 mask for IPv4 or a /120 for IPv6). Minimum value is 4 (16 IPs). This field is immutable. */
        perNodeHostBits: number;
    }
    /** IPAddress represents a single IP of a single IP Family. The object is designed to be used by APIs that operate on IP addresses. The object is used by the Service core API for allocation of IP addresses. An IP address can be represented in different formats, to guarantee the uniqueness of the IP, the name of the object is the IP address in canonical format, four decimal digits separated by dots suppressing leading zeros for IPv4 and the representation defined by RFC 5952 for IPv6. Valid: 192.168.1.5 or 2001:db8::1 or 2001:db8:aaaa:bbbb:cccc:dddd:eeee:1 Invalid: 10.01.2.3 or 2001:db8:0:0:0::1 */
    interface io$k8s$api$networking$v1alpha1$IPAddress {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$networking$v1alpha1$IPAddressSpec;
    }
    /** IPAddressList contains a list of IPAddress. */
    interface io$k8s$api$networking$v1alpha1$IPAddressList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of IPAddresses. */
        items: Schemas.io$k8s$api$networking$v1alpha1$IPAddress[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** IPAddressSpec describe the attributes in an IP Address. */
    interface io$k8s$api$networking$v1alpha1$IPAddressSpec {
        parentRef?: Schemas.io$k8s$api$networking$v1alpha1$ParentReference;
    }
    /** ParentReference describes a reference to a parent object. */
    interface io$k8s$api$networking$v1alpha1$ParentReference {
        /** Group is the group of the object being referenced. */
        group?: string;
        /** Name is the name of the object being referenced. */
        name?: string;
        /** Namespace is the namespace of the object being referenced. */
        namespace?: string;
        /** Resource is the resource of the object being referenced. */
        resource?: string;
        /** UID is the uid of the object being referenced. */
        uid?: string;
    }
    /** Overhead structure represents the resource overhead associated with running a pod. */
    interface io$k8s$api$node$v1$Overhead {
        /** podFixed represents the fixed resource overhead associated with running a pod. */
        podFixed?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        };
    }
    /** RuntimeClass defines a class of container runtime supported in the cluster. The RuntimeClass is used to determine which container runtime is used to run all containers in a pod. RuntimeClasses are manually defined by a user or cluster provisioner, and referenced in the PodSpec. The Kubelet is responsible for resolving the RuntimeClassName reference before running the pod.  For more details, see https://kubernetes.io/docs/concepts/containers/runtime-class/ */
    interface io$k8s$api$node$v1$RuntimeClass {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** handler specifies the underlying runtime and configuration that the CRI implementation will use to handle pods of this class. The possible values are specific to the node & CRI configuration.  It is assumed that all handlers are available on every node, and handlers of the same name are equivalent on every node. For example, a handler called "runc" might specify that the runc OCI runtime (using native Linux containers) will be used to run the containers in a pod. The Handler must be lowercase, conform to the DNS Label (RFC 1123) requirements, and is immutable. */
        handler: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        overhead?: Schemas.io$k8s$api$node$v1$Overhead;
        scheduling?: Schemas.io$k8s$api$node$v1$Scheduling;
    }
    /** RuntimeClassList is a list of RuntimeClass objects. */
    interface io$k8s$api$node$v1$RuntimeClassList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is a list of schema objects. */
        items: Schemas.io$k8s$api$node$v1$RuntimeClass[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** Scheduling specifies the scheduling constraints for nodes supporting a RuntimeClass. */
    interface io$k8s$api$node$v1$Scheduling {
        /** nodeSelector lists labels that must be present on nodes that support this RuntimeClass. Pods using this RuntimeClass can only be scheduled to a node matched by this selector. The RuntimeClass nodeSelector is merged with a pod's existing nodeSelector. Any conflicts will cause the pod to be rejected in admission. */
        nodeSelector?: {
            [key: string]: string;
        };
        /** tolerations are appended (excluding duplicates) to pods running with this RuntimeClass during admission, effectively unioning the set of nodes tolerated by the pod and the RuntimeClass. */
        tolerations?: Schemas.io$k8s$api$core$v1$Toleration[];
    }
    /** Eviction evicts a pod from its node subject to certain policies and safety constraints. This is a subresource of Pod.  A request to cause such an eviction is created by POSTing to .../pods/<pod name>/evictions. */
    interface io$k8s$api$policy$v1$Eviction {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        deleteOptions?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
    }
    /** PodDisruptionBudget is an object to define the max disruption that can be caused to a collection of pods */
    interface io$k8s$api$policy$v1$PodDisruptionBudget {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetSpec;
        status?: Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetStatus;
    }
    /** PodDisruptionBudgetList is a collection of PodDisruptionBudgets. */
    interface io$k8s$api$policy$v1$PodDisruptionBudgetList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is a list of PodDisruptionBudgets */
        items: Schemas.io$k8s$api$policy$v1$PodDisruptionBudget[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** PodDisruptionBudgetSpec is a description of a PodDisruptionBudget. */
    interface io$k8s$api$policy$v1$PodDisruptionBudgetSpec {
        maxUnavailable?: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
        minAvailable?: Schemas.io$k8s$apimachinery$pkg$util$intstr$IntOrString;
        selector?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        /**
         * UnhealthyPodEvictionPolicy defines the criteria for when unhealthy pods should be considered for eviction. Current implementation considers healthy pods, as pods that have status.conditions item with type="Ready",status="True".
         *
         * Valid policies are IfHealthyBudget and AlwaysAllow. If no policy is specified, the default behavior will be used, which corresponds to the IfHealthyBudget policy.
         *
         * IfHealthyBudget policy means that running pods (status.phase="Running"), but not yet healthy can be evicted only if the guarded application is not disrupted (status.currentHealthy is at least equal to status.desiredHealthy). Healthy pods will be subject to the PDB for eviction.
         *
         * AlwaysAllow policy means that all running pods (status.phase="Running"), but not yet healthy are considered disrupted and can be evicted regardless of whether the criteria in a PDB is met. This means perspective running pods of a disrupted application might not get a chance to become healthy. Healthy pods will be subject to the PDB for eviction.
         *
         * Additional policies may be added in the future. Clients making eviction decisions should disallow eviction of unhealthy pods if they encounter an unrecognized policy in this field.
         *
         * This field is beta-level. The eviction API uses this field when the feature gate PDBUnhealthyPodEvictionPolicy is enabled (enabled by default).
         */
        unhealthyPodEvictionPolicy?: string;
    }
    /** PodDisruptionBudgetStatus represents information about the status of a PodDisruptionBudget. Status may trail the actual state of a system. */
    interface io$k8s$api$policy$v1$PodDisruptionBudgetStatus {
        /**
         * Conditions contain conditions for PDB. The disruption controller sets the DisruptionAllowed condition. The following are known values for the reason field (additional reasons could be added in the future): - SyncFailed: The controller encountered an error and wasn't able to compute
         *               the number of allowed disruptions. Therefore no disruptions are
         *               allowed and the status of the condition will be False.
         * - InsufficientPods: The number of pods are either at or below the number
         *                     required by the PodDisruptionBudget. No disruptions are
         *                     allowed and the status of the condition will be False.
         * - SufficientPods: There are more pods than required by the PodDisruptionBudget.
         *                   The condition will be True, and the number of allowed
         *                   disruptions are provided by the disruptionsAllowed property.
         */
        conditions?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Condition[];
        /** current number of healthy pods */
        currentHealthy: number;
        /** minimum desired number of healthy pods */
        desiredHealthy: number;
        /** DisruptedPods contains information about pods whose eviction was processed by the API server eviction subresource handler but has not yet been observed by the PodDisruptionBudget controller. A pod will be in this map from the time when the API server processed the eviction request to the time when the pod is seen by PDB controller as having been marked for deletion (or after a timeout). The key in the map is the name of the pod and the value is the time when the API server processed the eviction request. If the deletion didn't occur and a pod is still there it will be removed from the list automatically by PodDisruptionBudget controller after some time. If everything goes smooth this map should be empty for the most of the time. Large number of entries in the map may indicate problems with pod deletions. */
        disruptedPods?: {
            [key: string]: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        };
        /** Number of pod disruptions that are currently allowed. */
        disruptionsAllowed: number;
        /** total number of pods counted by this disruption budget */
        expectedPods: number;
        /** Most recent generation observed when updating this PDB status. DisruptionsAllowed and other status information is valid only if observedGeneration equals to PDB's object generation. */
        observedGeneration?: number;
    }
    /** AggregationRule describes how to locate ClusterRoles to aggregate into the ClusterRole */
    interface io$k8s$api$rbac$v1$AggregationRule {
        /** ClusterRoleSelectors holds a list of selectors which will be used to find ClusterRoles and create the rules. If any of the selectors match, then the ClusterRole's permissions will be added */
        clusterRoleSelectors?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector[];
    }
    /** ClusterRole is a cluster level, logical grouping of PolicyRules that can be referenced as a unit by a RoleBinding or ClusterRoleBinding. */
    interface io$k8s$api$rbac$v1$ClusterRole {
        aggregationRule?: Schemas.io$k8s$api$rbac$v1$AggregationRule;
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** Rules holds all the PolicyRules for this ClusterRole */
        rules?: Schemas.io$k8s$api$rbac$v1$PolicyRule[];
    }
    /** ClusterRoleBinding references a ClusterRole, but not contain it.  It can reference a ClusterRole in the global namespace, and adds who information via Subject. */
    interface io$k8s$api$rbac$v1$ClusterRoleBinding {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        roleRef: Schemas.io$k8s$api$rbac$v1$RoleRef;
        /** Subjects holds references to the objects the role applies to. */
        subjects?: Schemas.io$k8s$api$rbac$v1$Subject[];
    }
    /** ClusterRoleBindingList is a collection of ClusterRoleBindings */
    interface io$k8s$api$rbac$v1$ClusterRoleBindingList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is a list of ClusterRoleBindings */
        items: Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ClusterRoleList is a collection of ClusterRoles */
    interface io$k8s$api$rbac$v1$ClusterRoleList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is a list of ClusterRoles */
        items: Schemas.io$k8s$api$rbac$v1$ClusterRole[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** PolicyRule holds information that describes a policy rule, but does not contain information about who the rule applies to or which namespace the rule applies to. */
    interface io$k8s$api$rbac$v1$PolicyRule {
        /** APIGroups is the name of the APIGroup that contains the resources.  If multiple API groups are specified, any action requested against one of the enumerated resources in any API group will be allowed. "" represents the core API group and "*" represents all API groups. */
        apiGroups?: string[];
        /** NonResourceURLs is a set of partial urls that a user should have access to.  *s are allowed, but only as the full, final step in the path Since non-resource URLs are not namespaced, this field is only applicable for ClusterRoles referenced from a ClusterRoleBinding. Rules can either apply to API resources (such as "pods" or "secrets") or non-resource URL paths (such as "/api"),  but not both. */
        nonResourceURLs?: string[];
        /** ResourceNames is an optional white list of names that the rule applies to.  An empty set means that everything is allowed. */
        resourceNames?: string[];
        /** Resources is a list of resources this rule applies to. '*' represents all resources. */
        resources?: string[];
        /** Verbs is a list of Verbs that apply to ALL the ResourceKinds contained in this rule. '*' represents all verbs. */
        verbs: string[];
    }
    /** Role is a namespaced, logical grouping of PolicyRules that can be referenced as a unit by a RoleBinding. */
    interface io$k8s$api$rbac$v1$Role {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** Rules holds all the PolicyRules for this Role */
        rules?: Schemas.io$k8s$api$rbac$v1$PolicyRule[];
    }
    /** RoleBinding references a role, but does not contain it.  It can reference a Role in the same namespace or a ClusterRole in the global namespace. It adds who information via Subjects and namespace information by which namespace it exists in.  RoleBindings in a given namespace only have effect in that namespace. */
    interface io$k8s$api$rbac$v1$RoleBinding {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        roleRef: Schemas.io$k8s$api$rbac$v1$RoleRef;
        /** Subjects holds references to the objects the role applies to. */
        subjects?: Schemas.io$k8s$api$rbac$v1$Subject[];
    }
    /** RoleBindingList is a collection of RoleBindings */
    interface io$k8s$api$rbac$v1$RoleBindingList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is a list of RoleBindings */
        items: Schemas.io$k8s$api$rbac$v1$RoleBinding[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** RoleList is a collection of Roles */
    interface io$k8s$api$rbac$v1$RoleList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is a list of Roles */
        items: Schemas.io$k8s$api$rbac$v1$Role[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** RoleRef contains information that points to the role being used */
    interface io$k8s$api$rbac$v1$RoleRef {
        /** APIGroup is the group for the resource being referenced */
        apiGroup: string;
        /** Kind is the type of resource being referenced */
        kind: string;
        /** Name is the name of resource being referenced */
        name: string;
    }
    /** Subject contains a reference to the object or user identities a role binding applies to.  This can either hold a direct API object reference, or a value for non-objects such as user and group names. */
    interface io$k8s$api$rbac$v1$Subject {
        /** APIGroup holds the API group of the referenced subject. Defaults to "" for ServiceAccount subjects. Defaults to "rbac.authorization.k8s.io" for User and Group subjects. */
        apiGroup?: string;
        /** Kind of object being referenced. Values defined by this API group are "User", "Group", and "ServiceAccount". If the Authorizer does not recognized the kind value, the Authorizer should report an error. */
        kind: string;
        /** Name of the object being referenced. */
        name: string;
        /** Namespace of the referenced object.  If the object kind is non-namespace, such as "User" or "Group", and this value is not empty the Authorizer should report an error. */
        namespace?: string;
    }
    /** AllocationResult contains attributes of an allocated resource. */
    interface io$k8s$api$resource$v1alpha2$AllocationResult {
        availableOnNodes?: Schemas.io$k8s$api$core$v1$NodeSelector;
        /**
         * ResourceHandles contain the state associated with an allocation that should be maintained throughout the lifetime of a claim. Each ResourceHandle contains data that should be passed to a specific kubelet plugin once it lands on a node. This data is returned by the driver after a successful allocation and is opaque to Kubernetes. Driver documentation may explain to users how to interpret this data if needed.
         *
         * Setting this field is optional. It has a maximum size of 32 entries. If null (or empty), it is assumed this allocation will be processed by a single kubelet plugin with no ResourceHandle data attached. The name of the kubelet plugin invoked will match the DriverName set in the ResourceClaimStatus this AllocationResult is embedded in.
         */
        resourceHandles?: Schemas.io$k8s$api$resource$v1alpha2$ResourceHandle[];
        /** Shareable determines whether the resource supports more than one consumer at a time. */
        shareable?: boolean;
    }
    /**
     * PodSchedulingContext objects hold information that is needed to schedule a Pod with ResourceClaims that use "WaitForFirstConsumer" allocation mode.
     *
     * This is an alpha type and requires enabling the DynamicResourceAllocation feature gate.
     */
    interface io$k8s$api$resource$v1alpha2$PodSchedulingContext {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContextSpec;
        status?: Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContextStatus;
    }
    /** PodSchedulingContextList is a collection of Pod scheduling objects. */
    interface io$k8s$api$resource$v1alpha2$PodSchedulingContextList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is the list of PodSchedulingContext objects. */
        items: Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** PodSchedulingContextSpec describes where resources for the Pod are needed. */
    interface io$k8s$api$resource$v1alpha2$PodSchedulingContextSpec {
        /**
         * PotentialNodes lists nodes where the Pod might be able to run.
         *
         * The size of this field is limited to 128. This is large enough for many clusters. Larger clusters may need more attempts to find a node that suits all pending resources. This may get increased in the future, but not reduced.
         */
        potentialNodes?: string[];
        /** SelectedNode is the node for which allocation of ResourceClaims that are referenced by the Pod and that use "WaitForFirstConsumer" allocation is to be attempted. */
        selectedNode?: string;
    }
    /** PodSchedulingContextStatus describes where resources for the Pod can be allocated. */
    interface io$k8s$api$resource$v1alpha2$PodSchedulingContextStatus {
        /** ResourceClaims describes resource availability for each pod.spec.resourceClaim entry where the corresponding ResourceClaim uses "WaitForFirstConsumer" allocation mode. */
        resourceClaims?: Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimSchedulingStatus[];
    }
    /**
     * ResourceClaim describes which resources are needed by a resource consumer. Its status tracks whether the resource has been allocated and what the resulting attributes are.
     *
     * This is an alpha type and requires enabling the DynamicResourceAllocation feature gate.
     */
    interface io$k8s$api$resource$v1alpha2$ResourceClaim {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimSpec;
        status?: Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimStatus;
    }
    /** ResourceClaimConsumerReference contains enough information to let you locate the consumer of a ResourceClaim. The user must be a resource in the same namespace as the ResourceClaim. */
    interface io$k8s$api$resource$v1alpha2$ResourceClaimConsumerReference {
        /** APIGroup is the group for the resource being referenced. It is empty for the core API. This matches the group in the APIVersion that is used when creating the resources. */
        apiGroup?: string;
        /** Name is the name of resource being referenced. */
        name: string;
        /** Resource is the type of resource being referenced, for example "pods". */
        resource: string;
        /** UID identifies exactly one incarnation of the resource. */
        uid: string;
    }
    /** ResourceClaimList is a collection of claims. */
    interface io$k8s$api$resource$v1alpha2$ResourceClaimList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is the list of resource claims. */
        items: Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ResourceClaimParametersReference contains enough information to let you locate the parameters for a ResourceClaim. The object must be in the same namespace as the ResourceClaim. */
    interface io$k8s$api$resource$v1alpha2$ResourceClaimParametersReference {
        /** APIGroup is the group for the resource being referenced. It is empty for the core API. This matches the group in the APIVersion that is used when creating the resources. */
        apiGroup?: string;
        /** Kind is the type of resource being referenced. This is the same value as in the parameter object's metadata, for example "ConfigMap". */
        kind: string;
        /** Name is the name of resource being referenced. */
        name: string;
    }
    /** ResourceClaimSchedulingStatus contains information about one particular ResourceClaim with "WaitForFirstConsumer" allocation mode. */
    interface io$k8s$api$resource$v1alpha2$ResourceClaimSchedulingStatus {
        /** Name matches the pod.spec.resourceClaims[*].Name field. */
        name?: string;
        /**
         * UnsuitableNodes lists nodes that the ResourceClaim cannot be allocated for.
         *
         * The size of this field is limited to 128, the same as for PodSchedulingSpec.PotentialNodes. This may get increased in the future, but not reduced.
         */
        unsuitableNodes?: string[];
    }
    /** ResourceClaimSpec defines how a resource is to be allocated. */
    interface io$k8s$api$resource$v1alpha2$ResourceClaimSpec {
        /** Allocation can start immediately or when a Pod wants to use the resource. "WaitForFirstConsumer" is the default. */
        allocationMode?: string;
        parametersRef?: Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimParametersReference;
        /** ResourceClassName references the driver and additional parameters via the name of a ResourceClass that was created as part of the driver deployment. */
        resourceClassName: string;
    }
    /** ResourceClaimStatus tracks whether the resource has been allocated and what the resulting attributes are. */
    interface io$k8s$api$resource$v1alpha2$ResourceClaimStatus {
        allocation?: Schemas.io$k8s$api$resource$v1alpha2$AllocationResult;
        /**
         * DeallocationRequested indicates that a ResourceClaim is to be deallocated.
         *
         * The driver then must deallocate this claim and reset the field together with clearing the Allocation field.
         *
         * While DeallocationRequested is set, no new consumers may be added to ReservedFor.
         */
        deallocationRequested?: boolean;
        /** DriverName is a copy of the driver name from the ResourceClass at the time when allocation started. */
        driverName?: string;
        /**
         * ReservedFor indicates which entities are currently allowed to use the claim. A Pod which references a ResourceClaim which is not reserved for that Pod will not be started.
         *
         * There can be at most 32 such reservations. This may get increased in the future, but not reduced.
         */
        reservedFor?: Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimConsumerReference[];
    }
    /** ResourceClaimTemplate is used to produce ResourceClaim objects. */
    interface io$k8s$api$resource$v1alpha2$ResourceClaimTemplate {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplateSpec;
    }
    /** ResourceClaimTemplateList is a collection of claim templates. */
    interface io$k8s$api$resource$v1alpha2$ResourceClaimTemplateList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is the list of resource claim templates. */
        items: Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ResourceClaimTemplateSpec contains the metadata and fields for a ResourceClaim. */
    interface io$k8s$api$resource$v1alpha2$ResourceClaimTemplateSpec {
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimSpec;
    }
    /**
     * ResourceClass is used by administrators to influence how resources are allocated.
     *
     * This is an alpha type and requires enabling the DynamicResourceAllocation feature gate.
     */
    interface io$k8s$api$resource$v1alpha2$ResourceClass {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /**
         * DriverName defines the name of the dynamic resource driver that is used for allocation of a ResourceClaim that uses this class.
         *
         * Resource drivers have a unique name in forward domain order (acme.example.com).
         */
        driverName: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        parametersRef?: Schemas.io$k8s$api$resource$v1alpha2$ResourceClassParametersReference;
        suitableNodes?: Schemas.io$k8s$api$core$v1$NodeSelector;
    }
    /** ResourceClassList is a collection of classes. */
    interface io$k8s$api$resource$v1alpha2$ResourceClassList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is the list of resource classes. */
        items: Schemas.io$k8s$api$resource$v1alpha2$ResourceClass[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** ResourceClassParametersReference contains enough information to let you locate the parameters for a ResourceClass. */
    interface io$k8s$api$resource$v1alpha2$ResourceClassParametersReference {
        /** APIGroup is the group for the resource being referenced. It is empty for the core API. This matches the group in the APIVersion that is used when creating the resources. */
        apiGroup?: string;
        /** Kind is the type of resource being referenced. This is the same value as in the parameter object's metadata. */
        kind: string;
        /** Name is the name of resource being referenced. */
        name: string;
        /** Namespace that contains the referenced resource. Must be empty for cluster-scoped resources and non-empty for namespaced resources. */
        namespace?: string;
    }
    /** ResourceHandle holds opaque resource data for processing by a specific kubelet plugin. */
    interface io$k8s$api$resource$v1alpha2$ResourceHandle {
        /**
         * Data contains the opaque data associated with this ResourceHandle. It is set by the controller component of the resource driver whose name matches the DriverName set in the ResourceClaimStatus this ResourceHandle is embedded in. It is set at allocation time and is intended for processing by the kubelet plugin whose name matches the DriverName set in this ResourceHandle.
         *
         * The maximum size of this field is 16KiB. This may get increased in the future, but not reduced.
         */
        data?: string;
        /** DriverName specifies the name of the resource driver whose kubelet plugin should be invoked to process this ResourceHandle's data once it lands on a node. This may differ from the DriverName set in ResourceClaimStatus this ResourceHandle is embedded in. */
        driverName?: string;
    }
    /** PriorityClass defines mapping from a priority class name to the priority integer value. The value can be any valid integer. */
    interface io$k8s$api$scheduling$v1$PriorityClass {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** description is an arbitrary string that usually provides guidelines on when this priority class should be used. */
        description?: string;
        /** globalDefault specifies whether this PriorityClass should be considered as the default priority for pods that do not have any priority class. Only one PriorityClass can be marked as `globalDefault`. However, if more than one PriorityClasses exists with their `globalDefault` field set to true, the smallest value of such global default PriorityClasses will be used as the default priority. */
        globalDefault?: boolean;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** preemptionPolicy is the Policy for preempting pods with lower priority. One of Never, PreemptLowerPriority. Defaults to PreemptLowerPriority if unset. */
        preemptionPolicy?: string;
        /** value represents the integer value of this priority class. This is the actual priority that pods receive when they have the name of this class in their pod spec. */
        value: number;
    }
    /** PriorityClassList is a collection of priority classes. */
    interface io$k8s$api$scheduling$v1$PriorityClassList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of PriorityClasses */
        items: Schemas.io$k8s$api$scheduling$v1$PriorityClass[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** CSIDriver captures information about a Container Storage Interface (CSI) volume driver deployed on the cluster. Kubernetes attach detach controller uses this object to determine whether attach is required. Kubelet uses this object to determine whether pod information needs to be passed on mount. CSIDriver objects are non-namespaced. */
    interface io$k8s$api$storage$v1$CSIDriver {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$storage$v1$CSIDriverSpec;
    }
    /** CSIDriverList is a collection of CSIDriver objects. */
    interface io$k8s$api$storage$v1$CSIDriverList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of CSIDriver */
        items: Schemas.io$k8s$api$storage$v1$CSIDriver[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** CSIDriverSpec is the specification of a CSIDriver. */
    interface io$k8s$api$storage$v1$CSIDriverSpec {
        /**
         * attachRequired indicates this CSI volume driver requires an attach operation (because it implements the CSI ControllerPublishVolume() method), and that the Kubernetes attach detach controller should call the attach volume interface which checks the volumeattachment status and waits until the volume is attached before proceeding to mounting. The CSI external-attacher coordinates with CSI volume driver and updates the volumeattachment status when the attach operation is complete. If the CSIDriverRegistry feature gate is enabled and the value is specified to false, the attach operation will be skipped. Otherwise the attach operation will be called.
         *
         * This field is immutable.
         */
        attachRequired?: boolean;
        /**
         * fsGroupPolicy defines if the underlying volume supports changing ownership and permission of the volume before being mounted. Refer to the specific FSGroupPolicy values for additional details.
         *
         * This field is immutable.
         *
         * Defaults to ReadWriteOnceWithFSType, which will examine each volume to determine if Kubernetes should modify ownership and permissions of the volume. With the default policy the defined fsGroup will only be applied if a fstype is defined and the volume's access mode contains ReadWriteOnce.
         */
        fsGroupPolicy?: string;
        /**
         * podInfoOnMount indicates this CSI volume driver requires additional pod information (like podName, podUID, etc.) during mount operations, if set to true. If set to false, pod information will not be passed on mount. Default is false.
         *
         * The CSI driver specifies podInfoOnMount as part of driver deployment. If true, Kubelet will pass pod information as VolumeContext in the CSI NodePublishVolume() calls. The CSI driver is responsible for parsing and validating the information passed in as VolumeContext.
         *
         * The following VolumeConext will be passed if podInfoOnMount is set to true. This list might grow, but the prefix will be used. "csi.storage.k8s.io/pod.name": pod.Name "csi.storage.k8s.io/pod.namespace": pod.Namespace "csi.storage.k8s.io/pod.uid": string(pod.UID) "csi.storage.k8s.io/ephemeral": "true" if the volume is an ephemeral inline volume
         *                                 defined by a CSIVolumeSource, otherwise "false"
         *
         * "csi.storage.k8s.io/ephemeral" is a new feature in Kubernetes 1.16. It is only required for drivers which support both the "Persistent" and "Ephemeral" VolumeLifecycleMode. Other drivers can leave pod info disabled and/or ignore this field. As Kubernetes 1.15 doesn't support this field, drivers can only support one mode when deployed on such a cluster and the deployment determines which mode that is, for example via a command line parameter of the driver.
         *
         * This field is immutable.
         */
        podInfoOnMount?: boolean;
        /**
         * requiresRepublish indicates the CSI driver wants `NodePublishVolume` being periodically called to reflect any possible change in the mounted volume. This field defaults to false.
         *
         * Note: After a successful initial NodePublishVolume call, subsequent calls to NodePublishVolume should only update the contents of the volume. New mount points will not be seen by a running container.
         */
        requiresRepublish?: boolean;
        /**
         * seLinuxMount specifies if the CSI driver supports "-o context" mount option.
         *
         * When "true", the CSI driver must ensure that all volumes provided by this CSI driver can be mounted separately with different `-o context` options. This is typical for storage backends that provide volumes as filesystems on block devices or as independent shared volumes. Kubernetes will call NodeStage / NodePublish with "-o context=xyz" mount option when mounting a ReadWriteOncePod volume used in Pod that has explicitly set SELinux context. In the future, it may be expanded to other volume AccessModes. In any case, Kubernetes will ensure that the volume is mounted only with a single SELinux context.
         *
         * When "false", Kubernetes won't pass any special SELinux mount options to the driver. This is typical for volumes that represent subdirectories of a bigger shared filesystem.
         *
         * Default is "false".
         */
        seLinuxMount?: boolean;
        /**
         * storageCapacity indicates that the CSI volume driver wants pod scheduling to consider the storage capacity that the driver deployment will report by creating CSIStorageCapacity objects with capacity information, if set to true.
         *
         * The check can be enabled immediately when deploying a driver. In that case, provisioning new volumes with late binding will pause until the driver deployment has published some suitable CSIStorageCapacity object.
         *
         * Alternatively, the driver can be deployed with the field unset or false and it can be flipped later when storage capacity information has been published.
         *
         * This field was immutable in Kubernetes <= 1.22 and now is mutable.
         */
        storageCapacity?: boolean;
        /**
         * tokenRequests indicates the CSI driver needs pods' service account tokens it is mounting volume for to do necessary authentication. Kubelet will pass the tokens in VolumeContext in the CSI NodePublishVolume calls. The CSI driver should parse and validate the following VolumeContext: "csi.storage.k8s.io/serviceAccount.tokens": {
         *   "<audience>": {
         *     "token": <token>,
         *     "expirationTimestamp": <expiration timestamp in RFC3339>,
         *   },
         *   ...
         * }
         *
         * Note: Audience in each TokenRequest should be different and at most one token is empty string. To receive a new token after expiry, RequiresRepublish can be used to trigger NodePublishVolume periodically.
         */
        tokenRequests?: Schemas.io$k8s$api$storage$v1$TokenRequest[];
        /**
         * volumeLifecycleModes defines what kind of volumes this CSI volume driver supports. The default if the list is empty is "Persistent", which is the usage defined by the CSI specification and implemented in Kubernetes via the usual PV/PVC mechanism.
         *
         * The other mode is "Ephemeral". In this mode, volumes are defined inline inside the pod spec with CSIVolumeSource and their lifecycle is tied to the lifecycle of that pod. A driver has to be aware of this because it is only going to get a NodePublishVolume call for such a volume.
         *
         * For more information about implementing this mode, see https://kubernetes-csi.github.io/docs/ephemeral-local-volumes.html A driver can support one or more of these modes and more modes may be added in the future.
         *
         * This field is beta. This field is immutable.
         */
        volumeLifecycleModes?: string[];
    }
    /** CSINode holds information about all CSI drivers installed on a node. CSI drivers do not need to create the CSINode object directly. As long as they use the node-driver-registrar sidecar container, the kubelet will automatically populate the CSINode object for the CSI driver as part of kubelet plugin registration. CSINode has the same name as a node. If the object is missing, it means either there are no CSI Drivers available on the node, or the Kubelet version is low enough that it doesn't create this object. CSINode has an OwnerReference that points to the corresponding node object. */
    interface io$k8s$api$storage$v1$CSINode {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$storage$v1$CSINodeSpec;
    }
    /** CSINodeDriver holds information about the specification of one CSI driver installed on a node */
    interface io$k8s$api$storage$v1$CSINodeDriver {
        allocatable?: Schemas.io$k8s$api$storage$v1$VolumeNodeResources;
        /** name represents the name of the CSI driver that this object refers to. This MUST be the same name returned by the CSI GetPluginName() call for that driver. */
        name: string;
        /** nodeID of the node from the driver point of view. This field enables Kubernetes to communicate with storage systems that do not share the same nomenclature for nodes. For example, Kubernetes may refer to a given node as "node1", but the storage system may refer to the same node as "nodeA". When Kubernetes issues a command to the storage system to attach a volume to a specific node, it can use this field to refer to the node name using the ID that the storage system will understand, e.g. "nodeA" instead of "node1". This field is required. */
        nodeID: string;
        /** topologyKeys is the list of keys supported by the driver. When a driver is initialized on a cluster, it provides a set of topology keys that it understands (e.g. "company.com/zone", "company.com/region"). When a driver is initialized on a node, it provides the same topology keys along with values. Kubelet will expose these topology keys as labels on its own node object. When Kubernetes does topology aware provisioning, it can use this list to determine which labels it should retrieve from the node object and pass back to the driver. It is possible for different nodes to use different topology keys. This can be empty if driver does not support topology. */
        topologyKeys?: string[];
    }
    /** CSINodeList is a collection of CSINode objects. */
    interface io$k8s$api$storage$v1$CSINodeList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of CSINode */
        items: Schemas.io$k8s$api$storage$v1$CSINode[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** CSINodeSpec holds information about the specification of all CSI drivers installed on a node */
    interface io$k8s$api$storage$v1$CSINodeSpec {
        /** drivers is a list of information of all CSI Drivers existing on a node. If all drivers in the list are uninstalled, this can become empty. */
        drivers: Schemas.io$k8s$api$storage$v1$CSINodeDriver[];
    }
    /**
     * CSIStorageCapacity stores the result of one CSI GetCapacity call. For a given StorageClass, this describes the available capacity in a particular topology segment.  This can be used when considering where to instantiate new PersistentVolumes.
     *
     * For example this can express things like: - StorageClass "standard" has "1234 GiB" available in "topology.kubernetes.io/zone=us-east1" - StorageClass "localssd" has "10 GiB" available in "kubernetes.io/hostname=knode-abc123"
     *
     * The following three cases all imply that no capacity is available for a certain combination: - no object exists with suitable topology and storage class name - such an object exists, but the capacity is unset - such an object exists, but the capacity is zero
     *
     * The producer of these objects can decide which approach is more suitable.
     *
     * They are consumed by the kube-scheduler when a CSI driver opts into capacity-aware scheduling with CSIDriverSpec.StorageCapacity. The scheduler compares the MaximumVolumeSize against the requested size of pending volumes to filter out unsuitable nodes. If MaximumVolumeSize is unset, it falls back to a comparison against the less precise Capacity. If that is also unset, the scheduler assumes that capacity is insufficient and tries some other node.
     */
    interface io$k8s$api$storage$v1$CSIStorageCapacity {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        capacity?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        maximumVolumeSize?: Schemas.io$k8s$apimachinery$pkg$api$resource$Quantity;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        nodeTopology?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector;
        /** storageClassName represents the name of the StorageClass that the reported capacity applies to. It must meet the same requirements as the name of a StorageClass object (non-empty, DNS subdomain). If that object no longer exists, the CSIStorageCapacity object is obsolete and should be removed by its creator. This field is immutable. */
        storageClassName: string;
    }
    /** CSIStorageCapacityList is a collection of CSIStorageCapacity objects. */
    interface io$k8s$api$storage$v1$CSIStorageCapacityList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of CSIStorageCapacity objects. */
        items: Schemas.io$k8s$api$storage$v1$CSIStorageCapacity[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /**
     * StorageClass describes the parameters for a class of storage for which PersistentVolumes can be dynamically provisioned.
     *
     * StorageClasses are non-namespaced; the name of the storage class according to etcd is in ObjectMeta.Name.
     */
    interface io$k8s$api$storage$v1$StorageClass {
        /** allowVolumeExpansion shows whether the storage class allow volume expand. */
        allowVolumeExpansion?: boolean;
        /** allowedTopologies restrict the node topologies where volumes can be dynamically provisioned. Each volume plugin defines its own supported topology specifications. An empty TopologySelectorTerm list means there is no topology restriction. This field is only honored by servers that enable the VolumeScheduling feature. */
        allowedTopologies?: Schemas.io$k8s$api$core$v1$TopologySelectorTerm[];
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        /** mountOptions controls the mountOptions for dynamically provisioned PersistentVolumes of this storage class. e.g. ["ro", "soft"]. Not validated - mount of the PVs will simply fail if one is invalid. */
        mountOptions?: string[];
        /** parameters holds the parameters for the provisioner that should create volumes of this storage class. */
        parameters?: {
            [key: string]: string;
        };
        /** provisioner indicates the type of the provisioner. */
        provisioner: string;
        /** reclaimPolicy controls the reclaimPolicy for dynamically provisioned PersistentVolumes of this storage class. Defaults to Delete. */
        reclaimPolicy?: string;
        /** volumeBindingMode indicates how PersistentVolumeClaims should be provisioned and bound.  When unset, VolumeBindingImmediate is used. This field is only honored by servers that enable the VolumeScheduling feature. */
        volumeBindingMode?: string;
    }
    /** StorageClassList is a collection of storage classes. */
    interface io$k8s$api$storage$v1$StorageClassList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of StorageClasses */
        items: Schemas.io$k8s$api$storage$v1$StorageClass[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** TokenRequest contains parameters of a service account token. */
    interface io$k8s$api$storage$v1$TokenRequest {
        /** audience is the intended audience of the token in "TokenRequestSpec". It will default to the audiences of kube apiserver. */
        audience: string;
        /** expirationSeconds is the duration of validity of the token in "TokenRequestSpec". It has the same default value of "ExpirationSeconds" in "TokenRequestSpec". */
        expirationSeconds?: number;
    }
    /**
     * VolumeAttachment captures the intent to attach or detach the specified volume to/from the specified node.
     *
     * VolumeAttachment objects are non-namespaced.
     */
    interface io$k8s$api$storage$v1$VolumeAttachment {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$api$storage$v1$VolumeAttachmentSpec;
        status?: Schemas.io$k8s$api$storage$v1$VolumeAttachmentStatus;
    }
    /** VolumeAttachmentList is a collection of VolumeAttachment objects. */
    interface io$k8s$api$storage$v1$VolumeAttachmentList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items is the list of VolumeAttachments */
        items: Schemas.io$k8s$api$storage$v1$VolumeAttachment[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** VolumeAttachmentSource represents a volume that should be attached. Right now only PersistenVolumes can be attached via external attacher, in future we may allow also inline volumes in pods. Exactly one member can be set. */
    interface io$k8s$api$storage$v1$VolumeAttachmentSource {
        inlineVolumeSpec?: Schemas.io$k8s$api$core$v1$PersistentVolumeSpec;
        /** persistentVolumeName represents the name of the persistent volume to attach. */
        persistentVolumeName?: string;
    }
    /** VolumeAttachmentSpec is the specification of a VolumeAttachment request. */
    interface io$k8s$api$storage$v1$VolumeAttachmentSpec {
        /** attacher indicates the name of the volume driver that MUST handle this request. This is the name returned by GetPluginName(). */
        attacher: string;
        /** nodeName represents the node that the volume should be attached to. */
        nodeName: string;
        source: Schemas.io$k8s$api$storage$v1$VolumeAttachmentSource;
    }
    /** VolumeAttachmentStatus is the status of a VolumeAttachment request. */
    interface io$k8s$api$storage$v1$VolumeAttachmentStatus {
        attachError?: Schemas.io$k8s$api$storage$v1$VolumeError;
        /** attached indicates the volume is successfully attached. This field must only be set by the entity completing the attach operation, i.e. the external-attacher. */
        attached: boolean;
        /** attachmentMetadata is populated with any information returned by the attach operation, upon successful attach, that must be passed into subsequent WaitForAttach or Mount calls. This field must only be set by the entity completing the attach operation, i.e. the external-attacher. */
        attachmentMetadata?: {
            [key: string]: string;
        };
        detachError?: Schemas.io$k8s$api$storage$v1$VolumeError;
    }
    /** VolumeError captures an error encountered during a volume operation. */
    interface io$k8s$api$storage$v1$VolumeError {
        /** message represents the error encountered during Attach or Detach operation. This string may be logged, so it should not contain sensitive information. */
        message?: string;
        time?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
    }
    /** VolumeNodeResources is a set of resource limits for scheduling of volumes. */
    interface io$k8s$api$storage$v1$VolumeNodeResources {
        /** count indicates the maximum number of unique volumes managed by the CSI driver that can be used on a node. A volume that is both attached and mounted on a node is considered to be used once, not twice. The same rule applies for a unique volume that is shared among multiple pods on the same node. If this field is not specified, then the supported number of volumes on this node is unbounded. */
        count?: number;
    }
    /** CustomResourceColumnDefinition specifies a column for server side printing. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceColumnDefinition {
        /** description is a human readable description of this column. */
        description?: string;
        /** format is an optional OpenAPI type definition for this column. The 'name' format is applied to the primary identifier column to assist in clients identifying column is the resource name. See https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#data-types for details. */
        format?: string;
        /** jsonPath is a simple JSON path (i.e. with array notation) which is evaluated against each custom resource to produce the value for this column. */
        jsonPath: string;
        /** name is a human readable name for the column. */
        name: string;
        /** priority is an integer defining the relative importance of this column compared to others. Lower numbers are considered higher priority. Columns that may be omitted in limited space scenarios should be given a priority greater than 0. */
        priority?: number;
        /** type is an OpenAPI type definition for this column. See https://github.com/OAI/OpenAPI-Specification/blob/master/versions/2.0.md#data-types for details. */
        type: string;
    }
    /** CustomResourceConversion describes how to convert different versions of a CR. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceConversion {
        /**
         * strategy specifies how custom resources are converted between versions. Allowed values are: - `"None"`: The converter only change the apiVersion and would not touch any other field in the custom resource. - `"Webhook"`: API Server will call to an external webhook to do the conversion. Additional information
         *   is needed for this option. This requires spec.preserveUnknownFields to be false, and spec.conversion.webhook to be set.
         */
        strategy: string;
        webhook?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$WebhookConversion;
    }
    /** CustomResourceDefinition represents a resource that should be exposed on the API server.  Its name MUST be in the format <.spec.name>.<.spec.group>. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionSpec;
        status?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionStatus;
    }
    /** CustomResourceDefinitionCondition contains details for the current condition of this pod. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** message is a human-readable message indicating details about last transition. */
        message?: string;
        /** reason is a unique, one-word, CamelCase reason for the condition's last transition. */
        reason?: string;
        /** status is the status of the condition. Can be True, False, Unknown. */
        status: string;
        /** type is the type of the condition. Types include Established, NamesAccepted and Terminating. */
        type: string;
    }
    /** CustomResourceDefinitionList is a list of CustomResourceDefinition objects. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** items list individual CustomResourceDefinition objects */
        items: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** CustomResourceDefinitionNames indicates the names to serve this CustomResourceDefinition */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionNames {
        /** categories is a list of grouped resources this custom resource belongs to (e.g. 'all'). This is published in API discovery documents, and used by clients to support invocations like `kubectl get all`. */
        categories?: string[];
        /** kind is the serialized kind of the resource. It is normally CamelCase and singular. Custom resource instances will use this value as the `kind` attribute in API calls. */
        kind: string;
        /** listKind is the serialized kind of the list for this resource. Defaults to "`kind`List". */
        listKind?: string;
        /** plural is the plural name of the resource to serve. The custom resources are served under `/apis/<group>/<version>/.../<plural>`. Must match the name of the CustomResourceDefinition (in the form `<names.plural>.<group>`). Must be all lowercase. */
        plural: string;
        /** shortNames are short names for the resource, exposed in API discovery documents, and used by clients to support invocations like `kubectl get <shortname>`. It must be all lowercase. */
        shortNames?: string[];
        /** singular is the singular name of the resource. It must be all lowercase. Defaults to lowercased `kind`. */
        singular?: string;
    }
    /** CustomResourceDefinitionSpec describes how a user wants their resource to appear */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionSpec {
        conversion?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceConversion;
        /** group is the API group of the defined custom resource. The custom resources are served under `/apis/<group>/...`. Must match the name of the CustomResourceDefinition (in the form `<names.plural>.<group>`). */
        group: string;
        names: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionNames;
        /** preserveUnknownFields indicates that object fields which are not specified in the OpenAPI schema should be preserved when persisting to storage. apiVersion, kind, metadata and known fields inside metadata are always preserved. This field is deprecated in favor of setting `x-preserve-unknown-fields` to true in `spec.versions[*].schema.openAPIV3Schema`. See https://kubernetes.io/docs/tasks/extend-kubernetes/custom-resources/custom-resource-definitions/#field-pruning for details. */
        preserveUnknownFields?: boolean;
        /** scope indicates whether the defined custom resource is cluster- or namespace-scoped. Allowed values are `Cluster` and `Namespaced`. */
        scope: string;
        /** versions is the list of all API versions of the defined custom resource. Version names are used to compute the order in which served versions are listed in API discovery. If the version string is "kube-like", it will sort above non "kube-like" version strings, which are ordered lexicographically. "Kube-like" versions start with a "v", then are followed by a number (the major version), then optionally the string "alpha" or "beta" and another number (the minor version). These are sorted first by GA > beta > alpha (where GA is a version with no suffix such as beta or alpha), and then by comparing major version, then minor version. An example sorted list of versions: v10, v2, v1, v11beta2, v10beta3, v3beta1, v12alpha1, v11alpha2, foo1, foo10. */
        versions: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionVersion[];
    }
    /** CustomResourceDefinitionStatus indicates the state of the CustomResourceDefinition */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionStatus {
        acceptedNames?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionNames;
        /** conditions indicate state for particular aspects of a CustomResourceDefinition */
        conditions?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionCondition[];
        /** storedVersions lists all versions of CustomResources that were ever persisted. Tracking these versions allows a migration path for stored versions in etcd. The field is mutable so a migration controller can finish a migration to another version (ensuring no old objects are left in storage), and then remove the rest of the versions from this list. Versions may not be removed from `spec.versions` while they exist in this list. */
        storedVersions?: string[];
    }
    /** CustomResourceDefinitionVersion describes a version for CRD. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionVersion {
        /** additionalPrinterColumns specifies additional columns returned in Table output. See https://kubernetes.io/docs/reference/using-api/api-concepts/#receiving-resources-as-tables for details. If no columns are specified, a single column displaying the age of the custom resource is used. */
        additionalPrinterColumns?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceColumnDefinition[];
        /** deprecated indicates this version of the custom resource API is deprecated. When set to true, API requests to this version receive a warning header in the server response. Defaults to false. */
        deprecated?: boolean;
        /** deprecationWarning overrides the default warning returned to API clients. May only be set when `deprecated` is true. The default warning indicates this version is deprecated and recommends use of the newest served version of equal or greater stability, if one exists. */
        deprecationWarning?: string;
        /** name is the version name, e.g. “v1”, “v2beta1”, etc. The custom resources are served under this version at `/apis/<group>/<version>/...` if `served` is true. */
        name: string;
        schema?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceValidation;
        /** served is a flag enabling/disabling this version from being served via REST APIs */
        served: boolean;
        /** storage indicates this version should be used when persisting custom resources to storage. There must be exactly one version with storage=true. */
        storage: boolean;
        subresources?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceSubresources;
    }
    /** CustomResourceSubresourceScale defines how to serve the scale subresource for CustomResources. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceSubresourceScale {
        /** labelSelectorPath defines the JSON path inside of a custom resource that corresponds to Scale `status.selector`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.status` or `.spec`. Must be set to work with HorizontalPodAutoscaler. The field pointed by this JSON path must be a string field (not a complex selector struct) which contains a serialized label selector in string form. More info: https://kubernetes.io/docs/tasks/access-kubernetes-api/custom-resources/custom-resource-definitions#scale-subresource If there is no value under the given path in the custom resource, the `status.selector` value in the `/scale` subresource will default to the empty string. */
        labelSelectorPath?: string;
        /** specReplicasPath defines the JSON path inside of a custom resource that corresponds to Scale `spec.replicas`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.spec`. If there is no value under the given path in the custom resource, the `/scale` subresource will return an error on GET. */
        specReplicasPath: string;
        /** statusReplicasPath defines the JSON path inside of a custom resource that corresponds to Scale `status.replicas`. Only JSON paths without the array notation are allowed. Must be a JSON Path under `.status`. If there is no value under the given path in the custom resource, the `status.replicas` value in the `/scale` subresource will default to 0. */
        statusReplicasPath: string;
    }
    /** CustomResourceSubresourceStatus defines how to serve the status subresource for CustomResources. Status is represented by the `.status` JSON path inside of a CustomResource. When set, * exposes a /status subresource for the custom resource * PUT requests to the /status subresource take a custom resource object, and ignore changes to anything except the status stanza * PUT/POST/PATCH requests to the custom resource ignore changes to the status stanza */
    type io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceSubresourceStatus = {};
    /** CustomResourceSubresources defines the status and scale subresources for CustomResources. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceSubresources {
        scale?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceSubresourceScale;
        status?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceSubresourceStatus;
    }
    /** CustomResourceValidation is a list of validation methods for CustomResources. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceValidation {
        openAPIV3Schema?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaProps;
    }
    /** ExternalDocumentation allows referencing an external resource for extended documentation. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$ExternalDocumentation {
        description?: string;
        url?: string;
    }
    /** JSON represents any valid JSON value. These types are supported: bool, int64, float64, string, []interface{}, map[string]interface{} and nil. */
    type io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSON = any;
    /** JSONSchemaProps is a JSON-Schema following Specification Draft 4 (http://json-schema.org/). */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaProps {
        $ref?: string;
        $schema?: string;
        additionalItems?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaPropsOrBool;
        additionalProperties?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaPropsOrBool;
        allOf?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaProps[];
        anyOf?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaProps[];
        default?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSON;
        definitions?: {
            [key: string]: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaProps;
        };
        dependencies?: {
            [key: string]: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaPropsOrStringArray;
        };
        description?: string;
        enum?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSON[];
        example?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSON;
        exclusiveMaximum?: boolean;
        exclusiveMinimum?: boolean;
        externalDocs?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$ExternalDocumentation;
        /**
         * format is an OpenAPI v3 format string. Unknown formats are ignored. The following formats are validated:
         *
         * - bsonobjectid: a bson object ID, i.e. a 24 characters hex string - uri: an URI as parsed by Golang net/url.ParseRequestURI - email: an email address as parsed by Golang net/mail.ParseAddress - hostname: a valid representation for an Internet host name, as defined by RFC 1034, section 3.1 [RFC1034]. - ipv4: an IPv4 IP as parsed by Golang net.ParseIP - ipv6: an IPv6 IP as parsed by Golang net.ParseIP - cidr: a CIDR as parsed by Golang net.ParseCIDR - mac: a MAC address as parsed by Golang net.ParseMAC - uuid: an UUID that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?[0-9a-f]{4}-?[0-9a-f]{4}-?[0-9a-f]{12}$ - uuid3: an UUID3 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?3[0-9a-f]{3}-?[0-9a-f]{4}-?[0-9a-f]{12}$ - uuid4: an UUID4 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?4[0-9a-f]{3}-?[89ab][0-9a-f]{3}-?[0-9a-f]{12}$ - uuid5: an UUID5 that allows uppercase defined by the regex (?i)^[0-9a-f]{8}-?[0-9a-f]{4}-?5[0-9a-f]{3}-?[89ab][0-9a-f]{3}-?[0-9a-f]{12}$ - isbn: an ISBN10 or ISBN13 number string like "0321751043" or "978-0321751041" - isbn10: an ISBN10 number string like "0321751043" - isbn13: an ISBN13 number string like "978-0321751041" - creditcard: a credit card number defined by the regex ^(?:4[0-9]{12}(?:[0-9]{3})?|5[1-5][0-9]{14}|6(?:011|5[0-9][0-9])[0-9]{12}|3[47][0-9]{13}|3(?:0[0-5]|[68][0-9])[0-9]{11}|(?:2131|1800|35\d{3})\d{11})$ with any non digit characters mixed in - ssn: a U.S. social security number following the regex ^\d{3}[- ]?\d{2}[- ]?\d{4}$ - hexcolor: an hexadecimal color code like "#FFFFFF: following the regex ^#?([0-9a-fA-F]{3}|[0-9a-fA-F]{6})$ - rgbcolor: an RGB color code like rgb like "rgb(255,255,2559" - byte: base64 encoded binary data - password: any kind of string - date: a date string like "2006-01-02" as defined by full-date in RFC3339 - duration: a duration string like "22 ns" as parsed by Golang time.ParseDuration or compatible with Scala duration format - datetime: a date time string like "2014-12-15T19:30:20.000Z" as defined by date-time in RFC3339.
         */
        format?: string;
        id?: string;
        items?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaPropsOrArray;
        maxItems?: number;
        maxLength?: number;
        maxProperties?: number;
        maximum?: number;
        minItems?: number;
        minLength?: number;
        minProperties?: number;
        minimum?: number;
        multipleOf?: number;
        not?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaProps;
        nullable?: boolean;
        oneOf?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaProps[];
        pattern?: string;
        patternProperties?: {
            [key: string]: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaProps;
        };
        properties?: {
            [key: string]: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaProps;
        };
        required?: string[];
        title?: string;
        type?: string;
        uniqueItems?: boolean;
        /** x-kubernetes-embedded-resource defines that the value is an embedded Kubernetes runtime.Object, with TypeMeta and ObjectMeta. The type must be object. It is allowed to further restrict the embedded object. kind, apiVersion and metadata are validated automatically. x-kubernetes-preserve-unknown-fields is allowed to be true, but does not have to be if the object is fully specified (up to kind, apiVersion, metadata). */
        "x-kubernetes-embedded-resource"?: boolean;
        /**
         * x-kubernetes-int-or-string specifies that this value is either an integer or a string. If this is true, an empty type is allowed and type as child of anyOf is permitted if following one of the following patterns:
         *
         * 1) anyOf:
         *    - type: integer
         *    - type: string
         * 2) allOf:
         *    - anyOf:
         *      - type: integer
         *      - type: string
         *    - ... zero or more
         */
        "x-kubernetes-int-or-string"?: boolean;
        /**
         * x-kubernetes-list-map-keys annotates an array with the x-kubernetes-list-type `map` by specifying the keys used as the index of the map.
         *
         * This tag MUST only be used on lists that have the "x-kubernetes-list-type" extension set to "map". Also, the values specified for this attribute must be a scalar typed field of the child structure (no nesting is supported).
         *
         * The properties specified must either be required or have a default value, to ensure those properties are present for all list items.
         */
        "x-kubernetes-list-map-keys"?: string[];
        /**
         * x-kubernetes-list-type annotates an array to further describe its topology. This extension must only be used on lists and may have 3 possible values:
         *
         * 1) `atomic`: the list is treated as a single entity, like a scalar.
         *      Atomic lists will be entirely replaced when updated. This extension
         *      may be used on any type of list (struct, scalar, ...).
         * 2) `set`:
         *      Sets are lists that must not have multiple items with the same value. Each
         *      value must be a scalar, an object with x-kubernetes-map-type `atomic` or an
         *      array with x-kubernetes-list-type `atomic`.
         * 3) `map`:
         *      These lists are like maps in that their elements have a non-index key
         *      used to identify them. Order is preserved upon merge. The map tag
         *      must only be used on a list with elements of type object.
         * Defaults to atomic for arrays.
         */
        "x-kubernetes-list-type"?: string;
        /**
         * x-kubernetes-map-type annotates an object to further describe its topology. This extension must only be used when type is object and may have 2 possible values:
         *
         * 1) `granular`:
         *      These maps are actual maps (key-value pairs) and each fields are independent
         *      from each other (they can each be manipulated by separate actors). This is
         *      the default behaviour for all maps.
         * 2) `atomic`: the list is treated as a single entity, like a scalar.
         *      Atomic maps will be entirely replaced when updated.
         */
        "x-kubernetes-map-type"?: string;
        /** x-kubernetes-preserve-unknown-fields stops the API server decoding step from pruning fields which are not specified in the validation schema. This affects fields recursively, but switches back to normal pruning behaviour if nested properties or additionalProperties are specified in the schema. This can either be true or undefined. False is forbidden. */
        "x-kubernetes-preserve-unknown-fields"?: boolean;
        /** x-kubernetes-validations describes a list of validation rules written in the CEL expression language. This field is an alpha-level. Using this field requires the feature gate `CustomResourceValidationExpressions` to be enabled. */
        "x-kubernetes-validations"?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$ValidationRule[];
    }
    /** JSONSchemaPropsOrArray represents a value that can either be a JSONSchemaProps or an array of JSONSchemaProps. Mainly here for serialization purposes. */
    type io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaPropsOrArray = any;
    /** JSONSchemaPropsOrBool represents JSONSchemaProps or a boolean value. Defaults to true for the boolean property. */
    type io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaPropsOrBool = any;
    /** JSONSchemaPropsOrStringArray represents a JSONSchemaProps or a string array. */
    type io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$JSONSchemaPropsOrStringArray = any;
    /** ServiceReference holds a reference to Service.legacy.k8s.io */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$ServiceReference {
        /** name is the name of the service. Required */
        name: string;
        /** namespace is the namespace of the service. Required */
        namespace: string;
        /** path is an optional URL path at which the webhook will be contacted. */
        path?: string;
        /** port is an optional service port at which the webhook will be contacted. `port` should be a valid port number (1-65535, inclusive). Defaults to 443 for backward compatibility. */
        port?: number;
    }
    /** ValidationRule describes a validation rule written in the CEL expression language. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$ValidationRule {
        /** Message represents the message displayed when validation fails. The message is required if the Rule contains line breaks. The message must not contain line breaks. If unset, the message is "failed rule: {Rule}". e.g. "must be a URL with the host matching spec.host" */
        message?: string;
        /** MessageExpression declares a CEL expression that evaluates to the validation failure message that is returned when this rule fails. Since messageExpression is used as a failure message, it must evaluate to a string. If both message and messageExpression are present on a rule, then messageExpression will be used if validation fails. If messageExpression results in a runtime error, the runtime error is logged, and the validation failure message is produced as if the messageExpression field were unset. If messageExpression evaluates to an empty string, a string with only spaces, or a string that contains line breaks, then the validation failure message will also be produced as if the messageExpression field were unset, and the fact that messageExpression produced an empty string/string with only spaces/string with line breaks will be logged. messageExpression has access to all the same variables as the rule; the only difference is the return type. Example: "x must be less than max ("+string(self.max)+")" */
        messageExpression?: string;
        /**
         * Rule represents the expression which will be evaluated by CEL. ref: https://github.com/google/cel-spec The Rule is scoped to the location of the x-kubernetes-validations extension in the schema. The `self` variable in the CEL expression is bound to the scoped value. Example: - Rule scoped to the root of a resource with a status subresource: {"rule": "self.status.actual <= self.spec.maxDesired"}
         *
         * If the Rule is scoped to an object with properties, the accessible properties of the object are field selectable via `self.field` and field presence can be checked via `has(self.field)`. Null valued fields are treated as absent fields in CEL expressions. If the Rule is scoped to an object with additionalProperties (i.e. a map) the value of the map are accessible via `self[mapKey]`, map containment can be checked via `mapKey in self` and all entries of the map are accessible via CEL macros and functions such as `self.all(...)`. If the Rule is scoped to an array, the elements of the array are accessible via `self[i]` and also by macros and functions. If the Rule is scoped to a scalar, `self` is bound to the scalar value. Examples: - Rule scoped to a map of objects: {"rule": "self.components['Widget'].priority < 10"} - Rule scoped to a list of integers: {"rule": "self.values.all(value, value >= 0 && value < 100)"} - Rule scoped to a string value: {"rule": "self.startsWith('kube')"}
         *
         * The `apiVersion`, `kind`, `metadata.name` and `metadata.generateName` are always accessible from the root of the object and from any x-kubernetes-embedded-resource annotated objects. No other metadata properties are accessible.
         *
         * Unknown data preserved in custom resources via x-kubernetes-preserve-unknown-fields is not accessible in CEL expressions. This includes: - Unknown field values that are preserved by object schemas with x-kubernetes-preserve-unknown-fields. - Object properties where the property schema is of an "unknown type". An "unknown type" is recursively defined as:
         *   - A schema with no type and x-kubernetes-preserve-unknown-fields set to true
         *   - An array where the items schema is of an "unknown type"
         *   - An object where the additionalProperties schema is of an "unknown type"
         *
         * Only property names of the form `[a-zA-Z_.-/][a-zA-Z0-9_.-/]*` are accessible. Accessible property names are escaped according to the following rules when accessed in the expression: - '__' escapes to '__underscores__' - '.' escapes to '__dot__' - '-' escapes to '__dash__' - '/' escapes to '__slash__' - Property names that exactly match a CEL RESERVED keyword escape to '__{keyword}__'. The keywords are:
         * 	  "true", "false", "null", "in", "as", "break", "const", "continue", "else", "for", "function", "if",
         * 	  "import", "let", "loop", "package", "namespace", "return".
         * Examples:
         *   - Rule accessing a property named "namespace": {"rule": "self.__namespace__ > 0"}
         *   - Rule accessing a property named "x-prop": {"rule": "self.x__dash__prop > 0"}
         *   - Rule accessing a property named "redact__d": {"rule": "self.redact__underscores__d > 0"}
         *
         * Equality on arrays with x-kubernetes-list-type of 'set' or 'map' ignores element order, i.e. [1, 2] == [2, 1]. Concatenation on arrays with x-kubernetes-list-type use the semantics of the list type:
         *   - 'set': `X + Y` performs a union where the array positions of all elements in `X` are preserved and
         *     non-intersecting elements in `Y` are appended, retaining their partial order.
         *   - 'map': `X + Y` performs a merge where the array positions of all keys in `X` are preserved but the values
         *     are overwritten by values in `Y` when the key sets of `X` and `Y` intersect. Elements in `Y` with
         *     non-intersecting keys are appended, retaining their partial order.
         */
        rule: string;
    }
    /** WebhookClientConfig contains the information to make a TLS connection with the webhook. */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$WebhookClientConfig {
        /** caBundle is a PEM encoded CA bundle which will be used to validate the webhook's server certificate. If unspecified, system trust roots on the apiserver are used. */
        caBundle?: Blob;
        service?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$ServiceReference;
        /**
         * url gives the location of the webhook, in standard URL form (`scheme://host:port/path`). Exactly one of `url` or `service` must be specified.
         *
         * The `host` should not refer to a service running in the cluster; use the `service` field instead. The host might be resolved via external DNS in some apiservers (e.g., `kube-apiserver` cannot resolve in-cluster DNS as that would be a layering violation). `host` may also be an IP address.
         *
         * Please note that using `localhost` or `127.0.0.1` as a `host` is risky unless you take great care to run this webhook on all hosts which run an apiserver which might need to make calls to this webhook. Such installs are likely to be non-portable, i.e., not easy to turn up in a new cluster.
         *
         * The scheme must be "https"; the URL must begin with "https://".
         *
         * A path is optional, and if present may be any string permissible in a URL. You may use the path to pass an arbitrary string to the webhook, for example, a cluster identifier.
         *
         * Attempting to use a user or basic auth e.g. "user:password@" is not allowed. Fragments ("#...") and query parameters ("?...") are not allowed, either.
         */
        url?: string;
    }
    /** WebhookConversion describes how to call a conversion webhook */
    interface io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$WebhookConversion {
        clientConfig?: Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$WebhookClientConfig;
        /** conversionReviewVersions is an ordered list of preferred `ConversionReview` versions the Webhook expects. The API server will use the first version in the list which it supports. If none of the versions specified in this list are supported by API server, conversion will fail for the custom resource. If a persisted Webhook configuration specifies allowed versions and does not include any versions known to the API Server, calls to the webhook will fail. */
        conversionReviewVersions: string[];
    }
    /**
     * Quantity is a fixed-point representation of a number. It provides convenient marshaling/unmarshaling in JSON and YAML, in addition to String() and AsInt64() accessors.
     *
     * The serialization format is:
     *
     * ``` <quantity>        ::= <signedNumber><suffix>
     *
     * 	(Note that <suffix> may be empty, from the "" case in <decimalSI>.)
     *
     * <digit>           ::= 0 | 1 | ... | 9 <digits>          ::= <digit> | <digit><digits> <number>          ::= <digits> | <digits>.<digits> | <digits>. | .<digits> <sign>            ::= "+" | "-" <signedNumber>    ::= <number> | <sign><number> <suffix>          ::= <binarySI> | <decimalExponent> | <decimalSI> <binarySI>        ::= Ki | Mi | Gi | Ti | Pi | Ei
     *
     * 	(International System of units; See: http://physics.nist.gov/cuu/Units/binary.html)
     *
     * <decimalSI>       ::= m | "" | k | M | G | T | P | E
     *
     * 	(Note that 1024 = 1Ki but 1000 = 1k; I didn't choose the capitalization.)
     *
     * <decimalExponent> ::= "e" <signedNumber> | "E" <signedNumber> ```
     *
     * No matter which of the three exponent forms is used, no quantity may represent a number greater than 2^63-1 in magnitude, nor may it have more than 3 decimal places. Numbers larger or more precise will be capped or rounded up. (E.g.: 0.1m will rounded up to 1m.) This may be extended in the future if we require larger or smaller quantities.
     *
     * When a Quantity is parsed from a string, it will remember the type of suffix it had, and will use the same type again when it is serialized.
     *
     * Before serializing, Quantity will be put in "canonical form". This means that Exponent/suffix will be adjusted up or down (with a corresponding increase or decrease in Mantissa) such that:
     *
     * - No precision is lost - No fractional digits will be emitted - The exponent (or suffix) is as large as possible.
     *
     * The sign will be omitted unless the number is negative.
     *
     * Examples:
     *
     * - 1.5 will be serialized as "1500m" - 1.5Gi will be serialized as "1536Mi"
     *
     * Note that the quantity will NEVER be internally represented by a floating point number. That is the whole point of this exercise.
     *
     * Non-canonical values will still parse as long as they are well formed, but will be re-emitted in their canonical form. (So always use canonical form, or don't diff.)
     *
     * This format is intended to make it difficult to use these numbers without writing some sort of special handling code in the hopes that that will cause implementors to also use a fixed point implementation.
     */
    type io$k8s$apimachinery$pkg$api$resource$Quantity = string;
    /** APIGroup contains the name, the supported versions, and the preferred version of a group. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        /** name is the name of the group. */
        name: string;
        preferredVersion?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$GroupVersionForDiscovery;
        /** a map of client CIDR to server address that is serving this group. This is to help clients reach servers in the most network-efficient way possible. Clients can use the appropriate server address as per the CIDR that they match. In case of multiple matches, clients should use the longest matching CIDR. The server returns only those CIDRs that it thinks that the client can match. For example: the master will return an internal IP CIDR only, if the client reaches the server using an internal IP. Server looks at X-Forwarded-For header or X-Real-Ip header or request.RemoteAddr (in that order) to get the client IP. */
        serverAddressByClientCIDRs?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ServerAddressByClientCIDR[];
        /** versions are the versions supported in this group. */
        versions: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$GroupVersionForDiscovery[];
    }
    /** APIGroupList is a list of APIGroup, to allow clients to discover the API at /apis. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$APIGroupList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** groups is a list of APIGroup. */
        groups: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
    }
    /** APIResource specifies the name of a resource and whether it is namespaced. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$APIResource {
        /** categories is a list of the grouped resources this resource belongs to (e.g. 'all') */
        categories?: string[];
        /** group is the preferred group of the resource.  Empty implies the group of the containing resource list. For subresources, this may have a different value, for example: Scale". */
        group?: string;
        /** kind is the kind for the resource (e.g. 'Foo' is the kind for a resource 'foo') */
        kind: string;
        /** name is the plural name of the resource. */
        name: string;
        /** namespaced indicates if a resource is namespaced or not. */
        namespaced: boolean;
        /** shortNames is a list of suggested short names of the resource. */
        shortNames?: string[];
        /** singularName is the singular name of the resource.  This allows clients to handle plural and singular opaquely. The singularName is more correct for reporting status on a single item and both singular and plural are allowed from the kubectl CLI interface. */
        singularName: string;
        /** The hash value of the storage version, the version this resource is converted to when written to the data store. Value must be treated as opaque by clients. Only equality comparison on the value is valid. This is an alpha feature and may change or be removed in the future. The field is populated by the apiserver only if the StorageVersionHash feature gate is enabled. This field will remain optional even if it graduates. */
        storageVersionHash?: string;
        /** verbs is a list of supported kube verbs (this includes get, list, watch, create, update, patch, delete, deletecollection, and proxy) */
        verbs: string[];
        /** version is the preferred version of the resource.  Empty implies the version of the containing resource list For subresources, this may have a different value, for example: v1 (while inside a v1beta1 version of the core resource's group)". */
        version?: string;
    }
    /** APIResourceList is a list of APIResource, it is used to expose the name of the resources supported in a specific group and version, and if the resource is namespaced. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** groupVersion is the group and version this APIResourceList is for. */
        groupVersion: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        /** resources contains the name of the resources and if they are namespaced. */
        resources: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResource[];
    }
    /** APIVersions lists the versions that are available, to allow clients to discover the API at /api, which is the root path of the legacy v1 API. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$APIVersions {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        /** a map of client CIDR to server address that is serving this group. This is to help clients reach servers in the most network-efficient way possible. Clients can use the appropriate server address as per the CIDR that they match. In case of multiple matches, clients should use the longest matching CIDR. The server returns only those CIDRs that it thinks that the client can match. For example: the master will return an internal IP CIDR only, if the client reaches the server using an internal IP. Server looks at X-Forwarded-For header or X-Real-Ip header or request.RemoteAddr (in that order) to get the client IP. */
        serverAddressByClientCIDRs: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ServerAddressByClientCIDR[];
        /** versions are the api versions that are available. */
        versions: string[];
    }
    /** Condition contains details for one aspect of the current state of this API Resource. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$Condition {
        lastTransitionTime: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** message is a human readable message indicating details about the transition. This may be an empty string. */
        message: string;
        /** observedGeneration represents the .metadata.generation that the condition was set based upon. For instance, if .metadata.generation is currently 12, but the .status.conditions[x].observedGeneration is 9, the condition is out of date with respect to the current state of the instance. */
        observedGeneration?: number;
        /** reason contains a programmatic identifier indicating the reason for the condition's last transition. Producers of specific condition types may define expected values and meanings for this field, and whether the values are considered a guaranteed API. The value should be a CamelCase string. This field may not be empty. */
        reason: string;
        /** status of the condition, one of True, False, Unknown. */
        status: string;
        /** type of condition in CamelCase or in foo.example.com/CamelCase. */
        type: string;
    }
    /** DeleteOptions may be provided when deleting an API object. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
        dryRun?: string[];
        /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
        gracePeriodSeconds?: number;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
        orphanDependents?: boolean;
        preconditions?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Preconditions;
        /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
        propagationPolicy?: string;
    }
    /**
     * FieldsV1 stores a set of fields in a data structure like a Trie, in JSON format.
     *
     * Each key is either a '.' representing the field itself, and will always map to an empty set, or a string representing a sub-field or item. The string will follow one of these four formats: 'f:<name>', where <name> is the name of a field in a struct, or key in a map 'v:<value>', where <value> is the exact json formatted value of a list item 'i:<index>', where <index> is position of a item in a list 'k:<keys>', where <keys> is a map of  a list item's key fields to their unique values If a key maps to an empty Fields value, the field that key represents is part of the set.
     *
     * The exact format is defined in sigs.k8s.io/structured-merge-diff
     */
    type io$k8s$apimachinery$pkg$apis$meta$v1$FieldsV1 = {};
    /** GroupVersion contains the "group/version" and "version" string of a version. It is made a struct to keep extensibility. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$GroupVersionForDiscovery {
        /** groupVersion specifies the API group and version in the form "group/version" */
        groupVersion: string;
        /** version specifies the version in the form of "version". This is to save the clients the trouble of splitting the GroupVersion. */
        version: string;
    }
    /** A label selector is a label query over a set of resources. The result of matchLabels and matchExpressions are ANDed. An empty label selector matches all objects. A null label selector matches no objects. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelector {
        /** matchExpressions is a list of label selector requirements. The requirements are ANDed. */
        matchExpressions?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelectorRequirement[];
        /** matchLabels is a map of {key,value} pairs. A single {key,value} in the matchLabels map is equivalent to an element of matchExpressions, whose key field is "key", the operator is "In", and the values array contains only "value". The requirements are ANDed. */
        matchLabels?: {
            [key: string]: string;
        };
    }
    /** A label selector requirement is a selector that contains values, a key, and an operator that relates the key and values. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$LabelSelectorRequirement {
        /** key is the label key that the selector applies to. */
        key: string;
        /** operator represents a key's relationship to a set of values. Valid operators are In, NotIn, Exists and DoesNotExist. */
        operator: string;
        /** values is an array of string values. If the operator is In or NotIn, the values array must be non-empty. If the operator is Exists or DoesNotExist, the values array must be empty. This array is replaced during a strategic merge patch. */
        values?: string[];
    }
    /** ListMeta describes metadata that synthetic resources must have, including lists and various status objects. A resource may have only one of {ObjectMeta, ListMeta}. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta {
        /** continue may be set if the user set a limit on the number of items returned, and indicates that the server has more data available. The value is opaque and may be used to issue another request to the endpoint that served this list to retrieve the next set of available objects. Continuing a consistent list may not be possible if the server configuration has changed or more than a few minutes have passed. The resourceVersion field returned when using this continue value will be identical to the value in the first response, unless you have received this token from an error message. */
        continue?: string;
        /** remainingItemCount is the number of subsequent items in the list which are not included in this list response. If the list request contained label or field selectors, then the number of remaining items is unknown and the field will be left unset and omitted during serialization. If the list is complete (either because it is not chunking or because this is the last chunk), then there are no more remaining items and this field will be left unset and omitted during serialization. Servers older than v1.15 do not set this field. The intended use of the remainingItemCount is *estimating* the size of a collection. Clients should not rely on the remainingItemCount to be set or to be exact. */
        remainingItemCount?: number;
        /** String that identifies the server's internal version of this object that can be used by clients to determine when objects have changed. Value must be treated as opaque by clients and passed unmodified back to the server. Populated by the system. Read-only. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#concurrency-control-and-consistency */
        resourceVersion?: string;
        /** Deprecated: selfLink is a legacy read-only field that is no longer populated by the system. */
        selfLink?: string;
    }
    /** ManagedFieldsEntry is a workflow-id, a FieldSet and the group version of the resource that the fieldset applies to. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$ManagedFieldsEntry {
        /** APIVersion defines the version of this resource that this field set applies to. The format is "group/version" just like the top-level APIVersion field. It is necessary to track the version of a field set because it cannot be automatically converted. */
        apiVersion?: string;
        /** FieldsType is the discriminator for the different fields format and version. There is currently only one possible value: "FieldsV1" */
        fieldsType?: string;
        fieldsV1?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$FieldsV1;
        /** Manager is an identifier of the workflow managing these fields. */
        manager?: string;
        /** Operation is the type of operation which lead to this ManagedFieldsEntry being created. The only valid values for this field are 'Apply' and 'Update'. */
        operation?: string;
        /** Subresource is the name of the subresource used to update that object, or empty string if the object was updated through the main resource. The value of this field is used to distinguish between managers, even if they share the same name. For example, a status update will be distinct from a regular update using the same manager name. Note that the APIVersion field is not related to the Subresource field and it always corresponds to the version of the main resource. */
        subresource?: string;
        time?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
    }
    /** MicroTime is version of Time with microsecond level precision. */
    type io$k8s$apimachinery$pkg$apis$meta$v1$MicroTime = string;
    /** ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta {
        /** Annotations is an unstructured key value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata. They are not queryable and should be preserved when modifying objects. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/annotations */
        annotations?: {
            [key: string]: string;
        };
        creationTimestamp?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** Number of seconds allowed for this object to gracefully terminate before it will be removed from the system. Only set when deletionTimestamp is also set. May only be shortened. Read-only. */
        deletionGracePeriodSeconds?: number;
        deletionTimestamp?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** Must be empty before the object is deleted from the registry. Each entry is an identifier for the responsible component that will remove the entry from the list. If the deletionTimestamp of the object is non-nil, entries in this list can only be removed. Finalizers may be processed and removed in any order.  Order is NOT enforced because it introduces significant risk of stuck finalizers. finalizers is a shared field, any actor with permission can reorder it. If the finalizer list is processed in order, then this can lead to a situation in which the component responsible for the first finalizer in the list is waiting for a signal (field value, external system, or other) produced by a component responsible for a finalizer later in the list, resulting in a deadlock. Without enforced ordering finalizers are free to order amongst themselves and are not vulnerable to ordering changes in the list. */
        finalizers?: string[];
        /**
         * GenerateName is an optional prefix, used by the server, to generate a unique name ONLY IF the Name field has not been provided. If this field is used, the name returned to the client will be different than the name passed. This value will also be combined with a unique suffix. The provided value has the same validation rules as the Name field, and may be truncated by the length of the suffix required to make the value unique on the server.
         *
         * If this field is specified and the generated name exists, the server will return a 409.
         *
         * Applied only if Name is not specified. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#idempotency
         */
        generateName?: string;
        /** A sequence number representing a specific generation of the desired state. Populated by the system. Read-only. */
        generation?: number;
        /** Map of string keys and values that can be used to organize and categorize (scope and select) objects. May match selectors of replication controllers and services. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels */
        labels?: {
            [key: string]: string;
        };
        /** ManagedFields maps workflow-id and version to the set of fields that are managed by that workflow. This is mostly for internal housekeeping, and users typically shouldn't need to set or understand this field. A workflow can be the user's name, a controller's name, or the name of a specific apply path like "ci-cd". The set of fields is always in the version that the workflow used when modifying the object. */
        managedFields?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ManagedFieldsEntry[];
        /** Name must be unique within a namespace. Is required when creating resources, although some resources may allow a client to request the generation of an appropriate name automatically. Name is primarily intended for creation idempotence and configuration definition. Cannot be updated. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names#names */
        name?: string;
        /**
         * Namespace defines the space within which each name must be unique. An empty namespace is equivalent to the "default" namespace, but "default" is the canonical representation. Not all objects are required to be scoped to a namespace - the value of this field for those objects will be empty.
         *
         * Must be a DNS_LABEL. Cannot be updated. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/namespaces
         */
        namespace?: string;
        /** List of objects depended by this object. If ALL objects in the list have been deleted, this object will be garbage collected. If this object is managed by a controller, then an entry in this list will point to this controller, with the controller field set to true. There cannot be more than one managing controller. */
        ownerReferences?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$OwnerReference[];
        /**
         * An opaque value that represents the internal version of this object that can be used by clients to determine when objects have changed. May be used for optimistic concurrency, change detection, and the watch operation on a resource or set of resources. Clients must treat these values as opaque and passed unmodified back to the server. They may only be valid for a particular resource or set of resources.
         *
         * Populated by the system. Read-only. Value must be treated as opaque by clients and . More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#concurrency-control-and-consistency
         */
        resourceVersion?: string;
        /** Deprecated: selfLink is a legacy read-only field that is no longer populated by the system. */
        selfLink?: string;
        /**
         * UID is the unique in time and space value for this object. It is typically generated by the server on successful creation of a resource and is not allowed to change on PUT operations.
         *
         * Populated by the system. Read-only. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names#uids
         */
        uid?: string;
    }
    /** OwnerReference contains enough information to let you identify an owning object. An owning object must be in the same namespace as the dependent, or be cluster-scoped, so there is no namespace field. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$OwnerReference {
        /** API version of the referent. */
        apiVersion: string;
        /** If true, AND if the owner has the "foregroundDeletion" finalizer, then the owner cannot be deleted from the key-value store until this reference is removed. See https://kubernetes.io/docs/concepts/architecture/garbage-collection/#foreground-deletion for how the garbage collector interacts with this field and enforces the foreground deletion. Defaults to false. To set this field, a user needs "delete" permission of the owner, otherwise 422 (Unprocessable Entity) will be returned. */
        blockOwnerDeletion?: boolean;
        /** If true, this reference points to the managing controller. */
        controller?: boolean;
        /** Kind of the referent. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind: string;
        /** Name of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names#names */
        name: string;
        /** UID of the referent. More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names#uids */
        uid: string;
    }
    /** Patch is provided to give a concrete name and type to the Kubernetes PATCH request body. */
    type io$k8s$apimachinery$pkg$apis$meta$v1$Patch = {};
    /** Preconditions must be fulfilled before an operation (update, delete, etc.) is carried out. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$Preconditions {
        /** Specifies the target ResourceVersion */
        resourceVersion?: string;
        /** Specifies the target UID. */
        uid?: string;
    }
    /** ServerAddressByClientCIDR helps the client to determine the server address that they should use, depending on the clientCIDR that they match. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$ServerAddressByClientCIDR {
        /** The CIDR with which clients can match their IP to figure out the server address that they should use. */
        clientCIDR: string;
        /** Address of this server, suitable for a client that matches the above CIDR. This can be a hostname, hostname:port, IP or IP:port. */
        serverAddress: string;
    }
    /** Status is a return value for calls that don't return other objects. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$Status {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Suggested HTTP return code for this status, 0 if not set. */
        code?: number;
        details?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$StatusDetails;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        /** A human-readable description of the status of this operation. */
        message?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
        /** A machine-readable description of why this operation is in the "Failure" status. If this value is empty there is no information available. A Reason clarifies an HTTP status code but does not override it. */
        reason?: string;
        /** Status of the operation. One of: "Success" or "Failure". More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status */
        status?: string;
    }
    /** StatusCause provides more information about an api.Status failure, including cases when multiple errors are encountered. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$StatusCause {
        /**
         * The field of the resource that has caused this error, as named by its JSON serialization. May include dot and postfix notation for nested attributes. Arrays are zero-indexed.  Fields may appear more than once in an array of causes due to fields having multiple errors. Optional.
         *
         * Examples:
         *   "name" - the field "name" on the current resource
         *   "items[0].name" - the field "name" on the first array entry in "items"
         */
        field?: string;
        /** A human-readable description of the cause of the error.  This field may be presented as-is to a reader. */
        message?: string;
        /** A machine-readable description of the cause of the error. If this value is empty there is no information available. */
        reason?: string;
    }
    /** StatusDetails is a set of additional properties that MAY be set by the server to provide additional information about a response. The Reason field of a Status object defines what attributes will be set. Clients must ignore fields that do not match the defined type of each attribute, and should assume that any attribute may be empty, invalid, or under defined. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$StatusDetails {
        /** The Causes array includes more details associated with the StatusReason failure. Not all StatusReasons may provide detailed causes. */
        causes?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$StatusCause[];
        /** The group attribute of the resource associated with the status StatusReason. */
        group?: string;
        /** The kind attribute of the resource associated with the status StatusReason. On some operations may differ from the requested resource Kind. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        /** The name attribute of the resource associated with the status StatusReason (when there is a single name which can be described). */
        name?: string;
        /** If specified, the time in seconds before the operation should be retried. Some errors may indicate the client must take an alternate action - for those errors this field may indicate how long to wait before taking the alternate action. */
        retryAfterSeconds?: number;
        /** UID of the resource. (when there is a single resource which can be described). More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/names#uids */
        uid?: string;
    }
    /** Time is a wrapper around time.Time which supports correct marshaling to YAML and JSON.  Wrappers are provided for many of the factory methods that the time package offers. */
    type io$k8s$apimachinery$pkg$apis$meta$v1$Time = string;
    /** Event represents a single event to a watched resource. */
    interface io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent {
        object: Schemas.io$k8s$apimachinery$pkg$runtime$RawExtension;
        type: string;
    }
    /**
     * RawExtension is used to hold extensions in external versions.
     *
     * To use this, make a field which has RawExtension as its type in your external, versioned struct, and Object in your internal struct. You also need to register your various plugin types.
     *
     * // Internal package:
     *
     * 	type MyAPIObject struct {
     * 		runtime.TypeMeta `json:",inline"`
     * 		MyPlugin runtime.Object `json:"myPlugin"`
     * 	}
     *
     * 	type PluginA struct {
     * 		AOption string `json:"aOption"`
     * 	}
     *
     * // External package:
     *
     * 	type MyAPIObject struct {
     * 		runtime.TypeMeta `json:",inline"`
     * 		MyPlugin runtime.RawExtension `json:"myPlugin"`
     * 	}
     *
     * 	type PluginA struct {
     * 		AOption string `json:"aOption"`
     * 	}
     *
     * // On the wire, the JSON will look something like this:
     *
     * 	{
     * 		"kind":"MyAPIObject",
     * 		"apiVersion":"v1",
     * 		"myPlugin": {
     * 			"kind":"PluginA",
     * 			"aOption":"foo",
     * 		},
     * 	}
     *
     * So what happens? Decode first uses json or yaml to unmarshal the serialized data into your external MyAPIObject. That causes the raw JSON to be stored, but not unpacked. The next step is to copy (using pkg/conversion) into the internal struct. The runtime package's DefaultScheme has conversion functions installed which will unpack the JSON stored in RawExtension, turning it into the correct object type, and storing it in the Object. (TODO: In the case where the object is of an unknown type, a runtime.Unknown object will be created and stored.)
     */
    type io$k8s$apimachinery$pkg$runtime$RawExtension = {};
    /** IntOrString is a type that can hold an int32 or a string.  When used in JSON or YAML marshalling and unmarshalling, it produces or consumes the inner type.  This allows you to have, for example, a JSON field that can accept a name or number. */
    type io$k8s$apimachinery$pkg$util$intstr$IntOrString = number | string;
    /** Info contains versioning information. how we'll want to distribute that information. */
    interface io$k8s$apimachinery$pkg$version$Info {
        buildDate: string;
        compiler: string;
        gitCommit: string;
        gitTreeState: string;
        gitVersion: string;
        goVersion: string;
        major: string;
        minor: string;
        platform: string;
    }
    /** APIService represents a server for a particular GroupVersion. Name must be "version.group". */
    interface io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ObjectMeta;
        spec?: Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceSpec;
        status?: Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceStatus;
    }
    /** APIServiceCondition describes the state of an APIService at a particular point */
    interface io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceCondition {
        lastTransitionTime?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Time;
        /** Human-readable message indicating details about last transition. */
        message?: string;
        /** Unique, one-word, CamelCase reason for the condition's last transition. */
        reason?: string;
        /** Status is the status of the condition. Can be True, False, Unknown. */
        status: string;
        /** Type is the type of the condition. */
        type: string;
    }
    /** APIServiceList is a list of APIService objects. */
    interface io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceList {
        /** APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources */
        apiVersion?: string;
        /** Items is the list of APIService */
        items: Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService[];
        /** Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds */
        kind?: string;
        metadata?: Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$ListMeta;
    }
    /** APIServiceSpec contains information for locating and communicating with a server. Only https is supported, though you are able to disable certificate verification. */
    interface io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceSpec {
        /** CABundle is a PEM encoded CA bundle which will be used to validate an API server's serving certificate. If unspecified, system trust roots on the apiserver are used. */
        caBundle?: Blob;
        /** Group is the API group name this server hosts */
        group?: string;
        /** GroupPriorityMininum is the priority this group should have at least. Higher priority means that the group is preferred by clients over lower priority ones. Note that other versions of this group might specify even higher GroupPriorityMininum values such that the whole group gets a higher priority. The primary sort is based on GroupPriorityMinimum, ordered highest number to lowest (20 before 10). The secondary sort is based on the alphabetical comparison of the name of the object.  (v1.bar before v1.foo) We'd recommend something like: *.k8s.io (except extensions) at 18000 and PaaSes (OpenShift, Deis) are recommended to be in the 2000s */
        groupPriorityMinimum: number;
        /** InsecureSkipTLSVerify disables TLS certificate verification when communicating with this server. This is strongly discouraged.  You should use the CABundle instead. */
        insecureSkipTLSVerify?: boolean;
        service?: Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$ServiceReference;
        /** Version is the API version this server hosts.  For example, "v1" */
        version?: string;
        /** VersionPriority controls the ordering of this API version inside of its group.  Must be greater than zero. The primary sort is based on VersionPriority, ordered highest to lowest (20 before 10). Since it's inside of a group, the number can be small, probably in the 10s. In case of equal version priorities, the version string will be used to compute the order inside a group. If the version string is "kube-like", it will sort above non "kube-like" version strings, which are ordered lexicographically. "Kube-like" versions start with a "v", then are followed by a number (the major version), then optionally the string "alpha" or "beta" and another number (the minor version). These are sorted first by GA > beta > alpha (where GA is a version with no suffix such as beta or alpha), and then by comparing major version, then minor version. An example sorted list of versions: v10, v2, v1, v11beta2, v10beta3, v3beta1, v12alpha1, v11alpha2, foo1, foo10. */
        versionPriority: number;
    }
    /** APIServiceStatus contains derived information about an API server */
    interface io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceStatus {
        /** Current service state of apiService. */
        conditions?: Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceCondition[];
    }
    /** ServiceReference holds a reference to Service.legacy.k8s.io */
    interface io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$ServiceReference {
        /** Name is the name of the service */
        name?: string;
        /** Namespace is the namespace of the service */
        namespace?: string;
        /** If specified, the port on the service that hosting webhook. Default to 443 for backward compatibility. `port` should be a valid port number (1-65535, inclusive). */
        port?: number;
    }
}
declare namespace RequestBodies {
    namespace io$k8s$api$core$v1$Secret {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$Secret;
        }
    }
    namespace io$k8s$api$core$v1$LimitRange {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$LimitRange;
        }
    }
    namespace io$k8s$api$storage$v1$VolumeAttachment {
        interface Content {
            "*/*": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
        }
    }
    namespace io$k8s$api$flowcontrol$v1beta3$FlowSchema {
        interface Content {
            "*/*": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
        }
    }
    namespace io$k8s$api$node$v1$RuntimeClass {
        interface Content {
            "*/*": Schemas.io$k8s$api$node$v1$RuntimeClass;
        }
    }
    namespace io$k8s$api$apps$v1$Deployment {
        interface Content {
            "*/*": Schemas.io$k8s$api$apps$v1$Deployment;
        }
    }
    namespace io$k8s$api$core$v1$ServiceAccount {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$ServiceAccount;
        }
    }
    namespace io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration {
        interface Content {
            "*/*": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
        }
    }
    namespace io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding {
        interface Content {
            "*/*": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
        }
    }
    namespace io$k8s$api$apps$v1$DaemonSet {
        interface Content {
            "*/*": Schemas.io$k8s$api$apps$v1$DaemonSet;
        }
    }
    namespace io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService {
        interface Content {
            "*/*": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
        }
    }
    namespace io$k8s$api$core$v1$Service {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$Service;
        }
    }
    namespace io$k8s$api$rbac$v1$RoleBinding {
        interface Content {
            "*/*": Schemas.io$k8s$api$rbac$v1$RoleBinding;
        }
    }
    namespace io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration {
        interface Content {
            "*/*": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
        }
    }
    namespace io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration {
        interface Content {
            "*/*": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
        }
    }
    namespace io$k8s$api$apps$v1$ReplicaSet {
        interface Content {
            "*/*": Schemas.io$k8s$api$apps$v1$ReplicaSet;
        }
    }
    namespace io$k8s$api$resource$v1alpha2$ResourceClaimTemplate {
        interface Content {
            "*/*": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
        }
    }
    namespace io$k8s$api$core$v1$Namespace {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$Namespace;
        }
    }
    namespace io$k8s$api$storage$v1$CSIStorageCapacity {
        interface Content {
            "*/*": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
        }
    }
    namespace io$k8s$api$batch$v1$Job {
        interface Content {
            "*/*": Schemas.io$k8s$api$batch$v1$Job;
        }
    }
    namespace io$k8s$api$core$v1$Node {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$Node;
        }
    }
    namespace io$k8s$api$certificates$v1alpha1$ClusterTrustBundle {
        interface Content {
            "*/*": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
        }
    }
    namespace io$k8s$api$core$v1$ReplicationController {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$ReplicationController;
        }
    }
    namespace io$k8s$api$events$v1$Event {
        interface Content {
            "*/*": Schemas.io$k8s$api$events$v1$Event;
        }
    }
    namespace io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions {
        interface Content {
            "*/*": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions;
        }
    }
    namespace io$k8s$api$storage$v1$CSIDriver {
        interface Content {
            "*/*": Schemas.io$k8s$api$storage$v1$CSIDriver;
        }
    }
    namespace io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler {
        interface Content {
            "*/*": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
        }
    }
    namespace io$k8s$api$autoscaling$v1$Scale {
        interface Content {
            "*/*": Schemas.io$k8s$api$autoscaling$v1$Scale;
        }
    }
    namespace io$k8s$api$rbac$v1$ClusterRole {
        interface Content {
            "*/*": Schemas.io$k8s$api$rbac$v1$ClusterRole;
        }
    }
    namespace io$k8s$api$discovery$v1$EndpointSlice {
        interface Content {
            "*/*": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
        }
    }
    namespace io$k8s$api$coordination$v1$Lease {
        interface Content {
            "*/*": Schemas.io$k8s$api$coordination$v1$Lease;
        }
    }
    namespace io$k8s$api$core$v1$ConfigMap {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$ConfigMap;
        }
    }
    namespace io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy {
        interface Content {
            "*/*": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
        }
    }
    namespace io$k8s$api$core$v1$Binding {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$Binding;
        }
    }
    namespace io$k8s$apimachinery$pkg$apis$meta$v1$Patch {
        interface Content {
            "application/json-patch+json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Patch;
            "application/merge-patch+json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Patch;
            "application/strategic-merge-patch+json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Patch;
            "application/apply-patch+yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Patch;
        }
    }
    namespace io$k8s$api$core$v1$Endpoints {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$Endpoints;
        }
    }
    namespace io$k8s$api$core$v1$Event {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$Event;
        }
    }
    namespace io$k8s$api$core$v1$PersistentVolumeClaim {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
        }
    }
    namespace io$k8s$api$core$v1$Pod {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$Pod;
        }
    }
    namespace io$k8s$api$core$v1$PodTemplate {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$PodTemplate;
        }
    }
    namespace io$k8s$api$core$v1$ResourceQuota {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$ResourceQuota;
        }
    }
    namespace io$k8s$api$core$v1$PersistentVolume {
        interface Content {
            "*/*": Schemas.io$k8s$api$core$v1$PersistentVolume;
        }
    }
    namespace io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration {
        interface Content {
            "*/*": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
        }
    }
    namespace io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition {
        interface Content {
            "*/*": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
        }
    }
    namespace io$k8s$api$apps$v1$ControllerRevision {
        interface Content {
            "*/*": Schemas.io$k8s$api$apps$v1$ControllerRevision;
        }
    }
    namespace io$k8s$api$apps$v1$StatefulSet {
        interface Content {
            "*/*": Schemas.io$k8s$api$apps$v1$StatefulSet;
        }
    }
    namespace io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler {
        interface Content {
            "*/*": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
        }
    }
    namespace io$k8s$api$batch$v1$CronJob {
        interface Content {
            "*/*": Schemas.io$k8s$api$batch$v1$CronJob;
        }
    }
    namespace io$k8s$api$certificates$v1$CertificateSigningRequest {
        interface Content {
            "*/*": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
        }
    }
    namespace io$k8s$api$flowcontrol$v1beta2$FlowSchema {
        interface Content {
            "*/*": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
        }
    }
    namespace io$k8s$api$apiserverinternal$v1alpha1$StorageVersion {
        interface Content {
            "*/*": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
        }
    }
    namespace io$k8s$api$networking$v1$IngressClass {
        interface Content {
            "*/*": Schemas.io$k8s$api$networking$v1$IngressClass;
        }
    }
    namespace io$k8s$api$networking$v1$Ingress {
        interface Content {
            "*/*": Schemas.io$k8s$api$networking$v1$Ingress;
        }
    }
    namespace io$k8s$api$networking$v1$NetworkPolicy {
        interface Content {
            "*/*": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
        }
    }
    namespace io$k8s$api$networking$v1alpha1$ClusterCIDR {
        interface Content {
            "*/*": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
        }
    }
    namespace io$k8s$api$networking$v1alpha1$IPAddress {
        interface Content {
            "*/*": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
        }
    }
    namespace io$k8s$api$policy$v1$PodDisruptionBudget {
        interface Content {
            "*/*": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
        }
    }
    namespace io$k8s$api$rbac$v1$ClusterRoleBinding {
        interface Content {
            "*/*": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
        }
    }
    namespace io$k8s$api$rbac$v1$Role {
        interface Content {
            "*/*": Schemas.io$k8s$api$rbac$v1$Role;
        }
    }
    namespace io$k8s$api$resource$v1alpha2$PodSchedulingContext {
        interface Content {
            "*/*": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
        }
    }
    namespace io$k8s$api$resource$v1alpha2$ResourceClaim {
        interface Content {
            "*/*": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
        }
    }
    namespace io$k8s$api$resource$v1alpha2$ResourceClass {
        interface Content {
            "*/*": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
        }
    }
    namespace io$k8s$api$scheduling$v1$PriorityClass {
        interface Content {
            "*/*": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
        }
    }
    namespace io$k8s$api$storage$v1$CSINode {
        interface Content {
            "*/*": Schemas.io$k8s$api$storage$v1$CSINode;
        }
    }
    namespace io$k8s$api$storage$v1$StorageClass {
        interface Content {
            "*/*": Schemas.io$k8s$api$storage$v1$StorageClass;
        }
    }
}
interface Response$getServiceAccountIssuerOpenIDConfiguration$Status$200 {
    "application/json": string;
}
interface Response$getCoreAPIVersions$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIVersions;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIVersions;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIVersions;
}
interface Response$getCoreV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listCoreV1ComponentStatus {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1ComponentStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ComponentStatusList;
    "application/yaml": Schemas.io$k8s$api$core$v1$ComponentStatusList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ComponentStatusList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$ComponentStatusList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$ComponentStatusList;
}
interface Parameter$readCoreV1ComponentStatus {
    /** name of the ComponentStatus */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1ComponentStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ComponentStatus;
    "application/yaml": Schemas.io$k8s$api$core$v1$ComponentStatus;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ComponentStatus;
}
interface Parameter$listCoreV1ConfigMapForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1ConfigMapForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ConfigMapList;
    "application/yaml": Schemas.io$k8s$api$core$v1$ConfigMapList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ConfigMapList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$ConfigMapList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$ConfigMapList;
}
interface Parameter$listCoreV1EndpointsForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1EndpointsForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$EndpointsList;
    "application/yaml": Schemas.io$k8s$api$core$v1$EndpointsList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$EndpointsList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$EndpointsList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$EndpointsList;
}
interface Parameter$listCoreV1EventForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1EventForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$EventList;
    "application/yaml": Schemas.io$k8s$api$core$v1$EventList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$EventList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$EventList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$EventList;
}
interface Parameter$listCoreV1LimitRangeForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1LimitRangeForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$LimitRangeList;
    "application/yaml": Schemas.io$k8s$api$core$v1$LimitRangeList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$LimitRangeList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$LimitRangeList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$LimitRangeList;
}
interface Parameter$listCoreV1Namespace {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1Namespace$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$NamespaceList;
    "application/yaml": Schemas.io$k8s$api$core$v1$NamespaceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$NamespaceList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$NamespaceList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$NamespaceList;
}
interface Parameter$createCoreV1Namespace {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createCoreV1Namespace = RequestBodies.io$k8s$api$core$v1$Namespace.Content;
interface Response$createCoreV1Namespace$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
interface Response$createCoreV1Namespace$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
interface Response$createCoreV1Namespace$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
interface Parameter$createCoreV1NamespacedBinding {
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
type RequestBody$createCoreV1NamespacedBinding = RequestBodies.io$k8s$api$core$v1$Binding.Content;
interface Response$createCoreV1NamespacedBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Binding;
    "application/yaml": Schemas.io$k8s$api$core$v1$Binding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Binding;
}
interface Response$createCoreV1NamespacedBinding$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Binding;
    "application/yaml": Schemas.io$k8s$api$core$v1$Binding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Binding;
}
interface Response$createCoreV1NamespacedBinding$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$Binding;
    "application/yaml": Schemas.io$k8s$api$core$v1$Binding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Binding;
}
interface Parameter$listCoreV1NamespacedConfigMap {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1NamespacedConfigMap$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ConfigMapList;
    "application/yaml": Schemas.io$k8s$api$core$v1$ConfigMapList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ConfigMapList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$ConfigMapList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$ConfigMapList;
}
interface Parameter$createCoreV1NamespacedConfigMap {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createCoreV1NamespacedConfigMap = RequestBodies.io$k8s$api$core$v1$ConfigMap.Content;
interface Response$createCoreV1NamespacedConfigMap$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/yaml": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ConfigMap;
}
interface Response$createCoreV1NamespacedConfigMap$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/yaml": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ConfigMap;
}
interface Response$createCoreV1NamespacedConfigMap$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/yaml": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ConfigMap;
}
interface Parameter$deleteCoreV1CollectionNamespacedConfigMap {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteCoreV1CollectionNamespacedConfigMap = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1CollectionNamespacedConfigMap$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readCoreV1NamespacedConfigMap {
    /** name of the ConfigMap */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1NamespacedConfigMap$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/yaml": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ConfigMap;
}
interface Parameter$replaceCoreV1NamespacedConfigMap {
    /** name of the ConfigMap */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1NamespacedConfigMap = RequestBodies.io$k8s$api$core$v1$ConfigMap.Content;
interface Response$replaceCoreV1NamespacedConfigMap$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/yaml": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ConfigMap;
}
interface Response$replaceCoreV1NamespacedConfigMap$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/yaml": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ConfigMap;
}
interface Parameter$deleteCoreV1NamespacedConfigMap {
    /** name of the ConfigMap */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteCoreV1NamespacedConfigMap = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1NamespacedConfigMap$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteCoreV1NamespacedConfigMap$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchCoreV1NamespacedConfigMap {
    /** name of the ConfigMap */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1NamespacedConfigMap = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1NamespacedConfigMap$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/yaml": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ConfigMap;
}
interface Response$patchCoreV1NamespacedConfigMap$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/yaml": Schemas.io$k8s$api$core$v1$ConfigMap;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ConfigMap;
}
interface Parameter$listCoreV1NamespacedEndpoints {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1NamespacedEndpoints$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$EndpointsList;
    "application/yaml": Schemas.io$k8s$api$core$v1$EndpointsList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$EndpointsList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$EndpointsList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$EndpointsList;
}
interface Parameter$createCoreV1NamespacedEndpoints {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createCoreV1NamespacedEndpoints = RequestBodies.io$k8s$api$core$v1$Endpoints.Content;
interface Response$createCoreV1NamespacedEndpoints$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/yaml": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Endpoints;
}
interface Response$createCoreV1NamespacedEndpoints$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/yaml": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Endpoints;
}
interface Response$createCoreV1NamespacedEndpoints$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/yaml": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Endpoints;
}
interface Parameter$deleteCoreV1CollectionNamespacedEndpoints {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteCoreV1CollectionNamespacedEndpoints = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1CollectionNamespacedEndpoints$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readCoreV1NamespacedEndpoints {
    /** name of the Endpoints */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1NamespacedEndpoints$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/yaml": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Endpoints;
}
interface Parameter$replaceCoreV1NamespacedEndpoints {
    /** name of the Endpoints */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1NamespacedEndpoints = RequestBodies.io$k8s$api$core$v1$Endpoints.Content;
interface Response$replaceCoreV1NamespacedEndpoints$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/yaml": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Endpoints;
}
interface Response$replaceCoreV1NamespacedEndpoints$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/yaml": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Endpoints;
}
interface Parameter$deleteCoreV1NamespacedEndpoints {
    /** name of the Endpoints */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteCoreV1NamespacedEndpoints = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1NamespacedEndpoints$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteCoreV1NamespacedEndpoints$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchCoreV1NamespacedEndpoints {
    /** name of the Endpoints */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1NamespacedEndpoints = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1NamespacedEndpoints$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/yaml": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Endpoints;
}
interface Response$patchCoreV1NamespacedEndpoints$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/yaml": Schemas.io$k8s$api$core$v1$Endpoints;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Endpoints;
}
interface Parameter$listCoreV1NamespacedEvent {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$EventList;
    "application/yaml": Schemas.io$k8s$api$core$v1$EventList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$EventList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$EventList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$EventList;
}
interface Parameter$createCoreV1NamespacedEvent {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createCoreV1NamespacedEvent = RequestBodies.io$k8s$api$core$v1$Event.Content;
interface Response$createCoreV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Event;
    "application/yaml": Schemas.io$k8s$api$core$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Event;
}
interface Response$createCoreV1NamespacedEvent$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Event;
    "application/yaml": Schemas.io$k8s$api$core$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Event;
}
interface Response$createCoreV1NamespacedEvent$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$Event;
    "application/yaml": Schemas.io$k8s$api$core$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Event;
}
interface Parameter$deleteCoreV1CollectionNamespacedEvent {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteCoreV1CollectionNamespacedEvent = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1CollectionNamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readCoreV1NamespacedEvent {
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Event;
    "application/yaml": Schemas.io$k8s$api$core$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Event;
}
interface Parameter$replaceCoreV1NamespacedEvent {
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1NamespacedEvent = RequestBodies.io$k8s$api$core$v1$Event.Content;
interface Response$replaceCoreV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Event;
    "application/yaml": Schemas.io$k8s$api$core$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Event;
}
interface Response$replaceCoreV1NamespacedEvent$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Event;
    "application/yaml": Schemas.io$k8s$api$core$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Event;
}
interface Parameter$deleteCoreV1NamespacedEvent {
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteCoreV1NamespacedEvent = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteCoreV1NamespacedEvent$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchCoreV1NamespacedEvent {
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1NamespacedEvent = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Event;
    "application/yaml": Schemas.io$k8s$api$core$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Event;
}
interface Response$patchCoreV1NamespacedEvent$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Event;
    "application/yaml": Schemas.io$k8s$api$core$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Event;
}
interface Parameter$listCoreV1NamespacedLimitRange {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1NamespacedLimitRange$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$LimitRangeList;
    "application/yaml": Schemas.io$k8s$api$core$v1$LimitRangeList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$LimitRangeList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$LimitRangeList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$LimitRangeList;
}
interface Parameter$createCoreV1NamespacedLimitRange {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createCoreV1NamespacedLimitRange = RequestBodies.io$k8s$api$core$v1$LimitRange.Content;
interface Response$createCoreV1NamespacedLimitRange$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/yaml": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$LimitRange;
}
interface Response$createCoreV1NamespacedLimitRange$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/yaml": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$LimitRange;
}
interface Response$createCoreV1NamespacedLimitRange$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/yaml": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$LimitRange;
}
interface Parameter$deleteCoreV1CollectionNamespacedLimitRange {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteCoreV1CollectionNamespacedLimitRange = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1CollectionNamespacedLimitRange$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readCoreV1NamespacedLimitRange {
    /** name of the LimitRange */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1NamespacedLimitRange$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/yaml": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$LimitRange;
}
interface Parameter$replaceCoreV1NamespacedLimitRange {
    /** name of the LimitRange */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1NamespacedLimitRange = RequestBodies.io$k8s$api$core$v1$LimitRange.Content;
interface Response$replaceCoreV1NamespacedLimitRange$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/yaml": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$LimitRange;
}
interface Response$replaceCoreV1NamespacedLimitRange$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/yaml": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$LimitRange;
}
interface Parameter$deleteCoreV1NamespacedLimitRange {
    /** name of the LimitRange */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteCoreV1NamespacedLimitRange = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1NamespacedLimitRange$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteCoreV1NamespacedLimitRange$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchCoreV1NamespacedLimitRange {
    /** name of the LimitRange */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1NamespacedLimitRange = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1NamespacedLimitRange$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/yaml": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$LimitRange;
}
interface Response$patchCoreV1NamespacedLimitRange$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/yaml": Schemas.io$k8s$api$core$v1$LimitRange;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$LimitRange;
}
interface Parameter$listCoreV1NamespacedPersistentVolumeClaim {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1NamespacedPersistentVolumeClaim$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaimList;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaimList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaimList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$PersistentVolumeClaimList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$PersistentVolumeClaimList;
}
interface Parameter$createCoreV1NamespacedPersistentVolumeClaim {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createCoreV1NamespacedPersistentVolumeClaim = RequestBodies.io$k8s$api$core$v1$PersistentVolumeClaim.Content;
interface Response$createCoreV1NamespacedPersistentVolumeClaim$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
interface Response$createCoreV1NamespacedPersistentVolumeClaim$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
interface Response$createCoreV1NamespacedPersistentVolumeClaim$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
interface Parameter$deleteCoreV1CollectionNamespacedPersistentVolumeClaim {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteCoreV1CollectionNamespacedPersistentVolumeClaim = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1CollectionNamespacedPersistentVolumeClaim$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readCoreV1NamespacedPersistentVolumeClaim {
    /** name of the PersistentVolumeClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1NamespacedPersistentVolumeClaim$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
interface Parameter$replaceCoreV1NamespacedPersistentVolumeClaim {
    /** name of the PersistentVolumeClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1NamespacedPersistentVolumeClaim = RequestBodies.io$k8s$api$core$v1$PersistentVolumeClaim.Content;
interface Response$replaceCoreV1NamespacedPersistentVolumeClaim$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
interface Response$replaceCoreV1NamespacedPersistentVolumeClaim$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
interface Parameter$deleteCoreV1NamespacedPersistentVolumeClaim {
    /** name of the PersistentVolumeClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteCoreV1NamespacedPersistentVolumeClaim = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1NamespacedPersistentVolumeClaim$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
interface Response$deleteCoreV1NamespacedPersistentVolumeClaim$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
interface Parameter$patchCoreV1NamespacedPersistentVolumeClaim {
    /** name of the PersistentVolumeClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1NamespacedPersistentVolumeClaim = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1NamespacedPersistentVolumeClaim$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
interface Response$patchCoreV1NamespacedPersistentVolumeClaim$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
interface Parameter$readCoreV1NamespacedPersistentVolumeClaimStatus {
    /** name of the PersistentVolumeClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1NamespacedPersistentVolumeClaimStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
interface Parameter$replaceCoreV1NamespacedPersistentVolumeClaimStatus {
    /** name of the PersistentVolumeClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1NamespacedPersistentVolumeClaimStatus = RequestBodies.io$k8s$api$core$v1$PersistentVolumeClaim.Content;
interface Response$replaceCoreV1NamespacedPersistentVolumeClaimStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
interface Response$replaceCoreV1NamespacedPersistentVolumeClaimStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
interface Parameter$patchCoreV1NamespacedPersistentVolumeClaimStatus {
    /** name of the PersistentVolumeClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1NamespacedPersistentVolumeClaimStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1NamespacedPersistentVolumeClaimStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
interface Response$patchCoreV1NamespacedPersistentVolumeClaimStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaim;
}
interface Parameter$listCoreV1NamespacedPod {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1NamespacedPod$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PodList;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$PodList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$PodList;
}
interface Parameter$createCoreV1NamespacedPod {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createCoreV1NamespacedPod = RequestBodies.io$k8s$api$core$v1$Pod.Content;
interface Response$createCoreV1NamespacedPod$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
interface Response$createCoreV1NamespacedPod$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
interface Response$createCoreV1NamespacedPod$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
interface Parameter$deleteCoreV1CollectionNamespacedPod {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteCoreV1CollectionNamespacedPod = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1CollectionNamespacedPod$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readCoreV1NamespacedPod {
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1NamespacedPod$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
interface Parameter$replaceCoreV1NamespacedPod {
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1NamespacedPod = RequestBodies.io$k8s$api$core$v1$Pod.Content;
interface Response$replaceCoreV1NamespacedPod$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
interface Response$replaceCoreV1NamespacedPod$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
interface Parameter$deleteCoreV1NamespacedPod {
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteCoreV1NamespacedPod = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1NamespacedPod$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
interface Response$deleteCoreV1NamespacedPod$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
interface Parameter$patchCoreV1NamespacedPod {
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1NamespacedPod = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1NamespacedPod$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
interface Response$patchCoreV1NamespacedPod$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
interface Parameter$connectCoreV1GetNamespacedPodAttach {
    /** The container in which to execute the command. Defaults to only container if there is only one container in the pod. */
    container?: string;
    /** name of the PodAttachOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Stderr if true indicates that stderr is to be redirected for the attach call. Defaults to true. */
    stderr?: boolean;
    /** Stdin if true, redirects the standard input stream of the pod for this call. Defaults to false. */
    stdin?: boolean;
    /** Stdout if true indicates that stdout is to be redirected for the attach call. Defaults to true. */
    stdout?: boolean;
    /** TTY if true indicates that a tty will be allocated for the attach call. This is passed through the container runtime so the tty is allocated on the worker node by the container runtime. Defaults to false. */
    tty?: boolean;
}
interface Response$connectCoreV1GetNamespacedPodAttach$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1PostNamespacedPodAttach {
    /** The container in which to execute the command. Defaults to only container if there is only one container in the pod. */
    container?: string;
    /** name of the PodAttachOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Stderr if true indicates that stderr is to be redirected for the attach call. Defaults to true. */
    stderr?: boolean;
    /** Stdin if true, redirects the standard input stream of the pod for this call. Defaults to false. */
    stdin?: boolean;
    /** Stdout if true indicates that stdout is to be redirected for the attach call. Defaults to true. */
    stdout?: boolean;
    /** TTY if true indicates that a tty will be allocated for the attach call. This is passed through the container runtime so the tty is allocated on the worker node by the container runtime. Defaults to false. */
    tty?: boolean;
}
interface Response$connectCoreV1PostNamespacedPodAttach$Status$200 {
    "*/*": string;
}
interface Parameter$createCoreV1NamespacedPodBinding {
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** name of the Binding */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
type RequestBody$createCoreV1NamespacedPodBinding = RequestBodies.io$k8s$api$core$v1$Binding.Content;
interface Response$createCoreV1NamespacedPodBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Binding;
    "application/yaml": Schemas.io$k8s$api$core$v1$Binding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Binding;
}
interface Response$createCoreV1NamespacedPodBinding$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Binding;
    "application/yaml": Schemas.io$k8s$api$core$v1$Binding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Binding;
}
interface Response$createCoreV1NamespacedPodBinding$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$Binding;
    "application/yaml": Schemas.io$k8s$api$core$v1$Binding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Binding;
}
interface Parameter$readCoreV1NamespacedPodEphemeralcontainers {
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1NamespacedPodEphemeralcontainers$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
interface Parameter$replaceCoreV1NamespacedPodEphemeralcontainers {
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1NamespacedPodEphemeralcontainers = RequestBodies.io$k8s$api$core$v1$Pod.Content;
interface Response$replaceCoreV1NamespacedPodEphemeralcontainers$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
interface Response$replaceCoreV1NamespacedPodEphemeralcontainers$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
interface Parameter$patchCoreV1NamespacedPodEphemeralcontainers {
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1NamespacedPodEphemeralcontainers = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1NamespacedPodEphemeralcontainers$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
interface Response$patchCoreV1NamespacedPodEphemeralcontainers$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
interface Parameter$createCoreV1NamespacedPodEviction {
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** name of the Eviction */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface RequestBody$createCoreV1NamespacedPodEviction {
    "*/*": Schemas.io$k8s$api$policy$v1$Eviction;
}
interface Response$createCoreV1NamespacedPodEviction$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1$Eviction;
    "application/yaml": Schemas.io$k8s$api$policy$v1$Eviction;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$Eviction;
}
interface Response$createCoreV1NamespacedPodEviction$Status$201 {
    "application/json": Schemas.io$k8s$api$policy$v1$Eviction;
    "application/yaml": Schemas.io$k8s$api$policy$v1$Eviction;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$Eviction;
}
interface Response$createCoreV1NamespacedPodEviction$Status$202 {
    "application/json": Schemas.io$k8s$api$policy$v1$Eviction;
    "application/yaml": Schemas.io$k8s$api$policy$v1$Eviction;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$Eviction;
}
interface Parameter$connectCoreV1GetNamespacedPodExec {
    /** Command is the remote command to execute. argv array. Not executed within a shell. */
    command?: string;
    /** Container in which to execute the command. Defaults to only container if there is only one container in the pod. */
    container?: string;
    /** name of the PodExecOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Redirect the standard error stream of the pod for this call. */
    stderr?: boolean;
    /** Redirect the standard input stream of the pod for this call. Defaults to false. */
    stdin?: boolean;
    /** Redirect the standard output stream of the pod for this call. */
    stdout?: boolean;
    /** TTY if true indicates that a tty will be allocated for the exec call. Defaults to false. */
    tty?: boolean;
}
interface Response$connectCoreV1GetNamespacedPodExec$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1PostNamespacedPodExec {
    /** Command is the remote command to execute. argv array. Not executed within a shell. */
    command?: string;
    /** Container in which to execute the command. Defaults to only container if there is only one container in the pod. */
    container?: string;
    /** name of the PodExecOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Redirect the standard error stream of the pod for this call. */
    stderr?: boolean;
    /** Redirect the standard input stream of the pod for this call. Defaults to false. */
    stdin?: boolean;
    /** Redirect the standard output stream of the pod for this call. */
    stdout?: boolean;
    /** TTY if true indicates that a tty will be allocated for the exec call. Defaults to false. */
    tty?: boolean;
}
interface Response$connectCoreV1PostNamespacedPodExec$Status$200 {
    "*/*": string;
}
interface Parameter$readCoreV1NamespacedPodLog {
    /** The container for which to stream logs. Defaults to only container if there is one container in the pod. */
    container?: string;
    /** Follow the log stream of the pod. Defaults to false. */
    follow?: boolean;
    /** insecureSkipTLSVerifyBackend indicates that the apiserver should not confirm the validity of the serving certificate of the backend it is connecting to.  This will make the HTTPS connection between the apiserver and the backend insecure. This means the apiserver cannot verify the log data it is receiving came from the real kubelet.  If the kubelet is configured to verify the apiserver's TLS credentials, it does not mean the connection to the real kubelet is vulnerable to a man in the middle attack (e.g. an attacker could not intercept the actual log data coming from the real kubelet). */
    insecureSkipTLSVerifyBackend?: boolean;
    /** If set, the number of bytes to read from the server before terminating the log output. This may not display a complete final line of logging, and may return slightly more or slightly less than the specified limit. */
    limitBytes?: number;
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** Return previous terminated container logs. Defaults to false. */
    previous?: boolean;
    /** A relative time in seconds before the current time from which to show logs. If this value precedes the time a pod was started, only logs since the pod start will be returned. If this value is in the future, no logs will be returned. Only one of sinceSeconds or sinceTime may be specified. */
    sinceSeconds?: number;
    /** If set, the number of lines from the end of the logs to show. If not specified, logs are shown from the creation of the container or sinceSeconds or sinceTime */
    tailLines?: number;
    /** If true, add an RFC3339 or RFC3339Nano timestamp at the beginning of every line of log output. Defaults to false. */
    timestamps?: boolean;
}
interface Response$readCoreV1NamespacedPodLog$Status$200 {
    "text/plain": string;
    "application/json": string;
    "application/yaml": string;
    "application/vnd.kubernetes.protobuf": string;
}
interface Parameter$connectCoreV1GetNamespacedPodPortforward {
    /** name of the PodPortForwardOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** List of ports to forward Required when using WebSockets */
    ports?: number;
}
interface Response$connectCoreV1GetNamespacedPodPortforward$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1PostNamespacedPodPortforward {
    /** name of the PodPortForwardOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** List of ports to forward Required when using WebSockets */
    ports?: number;
}
interface Response$connectCoreV1PostNamespacedPodPortforward$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1GetNamespacedPodProxy {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
interface Response$connectCoreV1GetNamespacedPodProxy$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1PutNamespacedPodProxy {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
interface Response$connectCoreV1PutNamespacedPodProxy$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1PostNamespacedPodProxy {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
interface Response$connectCoreV1PostNamespacedPodProxy$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1DeleteNamespacedPodProxy {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
interface Response$connectCoreV1DeleteNamespacedPodProxy$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1OptionsNamespacedPodProxy {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
interface Response$connectCoreV1OptionsNamespacedPodProxy$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1HeadNamespacedPodProxy {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
interface Response$connectCoreV1HeadNamespacedPodProxy$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1PatchNamespacedPodProxy {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
interface Response$connectCoreV1PatchNamespacedPodProxy$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1GetNamespacedPodProxyWithPath {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
interface Response$connectCoreV1GetNamespacedPodProxyWithPath$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1PutNamespacedPodProxyWithPath {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
interface Response$connectCoreV1PutNamespacedPodProxyWithPath$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1PostNamespacedPodProxyWithPath {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
interface Response$connectCoreV1PostNamespacedPodProxyWithPath$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1DeleteNamespacedPodProxyWithPath {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
interface Response$connectCoreV1DeleteNamespacedPodProxyWithPath$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1OptionsNamespacedPodProxyWithPath {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
interface Response$connectCoreV1OptionsNamespacedPodProxyWithPath$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1HeadNamespacedPodProxyWithPath {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
interface Response$connectCoreV1HeadNamespacedPodProxyWithPath$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1PatchNamespacedPodProxyWithPath {
    /** name of the PodProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the URL path to use for the current proxy request to pod. */
    path?: string;
}
interface Response$connectCoreV1PatchNamespacedPodProxyWithPath$Status$200 {
    "*/*": string;
}
interface Parameter$readCoreV1NamespacedPodStatus {
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1NamespacedPodStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
interface Parameter$replaceCoreV1NamespacedPodStatus {
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1NamespacedPodStatus = RequestBodies.io$k8s$api$core$v1$Pod.Content;
interface Response$replaceCoreV1NamespacedPodStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
interface Response$replaceCoreV1NamespacedPodStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
interface Parameter$patchCoreV1NamespacedPodStatus {
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1NamespacedPodStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1NamespacedPodStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
interface Response$patchCoreV1NamespacedPodStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Pod;
    "application/yaml": Schemas.io$k8s$api$core$v1$Pod;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Pod;
}
interface Parameter$listCoreV1NamespacedPodTemplate {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1NamespacedPodTemplate$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplateList;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplateList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplateList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$PodTemplateList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$PodTemplateList;
}
interface Parameter$createCoreV1NamespacedPodTemplate {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createCoreV1NamespacedPodTemplate = RequestBodies.io$k8s$api$core$v1$PodTemplate.Content;
interface Response$createCoreV1NamespacedPodTemplate$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplate;
}
interface Response$createCoreV1NamespacedPodTemplate$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplate;
}
interface Response$createCoreV1NamespacedPodTemplate$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplate;
}
interface Parameter$deleteCoreV1CollectionNamespacedPodTemplate {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteCoreV1CollectionNamespacedPodTemplate = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1CollectionNamespacedPodTemplate$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readCoreV1NamespacedPodTemplate {
    /** name of the PodTemplate */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1NamespacedPodTemplate$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplate;
}
interface Parameter$replaceCoreV1NamespacedPodTemplate {
    /** name of the PodTemplate */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1NamespacedPodTemplate = RequestBodies.io$k8s$api$core$v1$PodTemplate.Content;
interface Response$replaceCoreV1NamespacedPodTemplate$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplate;
}
interface Response$replaceCoreV1NamespacedPodTemplate$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplate;
}
interface Parameter$deleteCoreV1NamespacedPodTemplate {
    /** name of the PodTemplate */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteCoreV1NamespacedPodTemplate = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1NamespacedPodTemplate$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplate;
}
interface Response$deleteCoreV1NamespacedPodTemplate$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplate;
}
interface Parameter$patchCoreV1NamespacedPodTemplate {
    /** name of the PodTemplate */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1NamespacedPodTemplate = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1NamespacedPodTemplate$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplate;
}
interface Response$patchCoreV1NamespacedPodTemplate$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplate;
}
interface Parameter$listCoreV1NamespacedReplicationController {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1NamespacedReplicationController$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationControllerList;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationControllerList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationControllerList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$ReplicationControllerList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$ReplicationControllerList;
}
interface Parameter$createCoreV1NamespacedReplicationController {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createCoreV1NamespacedReplicationController = RequestBodies.io$k8s$api$core$v1$ReplicationController.Content;
interface Response$createCoreV1NamespacedReplicationController$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
interface Response$createCoreV1NamespacedReplicationController$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
interface Response$createCoreV1NamespacedReplicationController$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
interface Parameter$deleteCoreV1CollectionNamespacedReplicationController {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteCoreV1CollectionNamespacedReplicationController = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1CollectionNamespacedReplicationController$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readCoreV1NamespacedReplicationController {
    /** name of the ReplicationController */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1NamespacedReplicationController$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
interface Parameter$replaceCoreV1NamespacedReplicationController {
    /** name of the ReplicationController */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1NamespacedReplicationController = RequestBodies.io$k8s$api$core$v1$ReplicationController.Content;
interface Response$replaceCoreV1NamespacedReplicationController$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
interface Response$replaceCoreV1NamespacedReplicationController$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
interface Parameter$deleteCoreV1NamespacedReplicationController {
    /** name of the ReplicationController */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteCoreV1NamespacedReplicationController = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1NamespacedReplicationController$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteCoreV1NamespacedReplicationController$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchCoreV1NamespacedReplicationController {
    /** name of the ReplicationController */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1NamespacedReplicationController = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1NamespacedReplicationController$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
interface Response$patchCoreV1NamespacedReplicationController$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
interface Parameter$readCoreV1NamespacedReplicationControllerScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1NamespacedReplicationControllerScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
interface Parameter$replaceCoreV1NamespacedReplicationControllerScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1NamespacedReplicationControllerScale = RequestBodies.io$k8s$api$autoscaling$v1$Scale.Content;
interface Response$replaceCoreV1NamespacedReplicationControllerScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
interface Response$replaceCoreV1NamespacedReplicationControllerScale$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
interface Parameter$patchCoreV1NamespacedReplicationControllerScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1NamespacedReplicationControllerScale = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1NamespacedReplicationControllerScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
interface Response$patchCoreV1NamespacedReplicationControllerScale$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
interface Parameter$readCoreV1NamespacedReplicationControllerStatus {
    /** name of the ReplicationController */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1NamespacedReplicationControllerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
interface Parameter$replaceCoreV1NamespacedReplicationControllerStatus {
    /** name of the ReplicationController */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1NamespacedReplicationControllerStatus = RequestBodies.io$k8s$api$core$v1$ReplicationController.Content;
interface Response$replaceCoreV1NamespacedReplicationControllerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
interface Response$replaceCoreV1NamespacedReplicationControllerStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
interface Parameter$patchCoreV1NamespacedReplicationControllerStatus {
    /** name of the ReplicationController */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1NamespacedReplicationControllerStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1NamespacedReplicationControllerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
interface Response$patchCoreV1NamespacedReplicationControllerStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationController;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationController;
}
interface Parameter$listCoreV1NamespacedResourceQuota {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1NamespacedResourceQuota$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuotaList;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuotaList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuotaList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$ResourceQuotaList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$ResourceQuotaList;
}
interface Parameter$createCoreV1NamespacedResourceQuota {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createCoreV1NamespacedResourceQuota = RequestBodies.io$k8s$api$core$v1$ResourceQuota.Content;
interface Response$createCoreV1NamespacedResourceQuota$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
interface Response$createCoreV1NamespacedResourceQuota$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
interface Response$createCoreV1NamespacedResourceQuota$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
interface Parameter$deleteCoreV1CollectionNamespacedResourceQuota {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteCoreV1CollectionNamespacedResourceQuota = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1CollectionNamespacedResourceQuota$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readCoreV1NamespacedResourceQuota {
    /** name of the ResourceQuota */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1NamespacedResourceQuota$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
interface Parameter$replaceCoreV1NamespacedResourceQuota {
    /** name of the ResourceQuota */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1NamespacedResourceQuota = RequestBodies.io$k8s$api$core$v1$ResourceQuota.Content;
interface Response$replaceCoreV1NamespacedResourceQuota$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
interface Response$replaceCoreV1NamespacedResourceQuota$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
interface Parameter$deleteCoreV1NamespacedResourceQuota {
    /** name of the ResourceQuota */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteCoreV1NamespacedResourceQuota = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1NamespacedResourceQuota$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
interface Response$deleteCoreV1NamespacedResourceQuota$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
interface Parameter$patchCoreV1NamespacedResourceQuota {
    /** name of the ResourceQuota */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1NamespacedResourceQuota = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1NamespacedResourceQuota$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
interface Response$patchCoreV1NamespacedResourceQuota$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
interface Parameter$readCoreV1NamespacedResourceQuotaStatus {
    /** name of the ResourceQuota */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1NamespacedResourceQuotaStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
interface Parameter$replaceCoreV1NamespacedResourceQuotaStatus {
    /** name of the ResourceQuota */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1NamespacedResourceQuotaStatus = RequestBodies.io$k8s$api$core$v1$ResourceQuota.Content;
interface Response$replaceCoreV1NamespacedResourceQuotaStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
interface Response$replaceCoreV1NamespacedResourceQuotaStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
interface Parameter$patchCoreV1NamespacedResourceQuotaStatus {
    /** name of the ResourceQuota */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1NamespacedResourceQuotaStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1NamespacedResourceQuotaStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
interface Response$patchCoreV1NamespacedResourceQuotaStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuota;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuota;
}
interface Parameter$listCoreV1NamespacedSecret {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1NamespacedSecret$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$SecretList;
    "application/yaml": Schemas.io$k8s$api$core$v1$SecretList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$SecretList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$SecretList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$SecretList;
}
interface Parameter$createCoreV1NamespacedSecret {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createCoreV1NamespacedSecret = RequestBodies.io$k8s$api$core$v1$Secret.Content;
interface Response$createCoreV1NamespacedSecret$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Secret;
    "application/yaml": Schemas.io$k8s$api$core$v1$Secret;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Secret;
}
interface Response$createCoreV1NamespacedSecret$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Secret;
    "application/yaml": Schemas.io$k8s$api$core$v1$Secret;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Secret;
}
interface Response$createCoreV1NamespacedSecret$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$Secret;
    "application/yaml": Schemas.io$k8s$api$core$v1$Secret;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Secret;
}
interface Parameter$deleteCoreV1CollectionNamespacedSecret {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteCoreV1CollectionNamespacedSecret = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1CollectionNamespacedSecret$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readCoreV1NamespacedSecret {
    /** name of the Secret */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1NamespacedSecret$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Secret;
    "application/yaml": Schemas.io$k8s$api$core$v1$Secret;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Secret;
}
interface Parameter$replaceCoreV1NamespacedSecret {
    /** name of the Secret */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1NamespacedSecret = RequestBodies.io$k8s$api$core$v1$Secret.Content;
interface Response$replaceCoreV1NamespacedSecret$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Secret;
    "application/yaml": Schemas.io$k8s$api$core$v1$Secret;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Secret;
}
interface Response$replaceCoreV1NamespacedSecret$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Secret;
    "application/yaml": Schemas.io$k8s$api$core$v1$Secret;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Secret;
}
interface Parameter$deleteCoreV1NamespacedSecret {
    /** name of the Secret */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteCoreV1NamespacedSecret = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1NamespacedSecret$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteCoreV1NamespacedSecret$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchCoreV1NamespacedSecret {
    /** name of the Secret */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1NamespacedSecret = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1NamespacedSecret$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Secret;
    "application/yaml": Schemas.io$k8s$api$core$v1$Secret;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Secret;
}
interface Response$patchCoreV1NamespacedSecret$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Secret;
    "application/yaml": Schemas.io$k8s$api$core$v1$Secret;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Secret;
}
interface Parameter$listCoreV1NamespacedServiceAccount {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1NamespacedServiceAccount$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccountList;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccountList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccountList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$ServiceAccountList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$ServiceAccountList;
}
interface Parameter$createCoreV1NamespacedServiceAccount {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createCoreV1NamespacedServiceAccount = RequestBodies.io$k8s$api$core$v1$ServiceAccount.Content;
interface Response$createCoreV1NamespacedServiceAccount$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccount;
}
interface Response$createCoreV1NamespacedServiceAccount$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccount;
}
interface Response$createCoreV1NamespacedServiceAccount$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccount;
}
interface Parameter$deleteCoreV1CollectionNamespacedServiceAccount {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteCoreV1CollectionNamespacedServiceAccount = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1CollectionNamespacedServiceAccount$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readCoreV1NamespacedServiceAccount {
    /** name of the ServiceAccount */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1NamespacedServiceAccount$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccount;
}
interface Parameter$replaceCoreV1NamespacedServiceAccount {
    /** name of the ServiceAccount */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1NamespacedServiceAccount = RequestBodies.io$k8s$api$core$v1$ServiceAccount.Content;
interface Response$replaceCoreV1NamespacedServiceAccount$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccount;
}
interface Response$replaceCoreV1NamespacedServiceAccount$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccount;
}
interface Parameter$deleteCoreV1NamespacedServiceAccount {
    /** name of the ServiceAccount */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteCoreV1NamespacedServiceAccount = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1NamespacedServiceAccount$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccount;
}
interface Response$deleteCoreV1NamespacedServiceAccount$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccount;
}
interface Parameter$patchCoreV1NamespacedServiceAccount {
    /** name of the ServiceAccount */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1NamespacedServiceAccount = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1NamespacedServiceAccount$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccount;
}
interface Response$patchCoreV1NamespacedServiceAccount$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccount;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccount;
}
interface Parameter$createCoreV1NamespacedServiceAccountToken {
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** name of the TokenRequest */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface RequestBody$createCoreV1NamespacedServiceAccountToken {
    "*/*": Schemas.io$k8s$api$authentication$v1$TokenRequest;
}
interface Response$createCoreV1NamespacedServiceAccountToken$Status$200 {
    "application/json": Schemas.io$k8s$api$authentication$v1$TokenRequest;
    "application/yaml": Schemas.io$k8s$api$authentication$v1$TokenRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authentication$v1$TokenRequest;
}
interface Response$createCoreV1NamespacedServiceAccountToken$Status$201 {
    "application/json": Schemas.io$k8s$api$authentication$v1$TokenRequest;
    "application/yaml": Schemas.io$k8s$api$authentication$v1$TokenRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authentication$v1$TokenRequest;
}
interface Response$createCoreV1NamespacedServiceAccountToken$Status$202 {
    "application/json": Schemas.io$k8s$api$authentication$v1$TokenRequest;
    "application/yaml": Schemas.io$k8s$api$authentication$v1$TokenRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authentication$v1$TokenRequest;
}
interface Parameter$listCoreV1NamespacedService {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1NamespacedService$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceList;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$ServiceList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$ServiceList;
}
interface Parameter$createCoreV1NamespacedService {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createCoreV1NamespacedService = RequestBodies.io$k8s$api$core$v1$Service.Content;
interface Response$createCoreV1NamespacedService$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
interface Response$createCoreV1NamespacedService$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
interface Response$createCoreV1NamespacedService$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
interface Parameter$deleteCoreV1CollectionNamespacedService {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteCoreV1CollectionNamespacedService = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1CollectionNamespacedService$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readCoreV1NamespacedService {
    /** name of the Service */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1NamespacedService$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
interface Parameter$replaceCoreV1NamespacedService {
    /** name of the Service */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1NamespacedService = RequestBodies.io$k8s$api$core$v1$Service.Content;
interface Response$replaceCoreV1NamespacedService$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
interface Response$replaceCoreV1NamespacedService$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
interface Parameter$deleteCoreV1NamespacedService {
    /** name of the Service */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteCoreV1NamespacedService = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1NamespacedService$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
interface Response$deleteCoreV1NamespacedService$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
interface Parameter$patchCoreV1NamespacedService {
    /** name of the Service */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1NamespacedService = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1NamespacedService$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
interface Response$patchCoreV1NamespacedService$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
interface Parameter$connectCoreV1GetNamespacedServiceProxy {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
interface Response$connectCoreV1GetNamespacedServiceProxy$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1PutNamespacedServiceProxy {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
interface Response$connectCoreV1PutNamespacedServiceProxy$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1PostNamespacedServiceProxy {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
interface Response$connectCoreV1PostNamespacedServiceProxy$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1DeleteNamespacedServiceProxy {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
interface Response$connectCoreV1DeleteNamespacedServiceProxy$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1OptionsNamespacedServiceProxy {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
interface Response$connectCoreV1OptionsNamespacedServiceProxy$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1HeadNamespacedServiceProxy {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
interface Response$connectCoreV1HeadNamespacedServiceProxy$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1PatchNamespacedServiceProxy {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
interface Response$connectCoreV1PatchNamespacedServiceProxy$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1GetNamespacedServiceProxyWithPath {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
interface Response$connectCoreV1GetNamespacedServiceProxyWithPath$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1PutNamespacedServiceProxyWithPath {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
interface Response$connectCoreV1PutNamespacedServiceProxyWithPath$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1PostNamespacedServiceProxyWithPath {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
interface Response$connectCoreV1PostNamespacedServiceProxyWithPath$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1DeleteNamespacedServiceProxyWithPath {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
interface Response$connectCoreV1DeleteNamespacedServiceProxyWithPath$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1OptionsNamespacedServiceProxyWithPath {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
interface Response$connectCoreV1OptionsNamespacedServiceProxyWithPath$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1HeadNamespacedServiceProxyWithPath {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
interface Response$connectCoreV1HeadNamespacedServiceProxyWithPath$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1PatchNamespacedServiceProxyWithPath {
    /** name of the ServiceProxyOptions */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** Path is the part of URLs that include service endpoints, suffixes, and parameters to use for the current proxy request to service. For example, the whole request URL is http://localhost/api/v1/namespaces/kube-system/services/elasticsearch-logging/_search?q=user:kimchy. Path is _search?q=user:kimchy. */
    path?: string;
}
interface Response$connectCoreV1PatchNamespacedServiceProxyWithPath$Status$200 {
    "*/*": string;
}
interface Parameter$readCoreV1NamespacedServiceStatus {
    /** name of the Service */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1NamespacedServiceStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
interface Parameter$replaceCoreV1NamespacedServiceStatus {
    /** name of the Service */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1NamespacedServiceStatus = RequestBodies.io$k8s$api$core$v1$Service.Content;
interface Response$replaceCoreV1NamespacedServiceStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
interface Response$replaceCoreV1NamespacedServiceStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
interface Parameter$patchCoreV1NamespacedServiceStatus {
    /** name of the Service */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1NamespacedServiceStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1NamespacedServiceStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
interface Response$patchCoreV1NamespacedServiceStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Service;
    "application/yaml": Schemas.io$k8s$api$core$v1$Service;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Service;
}
interface Parameter$readCoreV1Namespace {
    /** name of the Namespace */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1Namespace$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
interface Parameter$replaceCoreV1Namespace {
    /** name of the Namespace */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1Namespace = RequestBodies.io$k8s$api$core$v1$Namespace.Content;
interface Response$replaceCoreV1Namespace$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
interface Response$replaceCoreV1Namespace$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
interface Parameter$deleteCoreV1Namespace {
    /** name of the Namespace */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteCoreV1Namespace = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1Namespace$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteCoreV1Namespace$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchCoreV1Namespace {
    /** name of the Namespace */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1Namespace = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1Namespace$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
interface Response$patchCoreV1Namespace$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
interface Parameter$replaceCoreV1NamespaceFinalize {
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** name of the Namespace */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
type RequestBody$replaceCoreV1NamespaceFinalize = RequestBodies.io$k8s$api$core$v1$Namespace.Content;
interface Response$replaceCoreV1NamespaceFinalize$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
interface Response$replaceCoreV1NamespaceFinalize$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
interface Parameter$readCoreV1NamespaceStatus {
    /** name of the Namespace */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1NamespaceStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
interface Parameter$replaceCoreV1NamespaceStatus {
    /** name of the Namespace */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1NamespaceStatus = RequestBodies.io$k8s$api$core$v1$Namespace.Content;
interface Response$replaceCoreV1NamespaceStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
interface Response$replaceCoreV1NamespaceStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
interface Parameter$patchCoreV1NamespaceStatus {
    /** name of the Namespace */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1NamespaceStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1NamespaceStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
interface Response$patchCoreV1NamespaceStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Namespace;
    "application/yaml": Schemas.io$k8s$api$core$v1$Namespace;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Namespace;
}
interface Parameter$listCoreV1Node {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1Node$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$NodeList;
    "application/yaml": Schemas.io$k8s$api$core$v1$NodeList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$NodeList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$NodeList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$NodeList;
}
interface Parameter$createCoreV1Node {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createCoreV1Node = RequestBodies.io$k8s$api$core$v1$Node.Content;
interface Response$createCoreV1Node$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
interface Response$createCoreV1Node$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
interface Response$createCoreV1Node$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
interface Parameter$deleteCoreV1CollectionNode {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteCoreV1CollectionNode = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1CollectionNode$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readCoreV1Node {
    /** name of the Node */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1Node$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
interface Parameter$replaceCoreV1Node {
    /** name of the Node */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1Node = RequestBodies.io$k8s$api$core$v1$Node.Content;
interface Response$replaceCoreV1Node$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
interface Response$replaceCoreV1Node$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
interface Parameter$deleteCoreV1Node {
    /** name of the Node */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteCoreV1Node = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1Node$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteCoreV1Node$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchCoreV1Node {
    /** name of the Node */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1Node = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1Node$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
interface Response$patchCoreV1Node$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
interface Parameter$connectCoreV1GetNodeProxy {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
interface Response$connectCoreV1GetNodeProxy$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1PutNodeProxy {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
interface Response$connectCoreV1PutNodeProxy$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1PostNodeProxy {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
interface Response$connectCoreV1PostNodeProxy$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1DeleteNodeProxy {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
interface Response$connectCoreV1DeleteNodeProxy$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1OptionsNodeProxy {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
interface Response$connectCoreV1OptionsNodeProxy$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1HeadNodeProxy {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
interface Response$connectCoreV1HeadNodeProxy$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1PatchNodeProxy {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
interface Response$connectCoreV1PatchNodeProxy$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1GetNodeProxyWithPath {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
interface Response$connectCoreV1GetNodeProxyWithPath$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1PutNodeProxyWithPath {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
interface Response$connectCoreV1PutNodeProxyWithPath$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1PostNodeProxyWithPath {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
interface Response$connectCoreV1PostNodeProxyWithPath$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1DeleteNodeProxyWithPath {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
interface Response$connectCoreV1DeleteNodeProxyWithPath$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1OptionsNodeProxyWithPath {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
interface Response$connectCoreV1OptionsNodeProxyWithPath$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1HeadNodeProxyWithPath {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
interface Response$connectCoreV1HeadNodeProxyWithPath$Status$200 {
    "*/*": string;
}
interface Parameter$connectCoreV1PatchNodeProxyWithPath {
    /** name of the NodeProxyOptions */
    name: string;
    /** Path is the URL path to use for the current proxy request to node. */
    path?: string;
}
interface Response$connectCoreV1PatchNodeProxyWithPath$Status$200 {
    "*/*": string;
}
interface Parameter$readCoreV1NodeStatus {
    /** name of the Node */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1NodeStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
interface Parameter$replaceCoreV1NodeStatus {
    /** name of the Node */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1NodeStatus = RequestBodies.io$k8s$api$core$v1$Node.Content;
interface Response$replaceCoreV1NodeStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
interface Response$replaceCoreV1NodeStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
interface Parameter$patchCoreV1NodeStatus {
    /** name of the Node */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1NodeStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1NodeStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
interface Response$patchCoreV1NodeStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$Node;
    "application/yaml": Schemas.io$k8s$api$core$v1$Node;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$Node;
}
interface Parameter$listCoreV1PersistentVolumeClaimForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1PersistentVolumeClaimForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeClaimList;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeClaimList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeClaimList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$PersistentVolumeClaimList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$PersistentVolumeClaimList;
}
interface Parameter$listCoreV1PersistentVolume {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1PersistentVolume$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolumeList;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolumeList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolumeList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$PersistentVolumeList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$PersistentVolumeList;
}
interface Parameter$createCoreV1PersistentVolume {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createCoreV1PersistentVolume = RequestBodies.io$k8s$api$core$v1$PersistentVolume.Content;
interface Response$createCoreV1PersistentVolume$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
interface Response$createCoreV1PersistentVolume$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
interface Response$createCoreV1PersistentVolume$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
interface Parameter$deleteCoreV1CollectionPersistentVolume {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteCoreV1CollectionPersistentVolume = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1CollectionPersistentVolume$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readCoreV1PersistentVolume {
    /** name of the PersistentVolume */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1PersistentVolume$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
interface Parameter$replaceCoreV1PersistentVolume {
    /** name of the PersistentVolume */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1PersistentVolume = RequestBodies.io$k8s$api$core$v1$PersistentVolume.Content;
interface Response$replaceCoreV1PersistentVolume$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
interface Response$replaceCoreV1PersistentVolume$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
interface Parameter$deleteCoreV1PersistentVolume {
    /** name of the PersistentVolume */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteCoreV1PersistentVolume = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoreV1PersistentVolume$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
interface Response$deleteCoreV1PersistentVolume$Status$202 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
interface Parameter$patchCoreV1PersistentVolume {
    /** name of the PersistentVolume */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1PersistentVolume = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1PersistentVolume$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
interface Response$patchCoreV1PersistentVolume$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
interface Parameter$readCoreV1PersistentVolumeStatus {
    /** name of the PersistentVolume */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoreV1PersistentVolumeStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
interface Parameter$replaceCoreV1PersistentVolumeStatus {
    /** name of the PersistentVolume */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoreV1PersistentVolumeStatus = RequestBodies.io$k8s$api$core$v1$PersistentVolume.Content;
interface Response$replaceCoreV1PersistentVolumeStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
interface Response$replaceCoreV1PersistentVolumeStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
interface Parameter$patchCoreV1PersistentVolumeStatus {
    /** name of the PersistentVolume */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoreV1PersistentVolumeStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoreV1PersistentVolumeStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
interface Response$patchCoreV1PersistentVolumeStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/yaml": Schemas.io$k8s$api$core$v1$PersistentVolume;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PersistentVolume;
}
interface Parameter$listCoreV1PodForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1PodForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PodList;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$PodList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$PodList;
}
interface Parameter$listCoreV1PodTemplateForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1PodTemplateForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$PodTemplateList;
    "application/yaml": Schemas.io$k8s$api$core$v1$PodTemplateList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$PodTemplateList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$PodTemplateList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$PodTemplateList;
}
interface Parameter$listCoreV1ReplicationControllerForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1ReplicationControllerForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ReplicationControllerList;
    "application/yaml": Schemas.io$k8s$api$core$v1$ReplicationControllerList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ReplicationControllerList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$ReplicationControllerList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$ReplicationControllerList;
}
interface Parameter$listCoreV1ResourceQuotaForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1ResourceQuotaForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ResourceQuotaList;
    "application/yaml": Schemas.io$k8s$api$core$v1$ResourceQuotaList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ResourceQuotaList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$ResourceQuotaList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$ResourceQuotaList;
}
interface Parameter$listCoreV1SecretForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1SecretForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$SecretList;
    "application/yaml": Schemas.io$k8s$api$core$v1$SecretList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$SecretList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$SecretList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$SecretList;
}
interface Parameter$listCoreV1ServiceAccountForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1ServiceAccountForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceAccountList;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceAccountList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceAccountList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$ServiceAccountList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$ServiceAccountList;
}
interface Parameter$listCoreV1ServiceForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoreV1ServiceForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$core$v1$ServiceList;
    "application/yaml": Schemas.io$k8s$api$core$v1$ServiceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$core$v1$ServiceList;
    "application/json;stream=watch": Schemas.io$k8s$api$core$v1$ServiceList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$core$v1$ServiceList;
}
interface Parameter$watchCoreV1ConfigMapListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1ConfigMapListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1EndpointsListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1EndpointsListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1EventListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1EventListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1LimitRangeListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1LimitRangeListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespaceList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespaceList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedConfigMapList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedConfigMapList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedConfigMap {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ConfigMap */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedConfigMap$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedEndpointsList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedEndpointsList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedEndpoints {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Endpoints */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedEndpoints$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedEventList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedEventList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedEvent {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedLimitRangeList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedLimitRangeList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedLimitRange {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the LimitRange */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedLimitRange$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedPersistentVolumeClaimList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedPersistentVolumeClaimList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedPersistentVolumeClaim {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the PersistentVolumeClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedPersistentVolumeClaim$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedPodList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedPodList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedPod {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Pod */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedPod$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedPodTemplateList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedPodTemplateList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedPodTemplate {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the PodTemplate */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedPodTemplate$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedReplicationControllerList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedReplicationControllerList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedReplicationController {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ReplicationController */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedReplicationController$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedResourceQuotaList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedResourceQuotaList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedResourceQuota {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ResourceQuota */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedResourceQuota$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedSecretList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedSecretList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedSecret {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Secret */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedSecret$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedServiceAccountList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedServiceAccountList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedServiceAccount {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ServiceAccount */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedServiceAccount$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedServiceList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedServiceList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NamespacedService {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Service */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NamespacedService$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1Namespace {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Namespace */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1Namespace$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1NodeList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1NodeList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1Node {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Node */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1Node$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1PersistentVolumeClaimListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1PersistentVolumeClaimListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1PersistentVolumeList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1PersistentVolumeList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1PersistentVolume {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the PersistentVolume */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1PersistentVolume$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1PodListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1PodListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1PodTemplateListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1PodTemplateListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1ReplicationControllerListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1ReplicationControllerListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1ResourceQuotaListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1ResourceQuotaListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1SecretListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1SecretListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1ServiceAccountListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1ServiceAccountListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoreV1ServiceListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoreV1ServiceListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getAPIVersions$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroupList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroupList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroupList;
}
interface Response$getAdmissionregistrationAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
interface Response$getAdmissionregistrationV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listAdmissionregistrationV1MutatingWebhookConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfigurationList;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfigurationList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfigurationList;
    "application/json;stream=watch": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfigurationList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfigurationList;
}
interface Parameter$createAdmissionregistrationV1MutatingWebhookConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createAdmissionregistrationV1MutatingWebhookConfiguration = RequestBodies.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration.Content;
interface Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
}
interface Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
}
interface Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$202 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
}
interface Parameter$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readAdmissionregistrationV1MutatingWebhookConfiguration {
    /** name of the MutatingWebhookConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
}
interface Parameter$replaceAdmissionregistrationV1MutatingWebhookConfiguration {
    /** name of the MutatingWebhookConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceAdmissionregistrationV1MutatingWebhookConfiguration = RequestBodies.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration.Content;
interface Response$replaceAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
}
interface Response$replaceAdmissionregistrationV1MutatingWebhookConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
}
interface Parameter$deleteAdmissionregistrationV1MutatingWebhookConfiguration {
    /** name of the MutatingWebhookConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteAdmissionregistrationV1MutatingWebhookConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteAdmissionregistrationV1MutatingWebhookConfiguration$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchAdmissionregistrationV1MutatingWebhookConfiguration {
    /** name of the MutatingWebhookConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchAdmissionregistrationV1MutatingWebhookConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
}
interface Response$patchAdmissionregistrationV1MutatingWebhookConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$MutatingWebhookConfiguration;
}
interface Parameter$listAdmissionregistrationV1ValidatingWebhookConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfigurationList;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfigurationList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfigurationList;
    "application/json;stream=watch": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfigurationList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfigurationList;
}
interface Parameter$createAdmissionregistrationV1ValidatingWebhookConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createAdmissionregistrationV1ValidatingWebhookConfiguration = RequestBodies.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration.Content;
interface Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
}
interface Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
}
interface Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$202 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
}
interface Parameter$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readAdmissionregistrationV1ValidatingWebhookConfiguration {
    /** name of the ValidatingWebhookConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
}
interface Parameter$replaceAdmissionregistrationV1ValidatingWebhookConfiguration {
    /** name of the ValidatingWebhookConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceAdmissionregistrationV1ValidatingWebhookConfiguration = RequestBodies.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration.Content;
interface Response$replaceAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
}
interface Response$replaceAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
}
interface Parameter$deleteAdmissionregistrationV1ValidatingWebhookConfiguration {
    /** name of the ValidatingWebhookConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteAdmissionregistrationV1ValidatingWebhookConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteAdmissionregistrationV1ValidatingWebhookConfiguration$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchAdmissionregistrationV1ValidatingWebhookConfiguration {
    /** name of the ValidatingWebhookConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchAdmissionregistrationV1ValidatingWebhookConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
}
interface Response$patchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1$ValidatingWebhookConfiguration;
}
interface Parameter$watchAdmissionregistrationV1MutatingWebhookConfigurationList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAdmissionregistrationV1MutatingWebhookConfigurationList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAdmissionregistrationV1MutatingWebhookConfiguration {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the MutatingWebhookConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAdmissionregistrationV1ValidatingWebhookConfigurationList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAdmissionregistrationV1ValidatingWebhookConfigurationList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAdmissionregistrationV1ValidatingWebhookConfiguration {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ValidatingWebhookConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getAdmissionregistrationV1alpha1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicy {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyList;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyList;
    "application/json;stream=watch": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyList;
}
interface Parameter$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy = RequestBodies.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy.Content;
interface Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
}
interface Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$201 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
}
interface Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$202 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
}
interface Parameter$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicy {
    /** name of the ValidatingAdmissionPolicy */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
}
interface Parameter$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy {
    /** name of the ValidatingAdmissionPolicy */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy = RequestBodies.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy.Content;
interface Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
}
interface Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$201 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
}
interface Parameter$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy {
    /** name of the ValidatingAdmissionPolicy */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy {
    /** name of the ValidatingAdmissionPolicy */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
}
interface Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$201 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
}
interface Parameter$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus {
    /** name of the ValidatingAdmissionPolicy */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
}
interface Parameter$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus {
    /** name of the ValidatingAdmissionPolicy */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus = RequestBodies.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy.Content;
interface Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
}
interface Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
}
interface Parameter$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus {
    /** name of the ValidatingAdmissionPolicy */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
}
interface Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicy;
}
interface Parameter$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBindingList;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBindingList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBindingList;
    "application/json;stream=watch": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBindingList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBindingList;
}
interface Parameter$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding = RequestBodies.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding.Content;
interface Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
}
interface Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$201 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
}
interface Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$202 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
}
interface Parameter$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding {
    /** name of the ValidatingAdmissionPolicyBinding */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
}
interface Parameter$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding {
    /** name of the ValidatingAdmissionPolicyBinding */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding = RequestBodies.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding.Content;
interface Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
}
interface Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$201 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
}
interface Parameter$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding {
    /** name of the ValidatingAdmissionPolicyBinding */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding {
    /** name of the ValidatingAdmissionPolicyBinding */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
}
interface Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$201 {
    "application/json": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
    "application/yaml": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$admissionregistration$v1alpha1$ValidatingAdmissionPolicyBinding;
}
interface Parameter$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ValidatingAdmissionPolicy */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBindingList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBindingList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ValidatingAdmissionPolicyBinding */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getApiextensionsAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
interface Response$getApiextensionsV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listApiextensionsV1CustomResourceDefinition {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listApiextensionsV1CustomResourceDefinition$Status$200 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionList;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionList;
    "application/json;stream=watch": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinitionList;
}
interface Parameter$createApiextensionsV1CustomResourceDefinition {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createApiextensionsV1CustomResourceDefinition = RequestBodies.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition.Content;
interface Response$createApiextensionsV1CustomResourceDefinition$Status$200 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
interface Response$createApiextensionsV1CustomResourceDefinition$Status$201 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
interface Response$createApiextensionsV1CustomResourceDefinition$Status$202 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
interface Parameter$deleteApiextensionsV1CollectionCustomResourceDefinition {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteApiextensionsV1CollectionCustomResourceDefinition = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteApiextensionsV1CollectionCustomResourceDefinition$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readApiextensionsV1CustomResourceDefinition {
    /** name of the CustomResourceDefinition */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readApiextensionsV1CustomResourceDefinition$Status$200 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
interface Parameter$replaceApiextensionsV1CustomResourceDefinition {
    /** name of the CustomResourceDefinition */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceApiextensionsV1CustomResourceDefinition = RequestBodies.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition.Content;
interface Response$replaceApiextensionsV1CustomResourceDefinition$Status$200 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
interface Response$replaceApiextensionsV1CustomResourceDefinition$Status$201 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
interface Parameter$deleteApiextensionsV1CustomResourceDefinition {
    /** name of the CustomResourceDefinition */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteApiextensionsV1CustomResourceDefinition = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteApiextensionsV1CustomResourceDefinition$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteApiextensionsV1CustomResourceDefinition$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchApiextensionsV1CustomResourceDefinition {
    /** name of the CustomResourceDefinition */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchApiextensionsV1CustomResourceDefinition = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchApiextensionsV1CustomResourceDefinition$Status$200 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
interface Response$patchApiextensionsV1CustomResourceDefinition$Status$201 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
interface Parameter$readApiextensionsV1CustomResourceDefinitionStatus {
    /** name of the CustomResourceDefinition */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readApiextensionsV1CustomResourceDefinitionStatus$Status$200 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
interface Parameter$replaceApiextensionsV1CustomResourceDefinitionStatus {
    /** name of the CustomResourceDefinition */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceApiextensionsV1CustomResourceDefinitionStatus = RequestBodies.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition.Content;
interface Response$replaceApiextensionsV1CustomResourceDefinitionStatus$Status$200 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
interface Response$replaceApiextensionsV1CustomResourceDefinitionStatus$Status$201 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
interface Parameter$patchApiextensionsV1CustomResourceDefinitionStatus {
    /** name of the CustomResourceDefinition */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchApiextensionsV1CustomResourceDefinitionStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchApiextensionsV1CustomResourceDefinitionStatus$Status$200 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
interface Response$patchApiextensionsV1CustomResourceDefinitionStatus$Status$201 {
    "application/json": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/yaml": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apiextensions$apiserver$pkg$apis$apiextensions$v1$CustomResourceDefinition;
}
interface Parameter$watchApiextensionsV1CustomResourceDefinitionList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchApiextensionsV1CustomResourceDefinitionList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchApiextensionsV1CustomResourceDefinition {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the CustomResourceDefinition */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchApiextensionsV1CustomResourceDefinition$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getApiregistrationAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
interface Response$getApiregistrationV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listApiregistrationV1APIService {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listApiregistrationV1APIService$Status$200 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceList;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceList;
    "application/json;stream=watch": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIServiceList;
}
interface Parameter$createApiregistrationV1APIService {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createApiregistrationV1APIService = RequestBodies.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService.Content;
interface Response$createApiregistrationV1APIService$Status$200 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
interface Response$createApiregistrationV1APIService$Status$201 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
interface Response$createApiregistrationV1APIService$Status$202 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
interface Parameter$deleteApiregistrationV1CollectionAPIService {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteApiregistrationV1CollectionAPIService = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteApiregistrationV1CollectionAPIService$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readApiregistrationV1APIService {
    /** name of the APIService */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readApiregistrationV1APIService$Status$200 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
interface Parameter$replaceApiregistrationV1APIService {
    /** name of the APIService */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceApiregistrationV1APIService = RequestBodies.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService.Content;
interface Response$replaceApiregistrationV1APIService$Status$200 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
interface Response$replaceApiregistrationV1APIService$Status$201 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
interface Parameter$deleteApiregistrationV1APIService {
    /** name of the APIService */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteApiregistrationV1APIService = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteApiregistrationV1APIService$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteApiregistrationV1APIService$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchApiregistrationV1APIService {
    /** name of the APIService */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchApiregistrationV1APIService = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchApiregistrationV1APIService$Status$200 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
interface Response$patchApiregistrationV1APIService$Status$201 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
interface Parameter$readApiregistrationV1APIServiceStatus {
    /** name of the APIService */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readApiregistrationV1APIServiceStatus$Status$200 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
interface Parameter$replaceApiregistrationV1APIServiceStatus {
    /** name of the APIService */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceApiregistrationV1APIServiceStatus = RequestBodies.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService.Content;
interface Response$replaceApiregistrationV1APIServiceStatus$Status$200 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
interface Response$replaceApiregistrationV1APIServiceStatus$Status$201 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
interface Parameter$patchApiregistrationV1APIServiceStatus {
    /** name of the APIService */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchApiregistrationV1APIServiceStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchApiregistrationV1APIServiceStatus$Status$200 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
interface Response$patchApiregistrationV1APIServiceStatus$Status$201 {
    "application/json": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/yaml": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$kube$aggregator$pkg$apis$apiregistration$v1$APIService;
}
interface Parameter$watchApiregistrationV1APIServiceList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchApiregistrationV1APIServiceList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchApiregistrationV1APIService {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the APIService */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchApiregistrationV1APIService$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getAppsAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
interface Response$getAppsV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listAppsV1ControllerRevisionForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listAppsV1ControllerRevisionForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ControllerRevisionList;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ControllerRevisionList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ControllerRevisionList;
    "application/json;stream=watch": Schemas.io$k8s$api$apps$v1$ControllerRevisionList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$apps$v1$ControllerRevisionList;
}
interface Parameter$listAppsV1DaemonSetForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listAppsV1DaemonSetForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSetList;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSetList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSetList;
    "application/json;stream=watch": Schemas.io$k8s$api$apps$v1$DaemonSetList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$apps$v1$DaemonSetList;
}
interface Parameter$listAppsV1DeploymentForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listAppsV1DeploymentForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$DeploymentList;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DeploymentList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DeploymentList;
    "application/json;stream=watch": Schemas.io$k8s$api$apps$v1$DeploymentList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$apps$v1$DeploymentList;
}
interface Parameter$listAppsV1NamespacedControllerRevision {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listAppsV1NamespacedControllerRevision$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ControllerRevisionList;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ControllerRevisionList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ControllerRevisionList;
    "application/json;stream=watch": Schemas.io$k8s$api$apps$v1$ControllerRevisionList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$apps$v1$ControllerRevisionList;
}
interface Parameter$createAppsV1NamespacedControllerRevision {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createAppsV1NamespacedControllerRevision = RequestBodies.io$k8s$api$apps$v1$ControllerRevision.Content;
interface Response$createAppsV1NamespacedControllerRevision$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ControllerRevision;
}
interface Response$createAppsV1NamespacedControllerRevision$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ControllerRevision;
}
interface Response$createAppsV1NamespacedControllerRevision$Status$202 {
    "application/json": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ControllerRevision;
}
interface Parameter$deleteAppsV1CollectionNamespacedControllerRevision {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteAppsV1CollectionNamespacedControllerRevision = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteAppsV1CollectionNamespacedControllerRevision$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readAppsV1NamespacedControllerRevision {
    /** name of the ControllerRevision */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readAppsV1NamespacedControllerRevision$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ControllerRevision;
}
interface Parameter$replaceAppsV1NamespacedControllerRevision {
    /** name of the ControllerRevision */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceAppsV1NamespacedControllerRevision = RequestBodies.io$k8s$api$apps$v1$ControllerRevision.Content;
interface Response$replaceAppsV1NamespacedControllerRevision$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ControllerRevision;
}
interface Response$replaceAppsV1NamespacedControllerRevision$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ControllerRevision;
}
interface Parameter$deleteAppsV1NamespacedControllerRevision {
    /** name of the ControllerRevision */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteAppsV1NamespacedControllerRevision = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteAppsV1NamespacedControllerRevision$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteAppsV1NamespacedControllerRevision$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchAppsV1NamespacedControllerRevision {
    /** name of the ControllerRevision */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchAppsV1NamespacedControllerRevision = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchAppsV1NamespacedControllerRevision$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ControllerRevision;
}
interface Response$patchAppsV1NamespacedControllerRevision$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ControllerRevision;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ControllerRevision;
}
interface Parameter$listAppsV1NamespacedDaemonSet {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listAppsV1NamespacedDaemonSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSetList;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSetList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSetList;
    "application/json;stream=watch": Schemas.io$k8s$api$apps$v1$DaemonSetList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$apps$v1$DaemonSetList;
}
interface Parameter$createAppsV1NamespacedDaemonSet {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createAppsV1NamespacedDaemonSet = RequestBodies.io$k8s$api$apps$v1$DaemonSet.Content;
interface Response$createAppsV1NamespacedDaemonSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
interface Response$createAppsV1NamespacedDaemonSet$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
interface Response$createAppsV1NamespacedDaemonSet$Status$202 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
interface Parameter$deleteAppsV1CollectionNamespacedDaemonSet {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteAppsV1CollectionNamespacedDaemonSet = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteAppsV1CollectionNamespacedDaemonSet$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readAppsV1NamespacedDaemonSet {
    /** name of the DaemonSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readAppsV1NamespacedDaemonSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
interface Parameter$replaceAppsV1NamespacedDaemonSet {
    /** name of the DaemonSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceAppsV1NamespacedDaemonSet = RequestBodies.io$k8s$api$apps$v1$DaemonSet.Content;
interface Response$replaceAppsV1NamespacedDaemonSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
interface Response$replaceAppsV1NamespacedDaemonSet$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
interface Parameter$deleteAppsV1NamespacedDaemonSet {
    /** name of the DaemonSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteAppsV1NamespacedDaemonSet = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteAppsV1NamespacedDaemonSet$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteAppsV1NamespacedDaemonSet$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchAppsV1NamespacedDaemonSet {
    /** name of the DaemonSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchAppsV1NamespacedDaemonSet = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchAppsV1NamespacedDaemonSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
interface Response$patchAppsV1NamespacedDaemonSet$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
interface Parameter$readAppsV1NamespacedDaemonSetStatus {
    /** name of the DaemonSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readAppsV1NamespacedDaemonSetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
interface Parameter$replaceAppsV1NamespacedDaemonSetStatus {
    /** name of the DaemonSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceAppsV1NamespacedDaemonSetStatus = RequestBodies.io$k8s$api$apps$v1$DaemonSet.Content;
interface Response$replaceAppsV1NamespacedDaemonSetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
interface Response$replaceAppsV1NamespacedDaemonSetStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
interface Parameter$patchAppsV1NamespacedDaemonSetStatus {
    /** name of the DaemonSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchAppsV1NamespacedDaemonSetStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchAppsV1NamespacedDaemonSetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
interface Response$patchAppsV1NamespacedDaemonSetStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DaemonSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DaemonSet;
}
interface Parameter$listAppsV1NamespacedDeployment {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listAppsV1NamespacedDeployment$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$DeploymentList;
    "application/yaml": Schemas.io$k8s$api$apps$v1$DeploymentList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$DeploymentList;
    "application/json;stream=watch": Schemas.io$k8s$api$apps$v1$DeploymentList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$apps$v1$DeploymentList;
}
interface Parameter$createAppsV1NamespacedDeployment {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createAppsV1NamespacedDeployment = RequestBodies.io$k8s$api$apps$v1$Deployment.Content;
interface Response$createAppsV1NamespacedDeployment$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
interface Response$createAppsV1NamespacedDeployment$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
interface Response$createAppsV1NamespacedDeployment$Status$202 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
interface Parameter$deleteAppsV1CollectionNamespacedDeployment {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteAppsV1CollectionNamespacedDeployment = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteAppsV1CollectionNamespacedDeployment$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readAppsV1NamespacedDeployment {
    /** name of the Deployment */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readAppsV1NamespacedDeployment$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
interface Parameter$replaceAppsV1NamespacedDeployment {
    /** name of the Deployment */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceAppsV1NamespacedDeployment = RequestBodies.io$k8s$api$apps$v1$Deployment.Content;
interface Response$replaceAppsV1NamespacedDeployment$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
interface Response$replaceAppsV1NamespacedDeployment$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
interface Parameter$deleteAppsV1NamespacedDeployment {
    /** name of the Deployment */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteAppsV1NamespacedDeployment = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteAppsV1NamespacedDeployment$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteAppsV1NamespacedDeployment$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchAppsV1NamespacedDeployment {
    /** name of the Deployment */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchAppsV1NamespacedDeployment = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchAppsV1NamespacedDeployment$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
interface Response$patchAppsV1NamespacedDeployment$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
interface Parameter$readAppsV1NamespacedDeploymentScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readAppsV1NamespacedDeploymentScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
interface Parameter$replaceAppsV1NamespacedDeploymentScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceAppsV1NamespacedDeploymentScale = RequestBodies.io$k8s$api$autoscaling$v1$Scale.Content;
interface Response$replaceAppsV1NamespacedDeploymentScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
interface Response$replaceAppsV1NamespacedDeploymentScale$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
interface Parameter$patchAppsV1NamespacedDeploymentScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchAppsV1NamespacedDeploymentScale = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchAppsV1NamespacedDeploymentScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
interface Response$patchAppsV1NamespacedDeploymentScale$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
interface Parameter$readAppsV1NamespacedDeploymentStatus {
    /** name of the Deployment */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readAppsV1NamespacedDeploymentStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
interface Parameter$replaceAppsV1NamespacedDeploymentStatus {
    /** name of the Deployment */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceAppsV1NamespacedDeploymentStatus = RequestBodies.io$k8s$api$apps$v1$Deployment.Content;
interface Response$replaceAppsV1NamespacedDeploymentStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
interface Response$replaceAppsV1NamespacedDeploymentStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
interface Parameter$patchAppsV1NamespacedDeploymentStatus {
    /** name of the Deployment */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchAppsV1NamespacedDeploymentStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchAppsV1NamespacedDeploymentStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
interface Response$patchAppsV1NamespacedDeploymentStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/yaml": Schemas.io$k8s$api$apps$v1$Deployment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$Deployment;
}
interface Parameter$listAppsV1NamespacedReplicaSet {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listAppsV1NamespacedReplicaSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSetList;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSetList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSetList;
    "application/json;stream=watch": Schemas.io$k8s$api$apps$v1$ReplicaSetList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$apps$v1$ReplicaSetList;
}
interface Parameter$createAppsV1NamespacedReplicaSet {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createAppsV1NamespacedReplicaSet = RequestBodies.io$k8s$api$apps$v1$ReplicaSet.Content;
interface Response$createAppsV1NamespacedReplicaSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
interface Response$createAppsV1NamespacedReplicaSet$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
interface Response$createAppsV1NamespacedReplicaSet$Status$202 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
interface Parameter$deleteAppsV1CollectionNamespacedReplicaSet {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteAppsV1CollectionNamespacedReplicaSet = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteAppsV1CollectionNamespacedReplicaSet$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readAppsV1NamespacedReplicaSet {
    /** name of the ReplicaSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readAppsV1NamespacedReplicaSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
interface Parameter$replaceAppsV1NamespacedReplicaSet {
    /** name of the ReplicaSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceAppsV1NamespacedReplicaSet = RequestBodies.io$k8s$api$apps$v1$ReplicaSet.Content;
interface Response$replaceAppsV1NamespacedReplicaSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
interface Response$replaceAppsV1NamespacedReplicaSet$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
interface Parameter$deleteAppsV1NamespacedReplicaSet {
    /** name of the ReplicaSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteAppsV1NamespacedReplicaSet = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteAppsV1NamespacedReplicaSet$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteAppsV1NamespacedReplicaSet$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchAppsV1NamespacedReplicaSet {
    /** name of the ReplicaSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchAppsV1NamespacedReplicaSet = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchAppsV1NamespacedReplicaSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
interface Response$patchAppsV1NamespacedReplicaSet$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
interface Parameter$readAppsV1NamespacedReplicaSetScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readAppsV1NamespacedReplicaSetScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
interface Parameter$replaceAppsV1NamespacedReplicaSetScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceAppsV1NamespacedReplicaSetScale = RequestBodies.io$k8s$api$autoscaling$v1$Scale.Content;
interface Response$replaceAppsV1NamespacedReplicaSetScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
interface Response$replaceAppsV1NamespacedReplicaSetScale$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
interface Parameter$patchAppsV1NamespacedReplicaSetScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchAppsV1NamespacedReplicaSetScale = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchAppsV1NamespacedReplicaSetScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
interface Response$patchAppsV1NamespacedReplicaSetScale$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
interface Parameter$readAppsV1NamespacedReplicaSetStatus {
    /** name of the ReplicaSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readAppsV1NamespacedReplicaSetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
interface Parameter$replaceAppsV1NamespacedReplicaSetStatus {
    /** name of the ReplicaSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceAppsV1NamespacedReplicaSetStatus = RequestBodies.io$k8s$api$apps$v1$ReplicaSet.Content;
interface Response$replaceAppsV1NamespacedReplicaSetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
interface Response$replaceAppsV1NamespacedReplicaSetStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
interface Parameter$patchAppsV1NamespacedReplicaSetStatus {
    /** name of the ReplicaSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchAppsV1NamespacedReplicaSetStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchAppsV1NamespacedReplicaSetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
interface Response$patchAppsV1NamespacedReplicaSetStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSet;
}
interface Parameter$listAppsV1NamespacedStatefulSet {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listAppsV1NamespacedStatefulSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSetList;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSetList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSetList;
    "application/json;stream=watch": Schemas.io$k8s$api$apps$v1$StatefulSetList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$apps$v1$StatefulSetList;
}
interface Parameter$createAppsV1NamespacedStatefulSet {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createAppsV1NamespacedStatefulSet = RequestBodies.io$k8s$api$apps$v1$StatefulSet.Content;
interface Response$createAppsV1NamespacedStatefulSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
interface Response$createAppsV1NamespacedStatefulSet$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
interface Response$createAppsV1NamespacedStatefulSet$Status$202 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
interface Parameter$deleteAppsV1CollectionNamespacedStatefulSet {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteAppsV1CollectionNamespacedStatefulSet = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteAppsV1CollectionNamespacedStatefulSet$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readAppsV1NamespacedStatefulSet {
    /** name of the StatefulSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readAppsV1NamespacedStatefulSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
interface Parameter$replaceAppsV1NamespacedStatefulSet {
    /** name of the StatefulSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceAppsV1NamespacedStatefulSet = RequestBodies.io$k8s$api$apps$v1$StatefulSet.Content;
interface Response$replaceAppsV1NamespacedStatefulSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
interface Response$replaceAppsV1NamespacedStatefulSet$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
interface Parameter$deleteAppsV1NamespacedStatefulSet {
    /** name of the StatefulSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteAppsV1NamespacedStatefulSet = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteAppsV1NamespacedStatefulSet$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteAppsV1NamespacedStatefulSet$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchAppsV1NamespacedStatefulSet {
    /** name of the StatefulSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchAppsV1NamespacedStatefulSet = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchAppsV1NamespacedStatefulSet$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
interface Response$patchAppsV1NamespacedStatefulSet$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
interface Parameter$readAppsV1NamespacedStatefulSetScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readAppsV1NamespacedStatefulSetScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
interface Parameter$replaceAppsV1NamespacedStatefulSetScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceAppsV1NamespacedStatefulSetScale = RequestBodies.io$k8s$api$autoscaling$v1$Scale.Content;
interface Response$replaceAppsV1NamespacedStatefulSetScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
interface Response$replaceAppsV1NamespacedStatefulSetScale$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
interface Parameter$patchAppsV1NamespacedStatefulSetScale {
    /** name of the Scale */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchAppsV1NamespacedStatefulSetScale = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchAppsV1NamespacedStatefulSetScale$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
interface Response$patchAppsV1NamespacedStatefulSetScale$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$Scale;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$Scale;
}
interface Parameter$readAppsV1NamespacedStatefulSetStatus {
    /** name of the StatefulSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readAppsV1NamespacedStatefulSetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
interface Parameter$replaceAppsV1NamespacedStatefulSetStatus {
    /** name of the StatefulSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceAppsV1NamespacedStatefulSetStatus = RequestBodies.io$k8s$api$apps$v1$StatefulSet.Content;
interface Response$replaceAppsV1NamespacedStatefulSetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
interface Response$replaceAppsV1NamespacedStatefulSetStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
interface Parameter$patchAppsV1NamespacedStatefulSetStatus {
    /** name of the StatefulSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchAppsV1NamespacedStatefulSetStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchAppsV1NamespacedStatefulSetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
interface Response$patchAppsV1NamespacedStatefulSetStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSet;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSet;
}
interface Parameter$listAppsV1ReplicaSetForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listAppsV1ReplicaSetForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$ReplicaSetList;
    "application/yaml": Schemas.io$k8s$api$apps$v1$ReplicaSetList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$ReplicaSetList;
    "application/json;stream=watch": Schemas.io$k8s$api$apps$v1$ReplicaSetList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$apps$v1$ReplicaSetList;
}
interface Parameter$listAppsV1StatefulSetForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listAppsV1StatefulSetForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$apps$v1$StatefulSetList;
    "application/yaml": Schemas.io$k8s$api$apps$v1$StatefulSetList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apps$v1$StatefulSetList;
    "application/json;stream=watch": Schemas.io$k8s$api$apps$v1$StatefulSetList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$apps$v1$StatefulSetList;
}
interface Parameter$watchAppsV1ControllerRevisionListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAppsV1ControllerRevisionListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAppsV1DaemonSetListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAppsV1DaemonSetListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAppsV1DeploymentListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAppsV1DeploymentListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAppsV1NamespacedControllerRevisionList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAppsV1NamespacedControllerRevisionList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAppsV1NamespacedControllerRevision {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ControllerRevision */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAppsV1NamespacedControllerRevision$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAppsV1NamespacedDaemonSetList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAppsV1NamespacedDaemonSetList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAppsV1NamespacedDaemonSet {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the DaemonSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAppsV1NamespacedDaemonSet$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAppsV1NamespacedDeploymentList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAppsV1NamespacedDeploymentList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAppsV1NamespacedDeployment {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Deployment */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAppsV1NamespacedDeployment$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAppsV1NamespacedReplicaSetList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAppsV1NamespacedReplicaSetList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAppsV1NamespacedReplicaSet {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ReplicaSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAppsV1NamespacedReplicaSet$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAppsV1NamespacedStatefulSetList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAppsV1NamespacedStatefulSetList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAppsV1NamespacedStatefulSet {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the StatefulSet */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAppsV1NamespacedStatefulSet$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAppsV1ReplicaSetListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAppsV1ReplicaSetListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAppsV1StatefulSetListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAppsV1StatefulSetListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getAuthenticationAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
interface Response$getAuthenticationV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$createAuthenticationV1TokenReview {
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface RequestBody$createAuthenticationV1TokenReview {
    "*/*": Schemas.io$k8s$api$authentication$v1$TokenReview;
}
interface Response$createAuthenticationV1TokenReview$Status$200 {
    "application/json": Schemas.io$k8s$api$authentication$v1$TokenReview;
    "application/yaml": Schemas.io$k8s$api$authentication$v1$TokenReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authentication$v1$TokenReview;
}
interface Response$createAuthenticationV1TokenReview$Status$201 {
    "application/json": Schemas.io$k8s$api$authentication$v1$TokenReview;
    "application/yaml": Schemas.io$k8s$api$authentication$v1$TokenReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authentication$v1$TokenReview;
}
interface Response$createAuthenticationV1TokenReview$Status$202 {
    "application/json": Schemas.io$k8s$api$authentication$v1$TokenReview;
    "application/yaml": Schemas.io$k8s$api$authentication$v1$TokenReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authentication$v1$TokenReview;
}
interface Response$getAuthenticationV1alpha1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$createAuthenticationV1alpha1SelfSubjectReview {
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface RequestBody$createAuthenticationV1alpha1SelfSubjectReview {
    "*/*": Schemas.io$k8s$api$authentication$v1alpha1$SelfSubjectReview;
}
interface Response$createAuthenticationV1alpha1SelfSubjectReview$Status$200 {
    "application/json": Schemas.io$k8s$api$authentication$v1alpha1$SelfSubjectReview;
    "application/yaml": Schemas.io$k8s$api$authentication$v1alpha1$SelfSubjectReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authentication$v1alpha1$SelfSubjectReview;
}
interface Response$createAuthenticationV1alpha1SelfSubjectReview$Status$201 {
    "application/json": Schemas.io$k8s$api$authentication$v1alpha1$SelfSubjectReview;
    "application/yaml": Schemas.io$k8s$api$authentication$v1alpha1$SelfSubjectReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authentication$v1alpha1$SelfSubjectReview;
}
interface Response$createAuthenticationV1alpha1SelfSubjectReview$Status$202 {
    "application/json": Schemas.io$k8s$api$authentication$v1alpha1$SelfSubjectReview;
    "application/yaml": Schemas.io$k8s$api$authentication$v1alpha1$SelfSubjectReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authentication$v1alpha1$SelfSubjectReview;
}
interface Response$getAuthenticationV1beta1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$createAuthenticationV1beta1SelfSubjectReview {
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface RequestBody$createAuthenticationV1beta1SelfSubjectReview {
    "*/*": Schemas.io$k8s$api$authentication$v1beta1$SelfSubjectReview;
}
interface Response$createAuthenticationV1beta1SelfSubjectReview$Status$200 {
    "application/json": Schemas.io$k8s$api$authentication$v1beta1$SelfSubjectReview;
    "application/yaml": Schemas.io$k8s$api$authentication$v1beta1$SelfSubjectReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authentication$v1beta1$SelfSubjectReview;
}
interface Response$createAuthenticationV1beta1SelfSubjectReview$Status$201 {
    "application/json": Schemas.io$k8s$api$authentication$v1beta1$SelfSubjectReview;
    "application/yaml": Schemas.io$k8s$api$authentication$v1beta1$SelfSubjectReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authentication$v1beta1$SelfSubjectReview;
}
interface Response$createAuthenticationV1beta1SelfSubjectReview$Status$202 {
    "application/json": Schemas.io$k8s$api$authentication$v1beta1$SelfSubjectReview;
    "application/yaml": Schemas.io$k8s$api$authentication$v1beta1$SelfSubjectReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authentication$v1beta1$SelfSubjectReview;
}
interface Response$getAuthorizationAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
interface Response$getAuthorizationV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$createAuthorizationV1NamespacedLocalSubjectAccessReview {
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface RequestBody$createAuthorizationV1NamespacedLocalSubjectAccessReview {
    "*/*": Schemas.io$k8s$api$authorization$v1$LocalSubjectAccessReview;
}
interface Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$200 {
    "application/json": Schemas.io$k8s$api$authorization$v1$LocalSubjectAccessReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$LocalSubjectAccessReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$LocalSubjectAccessReview;
}
interface Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$201 {
    "application/json": Schemas.io$k8s$api$authorization$v1$LocalSubjectAccessReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$LocalSubjectAccessReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$LocalSubjectAccessReview;
}
interface Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$202 {
    "application/json": Schemas.io$k8s$api$authorization$v1$LocalSubjectAccessReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$LocalSubjectAccessReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$LocalSubjectAccessReview;
}
interface Parameter$createAuthorizationV1SelfSubjectAccessReview {
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface RequestBody$createAuthorizationV1SelfSubjectAccessReview {
    "*/*": Schemas.io$k8s$api$authorization$v1$SelfSubjectAccessReview;
}
interface Response$createAuthorizationV1SelfSubjectAccessReview$Status$200 {
    "application/json": Schemas.io$k8s$api$authorization$v1$SelfSubjectAccessReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$SelfSubjectAccessReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$SelfSubjectAccessReview;
}
interface Response$createAuthorizationV1SelfSubjectAccessReview$Status$201 {
    "application/json": Schemas.io$k8s$api$authorization$v1$SelfSubjectAccessReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$SelfSubjectAccessReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$SelfSubjectAccessReview;
}
interface Response$createAuthorizationV1SelfSubjectAccessReview$Status$202 {
    "application/json": Schemas.io$k8s$api$authorization$v1$SelfSubjectAccessReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$SelfSubjectAccessReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$SelfSubjectAccessReview;
}
interface Parameter$createAuthorizationV1SelfSubjectRulesReview {
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface RequestBody$createAuthorizationV1SelfSubjectRulesReview {
    "*/*": Schemas.io$k8s$api$authorization$v1$SelfSubjectRulesReview;
}
interface Response$createAuthorizationV1SelfSubjectRulesReview$Status$200 {
    "application/json": Schemas.io$k8s$api$authorization$v1$SelfSubjectRulesReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$SelfSubjectRulesReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$SelfSubjectRulesReview;
}
interface Response$createAuthorizationV1SelfSubjectRulesReview$Status$201 {
    "application/json": Schemas.io$k8s$api$authorization$v1$SelfSubjectRulesReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$SelfSubjectRulesReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$SelfSubjectRulesReview;
}
interface Response$createAuthorizationV1SelfSubjectRulesReview$Status$202 {
    "application/json": Schemas.io$k8s$api$authorization$v1$SelfSubjectRulesReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$SelfSubjectRulesReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$SelfSubjectRulesReview;
}
interface Parameter$createAuthorizationV1SubjectAccessReview {
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface RequestBody$createAuthorizationV1SubjectAccessReview {
    "*/*": Schemas.io$k8s$api$authorization$v1$SubjectAccessReview;
}
interface Response$createAuthorizationV1SubjectAccessReview$Status$200 {
    "application/json": Schemas.io$k8s$api$authorization$v1$SubjectAccessReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$SubjectAccessReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$SubjectAccessReview;
}
interface Response$createAuthorizationV1SubjectAccessReview$Status$201 {
    "application/json": Schemas.io$k8s$api$authorization$v1$SubjectAccessReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$SubjectAccessReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$SubjectAccessReview;
}
interface Response$createAuthorizationV1SubjectAccessReview$Status$202 {
    "application/json": Schemas.io$k8s$api$authorization$v1$SubjectAccessReview;
    "application/yaml": Schemas.io$k8s$api$authorization$v1$SubjectAccessReview;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$authorization$v1$SubjectAccessReview;
}
interface Response$getAutoscalingAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
interface Response$getAutoscalingV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerList;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerList;
    "application/json;stream=watch": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerList;
}
interface Parameter$listAutoscalingV1NamespacedHorizontalPodAutoscaler {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerList;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerList;
    "application/json;stream=watch": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscalerList;
}
interface Parameter$createAutoscalingV1NamespacedHorizontalPodAutoscaler {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createAutoscalingV1NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler.Content;
interface Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
interface Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
interface Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$202 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
interface Parameter$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readAutoscalingV1NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
interface Parameter$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler.Content;
interface Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
interface Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
interface Parameter$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchAutoscalingV1NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchAutoscalingV1NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
interface Response$patchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
interface Parameter$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
interface Parameter$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus = RequestBodies.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler.Content;
interface Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
interface Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
interface Parameter$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
interface Response$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v1$HorizontalPodAutoscaler;
}
interface Parameter$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAutoscalingV1NamespacedHorizontalPodAutoscaler {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getAutoscalingV2APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerList;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerList;
    "application/json;stream=watch": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerList;
}
interface Parameter$listAutoscalingV2NamespacedHorizontalPodAutoscaler {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerList;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerList;
    "application/json;stream=watch": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscalerList;
}
interface Parameter$createAutoscalingV2NamespacedHorizontalPodAutoscaler {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createAutoscalingV2NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler.Content;
interface Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
interface Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
interface Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$202 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
interface Parameter$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readAutoscalingV2NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
interface Parameter$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler.Content;
interface Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
interface Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
interface Parameter$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchAutoscalingV2NamespacedHorizontalPodAutoscaler {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchAutoscalingV2NamespacedHorizontalPodAutoscaler = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
interface Response$patchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
interface Parameter$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
interface Parameter$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus = RequestBodies.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler.Content;
interface Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
interface Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
interface Parameter$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus {
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
interface Response$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/yaml": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$autoscaling$v2$HorizontalPodAutoscaler;
}
interface Parameter$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchAutoscalingV2NamespacedHorizontalPodAutoscaler {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the HorizontalPodAutoscaler */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getBatchAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
interface Response$getBatchV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listBatchV1CronJobForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listBatchV1CronJobForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJobList;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJobList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJobList;
    "application/json;stream=watch": Schemas.io$k8s$api$batch$v1$CronJobList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$batch$v1$CronJobList;
}
interface Parameter$listBatchV1JobForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listBatchV1JobForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$JobList;
    "application/yaml": Schemas.io$k8s$api$batch$v1$JobList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$JobList;
    "application/json;stream=watch": Schemas.io$k8s$api$batch$v1$JobList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$batch$v1$JobList;
}
interface Parameter$listBatchV1NamespacedCronJob {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listBatchV1NamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJobList;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJobList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJobList;
    "application/json;stream=watch": Schemas.io$k8s$api$batch$v1$CronJobList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$batch$v1$CronJobList;
}
interface Parameter$createBatchV1NamespacedCronJob {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createBatchV1NamespacedCronJob = RequestBodies.io$k8s$api$batch$v1$CronJob.Content;
interface Response$createBatchV1NamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
interface Response$createBatchV1NamespacedCronJob$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
interface Response$createBatchV1NamespacedCronJob$Status$202 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
interface Parameter$deleteBatchV1CollectionNamespacedCronJob {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteBatchV1CollectionNamespacedCronJob = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteBatchV1CollectionNamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readBatchV1NamespacedCronJob {
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readBatchV1NamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
interface Parameter$replaceBatchV1NamespacedCronJob {
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceBatchV1NamespacedCronJob = RequestBodies.io$k8s$api$batch$v1$CronJob.Content;
interface Response$replaceBatchV1NamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
interface Response$replaceBatchV1NamespacedCronJob$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
interface Parameter$deleteBatchV1NamespacedCronJob {
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteBatchV1NamespacedCronJob = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteBatchV1NamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteBatchV1NamespacedCronJob$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchBatchV1NamespacedCronJob {
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchBatchV1NamespacedCronJob = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchBatchV1NamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
interface Response$patchBatchV1NamespacedCronJob$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
interface Parameter$readBatchV1NamespacedCronJobStatus {
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readBatchV1NamespacedCronJobStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
interface Parameter$replaceBatchV1NamespacedCronJobStatus {
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceBatchV1NamespacedCronJobStatus = RequestBodies.io$k8s$api$batch$v1$CronJob.Content;
interface Response$replaceBatchV1NamespacedCronJobStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
interface Response$replaceBatchV1NamespacedCronJobStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
interface Parameter$patchBatchV1NamespacedCronJobStatus {
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchBatchV1NamespacedCronJobStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchBatchV1NamespacedCronJobStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
interface Response$patchBatchV1NamespacedCronJobStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/yaml": Schemas.io$k8s$api$batch$v1$CronJob;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$CronJob;
}
interface Parameter$listBatchV1NamespacedJob {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listBatchV1NamespacedJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$JobList;
    "application/yaml": Schemas.io$k8s$api$batch$v1$JobList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$JobList;
    "application/json;stream=watch": Schemas.io$k8s$api$batch$v1$JobList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$batch$v1$JobList;
}
interface Parameter$createBatchV1NamespacedJob {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createBatchV1NamespacedJob = RequestBodies.io$k8s$api$batch$v1$Job.Content;
interface Response$createBatchV1NamespacedJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
interface Response$createBatchV1NamespacedJob$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
interface Response$createBatchV1NamespacedJob$Status$202 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
interface Parameter$deleteBatchV1CollectionNamespacedJob {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteBatchV1CollectionNamespacedJob = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteBatchV1CollectionNamespacedJob$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readBatchV1NamespacedJob {
    /** name of the Job */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readBatchV1NamespacedJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
interface Parameter$replaceBatchV1NamespacedJob {
    /** name of the Job */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceBatchV1NamespacedJob = RequestBodies.io$k8s$api$batch$v1$Job.Content;
interface Response$replaceBatchV1NamespacedJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
interface Response$replaceBatchV1NamespacedJob$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
interface Parameter$deleteBatchV1NamespacedJob {
    /** name of the Job */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteBatchV1NamespacedJob = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteBatchV1NamespacedJob$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteBatchV1NamespacedJob$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchBatchV1NamespacedJob {
    /** name of the Job */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchBatchV1NamespacedJob = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchBatchV1NamespacedJob$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
interface Response$patchBatchV1NamespacedJob$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
interface Parameter$readBatchV1NamespacedJobStatus {
    /** name of the Job */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readBatchV1NamespacedJobStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
interface Parameter$replaceBatchV1NamespacedJobStatus {
    /** name of the Job */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceBatchV1NamespacedJobStatus = RequestBodies.io$k8s$api$batch$v1$Job.Content;
interface Response$replaceBatchV1NamespacedJobStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
interface Response$replaceBatchV1NamespacedJobStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
interface Parameter$patchBatchV1NamespacedJobStatus {
    /** name of the Job */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchBatchV1NamespacedJobStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchBatchV1NamespacedJobStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
interface Response$patchBatchV1NamespacedJobStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$batch$v1$Job;
    "application/yaml": Schemas.io$k8s$api$batch$v1$Job;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$batch$v1$Job;
}
interface Parameter$watchBatchV1CronJobListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchBatchV1CronJobListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchBatchV1JobListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchBatchV1JobListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchBatchV1NamespacedCronJobList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchBatchV1NamespacedCronJobList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchBatchV1NamespacedCronJob {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the CronJob */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchBatchV1NamespacedCronJob$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchBatchV1NamespacedJobList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchBatchV1NamespacedJobList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchBatchV1NamespacedJob {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Job */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchBatchV1NamespacedJob$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getCertificatesAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
interface Response$getCertificatesV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listCertificatesV1CertificateSigningRequest {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCertificatesV1CertificateSigningRequest$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequestList;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequestList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequestList;
    "application/json;stream=watch": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequestList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequestList;
}
interface Parameter$createCertificatesV1CertificateSigningRequest {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createCertificatesV1CertificateSigningRequest = RequestBodies.io$k8s$api$certificates$v1$CertificateSigningRequest.Content;
interface Response$createCertificatesV1CertificateSigningRequest$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
interface Response$createCertificatesV1CertificateSigningRequest$Status$201 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
interface Response$createCertificatesV1CertificateSigningRequest$Status$202 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
interface Parameter$deleteCertificatesV1CollectionCertificateSigningRequest {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteCertificatesV1CollectionCertificateSigningRequest = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCertificatesV1CollectionCertificateSigningRequest$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readCertificatesV1CertificateSigningRequest {
    /** name of the CertificateSigningRequest */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCertificatesV1CertificateSigningRequest$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
interface Parameter$replaceCertificatesV1CertificateSigningRequest {
    /** name of the CertificateSigningRequest */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCertificatesV1CertificateSigningRequest = RequestBodies.io$k8s$api$certificates$v1$CertificateSigningRequest.Content;
interface Response$replaceCertificatesV1CertificateSigningRequest$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
interface Response$replaceCertificatesV1CertificateSigningRequest$Status$201 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
interface Parameter$deleteCertificatesV1CertificateSigningRequest {
    /** name of the CertificateSigningRequest */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteCertificatesV1CertificateSigningRequest = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCertificatesV1CertificateSigningRequest$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteCertificatesV1CertificateSigningRequest$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchCertificatesV1CertificateSigningRequest {
    /** name of the CertificateSigningRequest */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCertificatesV1CertificateSigningRequest = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCertificatesV1CertificateSigningRequest$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
interface Response$patchCertificatesV1CertificateSigningRequest$Status$201 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
interface Parameter$readCertificatesV1CertificateSigningRequestApproval {
    /** name of the CertificateSigningRequest */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCertificatesV1CertificateSigningRequestApproval$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
interface Parameter$replaceCertificatesV1CertificateSigningRequestApproval {
    /** name of the CertificateSigningRequest */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCertificatesV1CertificateSigningRequestApproval = RequestBodies.io$k8s$api$certificates$v1$CertificateSigningRequest.Content;
interface Response$replaceCertificatesV1CertificateSigningRequestApproval$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
interface Response$replaceCertificatesV1CertificateSigningRequestApproval$Status$201 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
interface Parameter$patchCertificatesV1CertificateSigningRequestApproval {
    /** name of the CertificateSigningRequest */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCertificatesV1CertificateSigningRequestApproval = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCertificatesV1CertificateSigningRequestApproval$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
interface Response$patchCertificatesV1CertificateSigningRequestApproval$Status$201 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
interface Parameter$readCertificatesV1CertificateSigningRequestStatus {
    /** name of the CertificateSigningRequest */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCertificatesV1CertificateSigningRequestStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
interface Parameter$replaceCertificatesV1CertificateSigningRequestStatus {
    /** name of the CertificateSigningRequest */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCertificatesV1CertificateSigningRequestStatus = RequestBodies.io$k8s$api$certificates$v1$CertificateSigningRequest.Content;
interface Response$replaceCertificatesV1CertificateSigningRequestStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
interface Response$replaceCertificatesV1CertificateSigningRequestStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
interface Parameter$patchCertificatesV1CertificateSigningRequestStatus {
    /** name of the CertificateSigningRequest */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCertificatesV1CertificateSigningRequestStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCertificatesV1CertificateSigningRequestStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
interface Response$patchCertificatesV1CertificateSigningRequestStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/yaml": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1$CertificateSigningRequest;
}
interface Parameter$watchCertificatesV1CertificateSigningRequestList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCertificatesV1CertificateSigningRequestList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCertificatesV1CertificateSigningRequest {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the CertificateSigningRequest */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCertificatesV1CertificateSigningRequest$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getCertificatesV1alpha1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listCertificatesV1alpha1ClusterTrustBundle {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCertificatesV1alpha1ClusterTrustBundle$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundleList;
    "application/yaml": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundleList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundleList;
    "application/json;stream=watch": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundleList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundleList;
}
interface Parameter$createCertificatesV1alpha1ClusterTrustBundle {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createCertificatesV1alpha1ClusterTrustBundle = RequestBodies.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle.Content;
interface Response$createCertificatesV1alpha1ClusterTrustBundle$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
    "application/yaml": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
}
interface Response$createCertificatesV1alpha1ClusterTrustBundle$Status$201 {
    "application/json": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
    "application/yaml": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
}
interface Response$createCertificatesV1alpha1ClusterTrustBundle$Status$202 {
    "application/json": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
    "application/yaml": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
}
interface Parameter$deleteCertificatesV1alpha1CollectionClusterTrustBundle {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteCertificatesV1alpha1CollectionClusterTrustBundle = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCertificatesV1alpha1CollectionClusterTrustBundle$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readCertificatesV1alpha1ClusterTrustBundle {
    /** name of the ClusterTrustBundle */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCertificatesV1alpha1ClusterTrustBundle$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
    "application/yaml": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
}
interface Parameter$replaceCertificatesV1alpha1ClusterTrustBundle {
    /** name of the ClusterTrustBundle */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCertificatesV1alpha1ClusterTrustBundle = RequestBodies.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle.Content;
interface Response$replaceCertificatesV1alpha1ClusterTrustBundle$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
    "application/yaml": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
}
interface Response$replaceCertificatesV1alpha1ClusterTrustBundle$Status$201 {
    "application/json": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
    "application/yaml": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
}
interface Parameter$deleteCertificatesV1alpha1ClusterTrustBundle {
    /** name of the ClusterTrustBundle */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteCertificatesV1alpha1ClusterTrustBundle = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCertificatesV1alpha1ClusterTrustBundle$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteCertificatesV1alpha1ClusterTrustBundle$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchCertificatesV1alpha1ClusterTrustBundle {
    /** name of the ClusterTrustBundle */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCertificatesV1alpha1ClusterTrustBundle = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCertificatesV1alpha1ClusterTrustBundle$Status$200 {
    "application/json": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
    "application/yaml": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
}
interface Response$patchCertificatesV1alpha1ClusterTrustBundle$Status$201 {
    "application/json": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
    "application/yaml": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$certificates$v1alpha1$ClusterTrustBundle;
}
interface Parameter$watchCertificatesV1alpha1ClusterTrustBundleList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCertificatesV1alpha1ClusterTrustBundleList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCertificatesV1alpha1ClusterTrustBundle {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ClusterTrustBundle */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCertificatesV1alpha1ClusterTrustBundle$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getCoordinationAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
interface Response$getCoordinationV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listCoordinationV1LeaseForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoordinationV1LeaseForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$coordination$v1$LeaseList;
    "application/yaml": Schemas.io$k8s$api$coordination$v1$LeaseList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$coordination$v1$LeaseList;
    "application/json;stream=watch": Schemas.io$k8s$api$coordination$v1$LeaseList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$coordination$v1$LeaseList;
}
interface Parameter$listCoordinationV1NamespacedLease {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listCoordinationV1NamespacedLease$Status$200 {
    "application/json": Schemas.io$k8s$api$coordination$v1$LeaseList;
    "application/yaml": Schemas.io$k8s$api$coordination$v1$LeaseList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$coordination$v1$LeaseList;
    "application/json;stream=watch": Schemas.io$k8s$api$coordination$v1$LeaseList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$coordination$v1$LeaseList;
}
interface Parameter$createCoordinationV1NamespacedLease {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createCoordinationV1NamespacedLease = RequestBodies.io$k8s$api$coordination$v1$Lease.Content;
interface Response$createCoordinationV1NamespacedLease$Status$200 {
    "application/json": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/yaml": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$coordination$v1$Lease;
}
interface Response$createCoordinationV1NamespacedLease$Status$201 {
    "application/json": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/yaml": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$coordination$v1$Lease;
}
interface Response$createCoordinationV1NamespacedLease$Status$202 {
    "application/json": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/yaml": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$coordination$v1$Lease;
}
interface Parameter$deleteCoordinationV1CollectionNamespacedLease {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteCoordinationV1CollectionNamespacedLease = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoordinationV1CollectionNamespacedLease$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readCoordinationV1NamespacedLease {
    /** name of the Lease */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readCoordinationV1NamespacedLease$Status$200 {
    "application/json": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/yaml": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$coordination$v1$Lease;
}
interface Parameter$replaceCoordinationV1NamespacedLease {
    /** name of the Lease */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceCoordinationV1NamespacedLease = RequestBodies.io$k8s$api$coordination$v1$Lease.Content;
interface Response$replaceCoordinationV1NamespacedLease$Status$200 {
    "application/json": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/yaml": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$coordination$v1$Lease;
}
interface Response$replaceCoordinationV1NamespacedLease$Status$201 {
    "application/json": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/yaml": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$coordination$v1$Lease;
}
interface Parameter$deleteCoordinationV1NamespacedLease {
    /** name of the Lease */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteCoordinationV1NamespacedLease = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteCoordinationV1NamespacedLease$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteCoordinationV1NamespacedLease$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchCoordinationV1NamespacedLease {
    /** name of the Lease */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchCoordinationV1NamespacedLease = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchCoordinationV1NamespacedLease$Status$200 {
    "application/json": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/yaml": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$coordination$v1$Lease;
}
interface Response$patchCoordinationV1NamespacedLease$Status$201 {
    "application/json": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/yaml": Schemas.io$k8s$api$coordination$v1$Lease;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$coordination$v1$Lease;
}
interface Parameter$watchCoordinationV1LeaseListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoordinationV1LeaseListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoordinationV1NamespacedLeaseList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoordinationV1NamespacedLeaseList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchCoordinationV1NamespacedLease {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Lease */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchCoordinationV1NamespacedLease$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getDiscoveryAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
interface Response$getDiscoveryV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listDiscoveryV1EndpointSliceForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listDiscoveryV1EndpointSliceForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$discovery$v1$EndpointSliceList;
    "application/yaml": Schemas.io$k8s$api$discovery$v1$EndpointSliceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1$EndpointSliceList;
    "application/json;stream=watch": Schemas.io$k8s$api$discovery$v1$EndpointSliceList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$discovery$v1$EndpointSliceList;
}
interface Parameter$listDiscoveryV1NamespacedEndpointSlice {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listDiscoveryV1NamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$api$discovery$v1$EndpointSliceList;
    "application/yaml": Schemas.io$k8s$api$discovery$v1$EndpointSliceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1$EndpointSliceList;
    "application/json;stream=watch": Schemas.io$k8s$api$discovery$v1$EndpointSliceList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$discovery$v1$EndpointSliceList;
}
interface Parameter$createDiscoveryV1NamespacedEndpointSlice {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createDiscoveryV1NamespacedEndpointSlice = RequestBodies.io$k8s$api$discovery$v1$EndpointSlice.Content;
interface Response$createDiscoveryV1NamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
}
interface Response$createDiscoveryV1NamespacedEndpointSlice$Status$201 {
    "application/json": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
}
interface Response$createDiscoveryV1NamespacedEndpointSlice$Status$202 {
    "application/json": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
}
interface Parameter$deleteDiscoveryV1CollectionNamespacedEndpointSlice {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteDiscoveryV1CollectionNamespacedEndpointSlice = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteDiscoveryV1CollectionNamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readDiscoveryV1NamespacedEndpointSlice {
    /** name of the EndpointSlice */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readDiscoveryV1NamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
}
interface Parameter$replaceDiscoveryV1NamespacedEndpointSlice {
    /** name of the EndpointSlice */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceDiscoveryV1NamespacedEndpointSlice = RequestBodies.io$k8s$api$discovery$v1$EndpointSlice.Content;
interface Response$replaceDiscoveryV1NamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
}
interface Response$replaceDiscoveryV1NamespacedEndpointSlice$Status$201 {
    "application/json": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
}
interface Parameter$deleteDiscoveryV1NamespacedEndpointSlice {
    /** name of the EndpointSlice */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteDiscoveryV1NamespacedEndpointSlice = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteDiscoveryV1NamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteDiscoveryV1NamespacedEndpointSlice$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchDiscoveryV1NamespacedEndpointSlice {
    /** name of the EndpointSlice */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchDiscoveryV1NamespacedEndpointSlice = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchDiscoveryV1NamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
}
interface Response$patchDiscoveryV1NamespacedEndpointSlice$Status$201 {
    "application/json": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/yaml": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$discovery$v1$EndpointSlice;
}
interface Parameter$watchDiscoveryV1EndpointSliceListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchDiscoveryV1EndpointSliceListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchDiscoveryV1NamespacedEndpointSliceList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchDiscoveryV1NamespacedEndpointSliceList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchDiscoveryV1NamespacedEndpointSlice {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the EndpointSlice */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchDiscoveryV1NamespacedEndpointSlice$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getEventsAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
interface Response$getEventsV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listEventsV1EventForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listEventsV1EventForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$events$v1$EventList;
    "application/yaml": Schemas.io$k8s$api$events$v1$EventList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1$EventList;
    "application/json;stream=watch": Schemas.io$k8s$api$events$v1$EventList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$events$v1$EventList;
}
interface Parameter$listEventsV1NamespacedEvent {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listEventsV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$events$v1$EventList;
    "application/yaml": Schemas.io$k8s$api$events$v1$EventList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1$EventList;
    "application/json;stream=watch": Schemas.io$k8s$api$events$v1$EventList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$events$v1$EventList;
}
interface Parameter$createEventsV1NamespacedEvent {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createEventsV1NamespacedEvent = RequestBodies.io$k8s$api$events$v1$Event.Content;
interface Response$createEventsV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$events$v1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1$Event;
}
interface Response$createEventsV1NamespacedEvent$Status$201 {
    "application/json": Schemas.io$k8s$api$events$v1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1$Event;
}
interface Response$createEventsV1NamespacedEvent$Status$202 {
    "application/json": Schemas.io$k8s$api$events$v1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1$Event;
}
interface Parameter$deleteEventsV1CollectionNamespacedEvent {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteEventsV1CollectionNamespacedEvent = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteEventsV1CollectionNamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readEventsV1NamespacedEvent {
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readEventsV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$events$v1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1$Event;
}
interface Parameter$replaceEventsV1NamespacedEvent {
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceEventsV1NamespacedEvent = RequestBodies.io$k8s$api$events$v1$Event.Content;
interface Response$replaceEventsV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$events$v1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1$Event;
}
interface Response$replaceEventsV1NamespacedEvent$Status$201 {
    "application/json": Schemas.io$k8s$api$events$v1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1$Event;
}
interface Parameter$deleteEventsV1NamespacedEvent {
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteEventsV1NamespacedEvent = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteEventsV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteEventsV1NamespacedEvent$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchEventsV1NamespacedEvent {
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchEventsV1NamespacedEvent = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchEventsV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$api$events$v1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1$Event;
}
interface Response$patchEventsV1NamespacedEvent$Status$201 {
    "application/json": Schemas.io$k8s$api$events$v1$Event;
    "application/yaml": Schemas.io$k8s$api$events$v1$Event;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$events$v1$Event;
}
interface Parameter$watchEventsV1EventListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchEventsV1EventListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchEventsV1NamespacedEventList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchEventsV1NamespacedEventList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchEventsV1NamespacedEvent {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Event */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchEventsV1NamespacedEvent$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getFlowcontrolApiserverAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
interface Response$getFlowcontrolApiserverV1beta2APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listFlowcontrolApiserverV1beta2FlowSchema {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listFlowcontrolApiserverV1beta2FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchemaList;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchemaList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchemaList;
    "application/json;stream=watch": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchemaList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchemaList;
}
interface Parameter$createFlowcontrolApiserverV1beta2FlowSchema {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createFlowcontrolApiserverV1beta2FlowSchema = RequestBodies.io$k8s$api$flowcontrol$v1beta2$FlowSchema.Content;
interface Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
interface Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
interface Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$202 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
interface Parameter$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readFlowcontrolApiserverV1beta2FlowSchema {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readFlowcontrolApiserverV1beta2FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
interface Parameter$replaceFlowcontrolApiserverV1beta2FlowSchema {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceFlowcontrolApiserverV1beta2FlowSchema = RequestBodies.io$k8s$api$flowcontrol$v1beta2$FlowSchema.Content;
interface Response$replaceFlowcontrolApiserverV1beta2FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
interface Response$replaceFlowcontrolApiserverV1beta2FlowSchema$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
interface Parameter$deleteFlowcontrolApiserverV1beta2FlowSchema {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteFlowcontrolApiserverV1beta2FlowSchema = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteFlowcontrolApiserverV1beta2FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteFlowcontrolApiserverV1beta2FlowSchema$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchFlowcontrolApiserverV1beta2FlowSchema {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchFlowcontrolApiserverV1beta2FlowSchema = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchFlowcontrolApiserverV1beta2FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
interface Response$patchFlowcontrolApiserverV1beta2FlowSchema$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
interface Parameter$readFlowcontrolApiserverV1beta2FlowSchemaStatus {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
interface Parameter$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus = RequestBodies.io$k8s$api$flowcontrol$v1beta2$FlowSchema.Content;
interface Response$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
interface Response$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
interface Parameter$patchFlowcontrolApiserverV1beta2FlowSchemaStatus {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchFlowcontrolApiserverV1beta2FlowSchemaStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
interface Response$patchFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$FlowSchema;
}
interface Parameter$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationList;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationList;
    "application/json;stream=watch": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfigurationList;
}
interface Parameter$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration = RequestBodies.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration.Content;
interface Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
interface Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
interface Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$202 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
interface Parameter$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
interface Parameter$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration = RequestBodies.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration.Content;
interface Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
interface Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
interface Parameter$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
interface Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
interface Parameter$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
interface Parameter$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus = RequestBodies.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration.Content;
interface Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
interface Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
interface Parameter$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
interface Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta2$PriorityLevelConfiguration;
}
interface Parameter$watchFlowcontrolApiserverV1beta2FlowSchemaList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchFlowcontrolApiserverV1beta2FlowSchemaList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchFlowcontrolApiserverV1beta2FlowSchema {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchFlowcontrolApiserverV1beta2FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getFlowcontrolApiserverV1beta3APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listFlowcontrolApiserverV1beta3FlowSchema {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listFlowcontrolApiserverV1beta3FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchemaList;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchemaList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchemaList;
    "application/json;stream=watch": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchemaList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchemaList;
}
interface Parameter$createFlowcontrolApiserverV1beta3FlowSchema {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createFlowcontrolApiserverV1beta3FlowSchema = RequestBodies.io$k8s$api$flowcontrol$v1beta3$FlowSchema.Content;
interface Response$createFlowcontrolApiserverV1beta3FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
}
interface Response$createFlowcontrolApiserverV1beta3FlowSchema$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
}
interface Response$createFlowcontrolApiserverV1beta3FlowSchema$Status$202 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
}
interface Parameter$deleteFlowcontrolApiserverV1beta3CollectionFlowSchema {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteFlowcontrolApiserverV1beta3CollectionFlowSchema = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteFlowcontrolApiserverV1beta3CollectionFlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readFlowcontrolApiserverV1beta3FlowSchema {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readFlowcontrolApiserverV1beta3FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
}
interface Parameter$replaceFlowcontrolApiserverV1beta3FlowSchema {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceFlowcontrolApiserverV1beta3FlowSchema = RequestBodies.io$k8s$api$flowcontrol$v1beta3$FlowSchema.Content;
interface Response$replaceFlowcontrolApiserverV1beta3FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
}
interface Response$replaceFlowcontrolApiserverV1beta3FlowSchema$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
}
interface Parameter$deleteFlowcontrolApiserverV1beta3FlowSchema {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteFlowcontrolApiserverV1beta3FlowSchema = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteFlowcontrolApiserverV1beta3FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteFlowcontrolApiserverV1beta3FlowSchema$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchFlowcontrolApiserverV1beta3FlowSchema {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchFlowcontrolApiserverV1beta3FlowSchema = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchFlowcontrolApiserverV1beta3FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
}
interface Response$patchFlowcontrolApiserverV1beta3FlowSchema$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
}
interface Parameter$readFlowcontrolApiserverV1beta3FlowSchemaStatus {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
}
interface Parameter$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus = RequestBodies.io$k8s$api$flowcontrol$v1beta3$FlowSchema.Content;
interface Response$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
}
interface Response$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
}
interface Parameter$patchFlowcontrolApiserverV1beta3FlowSchemaStatus {
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchFlowcontrolApiserverV1beta3FlowSchemaStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
}
interface Response$patchFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$FlowSchema;
}
interface Parameter$listFlowcontrolApiserverV1beta3PriorityLevelConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfigurationList;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfigurationList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfigurationList;
    "application/json;stream=watch": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfigurationList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfigurationList;
}
interface Parameter$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration = RequestBodies.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration.Content;
interface Response$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
}
interface Response$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
}
interface Response$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$202 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
}
interface Parameter$deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readFlowcontrolApiserverV1beta3PriorityLevelConfiguration {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
}
interface Parameter$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration = RequestBodies.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration.Content;
interface Response$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
}
interface Response$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
}
interface Parameter$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
}
interface Response$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
}
interface Parameter$readFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
}
interface Parameter$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus = RequestBodies.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration.Content;
interface Response$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
}
interface Response$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
}
interface Parameter$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus {
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
}
interface Response$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/yaml": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$flowcontrol$v1beta3$PriorityLevelConfiguration;
}
interface Parameter$watchFlowcontrolApiserverV1beta3FlowSchemaList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchFlowcontrolApiserverV1beta3FlowSchemaList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchFlowcontrolApiserverV1beta3FlowSchema {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the FlowSchema */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchFlowcontrolApiserverV1beta3FlowSchema$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchFlowcontrolApiserverV1beta3PriorityLevelConfigurationList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchFlowcontrolApiserverV1beta3PriorityLevelConfigurationList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchFlowcontrolApiserverV1beta3PriorityLevelConfiguration {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the PriorityLevelConfiguration */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getInternalApiserverAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
interface Response$getInternalApiserverV1alpha1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listInternalApiserverV1alpha1StorageVersion {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listInternalApiserverV1alpha1StorageVersion$Status$200 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersionList;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersionList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersionList;
    "application/json;stream=watch": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersionList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersionList;
}
interface Parameter$createInternalApiserverV1alpha1StorageVersion {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createInternalApiserverV1alpha1StorageVersion = RequestBodies.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion.Content;
interface Response$createInternalApiserverV1alpha1StorageVersion$Status$200 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
interface Response$createInternalApiserverV1alpha1StorageVersion$Status$201 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
interface Response$createInternalApiserverV1alpha1StorageVersion$Status$202 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
interface Parameter$deleteInternalApiserverV1alpha1CollectionStorageVersion {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteInternalApiserverV1alpha1CollectionStorageVersion = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteInternalApiserverV1alpha1CollectionStorageVersion$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readInternalApiserverV1alpha1StorageVersion {
    /** name of the StorageVersion */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readInternalApiserverV1alpha1StorageVersion$Status$200 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
interface Parameter$replaceInternalApiserverV1alpha1StorageVersion {
    /** name of the StorageVersion */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceInternalApiserverV1alpha1StorageVersion = RequestBodies.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion.Content;
interface Response$replaceInternalApiserverV1alpha1StorageVersion$Status$200 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
interface Response$replaceInternalApiserverV1alpha1StorageVersion$Status$201 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
interface Parameter$deleteInternalApiserverV1alpha1StorageVersion {
    /** name of the StorageVersion */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteInternalApiserverV1alpha1StorageVersion = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteInternalApiserverV1alpha1StorageVersion$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteInternalApiserverV1alpha1StorageVersion$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchInternalApiserverV1alpha1StorageVersion {
    /** name of the StorageVersion */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchInternalApiserverV1alpha1StorageVersion = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchInternalApiserverV1alpha1StorageVersion$Status$200 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
interface Response$patchInternalApiserverV1alpha1StorageVersion$Status$201 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
interface Parameter$readInternalApiserverV1alpha1StorageVersionStatus {
    /** name of the StorageVersion */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readInternalApiserverV1alpha1StorageVersionStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
interface Parameter$replaceInternalApiserverV1alpha1StorageVersionStatus {
    /** name of the StorageVersion */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceInternalApiserverV1alpha1StorageVersionStatus = RequestBodies.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion.Content;
interface Response$replaceInternalApiserverV1alpha1StorageVersionStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
interface Response$replaceInternalApiserverV1alpha1StorageVersionStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
interface Parameter$patchInternalApiserverV1alpha1StorageVersionStatus {
    /** name of the StorageVersion */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchInternalApiserverV1alpha1StorageVersionStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchInternalApiserverV1alpha1StorageVersionStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
interface Response$patchInternalApiserverV1alpha1StorageVersionStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/yaml": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$apiserverinternal$v1alpha1$StorageVersion;
}
interface Parameter$watchInternalApiserverV1alpha1StorageVersionList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchInternalApiserverV1alpha1StorageVersionList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchInternalApiserverV1alpha1StorageVersion {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the StorageVersion */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchInternalApiserverV1alpha1StorageVersion$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getNetworkingAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
interface Response$getNetworkingV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listNetworkingV1IngressClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listNetworkingV1IngressClass$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$IngressClassList;
    "application/yaml": Schemas.io$k8s$api$networking$v1$IngressClassList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$IngressClassList;
    "application/json;stream=watch": Schemas.io$k8s$api$networking$v1$IngressClassList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$networking$v1$IngressClassList;
}
interface Parameter$createNetworkingV1IngressClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createNetworkingV1IngressClass = RequestBodies.io$k8s$api$networking$v1$IngressClass.Content;
interface Response$createNetworkingV1IngressClass$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/yaml": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$IngressClass;
}
interface Response$createNetworkingV1IngressClass$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/yaml": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$IngressClass;
}
interface Response$createNetworkingV1IngressClass$Status$202 {
    "application/json": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/yaml": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$IngressClass;
}
interface Parameter$deleteNetworkingV1CollectionIngressClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteNetworkingV1CollectionIngressClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteNetworkingV1CollectionIngressClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readNetworkingV1IngressClass {
    /** name of the IngressClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readNetworkingV1IngressClass$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/yaml": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$IngressClass;
}
interface Parameter$replaceNetworkingV1IngressClass {
    /** name of the IngressClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceNetworkingV1IngressClass = RequestBodies.io$k8s$api$networking$v1$IngressClass.Content;
interface Response$replaceNetworkingV1IngressClass$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/yaml": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$IngressClass;
}
interface Response$replaceNetworkingV1IngressClass$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/yaml": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$IngressClass;
}
interface Parameter$deleteNetworkingV1IngressClass {
    /** name of the IngressClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteNetworkingV1IngressClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteNetworkingV1IngressClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteNetworkingV1IngressClass$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchNetworkingV1IngressClass {
    /** name of the IngressClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchNetworkingV1IngressClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchNetworkingV1IngressClass$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/yaml": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$IngressClass;
}
interface Response$patchNetworkingV1IngressClass$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/yaml": Schemas.io$k8s$api$networking$v1$IngressClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$IngressClass;
}
interface Parameter$listNetworkingV1IngressForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listNetworkingV1IngressForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$IngressList;
    "application/yaml": Schemas.io$k8s$api$networking$v1$IngressList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$IngressList;
    "application/json;stream=watch": Schemas.io$k8s$api$networking$v1$IngressList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$networking$v1$IngressList;
}
interface Parameter$listNetworkingV1NamespacedIngress {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listNetworkingV1NamespacedIngress$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$IngressList;
    "application/yaml": Schemas.io$k8s$api$networking$v1$IngressList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$IngressList;
    "application/json;stream=watch": Schemas.io$k8s$api$networking$v1$IngressList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$networking$v1$IngressList;
}
interface Parameter$createNetworkingV1NamespacedIngress {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createNetworkingV1NamespacedIngress = RequestBodies.io$k8s$api$networking$v1$Ingress.Content;
interface Response$createNetworkingV1NamespacedIngress$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
interface Response$createNetworkingV1NamespacedIngress$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
interface Response$createNetworkingV1NamespacedIngress$Status$202 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
interface Parameter$deleteNetworkingV1CollectionNamespacedIngress {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteNetworkingV1CollectionNamespacedIngress = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteNetworkingV1CollectionNamespacedIngress$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readNetworkingV1NamespacedIngress {
    /** name of the Ingress */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readNetworkingV1NamespacedIngress$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
interface Parameter$replaceNetworkingV1NamespacedIngress {
    /** name of the Ingress */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceNetworkingV1NamespacedIngress = RequestBodies.io$k8s$api$networking$v1$Ingress.Content;
interface Response$replaceNetworkingV1NamespacedIngress$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
interface Response$replaceNetworkingV1NamespacedIngress$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
interface Parameter$deleteNetworkingV1NamespacedIngress {
    /** name of the Ingress */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteNetworkingV1NamespacedIngress = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteNetworkingV1NamespacedIngress$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteNetworkingV1NamespacedIngress$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchNetworkingV1NamespacedIngress {
    /** name of the Ingress */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchNetworkingV1NamespacedIngress = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchNetworkingV1NamespacedIngress$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
interface Response$patchNetworkingV1NamespacedIngress$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
interface Parameter$readNetworkingV1NamespacedIngressStatus {
    /** name of the Ingress */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readNetworkingV1NamespacedIngressStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
interface Parameter$replaceNetworkingV1NamespacedIngressStatus {
    /** name of the Ingress */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceNetworkingV1NamespacedIngressStatus = RequestBodies.io$k8s$api$networking$v1$Ingress.Content;
interface Response$replaceNetworkingV1NamespacedIngressStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
interface Response$replaceNetworkingV1NamespacedIngressStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
interface Parameter$patchNetworkingV1NamespacedIngressStatus {
    /** name of the Ingress */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchNetworkingV1NamespacedIngressStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchNetworkingV1NamespacedIngressStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
interface Response$patchNetworkingV1NamespacedIngressStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/yaml": Schemas.io$k8s$api$networking$v1$Ingress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$Ingress;
}
interface Parameter$listNetworkingV1NamespacedNetworkPolicy {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listNetworkingV1NamespacedNetworkPolicy$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicyList;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicyList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicyList;
    "application/json;stream=watch": Schemas.io$k8s$api$networking$v1$NetworkPolicyList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$networking$v1$NetworkPolicyList;
}
interface Parameter$createNetworkingV1NamespacedNetworkPolicy {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createNetworkingV1NamespacedNetworkPolicy = RequestBodies.io$k8s$api$networking$v1$NetworkPolicy.Content;
interface Response$createNetworkingV1NamespacedNetworkPolicy$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
}
interface Response$createNetworkingV1NamespacedNetworkPolicy$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
}
interface Response$createNetworkingV1NamespacedNetworkPolicy$Status$202 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
}
interface Parameter$deleteNetworkingV1CollectionNamespacedNetworkPolicy {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteNetworkingV1CollectionNamespacedNetworkPolicy = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteNetworkingV1CollectionNamespacedNetworkPolicy$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readNetworkingV1NamespacedNetworkPolicy {
    /** name of the NetworkPolicy */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readNetworkingV1NamespacedNetworkPolicy$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
}
interface Parameter$replaceNetworkingV1NamespacedNetworkPolicy {
    /** name of the NetworkPolicy */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceNetworkingV1NamespacedNetworkPolicy = RequestBodies.io$k8s$api$networking$v1$NetworkPolicy.Content;
interface Response$replaceNetworkingV1NamespacedNetworkPolicy$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
}
interface Response$replaceNetworkingV1NamespacedNetworkPolicy$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
}
interface Parameter$deleteNetworkingV1NamespacedNetworkPolicy {
    /** name of the NetworkPolicy */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteNetworkingV1NamespacedNetworkPolicy = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteNetworkingV1NamespacedNetworkPolicy$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteNetworkingV1NamespacedNetworkPolicy$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchNetworkingV1NamespacedNetworkPolicy {
    /** name of the NetworkPolicy */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchNetworkingV1NamespacedNetworkPolicy = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchNetworkingV1NamespacedNetworkPolicy$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
}
interface Response$patchNetworkingV1NamespacedNetworkPolicy$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
}
interface Parameter$readNetworkingV1NamespacedNetworkPolicyStatus {
    /** name of the NetworkPolicy */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readNetworkingV1NamespacedNetworkPolicyStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
}
interface Parameter$replaceNetworkingV1NamespacedNetworkPolicyStatus {
    /** name of the NetworkPolicy */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceNetworkingV1NamespacedNetworkPolicyStatus = RequestBodies.io$k8s$api$networking$v1$NetworkPolicy.Content;
interface Response$replaceNetworkingV1NamespacedNetworkPolicyStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
}
interface Response$replaceNetworkingV1NamespacedNetworkPolicyStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
}
interface Parameter$patchNetworkingV1NamespacedNetworkPolicyStatus {
    /** name of the NetworkPolicy */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchNetworkingV1NamespacedNetworkPolicyStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchNetworkingV1NamespacedNetworkPolicyStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
}
interface Response$patchNetworkingV1NamespacedNetworkPolicyStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicy;
}
interface Parameter$listNetworkingV1NetworkPolicyForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listNetworkingV1NetworkPolicyForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1$NetworkPolicyList;
    "application/yaml": Schemas.io$k8s$api$networking$v1$NetworkPolicyList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1$NetworkPolicyList;
    "application/json;stream=watch": Schemas.io$k8s$api$networking$v1$NetworkPolicyList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$networking$v1$NetworkPolicyList;
}
interface Parameter$watchNetworkingV1IngressClassList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchNetworkingV1IngressClassList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchNetworkingV1IngressClass {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the IngressClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchNetworkingV1IngressClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchNetworkingV1IngressListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchNetworkingV1IngressListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchNetworkingV1NamespacedIngressList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchNetworkingV1NamespacedIngressList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchNetworkingV1NamespacedIngress {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Ingress */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchNetworkingV1NamespacedIngress$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchNetworkingV1NamespacedNetworkPolicyList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchNetworkingV1NamespacedNetworkPolicyList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchNetworkingV1NamespacedNetworkPolicy {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the NetworkPolicy */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchNetworkingV1NamespacedNetworkPolicy$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchNetworkingV1NetworkPolicyListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchNetworkingV1NetworkPolicyListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getNetworkingV1alpha1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listNetworkingV1alpha1ClusterCIDR {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listNetworkingV1alpha1ClusterCIDR$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDRList;
    "application/yaml": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDRList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDRList;
    "application/json;stream=watch": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDRList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDRList;
}
interface Parameter$createNetworkingV1alpha1ClusterCIDR {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createNetworkingV1alpha1ClusterCIDR = RequestBodies.io$k8s$api$networking$v1alpha1$ClusterCIDR.Content;
interface Response$createNetworkingV1alpha1ClusterCIDR$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
    "application/yaml": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
}
interface Response$createNetworkingV1alpha1ClusterCIDR$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
    "application/yaml": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
}
interface Response$createNetworkingV1alpha1ClusterCIDR$Status$202 {
    "application/json": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
    "application/yaml": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
}
interface Parameter$deleteNetworkingV1alpha1CollectionClusterCIDR {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteNetworkingV1alpha1CollectionClusterCIDR = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteNetworkingV1alpha1CollectionClusterCIDR$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readNetworkingV1alpha1ClusterCIDR {
    /** name of the ClusterCIDR */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readNetworkingV1alpha1ClusterCIDR$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
    "application/yaml": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
}
interface Parameter$replaceNetworkingV1alpha1ClusterCIDR {
    /** name of the ClusterCIDR */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceNetworkingV1alpha1ClusterCIDR = RequestBodies.io$k8s$api$networking$v1alpha1$ClusterCIDR.Content;
interface Response$replaceNetworkingV1alpha1ClusterCIDR$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
    "application/yaml": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
}
interface Response$replaceNetworkingV1alpha1ClusterCIDR$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
    "application/yaml": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
}
interface Parameter$deleteNetworkingV1alpha1ClusterCIDR {
    /** name of the ClusterCIDR */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteNetworkingV1alpha1ClusterCIDR = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteNetworkingV1alpha1ClusterCIDR$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteNetworkingV1alpha1ClusterCIDR$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchNetworkingV1alpha1ClusterCIDR {
    /** name of the ClusterCIDR */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchNetworkingV1alpha1ClusterCIDR = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchNetworkingV1alpha1ClusterCIDR$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
    "application/yaml": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
}
interface Response$patchNetworkingV1alpha1ClusterCIDR$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
    "application/yaml": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1alpha1$ClusterCIDR;
}
interface Parameter$listNetworkingV1alpha1IPAddress {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listNetworkingV1alpha1IPAddress$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1alpha1$IPAddressList;
    "application/yaml": Schemas.io$k8s$api$networking$v1alpha1$IPAddressList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1alpha1$IPAddressList;
    "application/json;stream=watch": Schemas.io$k8s$api$networking$v1alpha1$IPAddressList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$networking$v1alpha1$IPAddressList;
}
interface Parameter$createNetworkingV1alpha1IPAddress {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createNetworkingV1alpha1IPAddress = RequestBodies.io$k8s$api$networking$v1alpha1$IPAddress.Content;
interface Response$createNetworkingV1alpha1IPAddress$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
    "application/yaml": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
}
interface Response$createNetworkingV1alpha1IPAddress$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
    "application/yaml": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
}
interface Response$createNetworkingV1alpha1IPAddress$Status$202 {
    "application/json": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
    "application/yaml": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
}
interface Parameter$deleteNetworkingV1alpha1CollectionIPAddress {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteNetworkingV1alpha1CollectionIPAddress = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteNetworkingV1alpha1CollectionIPAddress$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readNetworkingV1alpha1IPAddress {
    /** name of the IPAddress */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readNetworkingV1alpha1IPAddress$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
    "application/yaml": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
}
interface Parameter$replaceNetworkingV1alpha1IPAddress {
    /** name of the IPAddress */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceNetworkingV1alpha1IPAddress = RequestBodies.io$k8s$api$networking$v1alpha1$IPAddress.Content;
interface Response$replaceNetworkingV1alpha1IPAddress$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
    "application/yaml": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
}
interface Response$replaceNetworkingV1alpha1IPAddress$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
    "application/yaml": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
}
interface Parameter$deleteNetworkingV1alpha1IPAddress {
    /** name of the IPAddress */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteNetworkingV1alpha1IPAddress = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteNetworkingV1alpha1IPAddress$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteNetworkingV1alpha1IPAddress$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchNetworkingV1alpha1IPAddress {
    /** name of the IPAddress */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchNetworkingV1alpha1IPAddress = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchNetworkingV1alpha1IPAddress$Status$200 {
    "application/json": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
    "application/yaml": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
}
interface Response$patchNetworkingV1alpha1IPAddress$Status$201 {
    "application/json": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
    "application/yaml": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$networking$v1alpha1$IPAddress;
}
interface Parameter$watchNetworkingV1alpha1ClusterCIDRList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchNetworkingV1alpha1ClusterCIDRList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchNetworkingV1alpha1ClusterCIDR {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ClusterCIDR */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchNetworkingV1alpha1ClusterCIDR$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchNetworkingV1alpha1IPAddressList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchNetworkingV1alpha1IPAddressList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchNetworkingV1alpha1IPAddress {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the IPAddress */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchNetworkingV1alpha1IPAddress$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getNodeAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
interface Response$getNodeV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listNodeV1RuntimeClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listNodeV1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$api$node$v1$RuntimeClassList;
    "application/yaml": Schemas.io$k8s$api$node$v1$RuntimeClassList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1$RuntimeClassList;
    "application/json;stream=watch": Schemas.io$k8s$api$node$v1$RuntimeClassList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$node$v1$RuntimeClassList;
}
interface Parameter$createNodeV1RuntimeClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createNodeV1RuntimeClass = RequestBodies.io$k8s$api$node$v1$RuntimeClass.Content;
interface Response$createNodeV1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1$RuntimeClass;
}
interface Response$createNodeV1RuntimeClass$Status$201 {
    "application/json": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1$RuntimeClass;
}
interface Response$createNodeV1RuntimeClass$Status$202 {
    "application/json": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1$RuntimeClass;
}
interface Parameter$deleteNodeV1CollectionRuntimeClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteNodeV1CollectionRuntimeClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteNodeV1CollectionRuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readNodeV1RuntimeClass {
    /** name of the RuntimeClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readNodeV1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1$RuntimeClass;
}
interface Parameter$replaceNodeV1RuntimeClass {
    /** name of the RuntimeClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceNodeV1RuntimeClass = RequestBodies.io$k8s$api$node$v1$RuntimeClass.Content;
interface Response$replaceNodeV1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1$RuntimeClass;
}
interface Response$replaceNodeV1RuntimeClass$Status$201 {
    "application/json": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1$RuntimeClass;
}
interface Parameter$deleteNodeV1RuntimeClass {
    /** name of the RuntimeClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteNodeV1RuntimeClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteNodeV1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteNodeV1RuntimeClass$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchNodeV1RuntimeClass {
    /** name of the RuntimeClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchNodeV1RuntimeClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchNodeV1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1$RuntimeClass;
}
interface Response$patchNodeV1RuntimeClass$Status$201 {
    "application/json": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/yaml": Schemas.io$k8s$api$node$v1$RuntimeClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$node$v1$RuntimeClass;
}
interface Parameter$watchNodeV1RuntimeClassList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchNodeV1RuntimeClassList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchNodeV1RuntimeClass {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the RuntimeClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchNodeV1RuntimeClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getPolicyAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
interface Response$getPolicyV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listPolicyV1NamespacedPodDisruptionBudget {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listPolicyV1NamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetList;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetList;
    "application/json;stream=watch": Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetList;
}
interface Parameter$createPolicyV1NamespacedPodDisruptionBudget {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createPolicyV1NamespacedPodDisruptionBudget = RequestBodies.io$k8s$api$policy$v1$PodDisruptionBudget.Content;
interface Response$createPolicyV1NamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
interface Response$createPolicyV1NamespacedPodDisruptionBudget$Status$201 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
interface Response$createPolicyV1NamespacedPodDisruptionBudget$Status$202 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
interface Parameter$deletePolicyV1CollectionNamespacedPodDisruptionBudget {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deletePolicyV1CollectionNamespacedPodDisruptionBudget = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deletePolicyV1CollectionNamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readPolicyV1NamespacedPodDisruptionBudget {
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readPolicyV1NamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
interface Parameter$replacePolicyV1NamespacedPodDisruptionBudget {
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replacePolicyV1NamespacedPodDisruptionBudget = RequestBodies.io$k8s$api$policy$v1$PodDisruptionBudget.Content;
interface Response$replacePolicyV1NamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
interface Response$replacePolicyV1NamespacedPodDisruptionBudget$Status$201 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
interface Parameter$deletePolicyV1NamespacedPodDisruptionBudget {
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deletePolicyV1NamespacedPodDisruptionBudget = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deletePolicyV1NamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deletePolicyV1NamespacedPodDisruptionBudget$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchPolicyV1NamespacedPodDisruptionBudget {
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchPolicyV1NamespacedPodDisruptionBudget = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchPolicyV1NamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
interface Response$patchPolicyV1NamespacedPodDisruptionBudget$Status$201 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
interface Parameter$readPolicyV1NamespacedPodDisruptionBudgetStatus {
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readPolicyV1NamespacedPodDisruptionBudgetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
interface Parameter$replacePolicyV1NamespacedPodDisruptionBudgetStatus {
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replacePolicyV1NamespacedPodDisruptionBudgetStatus = RequestBodies.io$k8s$api$policy$v1$PodDisruptionBudget.Content;
interface Response$replacePolicyV1NamespacedPodDisruptionBudgetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
interface Response$replacePolicyV1NamespacedPodDisruptionBudgetStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
interface Parameter$patchPolicyV1NamespacedPodDisruptionBudgetStatus {
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchPolicyV1NamespacedPodDisruptionBudgetStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchPolicyV1NamespacedPodDisruptionBudgetStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
interface Response$patchPolicyV1NamespacedPodDisruptionBudgetStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudget;
}
interface Parameter$listPolicyV1PodDisruptionBudgetForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listPolicyV1PodDisruptionBudgetForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetList;
    "application/yaml": Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetList;
    "application/json;stream=watch": Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$policy$v1$PodDisruptionBudgetList;
}
interface Parameter$watchPolicyV1NamespacedPodDisruptionBudgetList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchPolicyV1NamespacedPodDisruptionBudgetList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchPolicyV1NamespacedPodDisruptionBudget {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the PodDisruptionBudget */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchPolicyV1NamespacedPodDisruptionBudget$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchPolicyV1PodDisruptionBudgetListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchPolicyV1PodDisruptionBudgetListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getRbacAuthorizationAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
interface Response$getRbacAuthorizationV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listRbacAuthorizationV1ClusterRoleBinding {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listRbacAuthorizationV1ClusterRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRoleBindingList;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRoleBindingList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRoleBindingList;
    "application/json;stream=watch": Schemas.io$k8s$api$rbac$v1$ClusterRoleBindingList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$rbac$v1$ClusterRoleBindingList;
}
interface Parameter$createRbacAuthorizationV1ClusterRoleBinding {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createRbacAuthorizationV1ClusterRoleBinding = RequestBodies.io$k8s$api$rbac$v1$ClusterRoleBinding.Content;
interface Response$createRbacAuthorizationV1ClusterRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
}
interface Response$createRbacAuthorizationV1ClusterRoleBinding$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
}
interface Response$createRbacAuthorizationV1ClusterRoleBinding$Status$202 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
}
interface Parameter$deleteRbacAuthorizationV1CollectionClusterRoleBinding {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteRbacAuthorizationV1CollectionClusterRoleBinding = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteRbacAuthorizationV1CollectionClusterRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readRbacAuthorizationV1ClusterRoleBinding {
    /** name of the ClusterRoleBinding */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readRbacAuthorizationV1ClusterRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
}
interface Parameter$replaceRbacAuthorizationV1ClusterRoleBinding {
    /** name of the ClusterRoleBinding */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceRbacAuthorizationV1ClusterRoleBinding = RequestBodies.io$k8s$api$rbac$v1$ClusterRoleBinding.Content;
interface Response$replaceRbacAuthorizationV1ClusterRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
}
interface Response$replaceRbacAuthorizationV1ClusterRoleBinding$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
}
interface Parameter$deleteRbacAuthorizationV1ClusterRoleBinding {
    /** name of the ClusterRoleBinding */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteRbacAuthorizationV1ClusterRoleBinding = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteRbacAuthorizationV1ClusterRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteRbacAuthorizationV1ClusterRoleBinding$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchRbacAuthorizationV1ClusterRoleBinding {
    /** name of the ClusterRoleBinding */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchRbacAuthorizationV1ClusterRoleBinding = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchRbacAuthorizationV1ClusterRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
}
interface Response$patchRbacAuthorizationV1ClusterRoleBinding$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRoleBinding;
}
interface Parameter$listRbacAuthorizationV1ClusterRole {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listRbacAuthorizationV1ClusterRole$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRoleList;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRoleList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRoleList;
    "application/json;stream=watch": Schemas.io$k8s$api$rbac$v1$ClusterRoleList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$rbac$v1$ClusterRoleList;
}
interface Parameter$createRbacAuthorizationV1ClusterRole {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createRbacAuthorizationV1ClusterRole = RequestBodies.io$k8s$api$rbac$v1$ClusterRole.Content;
interface Response$createRbacAuthorizationV1ClusterRole$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRole;
}
interface Response$createRbacAuthorizationV1ClusterRole$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRole;
}
interface Response$createRbacAuthorizationV1ClusterRole$Status$202 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRole;
}
interface Parameter$deleteRbacAuthorizationV1CollectionClusterRole {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteRbacAuthorizationV1CollectionClusterRole = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteRbacAuthorizationV1CollectionClusterRole$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readRbacAuthorizationV1ClusterRole {
    /** name of the ClusterRole */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readRbacAuthorizationV1ClusterRole$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRole;
}
interface Parameter$replaceRbacAuthorizationV1ClusterRole {
    /** name of the ClusterRole */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceRbacAuthorizationV1ClusterRole = RequestBodies.io$k8s$api$rbac$v1$ClusterRole.Content;
interface Response$replaceRbacAuthorizationV1ClusterRole$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRole;
}
interface Response$replaceRbacAuthorizationV1ClusterRole$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRole;
}
interface Parameter$deleteRbacAuthorizationV1ClusterRole {
    /** name of the ClusterRole */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteRbacAuthorizationV1ClusterRole = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteRbacAuthorizationV1ClusterRole$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteRbacAuthorizationV1ClusterRole$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchRbacAuthorizationV1ClusterRole {
    /** name of the ClusterRole */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchRbacAuthorizationV1ClusterRole = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchRbacAuthorizationV1ClusterRole$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRole;
}
interface Response$patchRbacAuthorizationV1ClusterRole$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$ClusterRole;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$ClusterRole;
}
interface Parameter$listRbacAuthorizationV1NamespacedRoleBinding {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listRbacAuthorizationV1NamespacedRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleBindingList;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleBindingList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleBindingList;
    "application/json;stream=watch": Schemas.io$k8s$api$rbac$v1$RoleBindingList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$rbac$v1$RoleBindingList;
}
interface Parameter$createRbacAuthorizationV1NamespacedRoleBinding {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createRbacAuthorizationV1NamespacedRoleBinding = RequestBodies.io$k8s$api$rbac$v1$RoleBinding.Content;
interface Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleBinding;
}
interface Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleBinding;
}
interface Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$202 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleBinding;
}
interface Parameter$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readRbacAuthorizationV1NamespacedRoleBinding {
    /** name of the RoleBinding */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readRbacAuthorizationV1NamespacedRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleBinding;
}
interface Parameter$replaceRbacAuthorizationV1NamespacedRoleBinding {
    /** name of the RoleBinding */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceRbacAuthorizationV1NamespacedRoleBinding = RequestBodies.io$k8s$api$rbac$v1$RoleBinding.Content;
interface Response$replaceRbacAuthorizationV1NamespacedRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleBinding;
}
interface Response$replaceRbacAuthorizationV1NamespacedRoleBinding$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleBinding;
}
interface Parameter$deleteRbacAuthorizationV1NamespacedRoleBinding {
    /** name of the RoleBinding */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteRbacAuthorizationV1NamespacedRoleBinding = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteRbacAuthorizationV1NamespacedRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteRbacAuthorizationV1NamespacedRoleBinding$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchRbacAuthorizationV1NamespacedRoleBinding {
    /** name of the RoleBinding */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchRbacAuthorizationV1NamespacedRoleBinding = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchRbacAuthorizationV1NamespacedRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleBinding;
}
interface Response$patchRbacAuthorizationV1NamespacedRoleBinding$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleBinding;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleBinding;
}
interface Parameter$listRbacAuthorizationV1NamespacedRole {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listRbacAuthorizationV1NamespacedRole$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleList;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleList;
    "application/json;stream=watch": Schemas.io$k8s$api$rbac$v1$RoleList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$rbac$v1$RoleList;
}
interface Parameter$createRbacAuthorizationV1NamespacedRole {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createRbacAuthorizationV1NamespacedRole = RequestBodies.io$k8s$api$rbac$v1$Role.Content;
interface Response$createRbacAuthorizationV1NamespacedRole$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$Role;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$Role;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$Role;
}
interface Response$createRbacAuthorizationV1NamespacedRole$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$Role;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$Role;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$Role;
}
interface Response$createRbacAuthorizationV1NamespacedRole$Status$202 {
    "application/json": Schemas.io$k8s$api$rbac$v1$Role;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$Role;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$Role;
}
interface Parameter$deleteRbacAuthorizationV1CollectionNamespacedRole {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteRbacAuthorizationV1CollectionNamespacedRole = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteRbacAuthorizationV1CollectionNamespacedRole$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readRbacAuthorizationV1NamespacedRole {
    /** name of the Role */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readRbacAuthorizationV1NamespacedRole$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$Role;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$Role;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$Role;
}
interface Parameter$replaceRbacAuthorizationV1NamespacedRole {
    /** name of the Role */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceRbacAuthorizationV1NamespacedRole = RequestBodies.io$k8s$api$rbac$v1$Role.Content;
interface Response$replaceRbacAuthorizationV1NamespacedRole$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$Role;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$Role;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$Role;
}
interface Response$replaceRbacAuthorizationV1NamespacedRole$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$Role;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$Role;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$Role;
}
interface Parameter$deleteRbacAuthorizationV1NamespacedRole {
    /** name of the Role */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteRbacAuthorizationV1NamespacedRole = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteRbacAuthorizationV1NamespacedRole$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteRbacAuthorizationV1NamespacedRole$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchRbacAuthorizationV1NamespacedRole {
    /** name of the Role */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchRbacAuthorizationV1NamespacedRole = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchRbacAuthorizationV1NamespacedRole$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$Role;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$Role;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$Role;
}
interface Response$patchRbacAuthorizationV1NamespacedRole$Status$201 {
    "application/json": Schemas.io$k8s$api$rbac$v1$Role;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$Role;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$Role;
}
interface Parameter$listRbacAuthorizationV1RoleBindingForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listRbacAuthorizationV1RoleBindingForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleBindingList;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleBindingList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleBindingList;
    "application/json;stream=watch": Schemas.io$k8s$api$rbac$v1$RoleBindingList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$rbac$v1$RoleBindingList;
}
interface Parameter$listRbacAuthorizationV1RoleForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listRbacAuthorizationV1RoleForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$rbac$v1$RoleList;
    "application/yaml": Schemas.io$k8s$api$rbac$v1$RoleList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$rbac$v1$RoleList;
    "application/json;stream=watch": Schemas.io$k8s$api$rbac$v1$RoleList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$rbac$v1$RoleList;
}
interface Parameter$watchRbacAuthorizationV1ClusterRoleBindingList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchRbacAuthorizationV1ClusterRoleBindingList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchRbacAuthorizationV1ClusterRoleBinding {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ClusterRoleBinding */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchRbacAuthorizationV1ClusterRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchRbacAuthorizationV1ClusterRoleList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchRbacAuthorizationV1ClusterRoleList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchRbacAuthorizationV1ClusterRole {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ClusterRole */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchRbacAuthorizationV1ClusterRole$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchRbacAuthorizationV1NamespacedRoleBindingList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchRbacAuthorizationV1NamespacedRoleBindingList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchRbacAuthorizationV1NamespacedRoleBinding {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the RoleBinding */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchRbacAuthorizationV1NamespacedRoleBinding$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchRbacAuthorizationV1NamespacedRoleList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchRbacAuthorizationV1NamespacedRoleList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchRbacAuthorizationV1NamespacedRole {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the Role */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchRbacAuthorizationV1NamespacedRole$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchRbacAuthorizationV1RoleBindingListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchRbacAuthorizationV1RoleBindingListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchRbacAuthorizationV1RoleListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchRbacAuthorizationV1RoleListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getResourceAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
interface Response$getResourceV1alpha2APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listResourceV1alpha2NamespacedPodSchedulingContext {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listResourceV1alpha2NamespacedPodSchedulingContext$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContextList;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContextList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContextList;
    "application/json;stream=watch": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContextList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContextList;
}
interface Parameter$createResourceV1alpha2NamespacedPodSchedulingContext {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createResourceV1alpha2NamespacedPodSchedulingContext = RequestBodies.io$k8s$api$resource$v1alpha2$PodSchedulingContext.Content;
interface Response$createResourceV1alpha2NamespacedPodSchedulingContext$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
}
interface Response$createResourceV1alpha2NamespacedPodSchedulingContext$Status$201 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
}
interface Response$createResourceV1alpha2NamespacedPodSchedulingContext$Status$202 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
}
interface Parameter$deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readResourceV1alpha2NamespacedPodSchedulingContext {
    /** name of the PodSchedulingContext */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readResourceV1alpha2NamespacedPodSchedulingContext$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
}
interface Parameter$replaceResourceV1alpha2NamespacedPodSchedulingContext {
    /** name of the PodSchedulingContext */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceResourceV1alpha2NamespacedPodSchedulingContext = RequestBodies.io$k8s$api$resource$v1alpha2$PodSchedulingContext.Content;
interface Response$replaceResourceV1alpha2NamespacedPodSchedulingContext$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
}
interface Response$replaceResourceV1alpha2NamespacedPodSchedulingContext$Status$201 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
}
interface Parameter$deleteResourceV1alpha2NamespacedPodSchedulingContext {
    /** name of the PodSchedulingContext */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteResourceV1alpha2NamespacedPodSchedulingContext = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteResourceV1alpha2NamespacedPodSchedulingContext$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
}
interface Response$deleteResourceV1alpha2NamespacedPodSchedulingContext$Status$202 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
}
interface Parameter$patchResourceV1alpha2NamespacedPodSchedulingContext {
    /** name of the PodSchedulingContext */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchResourceV1alpha2NamespacedPodSchedulingContext = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchResourceV1alpha2NamespacedPodSchedulingContext$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
}
interface Response$patchResourceV1alpha2NamespacedPodSchedulingContext$Status$201 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
}
interface Parameter$readResourceV1alpha2NamespacedPodSchedulingContextStatus {
    /** name of the PodSchedulingContext */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
}
interface Parameter$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus {
    /** name of the PodSchedulingContext */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus = RequestBodies.io$k8s$api$resource$v1alpha2$PodSchedulingContext.Content;
interface Response$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
}
interface Response$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
}
interface Parameter$patchResourceV1alpha2NamespacedPodSchedulingContextStatus {
    /** name of the PodSchedulingContext */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchResourceV1alpha2NamespacedPodSchedulingContextStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
}
interface Response$patchResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContext;
}
interface Parameter$listResourceV1alpha2NamespacedResourceClaim {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listResourceV1alpha2NamespacedResourceClaim$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimList;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimList;
    "application/json;stream=watch": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimList;
}
interface Parameter$createResourceV1alpha2NamespacedResourceClaim {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createResourceV1alpha2NamespacedResourceClaim = RequestBodies.io$k8s$api$resource$v1alpha2$ResourceClaim.Content;
interface Response$createResourceV1alpha2NamespacedResourceClaim$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
}
interface Response$createResourceV1alpha2NamespacedResourceClaim$Status$201 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
}
interface Response$createResourceV1alpha2NamespacedResourceClaim$Status$202 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
}
interface Parameter$deleteResourceV1alpha2CollectionNamespacedResourceClaim {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteResourceV1alpha2CollectionNamespacedResourceClaim = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteResourceV1alpha2CollectionNamespacedResourceClaim$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readResourceV1alpha2NamespacedResourceClaim {
    /** name of the ResourceClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readResourceV1alpha2NamespacedResourceClaim$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
}
interface Parameter$replaceResourceV1alpha2NamespacedResourceClaim {
    /** name of the ResourceClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceResourceV1alpha2NamespacedResourceClaim = RequestBodies.io$k8s$api$resource$v1alpha2$ResourceClaim.Content;
interface Response$replaceResourceV1alpha2NamespacedResourceClaim$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
}
interface Response$replaceResourceV1alpha2NamespacedResourceClaim$Status$201 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
}
interface Parameter$deleteResourceV1alpha2NamespacedResourceClaim {
    /** name of the ResourceClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteResourceV1alpha2NamespacedResourceClaim = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteResourceV1alpha2NamespacedResourceClaim$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
}
interface Response$deleteResourceV1alpha2NamespacedResourceClaim$Status$202 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
}
interface Parameter$patchResourceV1alpha2NamespacedResourceClaim {
    /** name of the ResourceClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchResourceV1alpha2NamespacedResourceClaim = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchResourceV1alpha2NamespacedResourceClaim$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
}
interface Response$patchResourceV1alpha2NamespacedResourceClaim$Status$201 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
}
interface Parameter$readResourceV1alpha2NamespacedResourceClaimStatus {
    /** name of the ResourceClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readResourceV1alpha2NamespacedResourceClaimStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
}
interface Parameter$replaceResourceV1alpha2NamespacedResourceClaimStatus {
    /** name of the ResourceClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceResourceV1alpha2NamespacedResourceClaimStatus = RequestBodies.io$k8s$api$resource$v1alpha2$ResourceClaim.Content;
interface Response$replaceResourceV1alpha2NamespacedResourceClaimStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
}
interface Response$replaceResourceV1alpha2NamespacedResourceClaimStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
}
interface Parameter$patchResourceV1alpha2NamespacedResourceClaimStatus {
    /** name of the ResourceClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchResourceV1alpha2NamespacedResourceClaimStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchResourceV1alpha2NamespacedResourceClaimStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
}
interface Response$patchResourceV1alpha2NamespacedResourceClaimStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaim;
}
interface Parameter$listResourceV1alpha2NamespacedResourceClaimTemplate {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listResourceV1alpha2NamespacedResourceClaimTemplate$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplateList;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplateList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplateList;
    "application/json;stream=watch": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplateList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplateList;
}
interface Parameter$createResourceV1alpha2NamespacedResourceClaimTemplate {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createResourceV1alpha2NamespacedResourceClaimTemplate = RequestBodies.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate.Content;
interface Response$createResourceV1alpha2NamespacedResourceClaimTemplate$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
}
interface Response$createResourceV1alpha2NamespacedResourceClaimTemplate$Status$201 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
}
interface Response$createResourceV1alpha2NamespacedResourceClaimTemplate$Status$202 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
}
interface Parameter$deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readResourceV1alpha2NamespacedResourceClaimTemplate {
    /** name of the ResourceClaimTemplate */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readResourceV1alpha2NamespacedResourceClaimTemplate$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
}
interface Parameter$replaceResourceV1alpha2NamespacedResourceClaimTemplate {
    /** name of the ResourceClaimTemplate */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceResourceV1alpha2NamespacedResourceClaimTemplate = RequestBodies.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate.Content;
interface Response$replaceResourceV1alpha2NamespacedResourceClaimTemplate$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
}
interface Response$replaceResourceV1alpha2NamespacedResourceClaimTemplate$Status$201 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
}
interface Parameter$deleteResourceV1alpha2NamespacedResourceClaimTemplate {
    /** name of the ResourceClaimTemplate */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteResourceV1alpha2NamespacedResourceClaimTemplate = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteResourceV1alpha2NamespacedResourceClaimTemplate$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
}
interface Response$deleteResourceV1alpha2NamespacedResourceClaimTemplate$Status$202 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
}
interface Parameter$patchResourceV1alpha2NamespacedResourceClaimTemplate {
    /** name of the ResourceClaimTemplate */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchResourceV1alpha2NamespacedResourceClaimTemplate = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchResourceV1alpha2NamespacedResourceClaimTemplate$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
}
interface Response$patchResourceV1alpha2NamespacedResourceClaimTemplate$Status$201 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplate;
}
interface Parameter$listResourceV1alpha2PodSchedulingContextForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listResourceV1alpha2PodSchedulingContextForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContextList;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContextList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContextList;
    "application/json;stream=watch": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContextList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$resource$v1alpha2$PodSchedulingContextList;
}
interface Parameter$listResourceV1alpha2ResourceClaimForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listResourceV1alpha2ResourceClaimForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimList;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimList;
    "application/json;stream=watch": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimList;
}
interface Parameter$listResourceV1alpha2ResourceClaimTemplateForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listResourceV1alpha2ResourceClaimTemplateForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplateList;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplateList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplateList;
    "application/json;stream=watch": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplateList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$resource$v1alpha2$ResourceClaimTemplateList;
}
interface Parameter$listResourceV1alpha2ResourceClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listResourceV1alpha2ResourceClass$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClassList;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClassList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClassList;
    "application/json;stream=watch": Schemas.io$k8s$api$resource$v1alpha2$ResourceClassList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$resource$v1alpha2$ResourceClassList;
}
interface Parameter$createResourceV1alpha2ResourceClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createResourceV1alpha2ResourceClass = RequestBodies.io$k8s$api$resource$v1alpha2$ResourceClass.Content;
interface Response$createResourceV1alpha2ResourceClass$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
}
interface Response$createResourceV1alpha2ResourceClass$Status$201 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
}
interface Response$createResourceV1alpha2ResourceClass$Status$202 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
}
interface Parameter$deleteResourceV1alpha2CollectionResourceClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteResourceV1alpha2CollectionResourceClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteResourceV1alpha2CollectionResourceClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readResourceV1alpha2ResourceClass {
    /** name of the ResourceClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readResourceV1alpha2ResourceClass$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
}
interface Parameter$replaceResourceV1alpha2ResourceClass {
    /** name of the ResourceClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceResourceV1alpha2ResourceClass = RequestBodies.io$k8s$api$resource$v1alpha2$ResourceClass.Content;
interface Response$replaceResourceV1alpha2ResourceClass$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
}
interface Response$replaceResourceV1alpha2ResourceClass$Status$201 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
}
interface Parameter$deleteResourceV1alpha2ResourceClass {
    /** name of the ResourceClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteResourceV1alpha2ResourceClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteResourceV1alpha2ResourceClass$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
}
interface Response$deleteResourceV1alpha2ResourceClass$Status$202 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
}
interface Parameter$patchResourceV1alpha2ResourceClass {
    /** name of the ResourceClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchResourceV1alpha2ResourceClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchResourceV1alpha2ResourceClass$Status$200 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
}
interface Response$patchResourceV1alpha2ResourceClass$Status$201 {
    "application/json": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
    "application/yaml": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$resource$v1alpha2$ResourceClass;
}
interface Parameter$watchResourceV1alpha2NamespacedPodSchedulingContextList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchResourceV1alpha2NamespacedPodSchedulingContextList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchResourceV1alpha2NamespacedPodSchedulingContext {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the PodSchedulingContext */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchResourceV1alpha2NamespacedPodSchedulingContext$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchResourceV1alpha2NamespacedResourceClaimList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchResourceV1alpha2NamespacedResourceClaimList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchResourceV1alpha2NamespacedResourceClaim {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ResourceClaim */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchResourceV1alpha2NamespacedResourceClaim$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchResourceV1alpha2NamespacedResourceClaimTemplateList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchResourceV1alpha2NamespacedResourceClaimTemplateList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchResourceV1alpha2NamespacedResourceClaimTemplate {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ResourceClaimTemplate */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchResourceV1alpha2NamespacedResourceClaimTemplate$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchResourceV1alpha2PodSchedulingContextListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchResourceV1alpha2PodSchedulingContextListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchResourceV1alpha2ResourceClaimListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchResourceV1alpha2ResourceClaimListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchResourceV1alpha2ResourceClaimTemplateListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchResourceV1alpha2ResourceClaimTemplateListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchResourceV1alpha2ResourceClassList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchResourceV1alpha2ResourceClassList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchResourceV1alpha2ResourceClass {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the ResourceClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchResourceV1alpha2ResourceClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getSchedulingAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
interface Response$getSchedulingV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listSchedulingV1PriorityClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listSchedulingV1PriorityClass$Status$200 {
    "application/json": Schemas.io$k8s$api$scheduling$v1$PriorityClassList;
    "application/yaml": Schemas.io$k8s$api$scheduling$v1$PriorityClassList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$scheduling$v1$PriorityClassList;
    "application/json;stream=watch": Schemas.io$k8s$api$scheduling$v1$PriorityClassList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$scheduling$v1$PriorityClassList;
}
interface Parameter$createSchedulingV1PriorityClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createSchedulingV1PriorityClass = RequestBodies.io$k8s$api$scheduling$v1$PriorityClass.Content;
interface Response$createSchedulingV1PriorityClass$Status$200 {
    "application/json": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/yaml": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
}
interface Response$createSchedulingV1PriorityClass$Status$201 {
    "application/json": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/yaml": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
}
interface Response$createSchedulingV1PriorityClass$Status$202 {
    "application/json": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/yaml": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
}
interface Parameter$deleteSchedulingV1CollectionPriorityClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteSchedulingV1CollectionPriorityClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteSchedulingV1CollectionPriorityClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readSchedulingV1PriorityClass {
    /** name of the PriorityClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readSchedulingV1PriorityClass$Status$200 {
    "application/json": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/yaml": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
}
interface Parameter$replaceSchedulingV1PriorityClass {
    /** name of the PriorityClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceSchedulingV1PriorityClass = RequestBodies.io$k8s$api$scheduling$v1$PriorityClass.Content;
interface Response$replaceSchedulingV1PriorityClass$Status$200 {
    "application/json": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/yaml": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
}
interface Response$replaceSchedulingV1PriorityClass$Status$201 {
    "application/json": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/yaml": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
}
interface Parameter$deleteSchedulingV1PriorityClass {
    /** name of the PriorityClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteSchedulingV1PriorityClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteSchedulingV1PriorityClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteSchedulingV1PriorityClass$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchSchedulingV1PriorityClass {
    /** name of the PriorityClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchSchedulingV1PriorityClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchSchedulingV1PriorityClass$Status$200 {
    "application/json": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/yaml": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
}
interface Response$patchSchedulingV1PriorityClass$Status$201 {
    "application/json": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/yaml": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$scheduling$v1$PriorityClass;
}
interface Parameter$watchSchedulingV1PriorityClassList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchSchedulingV1PriorityClassList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchSchedulingV1PriorityClass {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the PriorityClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchSchedulingV1PriorityClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Response$getStorageAPIGroup$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIGroup;
}
interface Response$getStorageV1APIResources$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$APIResourceList;
}
interface Parameter$listStorageV1CSIDriver {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listStorageV1CSIDriver$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIDriverList;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIDriverList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIDriverList;
    "application/json;stream=watch": Schemas.io$k8s$api$storage$v1$CSIDriverList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$storage$v1$CSIDriverList;
}
interface Parameter$createStorageV1CSIDriver {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createStorageV1CSIDriver = RequestBodies.io$k8s$api$storage$v1$CSIDriver.Content;
interface Response$createStorageV1CSIDriver$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIDriver;
}
interface Response$createStorageV1CSIDriver$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIDriver;
}
interface Response$createStorageV1CSIDriver$Status$202 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIDriver;
}
interface Parameter$deleteStorageV1CollectionCSIDriver {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteStorageV1CollectionCSIDriver = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteStorageV1CollectionCSIDriver$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readStorageV1CSIDriver {
    /** name of the CSIDriver */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readStorageV1CSIDriver$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIDriver;
}
interface Parameter$replaceStorageV1CSIDriver {
    /** name of the CSIDriver */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceStorageV1CSIDriver = RequestBodies.io$k8s$api$storage$v1$CSIDriver.Content;
interface Response$replaceStorageV1CSIDriver$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIDriver;
}
interface Response$replaceStorageV1CSIDriver$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIDriver;
}
interface Parameter$deleteStorageV1CSIDriver {
    /** name of the CSIDriver */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteStorageV1CSIDriver = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteStorageV1CSIDriver$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIDriver;
}
interface Response$deleteStorageV1CSIDriver$Status$202 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIDriver;
}
interface Parameter$patchStorageV1CSIDriver {
    /** name of the CSIDriver */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchStorageV1CSIDriver = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchStorageV1CSIDriver$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIDriver;
}
interface Response$patchStorageV1CSIDriver$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIDriver;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIDriver;
}
interface Parameter$listStorageV1CSINode {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listStorageV1CSINode$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSINodeList;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSINodeList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSINodeList;
    "application/json;stream=watch": Schemas.io$k8s$api$storage$v1$CSINodeList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$storage$v1$CSINodeList;
}
interface Parameter$createStorageV1CSINode {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createStorageV1CSINode = RequestBodies.io$k8s$api$storage$v1$CSINode.Content;
interface Response$createStorageV1CSINode$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSINode;
}
interface Response$createStorageV1CSINode$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSINode;
}
interface Response$createStorageV1CSINode$Status$202 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSINode;
}
interface Parameter$deleteStorageV1CollectionCSINode {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteStorageV1CollectionCSINode = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteStorageV1CollectionCSINode$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readStorageV1CSINode {
    /** name of the CSINode */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readStorageV1CSINode$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSINode;
}
interface Parameter$replaceStorageV1CSINode {
    /** name of the CSINode */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceStorageV1CSINode = RequestBodies.io$k8s$api$storage$v1$CSINode.Content;
interface Response$replaceStorageV1CSINode$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSINode;
}
interface Response$replaceStorageV1CSINode$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSINode;
}
interface Parameter$deleteStorageV1CSINode {
    /** name of the CSINode */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteStorageV1CSINode = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteStorageV1CSINode$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSINode;
}
interface Response$deleteStorageV1CSINode$Status$202 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSINode;
}
interface Parameter$patchStorageV1CSINode {
    /** name of the CSINode */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchStorageV1CSINode = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchStorageV1CSINode$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSINode;
}
interface Response$patchStorageV1CSINode$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSINode;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSINode;
}
interface Parameter$listStorageV1CSIStorageCapacityForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listStorageV1CSIStorageCapacityForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIStorageCapacityList;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIStorageCapacityList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIStorageCapacityList;
    "application/json;stream=watch": Schemas.io$k8s$api$storage$v1$CSIStorageCapacityList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$storage$v1$CSIStorageCapacityList;
}
interface Parameter$listStorageV1NamespacedCSIStorageCapacity {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listStorageV1NamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIStorageCapacityList;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIStorageCapacityList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIStorageCapacityList;
    "application/json;stream=watch": Schemas.io$k8s$api$storage$v1$CSIStorageCapacityList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$storage$v1$CSIStorageCapacityList;
}
interface Parameter$createStorageV1NamespacedCSIStorageCapacity {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createStorageV1NamespacedCSIStorageCapacity = RequestBodies.io$k8s$api$storage$v1$CSIStorageCapacity.Content;
interface Response$createStorageV1NamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
}
interface Response$createStorageV1NamespacedCSIStorageCapacity$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
}
interface Response$createStorageV1NamespacedCSIStorageCapacity$Status$202 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
}
interface Parameter$deleteStorageV1CollectionNamespacedCSIStorageCapacity {
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteStorageV1CollectionNamespacedCSIStorageCapacity = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteStorageV1CollectionNamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readStorageV1NamespacedCSIStorageCapacity {
    /** name of the CSIStorageCapacity */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readStorageV1NamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
}
interface Parameter$replaceStorageV1NamespacedCSIStorageCapacity {
    /** name of the CSIStorageCapacity */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceStorageV1NamespacedCSIStorageCapacity = RequestBodies.io$k8s$api$storage$v1$CSIStorageCapacity.Content;
interface Response$replaceStorageV1NamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
}
interface Response$replaceStorageV1NamespacedCSIStorageCapacity$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
}
interface Parameter$deleteStorageV1NamespacedCSIStorageCapacity {
    /** name of the CSIStorageCapacity */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteStorageV1NamespacedCSIStorageCapacity = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteStorageV1NamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Response$deleteStorageV1NamespacedCSIStorageCapacity$Status$202 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$patchStorageV1NamespacedCSIStorageCapacity {
    /** name of the CSIStorageCapacity */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchStorageV1NamespacedCSIStorageCapacity = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchStorageV1NamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
}
interface Response$patchStorageV1NamespacedCSIStorageCapacity$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
    "application/yaml": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$CSIStorageCapacity;
}
interface Parameter$listStorageV1StorageClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listStorageV1StorageClass$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$StorageClassList;
    "application/yaml": Schemas.io$k8s$api$storage$v1$StorageClassList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$StorageClassList;
    "application/json;stream=watch": Schemas.io$k8s$api$storage$v1$StorageClassList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$storage$v1$StorageClassList;
}
interface Parameter$createStorageV1StorageClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createStorageV1StorageClass = RequestBodies.io$k8s$api$storage$v1$StorageClass.Content;
interface Response$createStorageV1StorageClass$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/yaml": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$StorageClass;
}
interface Response$createStorageV1StorageClass$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/yaml": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$StorageClass;
}
interface Response$createStorageV1StorageClass$Status$202 {
    "application/json": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/yaml": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$StorageClass;
}
interface Parameter$deleteStorageV1CollectionStorageClass {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteStorageV1CollectionStorageClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteStorageV1CollectionStorageClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readStorageV1StorageClass {
    /** name of the StorageClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readStorageV1StorageClass$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/yaml": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$StorageClass;
}
interface Parameter$replaceStorageV1StorageClass {
    /** name of the StorageClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceStorageV1StorageClass = RequestBodies.io$k8s$api$storage$v1$StorageClass.Content;
interface Response$replaceStorageV1StorageClass$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/yaml": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$StorageClass;
}
interface Response$replaceStorageV1StorageClass$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/yaml": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$StorageClass;
}
interface Parameter$deleteStorageV1StorageClass {
    /** name of the StorageClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteStorageV1StorageClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteStorageV1StorageClass$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/yaml": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$StorageClass;
}
interface Response$deleteStorageV1StorageClass$Status$202 {
    "application/json": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/yaml": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$StorageClass;
}
interface Parameter$patchStorageV1StorageClass {
    /** name of the StorageClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchStorageV1StorageClass = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchStorageV1StorageClass$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/yaml": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$StorageClass;
}
interface Response$patchStorageV1StorageClass$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/yaml": Schemas.io$k8s$api$storage$v1$StorageClass;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$StorageClass;
}
interface Parameter$listStorageV1VolumeAttachment {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$listStorageV1VolumeAttachment$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachmentList;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachmentList;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachmentList;
    "application/json;stream=watch": Schemas.io$k8s$api$storage$v1$VolumeAttachmentList;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$api$storage$v1$VolumeAttachmentList;
}
interface Parameter$createStorageV1VolumeAttachment {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$createStorageV1VolumeAttachment = RequestBodies.io$k8s$api$storage$v1$VolumeAttachment.Content;
interface Response$createStorageV1VolumeAttachment$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
interface Response$createStorageV1VolumeAttachment$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
interface Response$createStorageV1VolumeAttachment$Status$202 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
interface Parameter$deleteStorageV1CollectionVolumeAttachment {
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
}
type RequestBody$deleteStorageV1CollectionVolumeAttachment = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteStorageV1CollectionVolumeAttachment$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$Status;
}
interface Parameter$readStorageV1VolumeAttachment {
    /** name of the VolumeAttachment */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readStorageV1VolumeAttachment$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
interface Parameter$replaceStorageV1VolumeAttachment {
    /** name of the VolumeAttachment */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceStorageV1VolumeAttachment = RequestBodies.io$k8s$api$storage$v1$VolumeAttachment.Content;
interface Response$replaceStorageV1VolumeAttachment$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
interface Response$replaceStorageV1VolumeAttachment$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
interface Parameter$deleteStorageV1VolumeAttachment {
    /** name of the VolumeAttachment */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** The duration in seconds before the object should be deleted. Value must be non-negative integer. The value zero indicates delete immediately. If this value is nil, the default grace period for the specified type will be used. Defaults to a per object value if not specified. zero means delete immediately. */
    gracePeriodSeconds?: number;
    /** Deprecated: please use the PropagationPolicy, this field will be deprecated in 1.7. Should the dependent objects be orphaned. If true/false, the "orphan" finalizer will be added to/removed from the object's finalizers list. Either this field or PropagationPolicy may be set, but not both. */
    orphanDependents?: boolean;
    /** Whether and how garbage collection will be performed. Either this field or OrphanDependents may be set, but not both. The default policy is decided by the existing finalizer set in the metadata.finalizers and the resource-specific default policy. Acceptable values are: 'Orphan' - orphan the dependents; 'Background' - allow the garbage collector to delete the dependents in the background; 'Foreground' - a cascading policy that deletes all dependents in the foreground. */
    propagationPolicy?: string;
}
type RequestBody$deleteStorageV1VolumeAttachment = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$DeleteOptions.Content;
interface Response$deleteStorageV1VolumeAttachment$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
interface Response$deleteStorageV1VolumeAttachment$Status$202 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
interface Parameter$patchStorageV1VolumeAttachment {
    /** name of the VolumeAttachment */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchStorageV1VolumeAttachment = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchStorageV1VolumeAttachment$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
interface Response$patchStorageV1VolumeAttachment$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
interface Parameter$readStorageV1VolumeAttachmentStatus {
    /** name of the VolumeAttachment */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
}
interface Response$readStorageV1VolumeAttachmentStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
interface Parameter$replaceStorageV1VolumeAttachmentStatus {
    /** name of the VolumeAttachment */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
}
type RequestBody$replaceStorageV1VolumeAttachmentStatus = RequestBodies.io$k8s$api$storage$v1$VolumeAttachment.Content;
interface Response$replaceStorageV1VolumeAttachmentStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
interface Response$replaceStorageV1VolumeAttachmentStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
interface Parameter$patchStorageV1VolumeAttachmentStatus {
    /** name of the VolumeAttachment */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /** When present, indicates that modifications should not be persisted. An invalid or unrecognized dryRun directive will result in an error response and no further processing of the request. Valid values are: - All: all dry run stages will be processed */
    dryRun?: string;
    /** fieldManager is a name associated with the actor or entity that is making these changes. The value must be less than or 128 characters long, and only contain printable characters, as defined by https://golang.org/pkg/unicode/#IsPrint. This field is required for apply requests (application/apply-patch) but optional for non-apply patch types (JsonPatch, MergePatch, StrategicMergePatch). */
    fieldManager?: string;
    /** fieldValidation instructs the server on how to handle objects in the request (POST/PUT/PATCH) containing unknown or duplicate fields. Valid values are: - Ignore: This will ignore any unknown fields that are silently dropped from the object, and will ignore all but the last duplicate field that the decoder encounters. This is the default behavior prior to v1.23. - Warn: This will send a warning via the standard warning response header for each unknown field that is dropped from the object, and for each duplicate field that is encountered. The request will still succeed if there are no other errors, and will only persist the last of any duplicate fields. This is the default in v1.23+ - Strict: This will fail the request with a BadRequest error if any unknown fields would be dropped from the object, or if any duplicate fields are present. The error returned from the server will contain all unknown and duplicate fields encountered. */
    fieldValidation?: string;
    /** Force is going to "force" Apply requests. It means user will re-acquire conflicting fields owned by other people. Force flag must be unset for non-apply patch requests. */
    force?: boolean;
}
type RequestBody$patchStorageV1VolumeAttachmentStatus = RequestBodies.io$k8s$apimachinery$pkg$apis$meta$v1$Patch.Content;
interface Response$patchStorageV1VolumeAttachmentStatus$Status$200 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
interface Response$patchStorageV1VolumeAttachmentStatus$Status$201 {
    "application/json": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/yaml": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$api$storage$v1$VolumeAttachment;
}
interface Parameter$watchStorageV1CSIDriverList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchStorageV1CSIDriverList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchStorageV1CSIDriver {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the CSIDriver */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchStorageV1CSIDriver$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchStorageV1CSINodeList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchStorageV1CSINodeList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchStorageV1CSINode {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the CSINode */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchStorageV1CSINode$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchStorageV1CSIStorageCapacityListForAllNamespaces {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchStorageV1CSIStorageCapacityListForAllNamespaces$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchStorageV1NamespacedCSIStorageCapacityList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchStorageV1NamespacedCSIStorageCapacityList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchStorageV1NamespacedCSIStorageCapacity {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the CSIStorageCapacity */
    name: string;
    /** object name and auth scope, such as for teams and projects */
    namespace: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchStorageV1NamespacedCSIStorageCapacity$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchStorageV1StorageClassList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchStorageV1StorageClassList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchStorageV1StorageClass {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the StorageClass */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchStorageV1StorageClass$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchStorageV1VolumeAttachmentList {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchStorageV1VolumeAttachmentList$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$watchStorageV1VolumeAttachment {
    /** allowWatchBookmarks requests watch events with type "BOOKMARK". Servers that do not implement bookmarks may ignore this flag and bookmarks are sent at the server's discretion. Clients should not assume bookmarks are returned at any specific interval, nor may they assume the server will send any BOOKMARK event during a session. If this is not a watch, this field is ignored. */
    allowWatchBookmarks?: boolean;
    /**
     * The continue option should be set when retrieving more results from the server. Since this value is server defined, clients may only use the continue value from a previous query result with identical query parameters (except for the value of continue) and the server may reject a continue value it does not recognize. If the specified continue value is no longer valid whether due to expiration (generally five to fifteen minutes) or a configuration change on the server, the server will respond with a 410 ResourceExpired error together with a continue token. If the client needs a consistent list, it must restart their list without the continue field. Otherwise, the client may send another list request with the token received with the 410 error, the server will respond with a list starting from the next key, but from the latest snapshot, which is inconsistent from the previous list results - objects that are created, modified, or deleted after the first list request will be included in the response, as long as their keys are after the "next key".
     *
     * This field is not supported when watch is true. Clients may start a watch from the last resourceVersion value returned by the server and not miss any modifications.
     */
    continue?: string;
    /** A selector to restrict the list of returned objects by their fields. Defaults to everything. */
    fieldSelector?: string;
    /** A selector to restrict the list of returned objects by their labels. Defaults to everything. */
    labelSelector?: string;
    /**
     * limit is a maximum number of responses to return for a list call. If more items exist, the server will set the `continue` field on the list metadata to a value that can be used with the same initial query to retrieve the next set of results. Setting a limit may return fewer than the requested amount of items (up to zero items) in the event all requested objects are filtered out and clients should only use the presence of the continue field to determine whether more results are available. Servers may choose not to support the limit argument and will return all of the available results. If limit is specified and the continue field is empty, clients may assume that no more results are available. This field is not supported if watch is true.
     *
     * The server guarantees that the objects returned when using continue will be identical to issuing a single list call without a limit - that is, no objects created, modified, or deleted after the first request is issued will be included in any subsequent continued requests. This is sometimes referred to as a consistent snapshot, and ensures that a client that is using limit to receive smaller chunks of a very large result can ensure they see all possible objects. If objects are updated during a chunked list the version of the object that was present at the time the first list result was calculated is returned.
     */
    limit?: number;
    /** name of the VolumeAttachment */
    name: string;
    /** If 'true', then the output is pretty printed. */
    pretty?: string;
    /**
     * resourceVersion sets a constraint on what resource versions a request may be served from. See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersion?: string;
    /**
     * resourceVersionMatch determines how resourceVersion is applied to list calls. It is highly recommended that resourceVersionMatch be set for list calls where resourceVersion is set See https://kubernetes.io/docs/reference/using-api/api-concepts/#resource-versions for details.
     *
     * Defaults to unset
     */
    resourceVersionMatch?: string;
    /**
     * `sendInitialEvents=true` may be set together with `watch=true`. In that case, the watch stream will begin with synthetic events to produce the current state of objects in the collection. Once all such events have been sent, a synthetic "Bookmark" event  will be sent. The bookmark will report the ResourceVersion (RV) corresponding to the set of objects, and be marked with `"k8s.io/initial-events-end": "true"` annotation. Afterwards, the watch stream will proceed as usual, sending watch events corresponding to changes (subsequent to the RV) to objects watched.
     *
     * When `sendInitialEvents` option is set, we require `resourceVersionMatch` option to also be set. The semantic of the watch request is as following: - `resourceVersionMatch` = NotOlderThan
     *   is interpreted as "data at least as new as the provided `resourceVersion`"
     *   and the bookmark event is send when the state is synced
     *   to a `resourceVersion` at least as fresh as the one provided by the ListOptions.
     *   If `resourceVersion` is unset, this is interpreted as "consistent read" and the
     *   bookmark event is send when the state is synced at least to the moment
     *   when request started being processed.
     * - `resourceVersionMatch` set to any other value or unset
     *   Invalid error is returned.
     *
     * Defaults to true if `resourceVersion=""` or `resourceVersion="0"` (for backward compatibility reasons) and to false otherwise.
     */
    sendInitialEvents?: boolean;
    /** Timeout for the list/watch call. This limits the duration of the call, regardless of any activity or inactivity. */
    timeoutSeconds?: number;
    /** Watch for changes to the described resources and return them as a stream of add, update, and remove notifications. Specify resourceVersion. */
    watch?: boolean;
}
interface Response$watchStorageV1VolumeAttachment$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/yaml": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/json;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
    "application/vnd.kubernetes.protobuf;stream=watch": Schemas.io$k8s$apimachinery$pkg$apis$meta$v1$WatchEvent;
}
interface Parameter$logFileHandler {
    /** path to the log */
    logpath: string;
}
interface Response$getServiceAccountIssuerOpenIDKeyset$Status$200 {
    "application/jwk-set+json": string;
}
interface Response$getCodeVersion$Status$200 {
    "application/json": Schemas.io$k8s$apimachinery$pkg$version$Info;
}
type ResponseContentType$getServiceAccountIssuerOpenIDConfiguration = keyof Response$getServiceAccountIssuerOpenIDConfiguration$Status$200;
type ResponseContentType$getCoreAPIVersions = keyof Response$getCoreAPIVersions$Status$200;
interface Params$getCoreAPIVersions<U extends ResponseContentType$getCoreAPIVersions> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getCoreV1APIResources = keyof Response$getCoreV1APIResources$Status$200;
interface Params$getCoreV1APIResources<U extends ResponseContentType$getCoreV1APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listCoreV1ComponentStatus = keyof Response$listCoreV1ComponentStatus$Status$200;
interface Params$listCoreV1ComponentStatus<U extends ResponseContentType$listCoreV1ComponentStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1ComponentStatus;
}
type ResponseContentType$readCoreV1ComponentStatus = keyof Response$readCoreV1ComponentStatus$Status$200;
interface Params$readCoreV1ComponentStatus<U extends ResponseContentType$readCoreV1ComponentStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1ComponentStatus;
}
type ResponseContentType$listCoreV1ConfigMapForAllNamespaces = keyof Response$listCoreV1ConfigMapForAllNamespaces$Status$200;
interface Params$listCoreV1ConfigMapForAllNamespaces<U extends ResponseContentType$listCoreV1ConfigMapForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1ConfigMapForAllNamespaces;
}
type ResponseContentType$listCoreV1EndpointsForAllNamespaces = keyof Response$listCoreV1EndpointsForAllNamespaces$Status$200;
interface Params$listCoreV1EndpointsForAllNamespaces<U extends ResponseContentType$listCoreV1EndpointsForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1EndpointsForAllNamespaces;
}
type ResponseContentType$listCoreV1EventForAllNamespaces = keyof Response$listCoreV1EventForAllNamespaces$Status$200;
interface Params$listCoreV1EventForAllNamespaces<U extends ResponseContentType$listCoreV1EventForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1EventForAllNamespaces;
}
type ResponseContentType$listCoreV1LimitRangeForAllNamespaces = keyof Response$listCoreV1LimitRangeForAllNamespaces$Status$200;
interface Params$listCoreV1LimitRangeForAllNamespaces<U extends ResponseContentType$listCoreV1LimitRangeForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1LimitRangeForAllNamespaces;
}
type ResponseContentType$listCoreV1Namespace = keyof Response$listCoreV1Namespace$Status$200;
interface Params$listCoreV1Namespace<U extends ResponseContentType$listCoreV1Namespace> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1Namespace;
}
type RequestContentType$createCoreV1Namespace = keyof RequestBody$createCoreV1Namespace;
type ResponseContentType$createCoreV1Namespace = keyof Response$createCoreV1Namespace$Status$200 | keyof Response$createCoreV1Namespace$Status$201 | keyof Response$createCoreV1Namespace$Status$202;
interface Params$createCoreV1Namespace<U extends ResponseContentType$createCoreV1Namespace> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1Namespace;
    requestBody: RequestBody$createCoreV1Namespace["*/*"];
}
type RequestContentType$createCoreV1NamespacedBinding = keyof RequestBody$createCoreV1NamespacedBinding;
type ResponseContentType$createCoreV1NamespacedBinding = keyof Response$createCoreV1NamespacedBinding$Status$200 | keyof Response$createCoreV1NamespacedBinding$Status$201 | keyof Response$createCoreV1NamespacedBinding$Status$202;
interface Params$createCoreV1NamespacedBinding<U extends ResponseContentType$createCoreV1NamespacedBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedBinding;
    requestBody: RequestBody$createCoreV1NamespacedBinding["*/*"];
}
type ResponseContentType$listCoreV1NamespacedConfigMap = keyof Response$listCoreV1NamespacedConfigMap$Status$200;
interface Params$listCoreV1NamespacedConfigMap<U extends ResponseContentType$listCoreV1NamespacedConfigMap> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedConfigMap;
}
type RequestContentType$createCoreV1NamespacedConfigMap = keyof RequestBody$createCoreV1NamespacedConfigMap;
type ResponseContentType$createCoreV1NamespacedConfigMap = keyof Response$createCoreV1NamespacedConfigMap$Status$200 | keyof Response$createCoreV1NamespacedConfigMap$Status$201 | keyof Response$createCoreV1NamespacedConfigMap$Status$202;
interface Params$createCoreV1NamespacedConfigMap<U extends ResponseContentType$createCoreV1NamespacedConfigMap> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedConfigMap;
    requestBody: RequestBody$createCoreV1NamespacedConfigMap["*/*"];
}
type RequestContentType$deleteCoreV1CollectionNamespacedConfigMap = keyof RequestBody$deleteCoreV1CollectionNamespacedConfigMap;
type ResponseContentType$deleteCoreV1CollectionNamespacedConfigMap = keyof Response$deleteCoreV1CollectionNamespacedConfigMap$Status$200;
interface Params$deleteCoreV1CollectionNamespacedConfigMap<U extends ResponseContentType$deleteCoreV1CollectionNamespacedConfigMap> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedConfigMap;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedConfigMap["*/*"];
}
type ResponseContentType$readCoreV1NamespacedConfigMap = keyof Response$readCoreV1NamespacedConfigMap$Status$200;
interface Params$readCoreV1NamespacedConfigMap<U extends ResponseContentType$readCoreV1NamespacedConfigMap> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedConfigMap;
}
type RequestContentType$replaceCoreV1NamespacedConfigMap = keyof RequestBody$replaceCoreV1NamespacedConfigMap;
type ResponseContentType$replaceCoreV1NamespacedConfigMap = keyof Response$replaceCoreV1NamespacedConfigMap$Status$200 | keyof Response$replaceCoreV1NamespacedConfigMap$Status$201;
interface Params$replaceCoreV1NamespacedConfigMap<U extends ResponseContentType$replaceCoreV1NamespacedConfigMap> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedConfigMap;
    requestBody: RequestBody$replaceCoreV1NamespacedConfigMap["*/*"];
}
type RequestContentType$deleteCoreV1NamespacedConfigMap = keyof RequestBody$deleteCoreV1NamespacedConfigMap;
type ResponseContentType$deleteCoreV1NamespacedConfigMap = keyof Response$deleteCoreV1NamespacedConfigMap$Status$200 | keyof Response$deleteCoreV1NamespacedConfigMap$Status$202;
interface Params$deleteCoreV1NamespacedConfigMap<U extends ResponseContentType$deleteCoreV1NamespacedConfigMap> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedConfigMap;
    requestBody: RequestBody$deleteCoreV1NamespacedConfigMap["*/*"];
}
type RequestContentType$patchCoreV1NamespacedConfigMap = keyof RequestBody$patchCoreV1NamespacedConfigMap;
type ResponseContentType$patchCoreV1NamespacedConfigMap = keyof Response$patchCoreV1NamespacedConfigMap$Status$200 | keyof Response$patchCoreV1NamespacedConfigMap$Status$201;
interface Params$patchCoreV1NamespacedConfigMap<T extends RequestContentType$patchCoreV1NamespacedConfigMap, U extends ResponseContentType$patchCoreV1NamespacedConfigMap> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedConfigMap;
    requestBody: RequestBody$patchCoreV1NamespacedConfigMap[T];
}
type ResponseContentType$listCoreV1NamespacedEndpoints = keyof Response$listCoreV1NamespacedEndpoints$Status$200;
interface Params$listCoreV1NamespacedEndpoints<U extends ResponseContentType$listCoreV1NamespacedEndpoints> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedEndpoints;
}
type RequestContentType$createCoreV1NamespacedEndpoints = keyof RequestBody$createCoreV1NamespacedEndpoints;
type ResponseContentType$createCoreV1NamespacedEndpoints = keyof Response$createCoreV1NamespacedEndpoints$Status$200 | keyof Response$createCoreV1NamespacedEndpoints$Status$201 | keyof Response$createCoreV1NamespacedEndpoints$Status$202;
interface Params$createCoreV1NamespacedEndpoints<U extends ResponseContentType$createCoreV1NamespacedEndpoints> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedEndpoints;
    requestBody: RequestBody$createCoreV1NamespacedEndpoints["*/*"];
}
type RequestContentType$deleteCoreV1CollectionNamespacedEndpoints = keyof RequestBody$deleteCoreV1CollectionNamespacedEndpoints;
type ResponseContentType$deleteCoreV1CollectionNamespacedEndpoints = keyof Response$deleteCoreV1CollectionNamespacedEndpoints$Status$200;
interface Params$deleteCoreV1CollectionNamespacedEndpoints<U extends ResponseContentType$deleteCoreV1CollectionNamespacedEndpoints> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedEndpoints;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedEndpoints["*/*"];
}
type ResponseContentType$readCoreV1NamespacedEndpoints = keyof Response$readCoreV1NamespacedEndpoints$Status$200;
interface Params$readCoreV1NamespacedEndpoints<U extends ResponseContentType$readCoreV1NamespacedEndpoints> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedEndpoints;
}
type RequestContentType$replaceCoreV1NamespacedEndpoints = keyof RequestBody$replaceCoreV1NamespacedEndpoints;
type ResponseContentType$replaceCoreV1NamespacedEndpoints = keyof Response$replaceCoreV1NamespacedEndpoints$Status$200 | keyof Response$replaceCoreV1NamespacedEndpoints$Status$201;
interface Params$replaceCoreV1NamespacedEndpoints<U extends ResponseContentType$replaceCoreV1NamespacedEndpoints> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedEndpoints;
    requestBody: RequestBody$replaceCoreV1NamespacedEndpoints["*/*"];
}
type RequestContentType$deleteCoreV1NamespacedEndpoints = keyof RequestBody$deleteCoreV1NamespacedEndpoints;
type ResponseContentType$deleteCoreV1NamespacedEndpoints = keyof Response$deleteCoreV1NamespacedEndpoints$Status$200 | keyof Response$deleteCoreV1NamespacedEndpoints$Status$202;
interface Params$deleteCoreV1NamespacedEndpoints<U extends ResponseContentType$deleteCoreV1NamespacedEndpoints> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedEndpoints;
    requestBody: RequestBody$deleteCoreV1NamespacedEndpoints["*/*"];
}
type RequestContentType$patchCoreV1NamespacedEndpoints = keyof RequestBody$patchCoreV1NamespacedEndpoints;
type ResponseContentType$patchCoreV1NamespacedEndpoints = keyof Response$patchCoreV1NamespacedEndpoints$Status$200 | keyof Response$patchCoreV1NamespacedEndpoints$Status$201;
interface Params$patchCoreV1NamespacedEndpoints<T extends RequestContentType$patchCoreV1NamespacedEndpoints, U extends ResponseContentType$patchCoreV1NamespacedEndpoints> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedEndpoints;
    requestBody: RequestBody$patchCoreV1NamespacedEndpoints[T];
}
type ResponseContentType$listCoreV1NamespacedEvent = keyof Response$listCoreV1NamespacedEvent$Status$200;
interface Params$listCoreV1NamespacedEvent<U extends ResponseContentType$listCoreV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedEvent;
}
type RequestContentType$createCoreV1NamespacedEvent = keyof RequestBody$createCoreV1NamespacedEvent;
type ResponseContentType$createCoreV1NamespacedEvent = keyof Response$createCoreV1NamespacedEvent$Status$200 | keyof Response$createCoreV1NamespacedEvent$Status$201 | keyof Response$createCoreV1NamespacedEvent$Status$202;
interface Params$createCoreV1NamespacedEvent<U extends ResponseContentType$createCoreV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedEvent;
    requestBody: RequestBody$createCoreV1NamespacedEvent["*/*"];
}
type RequestContentType$deleteCoreV1CollectionNamespacedEvent = keyof RequestBody$deleteCoreV1CollectionNamespacedEvent;
type ResponseContentType$deleteCoreV1CollectionNamespacedEvent = keyof Response$deleteCoreV1CollectionNamespacedEvent$Status$200;
interface Params$deleteCoreV1CollectionNamespacedEvent<U extends ResponseContentType$deleteCoreV1CollectionNamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedEvent;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedEvent["*/*"];
}
type ResponseContentType$readCoreV1NamespacedEvent = keyof Response$readCoreV1NamespacedEvent$Status$200;
interface Params$readCoreV1NamespacedEvent<U extends ResponseContentType$readCoreV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedEvent;
}
type RequestContentType$replaceCoreV1NamespacedEvent = keyof RequestBody$replaceCoreV1NamespacedEvent;
type ResponseContentType$replaceCoreV1NamespacedEvent = keyof Response$replaceCoreV1NamespacedEvent$Status$200 | keyof Response$replaceCoreV1NamespacedEvent$Status$201;
interface Params$replaceCoreV1NamespacedEvent<U extends ResponseContentType$replaceCoreV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedEvent;
    requestBody: RequestBody$replaceCoreV1NamespacedEvent["*/*"];
}
type RequestContentType$deleteCoreV1NamespacedEvent = keyof RequestBody$deleteCoreV1NamespacedEvent;
type ResponseContentType$deleteCoreV1NamespacedEvent = keyof Response$deleteCoreV1NamespacedEvent$Status$200 | keyof Response$deleteCoreV1NamespacedEvent$Status$202;
interface Params$deleteCoreV1NamespacedEvent<U extends ResponseContentType$deleteCoreV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedEvent;
    requestBody: RequestBody$deleteCoreV1NamespacedEvent["*/*"];
}
type RequestContentType$patchCoreV1NamespacedEvent = keyof RequestBody$patchCoreV1NamespacedEvent;
type ResponseContentType$patchCoreV1NamespacedEvent = keyof Response$patchCoreV1NamespacedEvent$Status$200 | keyof Response$patchCoreV1NamespacedEvent$Status$201;
interface Params$patchCoreV1NamespacedEvent<T extends RequestContentType$patchCoreV1NamespacedEvent, U extends ResponseContentType$patchCoreV1NamespacedEvent> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedEvent;
    requestBody: RequestBody$patchCoreV1NamespacedEvent[T];
}
type ResponseContentType$listCoreV1NamespacedLimitRange = keyof Response$listCoreV1NamespacedLimitRange$Status$200;
interface Params$listCoreV1NamespacedLimitRange<U extends ResponseContentType$listCoreV1NamespacedLimitRange> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedLimitRange;
}
type RequestContentType$createCoreV1NamespacedLimitRange = keyof RequestBody$createCoreV1NamespacedLimitRange;
type ResponseContentType$createCoreV1NamespacedLimitRange = keyof Response$createCoreV1NamespacedLimitRange$Status$200 | keyof Response$createCoreV1NamespacedLimitRange$Status$201 | keyof Response$createCoreV1NamespacedLimitRange$Status$202;
interface Params$createCoreV1NamespacedLimitRange<U extends ResponseContentType$createCoreV1NamespacedLimitRange> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedLimitRange;
    requestBody: RequestBody$createCoreV1NamespacedLimitRange["*/*"];
}
type RequestContentType$deleteCoreV1CollectionNamespacedLimitRange = keyof RequestBody$deleteCoreV1CollectionNamespacedLimitRange;
type ResponseContentType$deleteCoreV1CollectionNamespacedLimitRange = keyof Response$deleteCoreV1CollectionNamespacedLimitRange$Status$200;
interface Params$deleteCoreV1CollectionNamespacedLimitRange<U extends ResponseContentType$deleteCoreV1CollectionNamespacedLimitRange> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedLimitRange;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedLimitRange["*/*"];
}
type ResponseContentType$readCoreV1NamespacedLimitRange = keyof Response$readCoreV1NamespacedLimitRange$Status$200;
interface Params$readCoreV1NamespacedLimitRange<U extends ResponseContentType$readCoreV1NamespacedLimitRange> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedLimitRange;
}
type RequestContentType$replaceCoreV1NamespacedLimitRange = keyof RequestBody$replaceCoreV1NamespacedLimitRange;
type ResponseContentType$replaceCoreV1NamespacedLimitRange = keyof Response$replaceCoreV1NamespacedLimitRange$Status$200 | keyof Response$replaceCoreV1NamespacedLimitRange$Status$201;
interface Params$replaceCoreV1NamespacedLimitRange<U extends ResponseContentType$replaceCoreV1NamespacedLimitRange> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedLimitRange;
    requestBody: RequestBody$replaceCoreV1NamespacedLimitRange["*/*"];
}
type RequestContentType$deleteCoreV1NamespacedLimitRange = keyof RequestBody$deleteCoreV1NamespacedLimitRange;
type ResponseContentType$deleteCoreV1NamespacedLimitRange = keyof Response$deleteCoreV1NamespacedLimitRange$Status$200 | keyof Response$deleteCoreV1NamespacedLimitRange$Status$202;
interface Params$deleteCoreV1NamespacedLimitRange<U extends ResponseContentType$deleteCoreV1NamespacedLimitRange> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedLimitRange;
    requestBody: RequestBody$deleteCoreV1NamespacedLimitRange["*/*"];
}
type RequestContentType$patchCoreV1NamespacedLimitRange = keyof RequestBody$patchCoreV1NamespacedLimitRange;
type ResponseContentType$patchCoreV1NamespacedLimitRange = keyof Response$patchCoreV1NamespacedLimitRange$Status$200 | keyof Response$patchCoreV1NamespacedLimitRange$Status$201;
interface Params$patchCoreV1NamespacedLimitRange<T extends RequestContentType$patchCoreV1NamespacedLimitRange, U extends ResponseContentType$patchCoreV1NamespacedLimitRange> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedLimitRange;
    requestBody: RequestBody$patchCoreV1NamespacedLimitRange[T];
}
type ResponseContentType$listCoreV1NamespacedPersistentVolumeClaim = keyof Response$listCoreV1NamespacedPersistentVolumeClaim$Status$200;
interface Params$listCoreV1NamespacedPersistentVolumeClaim<U extends ResponseContentType$listCoreV1NamespacedPersistentVolumeClaim> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedPersistentVolumeClaim;
}
type RequestContentType$createCoreV1NamespacedPersistentVolumeClaim = keyof RequestBody$createCoreV1NamespacedPersistentVolumeClaim;
type ResponseContentType$createCoreV1NamespacedPersistentVolumeClaim = keyof Response$createCoreV1NamespacedPersistentVolumeClaim$Status$200 | keyof Response$createCoreV1NamespacedPersistentVolumeClaim$Status$201 | keyof Response$createCoreV1NamespacedPersistentVolumeClaim$Status$202;
interface Params$createCoreV1NamespacedPersistentVolumeClaim<U extends ResponseContentType$createCoreV1NamespacedPersistentVolumeClaim> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedPersistentVolumeClaim;
    requestBody: RequestBody$createCoreV1NamespacedPersistentVolumeClaim["*/*"];
}
type RequestContentType$deleteCoreV1CollectionNamespacedPersistentVolumeClaim = keyof RequestBody$deleteCoreV1CollectionNamespacedPersistentVolumeClaim;
type ResponseContentType$deleteCoreV1CollectionNamespacedPersistentVolumeClaim = keyof Response$deleteCoreV1CollectionNamespacedPersistentVolumeClaim$Status$200;
interface Params$deleteCoreV1CollectionNamespacedPersistentVolumeClaim<U extends ResponseContentType$deleteCoreV1CollectionNamespacedPersistentVolumeClaim> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedPersistentVolumeClaim;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedPersistentVolumeClaim["*/*"];
}
type ResponseContentType$readCoreV1NamespacedPersistentVolumeClaim = keyof Response$readCoreV1NamespacedPersistentVolumeClaim$Status$200;
interface Params$readCoreV1NamespacedPersistentVolumeClaim<U extends ResponseContentType$readCoreV1NamespacedPersistentVolumeClaim> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedPersistentVolumeClaim;
}
type RequestContentType$replaceCoreV1NamespacedPersistentVolumeClaim = keyof RequestBody$replaceCoreV1NamespacedPersistentVolumeClaim;
type ResponseContentType$replaceCoreV1NamespacedPersistentVolumeClaim = keyof Response$replaceCoreV1NamespacedPersistentVolumeClaim$Status$200 | keyof Response$replaceCoreV1NamespacedPersistentVolumeClaim$Status$201;
interface Params$replaceCoreV1NamespacedPersistentVolumeClaim<U extends ResponseContentType$replaceCoreV1NamespacedPersistentVolumeClaim> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedPersistentVolumeClaim;
    requestBody: RequestBody$replaceCoreV1NamespacedPersistentVolumeClaim["*/*"];
}
type RequestContentType$deleteCoreV1NamespacedPersistentVolumeClaim = keyof RequestBody$deleteCoreV1NamespacedPersistentVolumeClaim;
type ResponseContentType$deleteCoreV1NamespacedPersistentVolumeClaim = keyof Response$deleteCoreV1NamespacedPersistentVolumeClaim$Status$200 | keyof Response$deleteCoreV1NamespacedPersistentVolumeClaim$Status$202;
interface Params$deleteCoreV1NamespacedPersistentVolumeClaim<U extends ResponseContentType$deleteCoreV1NamespacedPersistentVolumeClaim> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedPersistentVolumeClaim;
    requestBody: RequestBody$deleteCoreV1NamespacedPersistentVolumeClaim["*/*"];
}
type RequestContentType$patchCoreV1NamespacedPersistentVolumeClaim = keyof RequestBody$patchCoreV1NamespacedPersistentVolumeClaim;
type ResponseContentType$patchCoreV1NamespacedPersistentVolumeClaim = keyof Response$patchCoreV1NamespacedPersistentVolumeClaim$Status$200 | keyof Response$patchCoreV1NamespacedPersistentVolumeClaim$Status$201;
interface Params$patchCoreV1NamespacedPersistentVolumeClaim<T extends RequestContentType$patchCoreV1NamespacedPersistentVolumeClaim, U extends ResponseContentType$patchCoreV1NamespacedPersistentVolumeClaim> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedPersistentVolumeClaim;
    requestBody: RequestBody$patchCoreV1NamespacedPersistentVolumeClaim[T];
}
type ResponseContentType$readCoreV1NamespacedPersistentVolumeClaimStatus = keyof Response$readCoreV1NamespacedPersistentVolumeClaimStatus$Status$200;
interface Params$readCoreV1NamespacedPersistentVolumeClaimStatus<U extends ResponseContentType$readCoreV1NamespacedPersistentVolumeClaimStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedPersistentVolumeClaimStatus;
}
type RequestContentType$replaceCoreV1NamespacedPersistentVolumeClaimStatus = keyof RequestBody$replaceCoreV1NamespacedPersistentVolumeClaimStatus;
type ResponseContentType$replaceCoreV1NamespacedPersistentVolumeClaimStatus = keyof Response$replaceCoreV1NamespacedPersistentVolumeClaimStatus$Status$200 | keyof Response$replaceCoreV1NamespacedPersistentVolumeClaimStatus$Status$201;
interface Params$replaceCoreV1NamespacedPersistentVolumeClaimStatus<U extends ResponseContentType$replaceCoreV1NamespacedPersistentVolumeClaimStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedPersistentVolumeClaimStatus;
    requestBody: RequestBody$replaceCoreV1NamespacedPersistentVolumeClaimStatus["*/*"];
}
type RequestContentType$patchCoreV1NamespacedPersistentVolumeClaimStatus = keyof RequestBody$patchCoreV1NamespacedPersistentVolumeClaimStatus;
type ResponseContentType$patchCoreV1NamespacedPersistentVolumeClaimStatus = keyof Response$patchCoreV1NamespacedPersistentVolumeClaimStatus$Status$200 | keyof Response$patchCoreV1NamespacedPersistentVolumeClaimStatus$Status$201;
interface Params$patchCoreV1NamespacedPersistentVolumeClaimStatus<T extends RequestContentType$patchCoreV1NamespacedPersistentVolumeClaimStatus, U extends ResponseContentType$patchCoreV1NamespacedPersistentVolumeClaimStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedPersistentVolumeClaimStatus;
    requestBody: RequestBody$patchCoreV1NamespacedPersistentVolumeClaimStatus[T];
}
type ResponseContentType$listCoreV1NamespacedPod = keyof Response$listCoreV1NamespacedPod$Status$200;
interface Params$listCoreV1NamespacedPod<U extends ResponseContentType$listCoreV1NamespacedPod> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedPod;
}
type RequestContentType$createCoreV1NamespacedPod = keyof RequestBody$createCoreV1NamespacedPod;
type ResponseContentType$createCoreV1NamespacedPod = keyof Response$createCoreV1NamespacedPod$Status$200 | keyof Response$createCoreV1NamespacedPod$Status$201 | keyof Response$createCoreV1NamespacedPod$Status$202;
interface Params$createCoreV1NamespacedPod<U extends ResponseContentType$createCoreV1NamespacedPod> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedPod;
    requestBody: RequestBody$createCoreV1NamespacedPod["*/*"];
}
type RequestContentType$deleteCoreV1CollectionNamespacedPod = keyof RequestBody$deleteCoreV1CollectionNamespacedPod;
type ResponseContentType$deleteCoreV1CollectionNamespacedPod = keyof Response$deleteCoreV1CollectionNamespacedPod$Status$200;
interface Params$deleteCoreV1CollectionNamespacedPod<U extends ResponseContentType$deleteCoreV1CollectionNamespacedPod> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedPod;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedPod["*/*"];
}
type ResponseContentType$readCoreV1NamespacedPod = keyof Response$readCoreV1NamespacedPod$Status$200;
interface Params$readCoreV1NamespacedPod<U extends ResponseContentType$readCoreV1NamespacedPod> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedPod;
}
type RequestContentType$replaceCoreV1NamespacedPod = keyof RequestBody$replaceCoreV1NamespacedPod;
type ResponseContentType$replaceCoreV1NamespacedPod = keyof Response$replaceCoreV1NamespacedPod$Status$200 | keyof Response$replaceCoreV1NamespacedPod$Status$201;
interface Params$replaceCoreV1NamespacedPod<U extends ResponseContentType$replaceCoreV1NamespacedPod> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedPod;
    requestBody: RequestBody$replaceCoreV1NamespacedPod["*/*"];
}
type RequestContentType$deleteCoreV1NamespacedPod = keyof RequestBody$deleteCoreV1NamespacedPod;
type ResponseContentType$deleteCoreV1NamespacedPod = keyof Response$deleteCoreV1NamespacedPod$Status$200 | keyof Response$deleteCoreV1NamespacedPod$Status$202;
interface Params$deleteCoreV1NamespacedPod<U extends ResponseContentType$deleteCoreV1NamespacedPod> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedPod;
    requestBody: RequestBody$deleteCoreV1NamespacedPod["*/*"];
}
type RequestContentType$patchCoreV1NamespacedPod = keyof RequestBody$patchCoreV1NamespacedPod;
type ResponseContentType$patchCoreV1NamespacedPod = keyof Response$patchCoreV1NamespacedPod$Status$200 | keyof Response$patchCoreV1NamespacedPod$Status$201;
interface Params$patchCoreV1NamespacedPod<T extends RequestContentType$patchCoreV1NamespacedPod, U extends ResponseContentType$patchCoreV1NamespacedPod> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedPod;
    requestBody: RequestBody$patchCoreV1NamespacedPod[T];
}
type ResponseContentType$connectCoreV1GetNamespacedPodAttach = keyof Response$connectCoreV1GetNamespacedPodAttach$Status$200;
interface Params$connectCoreV1GetNamespacedPodAttach {
    parameter: Parameter$connectCoreV1GetNamespacedPodAttach;
}
type ResponseContentType$connectCoreV1PostNamespacedPodAttach = keyof Response$connectCoreV1PostNamespacedPodAttach$Status$200;
interface Params$connectCoreV1PostNamespacedPodAttach {
    parameter: Parameter$connectCoreV1PostNamespacedPodAttach;
}
type RequestContentType$createCoreV1NamespacedPodBinding = keyof RequestBody$createCoreV1NamespacedPodBinding;
type ResponseContentType$createCoreV1NamespacedPodBinding = keyof Response$createCoreV1NamespacedPodBinding$Status$200 | keyof Response$createCoreV1NamespacedPodBinding$Status$201 | keyof Response$createCoreV1NamespacedPodBinding$Status$202;
interface Params$createCoreV1NamespacedPodBinding<U extends ResponseContentType$createCoreV1NamespacedPodBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedPodBinding;
    requestBody: RequestBody$createCoreV1NamespacedPodBinding["*/*"];
}
type ResponseContentType$readCoreV1NamespacedPodEphemeralcontainers = keyof Response$readCoreV1NamespacedPodEphemeralcontainers$Status$200;
interface Params$readCoreV1NamespacedPodEphemeralcontainers<U extends ResponseContentType$readCoreV1NamespacedPodEphemeralcontainers> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedPodEphemeralcontainers;
}
type RequestContentType$replaceCoreV1NamespacedPodEphemeralcontainers = keyof RequestBody$replaceCoreV1NamespacedPodEphemeralcontainers;
type ResponseContentType$replaceCoreV1NamespacedPodEphemeralcontainers = keyof Response$replaceCoreV1NamespacedPodEphemeralcontainers$Status$200 | keyof Response$replaceCoreV1NamespacedPodEphemeralcontainers$Status$201;
interface Params$replaceCoreV1NamespacedPodEphemeralcontainers<U extends ResponseContentType$replaceCoreV1NamespacedPodEphemeralcontainers> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedPodEphemeralcontainers;
    requestBody: RequestBody$replaceCoreV1NamespacedPodEphemeralcontainers["*/*"];
}
type RequestContentType$patchCoreV1NamespacedPodEphemeralcontainers = keyof RequestBody$patchCoreV1NamespacedPodEphemeralcontainers;
type ResponseContentType$patchCoreV1NamespacedPodEphemeralcontainers = keyof Response$patchCoreV1NamespacedPodEphemeralcontainers$Status$200 | keyof Response$patchCoreV1NamespacedPodEphemeralcontainers$Status$201;
interface Params$patchCoreV1NamespacedPodEphemeralcontainers<T extends RequestContentType$patchCoreV1NamespacedPodEphemeralcontainers, U extends ResponseContentType$patchCoreV1NamespacedPodEphemeralcontainers> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedPodEphemeralcontainers;
    requestBody: RequestBody$patchCoreV1NamespacedPodEphemeralcontainers[T];
}
type RequestContentType$createCoreV1NamespacedPodEviction = keyof RequestBody$createCoreV1NamespacedPodEviction;
type ResponseContentType$createCoreV1NamespacedPodEviction = keyof Response$createCoreV1NamespacedPodEviction$Status$200 | keyof Response$createCoreV1NamespacedPodEviction$Status$201 | keyof Response$createCoreV1NamespacedPodEviction$Status$202;
interface Params$createCoreV1NamespacedPodEviction<U extends ResponseContentType$createCoreV1NamespacedPodEviction> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedPodEviction;
    requestBody: RequestBody$createCoreV1NamespacedPodEviction["*/*"];
}
type ResponseContentType$connectCoreV1GetNamespacedPodExec = keyof Response$connectCoreV1GetNamespacedPodExec$Status$200;
interface Params$connectCoreV1GetNamespacedPodExec {
    parameter: Parameter$connectCoreV1GetNamespacedPodExec;
}
type ResponseContentType$connectCoreV1PostNamespacedPodExec = keyof Response$connectCoreV1PostNamespacedPodExec$Status$200;
interface Params$connectCoreV1PostNamespacedPodExec {
    parameter: Parameter$connectCoreV1PostNamespacedPodExec;
}
type ResponseContentType$readCoreV1NamespacedPodLog = keyof Response$readCoreV1NamespacedPodLog$Status$200;
interface Params$readCoreV1NamespacedPodLog<U extends ResponseContentType$readCoreV1NamespacedPodLog> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedPodLog;
}
type ResponseContentType$connectCoreV1GetNamespacedPodPortforward = keyof Response$connectCoreV1GetNamespacedPodPortforward$Status$200;
interface Params$connectCoreV1GetNamespacedPodPortforward {
    parameter: Parameter$connectCoreV1GetNamespacedPodPortforward;
}
type ResponseContentType$connectCoreV1PostNamespacedPodPortforward = keyof Response$connectCoreV1PostNamespacedPodPortforward$Status$200;
interface Params$connectCoreV1PostNamespacedPodPortforward {
    parameter: Parameter$connectCoreV1PostNamespacedPodPortforward;
}
type ResponseContentType$connectCoreV1GetNamespacedPodProxy = keyof Response$connectCoreV1GetNamespacedPodProxy$Status$200;
interface Params$connectCoreV1GetNamespacedPodProxy {
    parameter: Parameter$connectCoreV1GetNamespacedPodProxy;
}
type ResponseContentType$connectCoreV1PutNamespacedPodProxy = keyof Response$connectCoreV1PutNamespacedPodProxy$Status$200;
interface Params$connectCoreV1PutNamespacedPodProxy {
    parameter: Parameter$connectCoreV1PutNamespacedPodProxy;
}
type ResponseContentType$connectCoreV1PostNamespacedPodProxy = keyof Response$connectCoreV1PostNamespacedPodProxy$Status$200;
interface Params$connectCoreV1PostNamespacedPodProxy {
    parameter: Parameter$connectCoreV1PostNamespacedPodProxy;
}
type ResponseContentType$connectCoreV1DeleteNamespacedPodProxy = keyof Response$connectCoreV1DeleteNamespacedPodProxy$Status$200;
interface Params$connectCoreV1DeleteNamespacedPodProxy {
    parameter: Parameter$connectCoreV1DeleteNamespacedPodProxy;
}
type ResponseContentType$connectCoreV1OptionsNamespacedPodProxy = keyof Response$connectCoreV1OptionsNamespacedPodProxy$Status$200;
interface Params$connectCoreV1OptionsNamespacedPodProxy {
    parameter: Parameter$connectCoreV1OptionsNamespacedPodProxy;
}
type ResponseContentType$connectCoreV1HeadNamespacedPodProxy = keyof Response$connectCoreV1HeadNamespacedPodProxy$Status$200;
interface Params$connectCoreV1HeadNamespacedPodProxy {
    parameter: Parameter$connectCoreV1HeadNamespacedPodProxy;
}
type ResponseContentType$connectCoreV1PatchNamespacedPodProxy = keyof Response$connectCoreV1PatchNamespacedPodProxy$Status$200;
interface Params$connectCoreV1PatchNamespacedPodProxy {
    parameter: Parameter$connectCoreV1PatchNamespacedPodProxy;
}
type ResponseContentType$connectCoreV1GetNamespacedPodProxyWithPath = keyof Response$connectCoreV1GetNamespacedPodProxyWithPath$Status$200;
interface Params$connectCoreV1GetNamespacedPodProxyWithPath {
    parameter: Parameter$connectCoreV1GetNamespacedPodProxyWithPath;
}
type ResponseContentType$connectCoreV1PutNamespacedPodProxyWithPath = keyof Response$connectCoreV1PutNamespacedPodProxyWithPath$Status$200;
interface Params$connectCoreV1PutNamespacedPodProxyWithPath {
    parameter: Parameter$connectCoreV1PutNamespacedPodProxyWithPath;
}
type ResponseContentType$connectCoreV1PostNamespacedPodProxyWithPath = keyof Response$connectCoreV1PostNamespacedPodProxyWithPath$Status$200;
interface Params$connectCoreV1PostNamespacedPodProxyWithPath {
    parameter: Parameter$connectCoreV1PostNamespacedPodProxyWithPath;
}
type ResponseContentType$connectCoreV1DeleteNamespacedPodProxyWithPath = keyof Response$connectCoreV1DeleteNamespacedPodProxyWithPath$Status$200;
interface Params$connectCoreV1DeleteNamespacedPodProxyWithPath {
    parameter: Parameter$connectCoreV1DeleteNamespacedPodProxyWithPath;
}
type ResponseContentType$connectCoreV1OptionsNamespacedPodProxyWithPath = keyof Response$connectCoreV1OptionsNamespacedPodProxyWithPath$Status$200;
interface Params$connectCoreV1OptionsNamespacedPodProxyWithPath {
    parameter: Parameter$connectCoreV1OptionsNamespacedPodProxyWithPath;
}
type ResponseContentType$connectCoreV1HeadNamespacedPodProxyWithPath = keyof Response$connectCoreV1HeadNamespacedPodProxyWithPath$Status$200;
interface Params$connectCoreV1HeadNamespacedPodProxyWithPath {
    parameter: Parameter$connectCoreV1HeadNamespacedPodProxyWithPath;
}
type ResponseContentType$connectCoreV1PatchNamespacedPodProxyWithPath = keyof Response$connectCoreV1PatchNamespacedPodProxyWithPath$Status$200;
interface Params$connectCoreV1PatchNamespacedPodProxyWithPath {
    parameter: Parameter$connectCoreV1PatchNamespacedPodProxyWithPath;
}
type ResponseContentType$readCoreV1NamespacedPodStatus = keyof Response$readCoreV1NamespacedPodStatus$Status$200;
interface Params$readCoreV1NamespacedPodStatus<U extends ResponseContentType$readCoreV1NamespacedPodStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedPodStatus;
}
type RequestContentType$replaceCoreV1NamespacedPodStatus = keyof RequestBody$replaceCoreV1NamespacedPodStatus;
type ResponseContentType$replaceCoreV1NamespacedPodStatus = keyof Response$replaceCoreV1NamespacedPodStatus$Status$200 | keyof Response$replaceCoreV1NamespacedPodStatus$Status$201;
interface Params$replaceCoreV1NamespacedPodStatus<U extends ResponseContentType$replaceCoreV1NamespacedPodStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedPodStatus;
    requestBody: RequestBody$replaceCoreV1NamespacedPodStatus["*/*"];
}
type RequestContentType$patchCoreV1NamespacedPodStatus = keyof RequestBody$patchCoreV1NamespacedPodStatus;
type ResponseContentType$patchCoreV1NamespacedPodStatus = keyof Response$patchCoreV1NamespacedPodStatus$Status$200 | keyof Response$patchCoreV1NamespacedPodStatus$Status$201;
interface Params$patchCoreV1NamespacedPodStatus<T extends RequestContentType$patchCoreV1NamespacedPodStatus, U extends ResponseContentType$patchCoreV1NamespacedPodStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedPodStatus;
    requestBody: RequestBody$patchCoreV1NamespacedPodStatus[T];
}
type ResponseContentType$listCoreV1NamespacedPodTemplate = keyof Response$listCoreV1NamespacedPodTemplate$Status$200;
interface Params$listCoreV1NamespacedPodTemplate<U extends ResponseContentType$listCoreV1NamespacedPodTemplate> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedPodTemplate;
}
type RequestContentType$createCoreV1NamespacedPodTemplate = keyof RequestBody$createCoreV1NamespacedPodTemplate;
type ResponseContentType$createCoreV1NamespacedPodTemplate = keyof Response$createCoreV1NamespacedPodTemplate$Status$200 | keyof Response$createCoreV1NamespacedPodTemplate$Status$201 | keyof Response$createCoreV1NamespacedPodTemplate$Status$202;
interface Params$createCoreV1NamespacedPodTemplate<U extends ResponseContentType$createCoreV1NamespacedPodTemplate> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedPodTemplate;
    requestBody: RequestBody$createCoreV1NamespacedPodTemplate["*/*"];
}
type RequestContentType$deleteCoreV1CollectionNamespacedPodTemplate = keyof RequestBody$deleteCoreV1CollectionNamespacedPodTemplate;
type ResponseContentType$deleteCoreV1CollectionNamespacedPodTemplate = keyof Response$deleteCoreV1CollectionNamespacedPodTemplate$Status$200;
interface Params$deleteCoreV1CollectionNamespacedPodTemplate<U extends ResponseContentType$deleteCoreV1CollectionNamespacedPodTemplate> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedPodTemplate;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedPodTemplate["*/*"];
}
type ResponseContentType$readCoreV1NamespacedPodTemplate = keyof Response$readCoreV1NamespacedPodTemplate$Status$200;
interface Params$readCoreV1NamespacedPodTemplate<U extends ResponseContentType$readCoreV1NamespacedPodTemplate> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedPodTemplate;
}
type RequestContentType$replaceCoreV1NamespacedPodTemplate = keyof RequestBody$replaceCoreV1NamespacedPodTemplate;
type ResponseContentType$replaceCoreV1NamespacedPodTemplate = keyof Response$replaceCoreV1NamespacedPodTemplate$Status$200 | keyof Response$replaceCoreV1NamespacedPodTemplate$Status$201;
interface Params$replaceCoreV1NamespacedPodTemplate<U extends ResponseContentType$replaceCoreV1NamespacedPodTemplate> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedPodTemplate;
    requestBody: RequestBody$replaceCoreV1NamespacedPodTemplate["*/*"];
}
type RequestContentType$deleteCoreV1NamespacedPodTemplate = keyof RequestBody$deleteCoreV1NamespacedPodTemplate;
type ResponseContentType$deleteCoreV1NamespacedPodTemplate = keyof Response$deleteCoreV1NamespacedPodTemplate$Status$200 | keyof Response$deleteCoreV1NamespacedPodTemplate$Status$202;
interface Params$deleteCoreV1NamespacedPodTemplate<U extends ResponseContentType$deleteCoreV1NamespacedPodTemplate> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedPodTemplate;
    requestBody: RequestBody$deleteCoreV1NamespacedPodTemplate["*/*"];
}
type RequestContentType$patchCoreV1NamespacedPodTemplate = keyof RequestBody$patchCoreV1NamespacedPodTemplate;
type ResponseContentType$patchCoreV1NamespacedPodTemplate = keyof Response$patchCoreV1NamespacedPodTemplate$Status$200 | keyof Response$patchCoreV1NamespacedPodTemplate$Status$201;
interface Params$patchCoreV1NamespacedPodTemplate<T extends RequestContentType$patchCoreV1NamespacedPodTemplate, U extends ResponseContentType$patchCoreV1NamespacedPodTemplate> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedPodTemplate;
    requestBody: RequestBody$patchCoreV1NamespacedPodTemplate[T];
}
type ResponseContentType$listCoreV1NamespacedReplicationController = keyof Response$listCoreV1NamespacedReplicationController$Status$200;
interface Params$listCoreV1NamespacedReplicationController<U extends ResponseContentType$listCoreV1NamespacedReplicationController> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedReplicationController;
}
type RequestContentType$createCoreV1NamespacedReplicationController = keyof RequestBody$createCoreV1NamespacedReplicationController;
type ResponseContentType$createCoreV1NamespacedReplicationController = keyof Response$createCoreV1NamespacedReplicationController$Status$200 | keyof Response$createCoreV1NamespacedReplicationController$Status$201 | keyof Response$createCoreV1NamespacedReplicationController$Status$202;
interface Params$createCoreV1NamespacedReplicationController<U extends ResponseContentType$createCoreV1NamespacedReplicationController> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedReplicationController;
    requestBody: RequestBody$createCoreV1NamespacedReplicationController["*/*"];
}
type RequestContentType$deleteCoreV1CollectionNamespacedReplicationController = keyof RequestBody$deleteCoreV1CollectionNamespacedReplicationController;
type ResponseContentType$deleteCoreV1CollectionNamespacedReplicationController = keyof Response$deleteCoreV1CollectionNamespacedReplicationController$Status$200;
interface Params$deleteCoreV1CollectionNamespacedReplicationController<U extends ResponseContentType$deleteCoreV1CollectionNamespacedReplicationController> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedReplicationController;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedReplicationController["*/*"];
}
type ResponseContentType$readCoreV1NamespacedReplicationController = keyof Response$readCoreV1NamespacedReplicationController$Status$200;
interface Params$readCoreV1NamespacedReplicationController<U extends ResponseContentType$readCoreV1NamespacedReplicationController> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedReplicationController;
}
type RequestContentType$replaceCoreV1NamespacedReplicationController = keyof RequestBody$replaceCoreV1NamespacedReplicationController;
type ResponseContentType$replaceCoreV1NamespacedReplicationController = keyof Response$replaceCoreV1NamespacedReplicationController$Status$200 | keyof Response$replaceCoreV1NamespacedReplicationController$Status$201;
interface Params$replaceCoreV1NamespacedReplicationController<U extends ResponseContentType$replaceCoreV1NamespacedReplicationController> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedReplicationController;
    requestBody: RequestBody$replaceCoreV1NamespacedReplicationController["*/*"];
}
type RequestContentType$deleteCoreV1NamespacedReplicationController = keyof RequestBody$deleteCoreV1NamespacedReplicationController;
type ResponseContentType$deleteCoreV1NamespacedReplicationController = keyof Response$deleteCoreV1NamespacedReplicationController$Status$200 | keyof Response$deleteCoreV1NamespacedReplicationController$Status$202;
interface Params$deleteCoreV1NamespacedReplicationController<U extends ResponseContentType$deleteCoreV1NamespacedReplicationController> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedReplicationController;
    requestBody: RequestBody$deleteCoreV1NamespacedReplicationController["*/*"];
}
type RequestContentType$patchCoreV1NamespacedReplicationController = keyof RequestBody$patchCoreV1NamespacedReplicationController;
type ResponseContentType$patchCoreV1NamespacedReplicationController = keyof Response$patchCoreV1NamespacedReplicationController$Status$200 | keyof Response$patchCoreV1NamespacedReplicationController$Status$201;
interface Params$patchCoreV1NamespacedReplicationController<T extends RequestContentType$patchCoreV1NamespacedReplicationController, U extends ResponseContentType$patchCoreV1NamespacedReplicationController> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedReplicationController;
    requestBody: RequestBody$patchCoreV1NamespacedReplicationController[T];
}
type ResponseContentType$readCoreV1NamespacedReplicationControllerScale = keyof Response$readCoreV1NamespacedReplicationControllerScale$Status$200;
interface Params$readCoreV1NamespacedReplicationControllerScale<U extends ResponseContentType$readCoreV1NamespacedReplicationControllerScale> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedReplicationControllerScale;
}
type RequestContentType$replaceCoreV1NamespacedReplicationControllerScale = keyof RequestBody$replaceCoreV1NamespacedReplicationControllerScale;
type ResponseContentType$replaceCoreV1NamespacedReplicationControllerScale = keyof Response$replaceCoreV1NamespacedReplicationControllerScale$Status$200 | keyof Response$replaceCoreV1NamespacedReplicationControllerScale$Status$201;
interface Params$replaceCoreV1NamespacedReplicationControllerScale<U extends ResponseContentType$replaceCoreV1NamespacedReplicationControllerScale> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedReplicationControllerScale;
    requestBody: RequestBody$replaceCoreV1NamespacedReplicationControllerScale["*/*"];
}
type RequestContentType$patchCoreV1NamespacedReplicationControllerScale = keyof RequestBody$patchCoreV1NamespacedReplicationControllerScale;
type ResponseContentType$patchCoreV1NamespacedReplicationControllerScale = keyof Response$patchCoreV1NamespacedReplicationControllerScale$Status$200 | keyof Response$patchCoreV1NamespacedReplicationControllerScale$Status$201;
interface Params$patchCoreV1NamespacedReplicationControllerScale<T extends RequestContentType$patchCoreV1NamespacedReplicationControllerScale, U extends ResponseContentType$patchCoreV1NamespacedReplicationControllerScale> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedReplicationControllerScale;
    requestBody: RequestBody$patchCoreV1NamespacedReplicationControllerScale[T];
}
type ResponseContentType$readCoreV1NamespacedReplicationControllerStatus = keyof Response$readCoreV1NamespacedReplicationControllerStatus$Status$200;
interface Params$readCoreV1NamespacedReplicationControllerStatus<U extends ResponseContentType$readCoreV1NamespacedReplicationControllerStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedReplicationControllerStatus;
}
type RequestContentType$replaceCoreV1NamespacedReplicationControllerStatus = keyof RequestBody$replaceCoreV1NamespacedReplicationControllerStatus;
type ResponseContentType$replaceCoreV1NamespacedReplicationControllerStatus = keyof Response$replaceCoreV1NamespacedReplicationControllerStatus$Status$200 | keyof Response$replaceCoreV1NamespacedReplicationControllerStatus$Status$201;
interface Params$replaceCoreV1NamespacedReplicationControllerStatus<U extends ResponseContentType$replaceCoreV1NamespacedReplicationControllerStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedReplicationControllerStatus;
    requestBody: RequestBody$replaceCoreV1NamespacedReplicationControllerStatus["*/*"];
}
type RequestContentType$patchCoreV1NamespacedReplicationControllerStatus = keyof RequestBody$patchCoreV1NamespacedReplicationControllerStatus;
type ResponseContentType$patchCoreV1NamespacedReplicationControllerStatus = keyof Response$patchCoreV1NamespacedReplicationControllerStatus$Status$200 | keyof Response$patchCoreV1NamespacedReplicationControllerStatus$Status$201;
interface Params$patchCoreV1NamespacedReplicationControllerStatus<T extends RequestContentType$patchCoreV1NamespacedReplicationControllerStatus, U extends ResponseContentType$patchCoreV1NamespacedReplicationControllerStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedReplicationControllerStatus;
    requestBody: RequestBody$patchCoreV1NamespacedReplicationControllerStatus[T];
}
type ResponseContentType$listCoreV1NamespacedResourceQuota = keyof Response$listCoreV1NamespacedResourceQuota$Status$200;
interface Params$listCoreV1NamespacedResourceQuota<U extends ResponseContentType$listCoreV1NamespacedResourceQuota> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedResourceQuota;
}
type RequestContentType$createCoreV1NamespacedResourceQuota = keyof RequestBody$createCoreV1NamespacedResourceQuota;
type ResponseContentType$createCoreV1NamespacedResourceQuota = keyof Response$createCoreV1NamespacedResourceQuota$Status$200 | keyof Response$createCoreV1NamespacedResourceQuota$Status$201 | keyof Response$createCoreV1NamespacedResourceQuota$Status$202;
interface Params$createCoreV1NamespacedResourceQuota<U extends ResponseContentType$createCoreV1NamespacedResourceQuota> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedResourceQuota;
    requestBody: RequestBody$createCoreV1NamespacedResourceQuota["*/*"];
}
type RequestContentType$deleteCoreV1CollectionNamespacedResourceQuota = keyof RequestBody$deleteCoreV1CollectionNamespacedResourceQuota;
type ResponseContentType$deleteCoreV1CollectionNamespacedResourceQuota = keyof Response$deleteCoreV1CollectionNamespacedResourceQuota$Status$200;
interface Params$deleteCoreV1CollectionNamespacedResourceQuota<U extends ResponseContentType$deleteCoreV1CollectionNamespacedResourceQuota> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedResourceQuota;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedResourceQuota["*/*"];
}
type ResponseContentType$readCoreV1NamespacedResourceQuota = keyof Response$readCoreV1NamespacedResourceQuota$Status$200;
interface Params$readCoreV1NamespacedResourceQuota<U extends ResponseContentType$readCoreV1NamespacedResourceQuota> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedResourceQuota;
}
type RequestContentType$replaceCoreV1NamespacedResourceQuota = keyof RequestBody$replaceCoreV1NamespacedResourceQuota;
type ResponseContentType$replaceCoreV1NamespacedResourceQuota = keyof Response$replaceCoreV1NamespacedResourceQuota$Status$200 | keyof Response$replaceCoreV1NamespacedResourceQuota$Status$201;
interface Params$replaceCoreV1NamespacedResourceQuota<U extends ResponseContentType$replaceCoreV1NamespacedResourceQuota> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedResourceQuota;
    requestBody: RequestBody$replaceCoreV1NamespacedResourceQuota["*/*"];
}
type RequestContentType$deleteCoreV1NamespacedResourceQuota = keyof RequestBody$deleteCoreV1NamespacedResourceQuota;
type ResponseContentType$deleteCoreV1NamespacedResourceQuota = keyof Response$deleteCoreV1NamespacedResourceQuota$Status$200 | keyof Response$deleteCoreV1NamespacedResourceQuota$Status$202;
interface Params$deleteCoreV1NamespacedResourceQuota<U extends ResponseContentType$deleteCoreV1NamespacedResourceQuota> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedResourceQuota;
    requestBody: RequestBody$deleteCoreV1NamespacedResourceQuota["*/*"];
}
type RequestContentType$patchCoreV1NamespacedResourceQuota = keyof RequestBody$patchCoreV1NamespacedResourceQuota;
type ResponseContentType$patchCoreV1NamespacedResourceQuota = keyof Response$patchCoreV1NamespacedResourceQuota$Status$200 | keyof Response$patchCoreV1NamespacedResourceQuota$Status$201;
interface Params$patchCoreV1NamespacedResourceQuota<T extends RequestContentType$patchCoreV1NamespacedResourceQuota, U extends ResponseContentType$patchCoreV1NamespacedResourceQuota> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedResourceQuota;
    requestBody: RequestBody$patchCoreV1NamespacedResourceQuota[T];
}
type ResponseContentType$readCoreV1NamespacedResourceQuotaStatus = keyof Response$readCoreV1NamespacedResourceQuotaStatus$Status$200;
interface Params$readCoreV1NamespacedResourceQuotaStatus<U extends ResponseContentType$readCoreV1NamespacedResourceQuotaStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedResourceQuotaStatus;
}
type RequestContentType$replaceCoreV1NamespacedResourceQuotaStatus = keyof RequestBody$replaceCoreV1NamespacedResourceQuotaStatus;
type ResponseContentType$replaceCoreV1NamespacedResourceQuotaStatus = keyof Response$replaceCoreV1NamespacedResourceQuotaStatus$Status$200 | keyof Response$replaceCoreV1NamespacedResourceQuotaStatus$Status$201;
interface Params$replaceCoreV1NamespacedResourceQuotaStatus<U extends ResponseContentType$replaceCoreV1NamespacedResourceQuotaStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedResourceQuotaStatus;
    requestBody: RequestBody$replaceCoreV1NamespacedResourceQuotaStatus["*/*"];
}
type RequestContentType$patchCoreV1NamespacedResourceQuotaStatus = keyof RequestBody$patchCoreV1NamespacedResourceQuotaStatus;
type ResponseContentType$patchCoreV1NamespacedResourceQuotaStatus = keyof Response$patchCoreV1NamespacedResourceQuotaStatus$Status$200 | keyof Response$patchCoreV1NamespacedResourceQuotaStatus$Status$201;
interface Params$patchCoreV1NamespacedResourceQuotaStatus<T extends RequestContentType$patchCoreV1NamespacedResourceQuotaStatus, U extends ResponseContentType$patchCoreV1NamespacedResourceQuotaStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedResourceQuotaStatus;
    requestBody: RequestBody$patchCoreV1NamespacedResourceQuotaStatus[T];
}
type ResponseContentType$listCoreV1NamespacedSecret = keyof Response$listCoreV1NamespacedSecret$Status$200;
interface Params$listCoreV1NamespacedSecret<U extends ResponseContentType$listCoreV1NamespacedSecret> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedSecret;
}
type RequestContentType$createCoreV1NamespacedSecret = keyof RequestBody$createCoreV1NamespacedSecret;
type ResponseContentType$createCoreV1NamespacedSecret = keyof Response$createCoreV1NamespacedSecret$Status$200 | keyof Response$createCoreV1NamespacedSecret$Status$201 | keyof Response$createCoreV1NamespacedSecret$Status$202;
interface Params$createCoreV1NamespacedSecret<U extends ResponseContentType$createCoreV1NamespacedSecret> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedSecret;
    requestBody: RequestBody$createCoreV1NamespacedSecret["*/*"];
}
type RequestContentType$deleteCoreV1CollectionNamespacedSecret = keyof RequestBody$deleteCoreV1CollectionNamespacedSecret;
type ResponseContentType$deleteCoreV1CollectionNamespacedSecret = keyof Response$deleteCoreV1CollectionNamespacedSecret$Status$200;
interface Params$deleteCoreV1CollectionNamespacedSecret<U extends ResponseContentType$deleteCoreV1CollectionNamespacedSecret> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedSecret;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedSecret["*/*"];
}
type ResponseContentType$readCoreV1NamespacedSecret = keyof Response$readCoreV1NamespacedSecret$Status$200;
interface Params$readCoreV1NamespacedSecret<U extends ResponseContentType$readCoreV1NamespacedSecret> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedSecret;
}
type RequestContentType$replaceCoreV1NamespacedSecret = keyof RequestBody$replaceCoreV1NamespacedSecret;
type ResponseContentType$replaceCoreV1NamespacedSecret = keyof Response$replaceCoreV1NamespacedSecret$Status$200 | keyof Response$replaceCoreV1NamespacedSecret$Status$201;
interface Params$replaceCoreV1NamespacedSecret<U extends ResponseContentType$replaceCoreV1NamespacedSecret> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedSecret;
    requestBody: RequestBody$replaceCoreV1NamespacedSecret["*/*"];
}
type RequestContentType$deleteCoreV1NamespacedSecret = keyof RequestBody$deleteCoreV1NamespacedSecret;
type ResponseContentType$deleteCoreV1NamespacedSecret = keyof Response$deleteCoreV1NamespacedSecret$Status$200 | keyof Response$deleteCoreV1NamespacedSecret$Status$202;
interface Params$deleteCoreV1NamespacedSecret<U extends ResponseContentType$deleteCoreV1NamespacedSecret> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedSecret;
    requestBody: RequestBody$deleteCoreV1NamespacedSecret["*/*"];
}
type RequestContentType$patchCoreV1NamespacedSecret = keyof RequestBody$patchCoreV1NamespacedSecret;
type ResponseContentType$patchCoreV1NamespacedSecret = keyof Response$patchCoreV1NamespacedSecret$Status$200 | keyof Response$patchCoreV1NamespacedSecret$Status$201;
interface Params$patchCoreV1NamespacedSecret<T extends RequestContentType$patchCoreV1NamespacedSecret, U extends ResponseContentType$patchCoreV1NamespacedSecret> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedSecret;
    requestBody: RequestBody$patchCoreV1NamespacedSecret[T];
}
type ResponseContentType$listCoreV1NamespacedServiceAccount = keyof Response$listCoreV1NamespacedServiceAccount$Status$200;
interface Params$listCoreV1NamespacedServiceAccount<U extends ResponseContentType$listCoreV1NamespacedServiceAccount> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedServiceAccount;
}
type RequestContentType$createCoreV1NamespacedServiceAccount = keyof RequestBody$createCoreV1NamespacedServiceAccount;
type ResponseContentType$createCoreV1NamespacedServiceAccount = keyof Response$createCoreV1NamespacedServiceAccount$Status$200 | keyof Response$createCoreV1NamespacedServiceAccount$Status$201 | keyof Response$createCoreV1NamespacedServiceAccount$Status$202;
interface Params$createCoreV1NamespacedServiceAccount<U extends ResponseContentType$createCoreV1NamespacedServiceAccount> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedServiceAccount;
    requestBody: RequestBody$createCoreV1NamespacedServiceAccount["*/*"];
}
type RequestContentType$deleteCoreV1CollectionNamespacedServiceAccount = keyof RequestBody$deleteCoreV1CollectionNamespacedServiceAccount;
type ResponseContentType$deleteCoreV1CollectionNamespacedServiceAccount = keyof Response$deleteCoreV1CollectionNamespacedServiceAccount$Status$200;
interface Params$deleteCoreV1CollectionNamespacedServiceAccount<U extends ResponseContentType$deleteCoreV1CollectionNamespacedServiceAccount> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedServiceAccount;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedServiceAccount["*/*"];
}
type ResponseContentType$readCoreV1NamespacedServiceAccount = keyof Response$readCoreV1NamespacedServiceAccount$Status$200;
interface Params$readCoreV1NamespacedServiceAccount<U extends ResponseContentType$readCoreV1NamespacedServiceAccount> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedServiceAccount;
}
type RequestContentType$replaceCoreV1NamespacedServiceAccount = keyof RequestBody$replaceCoreV1NamespacedServiceAccount;
type ResponseContentType$replaceCoreV1NamespacedServiceAccount = keyof Response$replaceCoreV1NamespacedServiceAccount$Status$200 | keyof Response$replaceCoreV1NamespacedServiceAccount$Status$201;
interface Params$replaceCoreV1NamespacedServiceAccount<U extends ResponseContentType$replaceCoreV1NamespacedServiceAccount> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedServiceAccount;
    requestBody: RequestBody$replaceCoreV1NamespacedServiceAccount["*/*"];
}
type RequestContentType$deleteCoreV1NamespacedServiceAccount = keyof RequestBody$deleteCoreV1NamespacedServiceAccount;
type ResponseContentType$deleteCoreV1NamespacedServiceAccount = keyof Response$deleteCoreV1NamespacedServiceAccount$Status$200 | keyof Response$deleteCoreV1NamespacedServiceAccount$Status$202;
interface Params$deleteCoreV1NamespacedServiceAccount<U extends ResponseContentType$deleteCoreV1NamespacedServiceAccount> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedServiceAccount;
    requestBody: RequestBody$deleteCoreV1NamespacedServiceAccount["*/*"];
}
type RequestContentType$patchCoreV1NamespacedServiceAccount = keyof RequestBody$patchCoreV1NamespacedServiceAccount;
type ResponseContentType$patchCoreV1NamespacedServiceAccount = keyof Response$patchCoreV1NamespacedServiceAccount$Status$200 | keyof Response$patchCoreV1NamespacedServiceAccount$Status$201;
interface Params$patchCoreV1NamespacedServiceAccount<T extends RequestContentType$patchCoreV1NamespacedServiceAccount, U extends ResponseContentType$patchCoreV1NamespacedServiceAccount> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedServiceAccount;
    requestBody: RequestBody$patchCoreV1NamespacedServiceAccount[T];
}
type RequestContentType$createCoreV1NamespacedServiceAccountToken = keyof RequestBody$createCoreV1NamespacedServiceAccountToken;
type ResponseContentType$createCoreV1NamespacedServiceAccountToken = keyof Response$createCoreV1NamespacedServiceAccountToken$Status$200 | keyof Response$createCoreV1NamespacedServiceAccountToken$Status$201 | keyof Response$createCoreV1NamespacedServiceAccountToken$Status$202;
interface Params$createCoreV1NamespacedServiceAccountToken<U extends ResponseContentType$createCoreV1NamespacedServiceAccountToken> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedServiceAccountToken;
    requestBody: RequestBody$createCoreV1NamespacedServiceAccountToken["*/*"];
}
type ResponseContentType$listCoreV1NamespacedService = keyof Response$listCoreV1NamespacedService$Status$200;
interface Params$listCoreV1NamespacedService<U extends ResponseContentType$listCoreV1NamespacedService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1NamespacedService;
}
type RequestContentType$createCoreV1NamespacedService = keyof RequestBody$createCoreV1NamespacedService;
type ResponseContentType$createCoreV1NamespacedService = keyof Response$createCoreV1NamespacedService$Status$200 | keyof Response$createCoreV1NamespacedService$Status$201 | keyof Response$createCoreV1NamespacedService$Status$202;
interface Params$createCoreV1NamespacedService<U extends ResponseContentType$createCoreV1NamespacedService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1NamespacedService;
    requestBody: RequestBody$createCoreV1NamespacedService["*/*"];
}
type RequestContentType$deleteCoreV1CollectionNamespacedService = keyof RequestBody$deleteCoreV1CollectionNamespacedService;
type ResponseContentType$deleteCoreV1CollectionNamespacedService = keyof Response$deleteCoreV1CollectionNamespacedService$Status$200;
interface Params$deleteCoreV1CollectionNamespacedService<U extends ResponseContentType$deleteCoreV1CollectionNamespacedService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNamespacedService;
    requestBody: RequestBody$deleteCoreV1CollectionNamespacedService["*/*"];
}
type ResponseContentType$readCoreV1NamespacedService = keyof Response$readCoreV1NamespacedService$Status$200;
interface Params$readCoreV1NamespacedService<U extends ResponseContentType$readCoreV1NamespacedService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedService;
}
type RequestContentType$replaceCoreV1NamespacedService = keyof RequestBody$replaceCoreV1NamespacedService;
type ResponseContentType$replaceCoreV1NamespacedService = keyof Response$replaceCoreV1NamespacedService$Status$200 | keyof Response$replaceCoreV1NamespacedService$Status$201;
interface Params$replaceCoreV1NamespacedService<U extends ResponseContentType$replaceCoreV1NamespacedService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedService;
    requestBody: RequestBody$replaceCoreV1NamespacedService["*/*"];
}
type RequestContentType$deleteCoreV1NamespacedService = keyof RequestBody$deleteCoreV1NamespacedService;
type ResponseContentType$deleteCoreV1NamespacedService = keyof Response$deleteCoreV1NamespacedService$Status$200 | keyof Response$deleteCoreV1NamespacedService$Status$202;
interface Params$deleteCoreV1NamespacedService<U extends ResponseContentType$deleteCoreV1NamespacedService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1NamespacedService;
    requestBody: RequestBody$deleteCoreV1NamespacedService["*/*"];
}
type RequestContentType$patchCoreV1NamespacedService = keyof RequestBody$patchCoreV1NamespacedService;
type ResponseContentType$patchCoreV1NamespacedService = keyof Response$patchCoreV1NamespacedService$Status$200 | keyof Response$patchCoreV1NamespacedService$Status$201;
interface Params$patchCoreV1NamespacedService<T extends RequestContentType$patchCoreV1NamespacedService, U extends ResponseContentType$patchCoreV1NamespacedService> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedService;
    requestBody: RequestBody$patchCoreV1NamespacedService[T];
}
type ResponseContentType$connectCoreV1GetNamespacedServiceProxy = keyof Response$connectCoreV1GetNamespacedServiceProxy$Status$200;
interface Params$connectCoreV1GetNamespacedServiceProxy {
    parameter: Parameter$connectCoreV1GetNamespacedServiceProxy;
}
type ResponseContentType$connectCoreV1PutNamespacedServiceProxy = keyof Response$connectCoreV1PutNamespacedServiceProxy$Status$200;
interface Params$connectCoreV1PutNamespacedServiceProxy {
    parameter: Parameter$connectCoreV1PutNamespacedServiceProxy;
}
type ResponseContentType$connectCoreV1PostNamespacedServiceProxy = keyof Response$connectCoreV1PostNamespacedServiceProxy$Status$200;
interface Params$connectCoreV1PostNamespacedServiceProxy {
    parameter: Parameter$connectCoreV1PostNamespacedServiceProxy;
}
type ResponseContentType$connectCoreV1DeleteNamespacedServiceProxy = keyof Response$connectCoreV1DeleteNamespacedServiceProxy$Status$200;
interface Params$connectCoreV1DeleteNamespacedServiceProxy {
    parameter: Parameter$connectCoreV1DeleteNamespacedServiceProxy;
}
type ResponseContentType$connectCoreV1OptionsNamespacedServiceProxy = keyof Response$connectCoreV1OptionsNamespacedServiceProxy$Status$200;
interface Params$connectCoreV1OptionsNamespacedServiceProxy {
    parameter: Parameter$connectCoreV1OptionsNamespacedServiceProxy;
}
type ResponseContentType$connectCoreV1HeadNamespacedServiceProxy = keyof Response$connectCoreV1HeadNamespacedServiceProxy$Status$200;
interface Params$connectCoreV1HeadNamespacedServiceProxy {
    parameter: Parameter$connectCoreV1HeadNamespacedServiceProxy;
}
type ResponseContentType$connectCoreV1PatchNamespacedServiceProxy = keyof Response$connectCoreV1PatchNamespacedServiceProxy$Status$200;
interface Params$connectCoreV1PatchNamespacedServiceProxy {
    parameter: Parameter$connectCoreV1PatchNamespacedServiceProxy;
}
type ResponseContentType$connectCoreV1GetNamespacedServiceProxyWithPath = keyof Response$connectCoreV1GetNamespacedServiceProxyWithPath$Status$200;
interface Params$connectCoreV1GetNamespacedServiceProxyWithPath {
    parameter: Parameter$connectCoreV1GetNamespacedServiceProxyWithPath;
}
type ResponseContentType$connectCoreV1PutNamespacedServiceProxyWithPath = keyof Response$connectCoreV1PutNamespacedServiceProxyWithPath$Status$200;
interface Params$connectCoreV1PutNamespacedServiceProxyWithPath {
    parameter: Parameter$connectCoreV1PutNamespacedServiceProxyWithPath;
}
type ResponseContentType$connectCoreV1PostNamespacedServiceProxyWithPath = keyof Response$connectCoreV1PostNamespacedServiceProxyWithPath$Status$200;
interface Params$connectCoreV1PostNamespacedServiceProxyWithPath {
    parameter: Parameter$connectCoreV1PostNamespacedServiceProxyWithPath;
}
type ResponseContentType$connectCoreV1DeleteNamespacedServiceProxyWithPath = keyof Response$connectCoreV1DeleteNamespacedServiceProxyWithPath$Status$200;
interface Params$connectCoreV1DeleteNamespacedServiceProxyWithPath {
    parameter: Parameter$connectCoreV1DeleteNamespacedServiceProxyWithPath;
}
type ResponseContentType$connectCoreV1OptionsNamespacedServiceProxyWithPath = keyof Response$connectCoreV1OptionsNamespacedServiceProxyWithPath$Status$200;
interface Params$connectCoreV1OptionsNamespacedServiceProxyWithPath {
    parameter: Parameter$connectCoreV1OptionsNamespacedServiceProxyWithPath;
}
type ResponseContentType$connectCoreV1HeadNamespacedServiceProxyWithPath = keyof Response$connectCoreV1HeadNamespacedServiceProxyWithPath$Status$200;
interface Params$connectCoreV1HeadNamespacedServiceProxyWithPath {
    parameter: Parameter$connectCoreV1HeadNamespacedServiceProxyWithPath;
}
type ResponseContentType$connectCoreV1PatchNamespacedServiceProxyWithPath = keyof Response$connectCoreV1PatchNamespacedServiceProxyWithPath$Status$200;
interface Params$connectCoreV1PatchNamespacedServiceProxyWithPath {
    parameter: Parameter$connectCoreV1PatchNamespacedServiceProxyWithPath;
}
type ResponseContentType$readCoreV1NamespacedServiceStatus = keyof Response$readCoreV1NamespacedServiceStatus$Status$200;
interface Params$readCoreV1NamespacedServiceStatus<U extends ResponseContentType$readCoreV1NamespacedServiceStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespacedServiceStatus;
}
type RequestContentType$replaceCoreV1NamespacedServiceStatus = keyof RequestBody$replaceCoreV1NamespacedServiceStatus;
type ResponseContentType$replaceCoreV1NamespacedServiceStatus = keyof Response$replaceCoreV1NamespacedServiceStatus$Status$200 | keyof Response$replaceCoreV1NamespacedServiceStatus$Status$201;
interface Params$replaceCoreV1NamespacedServiceStatus<U extends ResponseContentType$replaceCoreV1NamespacedServiceStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespacedServiceStatus;
    requestBody: RequestBody$replaceCoreV1NamespacedServiceStatus["*/*"];
}
type RequestContentType$patchCoreV1NamespacedServiceStatus = keyof RequestBody$patchCoreV1NamespacedServiceStatus;
type ResponseContentType$patchCoreV1NamespacedServiceStatus = keyof Response$patchCoreV1NamespacedServiceStatus$Status$200 | keyof Response$patchCoreV1NamespacedServiceStatus$Status$201;
interface Params$patchCoreV1NamespacedServiceStatus<T extends RequestContentType$patchCoreV1NamespacedServiceStatus, U extends ResponseContentType$patchCoreV1NamespacedServiceStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespacedServiceStatus;
    requestBody: RequestBody$patchCoreV1NamespacedServiceStatus[T];
}
type ResponseContentType$readCoreV1Namespace = keyof Response$readCoreV1Namespace$Status$200;
interface Params$readCoreV1Namespace<U extends ResponseContentType$readCoreV1Namespace> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1Namespace;
}
type RequestContentType$replaceCoreV1Namespace = keyof RequestBody$replaceCoreV1Namespace;
type ResponseContentType$replaceCoreV1Namespace = keyof Response$replaceCoreV1Namespace$Status$200 | keyof Response$replaceCoreV1Namespace$Status$201;
interface Params$replaceCoreV1Namespace<U extends ResponseContentType$replaceCoreV1Namespace> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1Namespace;
    requestBody: RequestBody$replaceCoreV1Namespace["*/*"];
}
type RequestContentType$deleteCoreV1Namespace = keyof RequestBody$deleteCoreV1Namespace;
type ResponseContentType$deleteCoreV1Namespace = keyof Response$deleteCoreV1Namespace$Status$200 | keyof Response$deleteCoreV1Namespace$Status$202;
interface Params$deleteCoreV1Namespace<U extends ResponseContentType$deleteCoreV1Namespace> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1Namespace;
    requestBody: RequestBody$deleteCoreV1Namespace["*/*"];
}
type RequestContentType$patchCoreV1Namespace = keyof RequestBody$patchCoreV1Namespace;
type ResponseContentType$patchCoreV1Namespace = keyof Response$patchCoreV1Namespace$Status$200 | keyof Response$patchCoreV1Namespace$Status$201;
interface Params$patchCoreV1Namespace<T extends RequestContentType$patchCoreV1Namespace, U extends ResponseContentType$patchCoreV1Namespace> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1Namespace;
    requestBody: RequestBody$patchCoreV1Namespace[T];
}
type RequestContentType$replaceCoreV1NamespaceFinalize = keyof RequestBody$replaceCoreV1NamespaceFinalize;
type ResponseContentType$replaceCoreV1NamespaceFinalize = keyof Response$replaceCoreV1NamespaceFinalize$Status$200 | keyof Response$replaceCoreV1NamespaceFinalize$Status$201;
interface Params$replaceCoreV1NamespaceFinalize<U extends ResponseContentType$replaceCoreV1NamespaceFinalize> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespaceFinalize;
    requestBody: RequestBody$replaceCoreV1NamespaceFinalize["*/*"];
}
type ResponseContentType$readCoreV1NamespaceStatus = keyof Response$readCoreV1NamespaceStatus$Status$200;
interface Params$readCoreV1NamespaceStatus<U extends ResponseContentType$readCoreV1NamespaceStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NamespaceStatus;
}
type RequestContentType$replaceCoreV1NamespaceStatus = keyof RequestBody$replaceCoreV1NamespaceStatus;
type ResponseContentType$replaceCoreV1NamespaceStatus = keyof Response$replaceCoreV1NamespaceStatus$Status$200 | keyof Response$replaceCoreV1NamespaceStatus$Status$201;
interface Params$replaceCoreV1NamespaceStatus<U extends ResponseContentType$replaceCoreV1NamespaceStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NamespaceStatus;
    requestBody: RequestBody$replaceCoreV1NamespaceStatus["*/*"];
}
type RequestContentType$patchCoreV1NamespaceStatus = keyof RequestBody$patchCoreV1NamespaceStatus;
type ResponseContentType$patchCoreV1NamespaceStatus = keyof Response$patchCoreV1NamespaceStatus$Status$200 | keyof Response$patchCoreV1NamespaceStatus$Status$201;
interface Params$patchCoreV1NamespaceStatus<T extends RequestContentType$patchCoreV1NamespaceStatus, U extends ResponseContentType$patchCoreV1NamespaceStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NamespaceStatus;
    requestBody: RequestBody$patchCoreV1NamespaceStatus[T];
}
type ResponseContentType$listCoreV1Node = keyof Response$listCoreV1Node$Status$200;
interface Params$listCoreV1Node<U extends ResponseContentType$listCoreV1Node> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1Node;
}
type RequestContentType$createCoreV1Node = keyof RequestBody$createCoreV1Node;
type ResponseContentType$createCoreV1Node = keyof Response$createCoreV1Node$Status$200 | keyof Response$createCoreV1Node$Status$201 | keyof Response$createCoreV1Node$Status$202;
interface Params$createCoreV1Node<U extends ResponseContentType$createCoreV1Node> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1Node;
    requestBody: RequestBody$createCoreV1Node["*/*"];
}
type RequestContentType$deleteCoreV1CollectionNode = keyof RequestBody$deleteCoreV1CollectionNode;
type ResponseContentType$deleteCoreV1CollectionNode = keyof Response$deleteCoreV1CollectionNode$Status$200;
interface Params$deleteCoreV1CollectionNode<U extends ResponseContentType$deleteCoreV1CollectionNode> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionNode;
    requestBody: RequestBody$deleteCoreV1CollectionNode["*/*"];
}
type ResponseContentType$readCoreV1Node = keyof Response$readCoreV1Node$Status$200;
interface Params$readCoreV1Node<U extends ResponseContentType$readCoreV1Node> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1Node;
}
type RequestContentType$replaceCoreV1Node = keyof RequestBody$replaceCoreV1Node;
type ResponseContentType$replaceCoreV1Node = keyof Response$replaceCoreV1Node$Status$200 | keyof Response$replaceCoreV1Node$Status$201;
interface Params$replaceCoreV1Node<U extends ResponseContentType$replaceCoreV1Node> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1Node;
    requestBody: RequestBody$replaceCoreV1Node["*/*"];
}
type RequestContentType$deleteCoreV1Node = keyof RequestBody$deleteCoreV1Node;
type ResponseContentType$deleteCoreV1Node = keyof Response$deleteCoreV1Node$Status$200 | keyof Response$deleteCoreV1Node$Status$202;
interface Params$deleteCoreV1Node<U extends ResponseContentType$deleteCoreV1Node> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1Node;
    requestBody: RequestBody$deleteCoreV1Node["*/*"];
}
type RequestContentType$patchCoreV1Node = keyof RequestBody$patchCoreV1Node;
type ResponseContentType$patchCoreV1Node = keyof Response$patchCoreV1Node$Status$200 | keyof Response$patchCoreV1Node$Status$201;
interface Params$patchCoreV1Node<T extends RequestContentType$patchCoreV1Node, U extends ResponseContentType$patchCoreV1Node> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1Node;
    requestBody: RequestBody$patchCoreV1Node[T];
}
type ResponseContentType$connectCoreV1GetNodeProxy = keyof Response$connectCoreV1GetNodeProxy$Status$200;
interface Params$connectCoreV1GetNodeProxy {
    parameter: Parameter$connectCoreV1GetNodeProxy;
}
type ResponseContentType$connectCoreV1PutNodeProxy = keyof Response$connectCoreV1PutNodeProxy$Status$200;
interface Params$connectCoreV1PutNodeProxy {
    parameter: Parameter$connectCoreV1PutNodeProxy;
}
type ResponseContentType$connectCoreV1PostNodeProxy = keyof Response$connectCoreV1PostNodeProxy$Status$200;
interface Params$connectCoreV1PostNodeProxy {
    parameter: Parameter$connectCoreV1PostNodeProxy;
}
type ResponseContentType$connectCoreV1DeleteNodeProxy = keyof Response$connectCoreV1DeleteNodeProxy$Status$200;
interface Params$connectCoreV1DeleteNodeProxy {
    parameter: Parameter$connectCoreV1DeleteNodeProxy;
}
type ResponseContentType$connectCoreV1OptionsNodeProxy = keyof Response$connectCoreV1OptionsNodeProxy$Status$200;
interface Params$connectCoreV1OptionsNodeProxy {
    parameter: Parameter$connectCoreV1OptionsNodeProxy;
}
type ResponseContentType$connectCoreV1HeadNodeProxy = keyof Response$connectCoreV1HeadNodeProxy$Status$200;
interface Params$connectCoreV1HeadNodeProxy {
    parameter: Parameter$connectCoreV1HeadNodeProxy;
}
type ResponseContentType$connectCoreV1PatchNodeProxy = keyof Response$connectCoreV1PatchNodeProxy$Status$200;
interface Params$connectCoreV1PatchNodeProxy {
    parameter: Parameter$connectCoreV1PatchNodeProxy;
}
type ResponseContentType$connectCoreV1GetNodeProxyWithPath = keyof Response$connectCoreV1GetNodeProxyWithPath$Status$200;
interface Params$connectCoreV1GetNodeProxyWithPath {
    parameter: Parameter$connectCoreV1GetNodeProxyWithPath;
}
type ResponseContentType$connectCoreV1PutNodeProxyWithPath = keyof Response$connectCoreV1PutNodeProxyWithPath$Status$200;
interface Params$connectCoreV1PutNodeProxyWithPath {
    parameter: Parameter$connectCoreV1PutNodeProxyWithPath;
}
type ResponseContentType$connectCoreV1PostNodeProxyWithPath = keyof Response$connectCoreV1PostNodeProxyWithPath$Status$200;
interface Params$connectCoreV1PostNodeProxyWithPath {
    parameter: Parameter$connectCoreV1PostNodeProxyWithPath;
}
type ResponseContentType$connectCoreV1DeleteNodeProxyWithPath = keyof Response$connectCoreV1DeleteNodeProxyWithPath$Status$200;
interface Params$connectCoreV1DeleteNodeProxyWithPath {
    parameter: Parameter$connectCoreV1DeleteNodeProxyWithPath;
}
type ResponseContentType$connectCoreV1OptionsNodeProxyWithPath = keyof Response$connectCoreV1OptionsNodeProxyWithPath$Status$200;
interface Params$connectCoreV1OptionsNodeProxyWithPath {
    parameter: Parameter$connectCoreV1OptionsNodeProxyWithPath;
}
type ResponseContentType$connectCoreV1HeadNodeProxyWithPath = keyof Response$connectCoreV1HeadNodeProxyWithPath$Status$200;
interface Params$connectCoreV1HeadNodeProxyWithPath {
    parameter: Parameter$connectCoreV1HeadNodeProxyWithPath;
}
type ResponseContentType$connectCoreV1PatchNodeProxyWithPath = keyof Response$connectCoreV1PatchNodeProxyWithPath$Status$200;
interface Params$connectCoreV1PatchNodeProxyWithPath {
    parameter: Parameter$connectCoreV1PatchNodeProxyWithPath;
}
type ResponseContentType$readCoreV1NodeStatus = keyof Response$readCoreV1NodeStatus$Status$200;
interface Params$readCoreV1NodeStatus<U extends ResponseContentType$readCoreV1NodeStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1NodeStatus;
}
type RequestContentType$replaceCoreV1NodeStatus = keyof RequestBody$replaceCoreV1NodeStatus;
type ResponseContentType$replaceCoreV1NodeStatus = keyof Response$replaceCoreV1NodeStatus$Status$200 | keyof Response$replaceCoreV1NodeStatus$Status$201;
interface Params$replaceCoreV1NodeStatus<U extends ResponseContentType$replaceCoreV1NodeStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1NodeStatus;
    requestBody: RequestBody$replaceCoreV1NodeStatus["*/*"];
}
type RequestContentType$patchCoreV1NodeStatus = keyof RequestBody$patchCoreV1NodeStatus;
type ResponseContentType$patchCoreV1NodeStatus = keyof Response$patchCoreV1NodeStatus$Status$200 | keyof Response$patchCoreV1NodeStatus$Status$201;
interface Params$patchCoreV1NodeStatus<T extends RequestContentType$patchCoreV1NodeStatus, U extends ResponseContentType$patchCoreV1NodeStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1NodeStatus;
    requestBody: RequestBody$patchCoreV1NodeStatus[T];
}
type ResponseContentType$listCoreV1PersistentVolumeClaimForAllNamespaces = keyof Response$listCoreV1PersistentVolumeClaimForAllNamespaces$Status$200;
interface Params$listCoreV1PersistentVolumeClaimForAllNamespaces<U extends ResponseContentType$listCoreV1PersistentVolumeClaimForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1PersistentVolumeClaimForAllNamespaces;
}
type ResponseContentType$listCoreV1PersistentVolume = keyof Response$listCoreV1PersistentVolume$Status$200;
interface Params$listCoreV1PersistentVolume<U extends ResponseContentType$listCoreV1PersistentVolume> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1PersistentVolume;
}
type RequestContentType$createCoreV1PersistentVolume = keyof RequestBody$createCoreV1PersistentVolume;
type ResponseContentType$createCoreV1PersistentVolume = keyof Response$createCoreV1PersistentVolume$Status$200 | keyof Response$createCoreV1PersistentVolume$Status$201 | keyof Response$createCoreV1PersistentVolume$Status$202;
interface Params$createCoreV1PersistentVolume<U extends ResponseContentType$createCoreV1PersistentVolume> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoreV1PersistentVolume;
    requestBody: RequestBody$createCoreV1PersistentVolume["*/*"];
}
type RequestContentType$deleteCoreV1CollectionPersistentVolume = keyof RequestBody$deleteCoreV1CollectionPersistentVolume;
type ResponseContentType$deleteCoreV1CollectionPersistentVolume = keyof Response$deleteCoreV1CollectionPersistentVolume$Status$200;
interface Params$deleteCoreV1CollectionPersistentVolume<U extends ResponseContentType$deleteCoreV1CollectionPersistentVolume> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1CollectionPersistentVolume;
    requestBody: RequestBody$deleteCoreV1CollectionPersistentVolume["*/*"];
}
type ResponseContentType$readCoreV1PersistentVolume = keyof Response$readCoreV1PersistentVolume$Status$200;
interface Params$readCoreV1PersistentVolume<U extends ResponseContentType$readCoreV1PersistentVolume> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1PersistentVolume;
}
type RequestContentType$replaceCoreV1PersistentVolume = keyof RequestBody$replaceCoreV1PersistentVolume;
type ResponseContentType$replaceCoreV1PersistentVolume = keyof Response$replaceCoreV1PersistentVolume$Status$200 | keyof Response$replaceCoreV1PersistentVolume$Status$201;
interface Params$replaceCoreV1PersistentVolume<U extends ResponseContentType$replaceCoreV1PersistentVolume> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1PersistentVolume;
    requestBody: RequestBody$replaceCoreV1PersistentVolume["*/*"];
}
type RequestContentType$deleteCoreV1PersistentVolume = keyof RequestBody$deleteCoreV1PersistentVolume;
type ResponseContentType$deleteCoreV1PersistentVolume = keyof Response$deleteCoreV1PersistentVolume$Status$200 | keyof Response$deleteCoreV1PersistentVolume$Status$202;
interface Params$deleteCoreV1PersistentVolume<U extends ResponseContentType$deleteCoreV1PersistentVolume> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoreV1PersistentVolume;
    requestBody: RequestBody$deleteCoreV1PersistentVolume["*/*"];
}
type RequestContentType$patchCoreV1PersistentVolume = keyof RequestBody$patchCoreV1PersistentVolume;
type ResponseContentType$patchCoreV1PersistentVolume = keyof Response$patchCoreV1PersistentVolume$Status$200 | keyof Response$patchCoreV1PersistentVolume$Status$201;
interface Params$patchCoreV1PersistentVolume<T extends RequestContentType$patchCoreV1PersistentVolume, U extends ResponseContentType$patchCoreV1PersistentVolume> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1PersistentVolume;
    requestBody: RequestBody$patchCoreV1PersistentVolume[T];
}
type ResponseContentType$readCoreV1PersistentVolumeStatus = keyof Response$readCoreV1PersistentVolumeStatus$Status$200;
interface Params$readCoreV1PersistentVolumeStatus<U extends ResponseContentType$readCoreV1PersistentVolumeStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoreV1PersistentVolumeStatus;
}
type RequestContentType$replaceCoreV1PersistentVolumeStatus = keyof RequestBody$replaceCoreV1PersistentVolumeStatus;
type ResponseContentType$replaceCoreV1PersistentVolumeStatus = keyof Response$replaceCoreV1PersistentVolumeStatus$Status$200 | keyof Response$replaceCoreV1PersistentVolumeStatus$Status$201;
interface Params$replaceCoreV1PersistentVolumeStatus<U extends ResponseContentType$replaceCoreV1PersistentVolumeStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoreV1PersistentVolumeStatus;
    requestBody: RequestBody$replaceCoreV1PersistentVolumeStatus["*/*"];
}
type RequestContentType$patchCoreV1PersistentVolumeStatus = keyof RequestBody$patchCoreV1PersistentVolumeStatus;
type ResponseContentType$patchCoreV1PersistentVolumeStatus = keyof Response$patchCoreV1PersistentVolumeStatus$Status$200 | keyof Response$patchCoreV1PersistentVolumeStatus$Status$201;
interface Params$patchCoreV1PersistentVolumeStatus<T extends RequestContentType$patchCoreV1PersistentVolumeStatus, U extends ResponseContentType$patchCoreV1PersistentVolumeStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoreV1PersistentVolumeStatus;
    requestBody: RequestBody$patchCoreV1PersistentVolumeStatus[T];
}
type ResponseContentType$listCoreV1PodForAllNamespaces = keyof Response$listCoreV1PodForAllNamespaces$Status$200;
interface Params$listCoreV1PodForAllNamespaces<U extends ResponseContentType$listCoreV1PodForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1PodForAllNamespaces;
}
type ResponseContentType$listCoreV1PodTemplateForAllNamespaces = keyof Response$listCoreV1PodTemplateForAllNamespaces$Status$200;
interface Params$listCoreV1PodTemplateForAllNamespaces<U extends ResponseContentType$listCoreV1PodTemplateForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1PodTemplateForAllNamespaces;
}
type ResponseContentType$listCoreV1ReplicationControllerForAllNamespaces = keyof Response$listCoreV1ReplicationControllerForAllNamespaces$Status$200;
interface Params$listCoreV1ReplicationControllerForAllNamespaces<U extends ResponseContentType$listCoreV1ReplicationControllerForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1ReplicationControllerForAllNamespaces;
}
type ResponseContentType$listCoreV1ResourceQuotaForAllNamespaces = keyof Response$listCoreV1ResourceQuotaForAllNamespaces$Status$200;
interface Params$listCoreV1ResourceQuotaForAllNamespaces<U extends ResponseContentType$listCoreV1ResourceQuotaForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1ResourceQuotaForAllNamespaces;
}
type ResponseContentType$listCoreV1SecretForAllNamespaces = keyof Response$listCoreV1SecretForAllNamespaces$Status$200;
interface Params$listCoreV1SecretForAllNamespaces<U extends ResponseContentType$listCoreV1SecretForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1SecretForAllNamespaces;
}
type ResponseContentType$listCoreV1ServiceAccountForAllNamespaces = keyof Response$listCoreV1ServiceAccountForAllNamespaces$Status$200;
interface Params$listCoreV1ServiceAccountForAllNamespaces<U extends ResponseContentType$listCoreV1ServiceAccountForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1ServiceAccountForAllNamespaces;
}
type ResponseContentType$listCoreV1ServiceForAllNamespaces = keyof Response$listCoreV1ServiceForAllNamespaces$Status$200;
interface Params$listCoreV1ServiceForAllNamespaces<U extends ResponseContentType$listCoreV1ServiceForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoreV1ServiceForAllNamespaces;
}
type ResponseContentType$watchCoreV1ConfigMapListForAllNamespaces = keyof Response$watchCoreV1ConfigMapListForAllNamespaces$Status$200;
interface Params$watchCoreV1ConfigMapListForAllNamespaces<U extends ResponseContentType$watchCoreV1ConfigMapListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1ConfigMapListForAllNamespaces;
}
type ResponseContentType$watchCoreV1EndpointsListForAllNamespaces = keyof Response$watchCoreV1EndpointsListForAllNamespaces$Status$200;
interface Params$watchCoreV1EndpointsListForAllNamespaces<U extends ResponseContentType$watchCoreV1EndpointsListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1EndpointsListForAllNamespaces;
}
type ResponseContentType$watchCoreV1EventListForAllNamespaces = keyof Response$watchCoreV1EventListForAllNamespaces$Status$200;
interface Params$watchCoreV1EventListForAllNamespaces<U extends ResponseContentType$watchCoreV1EventListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1EventListForAllNamespaces;
}
type ResponseContentType$watchCoreV1LimitRangeListForAllNamespaces = keyof Response$watchCoreV1LimitRangeListForAllNamespaces$Status$200;
interface Params$watchCoreV1LimitRangeListForAllNamespaces<U extends ResponseContentType$watchCoreV1LimitRangeListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1LimitRangeListForAllNamespaces;
}
type ResponseContentType$watchCoreV1NamespaceList = keyof Response$watchCoreV1NamespaceList$Status$200;
interface Params$watchCoreV1NamespaceList<U extends ResponseContentType$watchCoreV1NamespaceList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespaceList;
}
type ResponseContentType$watchCoreV1NamespacedConfigMapList = keyof Response$watchCoreV1NamespacedConfigMapList$Status$200;
interface Params$watchCoreV1NamespacedConfigMapList<U extends ResponseContentType$watchCoreV1NamespacedConfigMapList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedConfigMapList;
}
type ResponseContentType$watchCoreV1NamespacedConfigMap = keyof Response$watchCoreV1NamespacedConfigMap$Status$200;
interface Params$watchCoreV1NamespacedConfigMap<U extends ResponseContentType$watchCoreV1NamespacedConfigMap> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedConfigMap;
}
type ResponseContentType$watchCoreV1NamespacedEndpointsList = keyof Response$watchCoreV1NamespacedEndpointsList$Status$200;
interface Params$watchCoreV1NamespacedEndpointsList<U extends ResponseContentType$watchCoreV1NamespacedEndpointsList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedEndpointsList;
}
type ResponseContentType$watchCoreV1NamespacedEndpoints = keyof Response$watchCoreV1NamespacedEndpoints$Status$200;
interface Params$watchCoreV1NamespacedEndpoints<U extends ResponseContentType$watchCoreV1NamespacedEndpoints> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedEndpoints;
}
type ResponseContentType$watchCoreV1NamespacedEventList = keyof Response$watchCoreV1NamespacedEventList$Status$200;
interface Params$watchCoreV1NamespacedEventList<U extends ResponseContentType$watchCoreV1NamespacedEventList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedEventList;
}
type ResponseContentType$watchCoreV1NamespacedEvent = keyof Response$watchCoreV1NamespacedEvent$Status$200;
interface Params$watchCoreV1NamespacedEvent<U extends ResponseContentType$watchCoreV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedEvent;
}
type ResponseContentType$watchCoreV1NamespacedLimitRangeList = keyof Response$watchCoreV1NamespacedLimitRangeList$Status$200;
interface Params$watchCoreV1NamespacedLimitRangeList<U extends ResponseContentType$watchCoreV1NamespacedLimitRangeList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedLimitRangeList;
}
type ResponseContentType$watchCoreV1NamespacedLimitRange = keyof Response$watchCoreV1NamespacedLimitRange$Status$200;
interface Params$watchCoreV1NamespacedLimitRange<U extends ResponseContentType$watchCoreV1NamespacedLimitRange> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedLimitRange;
}
type ResponseContentType$watchCoreV1NamespacedPersistentVolumeClaimList = keyof Response$watchCoreV1NamespacedPersistentVolumeClaimList$Status$200;
interface Params$watchCoreV1NamespacedPersistentVolumeClaimList<U extends ResponseContentType$watchCoreV1NamespacedPersistentVolumeClaimList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedPersistentVolumeClaimList;
}
type ResponseContentType$watchCoreV1NamespacedPersistentVolumeClaim = keyof Response$watchCoreV1NamespacedPersistentVolumeClaim$Status$200;
interface Params$watchCoreV1NamespacedPersistentVolumeClaim<U extends ResponseContentType$watchCoreV1NamespacedPersistentVolumeClaim> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedPersistentVolumeClaim;
}
type ResponseContentType$watchCoreV1NamespacedPodList = keyof Response$watchCoreV1NamespacedPodList$Status$200;
interface Params$watchCoreV1NamespacedPodList<U extends ResponseContentType$watchCoreV1NamespacedPodList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedPodList;
}
type ResponseContentType$watchCoreV1NamespacedPod = keyof Response$watchCoreV1NamespacedPod$Status$200;
interface Params$watchCoreV1NamespacedPod<U extends ResponseContentType$watchCoreV1NamespacedPod> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedPod;
}
type ResponseContentType$watchCoreV1NamespacedPodTemplateList = keyof Response$watchCoreV1NamespacedPodTemplateList$Status$200;
interface Params$watchCoreV1NamespacedPodTemplateList<U extends ResponseContentType$watchCoreV1NamespacedPodTemplateList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedPodTemplateList;
}
type ResponseContentType$watchCoreV1NamespacedPodTemplate = keyof Response$watchCoreV1NamespacedPodTemplate$Status$200;
interface Params$watchCoreV1NamespacedPodTemplate<U extends ResponseContentType$watchCoreV1NamespacedPodTemplate> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedPodTemplate;
}
type ResponseContentType$watchCoreV1NamespacedReplicationControllerList = keyof Response$watchCoreV1NamespacedReplicationControllerList$Status$200;
interface Params$watchCoreV1NamespacedReplicationControllerList<U extends ResponseContentType$watchCoreV1NamespacedReplicationControllerList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedReplicationControllerList;
}
type ResponseContentType$watchCoreV1NamespacedReplicationController = keyof Response$watchCoreV1NamespacedReplicationController$Status$200;
interface Params$watchCoreV1NamespacedReplicationController<U extends ResponseContentType$watchCoreV1NamespacedReplicationController> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedReplicationController;
}
type ResponseContentType$watchCoreV1NamespacedResourceQuotaList = keyof Response$watchCoreV1NamespacedResourceQuotaList$Status$200;
interface Params$watchCoreV1NamespacedResourceQuotaList<U extends ResponseContentType$watchCoreV1NamespacedResourceQuotaList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedResourceQuotaList;
}
type ResponseContentType$watchCoreV1NamespacedResourceQuota = keyof Response$watchCoreV1NamespacedResourceQuota$Status$200;
interface Params$watchCoreV1NamespacedResourceQuota<U extends ResponseContentType$watchCoreV1NamespacedResourceQuota> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedResourceQuota;
}
type ResponseContentType$watchCoreV1NamespacedSecretList = keyof Response$watchCoreV1NamespacedSecretList$Status$200;
interface Params$watchCoreV1NamespacedSecretList<U extends ResponseContentType$watchCoreV1NamespacedSecretList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedSecretList;
}
type ResponseContentType$watchCoreV1NamespacedSecret = keyof Response$watchCoreV1NamespacedSecret$Status$200;
interface Params$watchCoreV1NamespacedSecret<U extends ResponseContentType$watchCoreV1NamespacedSecret> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedSecret;
}
type ResponseContentType$watchCoreV1NamespacedServiceAccountList = keyof Response$watchCoreV1NamespacedServiceAccountList$Status$200;
interface Params$watchCoreV1NamespacedServiceAccountList<U extends ResponseContentType$watchCoreV1NamespacedServiceAccountList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedServiceAccountList;
}
type ResponseContentType$watchCoreV1NamespacedServiceAccount = keyof Response$watchCoreV1NamespacedServiceAccount$Status$200;
interface Params$watchCoreV1NamespacedServiceAccount<U extends ResponseContentType$watchCoreV1NamespacedServiceAccount> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedServiceAccount;
}
type ResponseContentType$watchCoreV1NamespacedServiceList = keyof Response$watchCoreV1NamespacedServiceList$Status$200;
interface Params$watchCoreV1NamespacedServiceList<U extends ResponseContentType$watchCoreV1NamespacedServiceList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedServiceList;
}
type ResponseContentType$watchCoreV1NamespacedService = keyof Response$watchCoreV1NamespacedService$Status$200;
interface Params$watchCoreV1NamespacedService<U extends ResponseContentType$watchCoreV1NamespacedService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NamespacedService;
}
type ResponseContentType$watchCoreV1Namespace = keyof Response$watchCoreV1Namespace$Status$200;
interface Params$watchCoreV1Namespace<U extends ResponseContentType$watchCoreV1Namespace> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1Namespace;
}
type ResponseContentType$watchCoreV1NodeList = keyof Response$watchCoreV1NodeList$Status$200;
interface Params$watchCoreV1NodeList<U extends ResponseContentType$watchCoreV1NodeList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1NodeList;
}
type ResponseContentType$watchCoreV1Node = keyof Response$watchCoreV1Node$Status$200;
interface Params$watchCoreV1Node<U extends ResponseContentType$watchCoreV1Node> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1Node;
}
type ResponseContentType$watchCoreV1PersistentVolumeClaimListForAllNamespaces = keyof Response$watchCoreV1PersistentVolumeClaimListForAllNamespaces$Status$200;
interface Params$watchCoreV1PersistentVolumeClaimListForAllNamespaces<U extends ResponseContentType$watchCoreV1PersistentVolumeClaimListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1PersistentVolumeClaimListForAllNamespaces;
}
type ResponseContentType$watchCoreV1PersistentVolumeList = keyof Response$watchCoreV1PersistentVolumeList$Status$200;
interface Params$watchCoreV1PersistentVolumeList<U extends ResponseContentType$watchCoreV1PersistentVolumeList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1PersistentVolumeList;
}
type ResponseContentType$watchCoreV1PersistentVolume = keyof Response$watchCoreV1PersistentVolume$Status$200;
interface Params$watchCoreV1PersistentVolume<U extends ResponseContentType$watchCoreV1PersistentVolume> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1PersistentVolume;
}
type ResponseContentType$watchCoreV1PodListForAllNamespaces = keyof Response$watchCoreV1PodListForAllNamespaces$Status$200;
interface Params$watchCoreV1PodListForAllNamespaces<U extends ResponseContentType$watchCoreV1PodListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1PodListForAllNamespaces;
}
type ResponseContentType$watchCoreV1PodTemplateListForAllNamespaces = keyof Response$watchCoreV1PodTemplateListForAllNamespaces$Status$200;
interface Params$watchCoreV1PodTemplateListForAllNamespaces<U extends ResponseContentType$watchCoreV1PodTemplateListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1PodTemplateListForAllNamespaces;
}
type ResponseContentType$watchCoreV1ReplicationControllerListForAllNamespaces = keyof Response$watchCoreV1ReplicationControllerListForAllNamespaces$Status$200;
interface Params$watchCoreV1ReplicationControllerListForAllNamespaces<U extends ResponseContentType$watchCoreV1ReplicationControllerListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1ReplicationControllerListForAllNamespaces;
}
type ResponseContentType$watchCoreV1ResourceQuotaListForAllNamespaces = keyof Response$watchCoreV1ResourceQuotaListForAllNamespaces$Status$200;
interface Params$watchCoreV1ResourceQuotaListForAllNamespaces<U extends ResponseContentType$watchCoreV1ResourceQuotaListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1ResourceQuotaListForAllNamespaces;
}
type ResponseContentType$watchCoreV1SecretListForAllNamespaces = keyof Response$watchCoreV1SecretListForAllNamespaces$Status$200;
interface Params$watchCoreV1SecretListForAllNamespaces<U extends ResponseContentType$watchCoreV1SecretListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1SecretListForAllNamespaces;
}
type ResponseContentType$watchCoreV1ServiceAccountListForAllNamespaces = keyof Response$watchCoreV1ServiceAccountListForAllNamespaces$Status$200;
interface Params$watchCoreV1ServiceAccountListForAllNamespaces<U extends ResponseContentType$watchCoreV1ServiceAccountListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1ServiceAccountListForAllNamespaces;
}
type ResponseContentType$watchCoreV1ServiceListForAllNamespaces = keyof Response$watchCoreV1ServiceListForAllNamespaces$Status$200;
interface Params$watchCoreV1ServiceListForAllNamespaces<U extends ResponseContentType$watchCoreV1ServiceListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoreV1ServiceListForAllNamespaces;
}
type ResponseContentType$getAPIVersions = keyof Response$getAPIVersions$Status$200;
interface Params$getAPIVersions<U extends ResponseContentType$getAPIVersions> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getAdmissionregistrationAPIGroup = keyof Response$getAdmissionregistrationAPIGroup$Status$200;
interface Params$getAdmissionregistrationAPIGroup<U extends ResponseContentType$getAdmissionregistrationAPIGroup> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getAdmissionregistrationV1APIResources = keyof Response$getAdmissionregistrationV1APIResources$Status$200;
interface Params$getAdmissionregistrationV1APIResources<U extends ResponseContentType$getAdmissionregistrationV1APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listAdmissionregistrationV1MutatingWebhookConfiguration = keyof Response$listAdmissionregistrationV1MutatingWebhookConfiguration$Status$200;
interface Params$listAdmissionregistrationV1MutatingWebhookConfiguration<U extends ResponseContentType$listAdmissionregistrationV1MutatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAdmissionregistrationV1MutatingWebhookConfiguration;
}
type RequestContentType$createAdmissionregistrationV1MutatingWebhookConfiguration = keyof RequestBody$createAdmissionregistrationV1MutatingWebhookConfiguration;
type ResponseContentType$createAdmissionregistrationV1MutatingWebhookConfiguration = keyof Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | keyof Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$201 | keyof Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$202;
interface Params$createAdmissionregistrationV1MutatingWebhookConfiguration<U extends ResponseContentType$createAdmissionregistrationV1MutatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAdmissionregistrationV1MutatingWebhookConfiguration;
    requestBody: RequestBody$createAdmissionregistrationV1MutatingWebhookConfiguration["*/*"];
}
type RequestContentType$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration = keyof RequestBody$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration;
type ResponseContentType$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration = keyof Response$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration$Status$200;
interface Params$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration<U extends ResponseContentType$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration;
    requestBody: RequestBody$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration["*/*"];
}
type ResponseContentType$readAdmissionregistrationV1MutatingWebhookConfiguration = keyof Response$readAdmissionregistrationV1MutatingWebhookConfiguration$Status$200;
interface Params$readAdmissionregistrationV1MutatingWebhookConfiguration<U extends ResponseContentType$readAdmissionregistrationV1MutatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAdmissionregistrationV1MutatingWebhookConfiguration;
}
type RequestContentType$replaceAdmissionregistrationV1MutatingWebhookConfiguration = keyof RequestBody$replaceAdmissionregistrationV1MutatingWebhookConfiguration;
type ResponseContentType$replaceAdmissionregistrationV1MutatingWebhookConfiguration = keyof Response$replaceAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | keyof Response$replaceAdmissionregistrationV1MutatingWebhookConfiguration$Status$201;
interface Params$replaceAdmissionregistrationV1MutatingWebhookConfiguration<U extends ResponseContentType$replaceAdmissionregistrationV1MutatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAdmissionregistrationV1MutatingWebhookConfiguration;
    requestBody: RequestBody$replaceAdmissionregistrationV1MutatingWebhookConfiguration["*/*"];
}
type RequestContentType$deleteAdmissionregistrationV1MutatingWebhookConfiguration = keyof RequestBody$deleteAdmissionregistrationV1MutatingWebhookConfiguration;
type ResponseContentType$deleteAdmissionregistrationV1MutatingWebhookConfiguration = keyof Response$deleteAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | keyof Response$deleteAdmissionregistrationV1MutatingWebhookConfiguration$Status$202;
interface Params$deleteAdmissionregistrationV1MutatingWebhookConfiguration<U extends ResponseContentType$deleteAdmissionregistrationV1MutatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAdmissionregistrationV1MutatingWebhookConfiguration;
    requestBody: RequestBody$deleteAdmissionregistrationV1MutatingWebhookConfiguration["*/*"];
}
type RequestContentType$patchAdmissionregistrationV1MutatingWebhookConfiguration = keyof RequestBody$patchAdmissionregistrationV1MutatingWebhookConfiguration;
type ResponseContentType$patchAdmissionregistrationV1MutatingWebhookConfiguration = keyof Response$patchAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | keyof Response$patchAdmissionregistrationV1MutatingWebhookConfiguration$Status$201;
interface Params$patchAdmissionregistrationV1MutatingWebhookConfiguration<T extends RequestContentType$patchAdmissionregistrationV1MutatingWebhookConfiguration, U extends ResponseContentType$patchAdmissionregistrationV1MutatingWebhookConfiguration> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAdmissionregistrationV1MutatingWebhookConfiguration;
    requestBody: RequestBody$patchAdmissionregistrationV1MutatingWebhookConfiguration[T];
}
type ResponseContentType$listAdmissionregistrationV1ValidatingWebhookConfiguration = keyof Response$listAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200;
interface Params$listAdmissionregistrationV1ValidatingWebhookConfiguration<U extends ResponseContentType$listAdmissionregistrationV1ValidatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAdmissionregistrationV1ValidatingWebhookConfiguration;
}
type RequestContentType$createAdmissionregistrationV1ValidatingWebhookConfiguration = keyof RequestBody$createAdmissionregistrationV1ValidatingWebhookConfiguration;
type ResponseContentType$createAdmissionregistrationV1ValidatingWebhookConfiguration = keyof Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | keyof Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201 | keyof Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$202;
interface Params$createAdmissionregistrationV1ValidatingWebhookConfiguration<U extends ResponseContentType$createAdmissionregistrationV1ValidatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAdmissionregistrationV1ValidatingWebhookConfiguration;
    requestBody: RequestBody$createAdmissionregistrationV1ValidatingWebhookConfiguration["*/*"];
}
type RequestContentType$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration = keyof RequestBody$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration;
type ResponseContentType$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration = keyof Response$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration$Status$200;
interface Params$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration<U extends ResponseContentType$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration;
    requestBody: RequestBody$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration["*/*"];
}
type ResponseContentType$readAdmissionregistrationV1ValidatingWebhookConfiguration = keyof Response$readAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200;
interface Params$readAdmissionregistrationV1ValidatingWebhookConfiguration<U extends ResponseContentType$readAdmissionregistrationV1ValidatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAdmissionregistrationV1ValidatingWebhookConfiguration;
}
type RequestContentType$replaceAdmissionregistrationV1ValidatingWebhookConfiguration = keyof RequestBody$replaceAdmissionregistrationV1ValidatingWebhookConfiguration;
type ResponseContentType$replaceAdmissionregistrationV1ValidatingWebhookConfiguration = keyof Response$replaceAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | keyof Response$replaceAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201;
interface Params$replaceAdmissionregistrationV1ValidatingWebhookConfiguration<U extends ResponseContentType$replaceAdmissionregistrationV1ValidatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAdmissionregistrationV1ValidatingWebhookConfiguration;
    requestBody: RequestBody$replaceAdmissionregistrationV1ValidatingWebhookConfiguration["*/*"];
}
type RequestContentType$deleteAdmissionregistrationV1ValidatingWebhookConfiguration = keyof RequestBody$deleteAdmissionregistrationV1ValidatingWebhookConfiguration;
type ResponseContentType$deleteAdmissionregistrationV1ValidatingWebhookConfiguration = keyof Response$deleteAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | keyof Response$deleteAdmissionregistrationV1ValidatingWebhookConfiguration$Status$202;
interface Params$deleteAdmissionregistrationV1ValidatingWebhookConfiguration<U extends ResponseContentType$deleteAdmissionregistrationV1ValidatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAdmissionregistrationV1ValidatingWebhookConfiguration;
    requestBody: RequestBody$deleteAdmissionregistrationV1ValidatingWebhookConfiguration["*/*"];
}
type RequestContentType$patchAdmissionregistrationV1ValidatingWebhookConfiguration = keyof RequestBody$patchAdmissionregistrationV1ValidatingWebhookConfiguration;
type ResponseContentType$patchAdmissionregistrationV1ValidatingWebhookConfiguration = keyof Response$patchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | keyof Response$patchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201;
interface Params$patchAdmissionregistrationV1ValidatingWebhookConfiguration<T extends RequestContentType$patchAdmissionregistrationV1ValidatingWebhookConfiguration, U extends ResponseContentType$patchAdmissionregistrationV1ValidatingWebhookConfiguration> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAdmissionregistrationV1ValidatingWebhookConfiguration;
    requestBody: RequestBody$patchAdmissionregistrationV1ValidatingWebhookConfiguration[T];
}
type ResponseContentType$watchAdmissionregistrationV1MutatingWebhookConfigurationList = keyof Response$watchAdmissionregistrationV1MutatingWebhookConfigurationList$Status$200;
interface Params$watchAdmissionregistrationV1MutatingWebhookConfigurationList<U extends ResponseContentType$watchAdmissionregistrationV1MutatingWebhookConfigurationList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAdmissionregistrationV1MutatingWebhookConfigurationList;
}
type ResponseContentType$watchAdmissionregistrationV1MutatingWebhookConfiguration = keyof Response$watchAdmissionregistrationV1MutatingWebhookConfiguration$Status$200;
interface Params$watchAdmissionregistrationV1MutatingWebhookConfiguration<U extends ResponseContentType$watchAdmissionregistrationV1MutatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAdmissionregistrationV1MutatingWebhookConfiguration;
}
type ResponseContentType$watchAdmissionregistrationV1ValidatingWebhookConfigurationList = keyof Response$watchAdmissionregistrationV1ValidatingWebhookConfigurationList$Status$200;
interface Params$watchAdmissionregistrationV1ValidatingWebhookConfigurationList<U extends ResponseContentType$watchAdmissionregistrationV1ValidatingWebhookConfigurationList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAdmissionregistrationV1ValidatingWebhookConfigurationList;
}
type ResponseContentType$watchAdmissionregistrationV1ValidatingWebhookConfiguration = keyof Response$watchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200;
interface Params$watchAdmissionregistrationV1ValidatingWebhookConfiguration<U extends ResponseContentType$watchAdmissionregistrationV1ValidatingWebhookConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAdmissionregistrationV1ValidatingWebhookConfiguration;
}
type ResponseContentType$getAdmissionregistrationV1alpha1APIResources = keyof Response$getAdmissionregistrationV1alpha1APIResources$Status$200;
interface Params$getAdmissionregistrationV1alpha1APIResources<U extends ResponseContentType$getAdmissionregistrationV1alpha1APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicy = keyof Response$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200;
interface Params$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicy<U extends ResponseContentType$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicy;
}
type RequestContentType$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy = keyof RequestBody$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy;
type ResponseContentType$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy = keyof Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200 | keyof Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$201 | keyof Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$202;
interface Params$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy<U extends ResponseContentType$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy;
    requestBody: RequestBody$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy["*/*"];
}
type RequestContentType$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy = keyof RequestBody$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy;
type ResponseContentType$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy = keyof Response$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy$Status$200;
interface Params$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy<U extends ResponseContentType$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy;
    requestBody: RequestBody$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy["*/*"];
}
type ResponseContentType$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicy = keyof Response$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200;
interface Params$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicy<U extends ResponseContentType$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicy;
}
type RequestContentType$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy = keyof RequestBody$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy;
type ResponseContentType$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy = keyof Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200 | keyof Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$201;
interface Params$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy<U extends ResponseContentType$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy;
    requestBody: RequestBody$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy["*/*"];
}
type RequestContentType$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy = keyof RequestBody$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy;
type ResponseContentType$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy = keyof Response$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200 | keyof Response$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$202;
interface Params$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy<U extends ResponseContentType$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy;
    requestBody: RequestBody$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy["*/*"];
}
type RequestContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy = keyof RequestBody$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy;
type ResponseContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy = keyof Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200 | keyof Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$201;
interface Params$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy<T extends RequestContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, U extends ResponseContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy;
    requestBody: RequestBody$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy[T];
}
type ResponseContentType$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus = keyof Response$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$200;
interface Params$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus<U extends ResponseContentType$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus;
}
type RequestContentType$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus = keyof RequestBody$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus;
type ResponseContentType$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus = keyof Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$200 | keyof Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$201;
interface Params$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus<U extends ResponseContentType$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus;
    requestBody: RequestBody$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus["*/*"];
}
type RequestContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus = keyof RequestBody$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus;
type ResponseContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus = keyof Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$200 | keyof Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$201;
interface Params$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus<T extends RequestContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus, U extends ResponseContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus;
    requestBody: RequestBody$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus[T];
}
type ResponseContentType$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding = keyof Response$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200;
interface Params$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding<U extends ResponseContentType$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding;
}
type RequestContentType$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding = keyof RequestBody$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding;
type ResponseContentType$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding = keyof Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200 | keyof Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$201 | keyof Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$202;
interface Params$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding<U extends ResponseContentType$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding;
    requestBody: RequestBody$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding["*/*"];
}
type RequestContentType$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding = keyof RequestBody$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding;
type ResponseContentType$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding = keyof Response$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding$Status$200;
interface Params$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding<U extends ResponseContentType$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding;
    requestBody: RequestBody$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding["*/*"];
}
type ResponseContentType$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding = keyof Response$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200;
interface Params$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding<U extends ResponseContentType$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding;
}
type RequestContentType$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding = keyof RequestBody$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding;
type ResponseContentType$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding = keyof Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200 | keyof Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$201;
interface Params$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding<U extends ResponseContentType$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding;
    requestBody: RequestBody$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding["*/*"];
}
type RequestContentType$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding = keyof RequestBody$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding;
type ResponseContentType$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding = keyof Response$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200 | keyof Response$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$202;
interface Params$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding<U extends ResponseContentType$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding;
    requestBody: RequestBody$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding["*/*"];
}
type RequestContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding = keyof RequestBody$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding;
type ResponseContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding = keyof Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200 | keyof Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$201;
interface Params$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding<T extends RequestContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, U extends ResponseContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding;
    requestBody: RequestBody$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding[T];
}
type ResponseContentType$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyList = keyof Response$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyList$Status$200;
interface Params$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyList<U extends ResponseContentType$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyList;
}
type ResponseContentType$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy = keyof Response$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200;
interface Params$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy<U extends ResponseContentType$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy;
}
type ResponseContentType$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBindingList = keyof Response$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBindingList$Status$200;
interface Params$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBindingList<U extends ResponseContentType$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBindingList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBindingList;
}
type ResponseContentType$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding = keyof Response$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200;
interface Params$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding<U extends ResponseContentType$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding;
}
type ResponseContentType$getApiextensionsAPIGroup = keyof Response$getApiextensionsAPIGroup$Status$200;
interface Params$getApiextensionsAPIGroup<U extends ResponseContentType$getApiextensionsAPIGroup> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getApiextensionsV1APIResources = keyof Response$getApiextensionsV1APIResources$Status$200;
interface Params$getApiextensionsV1APIResources<U extends ResponseContentType$getApiextensionsV1APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listApiextensionsV1CustomResourceDefinition = keyof Response$listApiextensionsV1CustomResourceDefinition$Status$200;
interface Params$listApiextensionsV1CustomResourceDefinition<U extends ResponseContentType$listApiextensionsV1CustomResourceDefinition> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listApiextensionsV1CustomResourceDefinition;
}
type RequestContentType$createApiextensionsV1CustomResourceDefinition = keyof RequestBody$createApiextensionsV1CustomResourceDefinition;
type ResponseContentType$createApiextensionsV1CustomResourceDefinition = keyof Response$createApiextensionsV1CustomResourceDefinition$Status$200 | keyof Response$createApiextensionsV1CustomResourceDefinition$Status$201 | keyof Response$createApiextensionsV1CustomResourceDefinition$Status$202;
interface Params$createApiextensionsV1CustomResourceDefinition<U extends ResponseContentType$createApiextensionsV1CustomResourceDefinition> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createApiextensionsV1CustomResourceDefinition;
    requestBody: RequestBody$createApiextensionsV1CustomResourceDefinition["*/*"];
}
type RequestContentType$deleteApiextensionsV1CollectionCustomResourceDefinition = keyof RequestBody$deleteApiextensionsV1CollectionCustomResourceDefinition;
type ResponseContentType$deleteApiextensionsV1CollectionCustomResourceDefinition = keyof Response$deleteApiextensionsV1CollectionCustomResourceDefinition$Status$200;
interface Params$deleteApiextensionsV1CollectionCustomResourceDefinition<U extends ResponseContentType$deleteApiextensionsV1CollectionCustomResourceDefinition> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteApiextensionsV1CollectionCustomResourceDefinition;
    requestBody: RequestBody$deleteApiextensionsV1CollectionCustomResourceDefinition["*/*"];
}
type ResponseContentType$readApiextensionsV1CustomResourceDefinition = keyof Response$readApiextensionsV1CustomResourceDefinition$Status$200;
interface Params$readApiextensionsV1CustomResourceDefinition<U extends ResponseContentType$readApiextensionsV1CustomResourceDefinition> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readApiextensionsV1CustomResourceDefinition;
}
type RequestContentType$replaceApiextensionsV1CustomResourceDefinition = keyof RequestBody$replaceApiextensionsV1CustomResourceDefinition;
type ResponseContentType$replaceApiextensionsV1CustomResourceDefinition = keyof Response$replaceApiextensionsV1CustomResourceDefinition$Status$200 | keyof Response$replaceApiextensionsV1CustomResourceDefinition$Status$201;
interface Params$replaceApiextensionsV1CustomResourceDefinition<U extends ResponseContentType$replaceApiextensionsV1CustomResourceDefinition> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceApiextensionsV1CustomResourceDefinition;
    requestBody: RequestBody$replaceApiextensionsV1CustomResourceDefinition["*/*"];
}
type RequestContentType$deleteApiextensionsV1CustomResourceDefinition = keyof RequestBody$deleteApiextensionsV1CustomResourceDefinition;
type ResponseContentType$deleteApiextensionsV1CustomResourceDefinition = keyof Response$deleteApiextensionsV1CustomResourceDefinition$Status$200 | keyof Response$deleteApiextensionsV1CustomResourceDefinition$Status$202;
interface Params$deleteApiextensionsV1CustomResourceDefinition<U extends ResponseContentType$deleteApiextensionsV1CustomResourceDefinition> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteApiextensionsV1CustomResourceDefinition;
    requestBody: RequestBody$deleteApiextensionsV1CustomResourceDefinition["*/*"];
}
type RequestContentType$patchApiextensionsV1CustomResourceDefinition = keyof RequestBody$patchApiextensionsV1CustomResourceDefinition;
type ResponseContentType$patchApiextensionsV1CustomResourceDefinition = keyof Response$patchApiextensionsV1CustomResourceDefinition$Status$200 | keyof Response$patchApiextensionsV1CustomResourceDefinition$Status$201;
interface Params$patchApiextensionsV1CustomResourceDefinition<T extends RequestContentType$patchApiextensionsV1CustomResourceDefinition, U extends ResponseContentType$patchApiextensionsV1CustomResourceDefinition> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchApiextensionsV1CustomResourceDefinition;
    requestBody: RequestBody$patchApiextensionsV1CustomResourceDefinition[T];
}
type ResponseContentType$readApiextensionsV1CustomResourceDefinitionStatus = keyof Response$readApiextensionsV1CustomResourceDefinitionStatus$Status$200;
interface Params$readApiextensionsV1CustomResourceDefinitionStatus<U extends ResponseContentType$readApiextensionsV1CustomResourceDefinitionStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readApiextensionsV1CustomResourceDefinitionStatus;
}
type RequestContentType$replaceApiextensionsV1CustomResourceDefinitionStatus = keyof RequestBody$replaceApiextensionsV1CustomResourceDefinitionStatus;
type ResponseContentType$replaceApiextensionsV1CustomResourceDefinitionStatus = keyof Response$replaceApiextensionsV1CustomResourceDefinitionStatus$Status$200 | keyof Response$replaceApiextensionsV1CustomResourceDefinitionStatus$Status$201;
interface Params$replaceApiextensionsV1CustomResourceDefinitionStatus<U extends ResponseContentType$replaceApiextensionsV1CustomResourceDefinitionStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceApiextensionsV1CustomResourceDefinitionStatus;
    requestBody: RequestBody$replaceApiextensionsV1CustomResourceDefinitionStatus["*/*"];
}
type RequestContentType$patchApiextensionsV1CustomResourceDefinitionStatus = keyof RequestBody$patchApiextensionsV1CustomResourceDefinitionStatus;
type ResponseContentType$patchApiextensionsV1CustomResourceDefinitionStatus = keyof Response$patchApiextensionsV1CustomResourceDefinitionStatus$Status$200 | keyof Response$patchApiextensionsV1CustomResourceDefinitionStatus$Status$201;
interface Params$patchApiextensionsV1CustomResourceDefinitionStatus<T extends RequestContentType$patchApiextensionsV1CustomResourceDefinitionStatus, U extends ResponseContentType$patchApiextensionsV1CustomResourceDefinitionStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchApiextensionsV1CustomResourceDefinitionStatus;
    requestBody: RequestBody$patchApiextensionsV1CustomResourceDefinitionStatus[T];
}
type ResponseContentType$watchApiextensionsV1CustomResourceDefinitionList = keyof Response$watchApiextensionsV1CustomResourceDefinitionList$Status$200;
interface Params$watchApiextensionsV1CustomResourceDefinitionList<U extends ResponseContentType$watchApiextensionsV1CustomResourceDefinitionList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchApiextensionsV1CustomResourceDefinitionList;
}
type ResponseContentType$watchApiextensionsV1CustomResourceDefinition = keyof Response$watchApiextensionsV1CustomResourceDefinition$Status$200;
interface Params$watchApiextensionsV1CustomResourceDefinition<U extends ResponseContentType$watchApiextensionsV1CustomResourceDefinition> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchApiextensionsV1CustomResourceDefinition;
}
type ResponseContentType$getApiregistrationAPIGroup = keyof Response$getApiregistrationAPIGroup$Status$200;
interface Params$getApiregistrationAPIGroup<U extends ResponseContentType$getApiregistrationAPIGroup> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getApiregistrationV1APIResources = keyof Response$getApiregistrationV1APIResources$Status$200;
interface Params$getApiregistrationV1APIResources<U extends ResponseContentType$getApiregistrationV1APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listApiregistrationV1APIService = keyof Response$listApiregistrationV1APIService$Status$200;
interface Params$listApiregistrationV1APIService<U extends ResponseContentType$listApiregistrationV1APIService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listApiregistrationV1APIService;
}
type RequestContentType$createApiregistrationV1APIService = keyof RequestBody$createApiregistrationV1APIService;
type ResponseContentType$createApiregistrationV1APIService = keyof Response$createApiregistrationV1APIService$Status$200 | keyof Response$createApiregistrationV1APIService$Status$201 | keyof Response$createApiregistrationV1APIService$Status$202;
interface Params$createApiregistrationV1APIService<U extends ResponseContentType$createApiregistrationV1APIService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createApiregistrationV1APIService;
    requestBody: RequestBody$createApiregistrationV1APIService["*/*"];
}
type RequestContentType$deleteApiregistrationV1CollectionAPIService = keyof RequestBody$deleteApiregistrationV1CollectionAPIService;
type ResponseContentType$deleteApiregistrationV1CollectionAPIService = keyof Response$deleteApiregistrationV1CollectionAPIService$Status$200;
interface Params$deleteApiregistrationV1CollectionAPIService<U extends ResponseContentType$deleteApiregistrationV1CollectionAPIService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteApiregistrationV1CollectionAPIService;
    requestBody: RequestBody$deleteApiregistrationV1CollectionAPIService["*/*"];
}
type ResponseContentType$readApiregistrationV1APIService = keyof Response$readApiregistrationV1APIService$Status$200;
interface Params$readApiregistrationV1APIService<U extends ResponseContentType$readApiregistrationV1APIService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readApiregistrationV1APIService;
}
type RequestContentType$replaceApiregistrationV1APIService = keyof RequestBody$replaceApiregistrationV1APIService;
type ResponseContentType$replaceApiregistrationV1APIService = keyof Response$replaceApiregistrationV1APIService$Status$200 | keyof Response$replaceApiregistrationV1APIService$Status$201;
interface Params$replaceApiregistrationV1APIService<U extends ResponseContentType$replaceApiregistrationV1APIService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceApiregistrationV1APIService;
    requestBody: RequestBody$replaceApiregistrationV1APIService["*/*"];
}
type RequestContentType$deleteApiregistrationV1APIService = keyof RequestBody$deleteApiregistrationV1APIService;
type ResponseContentType$deleteApiregistrationV1APIService = keyof Response$deleteApiregistrationV1APIService$Status$200 | keyof Response$deleteApiregistrationV1APIService$Status$202;
interface Params$deleteApiregistrationV1APIService<U extends ResponseContentType$deleteApiregistrationV1APIService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteApiregistrationV1APIService;
    requestBody: RequestBody$deleteApiregistrationV1APIService["*/*"];
}
type RequestContentType$patchApiregistrationV1APIService = keyof RequestBody$patchApiregistrationV1APIService;
type ResponseContentType$patchApiregistrationV1APIService = keyof Response$patchApiregistrationV1APIService$Status$200 | keyof Response$patchApiregistrationV1APIService$Status$201;
interface Params$patchApiregistrationV1APIService<T extends RequestContentType$patchApiregistrationV1APIService, U extends ResponseContentType$patchApiregistrationV1APIService> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchApiregistrationV1APIService;
    requestBody: RequestBody$patchApiregistrationV1APIService[T];
}
type ResponseContentType$readApiregistrationV1APIServiceStatus = keyof Response$readApiregistrationV1APIServiceStatus$Status$200;
interface Params$readApiregistrationV1APIServiceStatus<U extends ResponseContentType$readApiregistrationV1APIServiceStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readApiregistrationV1APIServiceStatus;
}
type RequestContentType$replaceApiregistrationV1APIServiceStatus = keyof RequestBody$replaceApiregistrationV1APIServiceStatus;
type ResponseContentType$replaceApiregistrationV1APIServiceStatus = keyof Response$replaceApiregistrationV1APIServiceStatus$Status$200 | keyof Response$replaceApiregistrationV1APIServiceStatus$Status$201;
interface Params$replaceApiregistrationV1APIServiceStatus<U extends ResponseContentType$replaceApiregistrationV1APIServiceStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceApiregistrationV1APIServiceStatus;
    requestBody: RequestBody$replaceApiregistrationV1APIServiceStatus["*/*"];
}
type RequestContentType$patchApiregistrationV1APIServiceStatus = keyof RequestBody$patchApiregistrationV1APIServiceStatus;
type ResponseContentType$patchApiregistrationV1APIServiceStatus = keyof Response$patchApiregistrationV1APIServiceStatus$Status$200 | keyof Response$patchApiregistrationV1APIServiceStatus$Status$201;
interface Params$patchApiregistrationV1APIServiceStatus<T extends RequestContentType$patchApiregistrationV1APIServiceStatus, U extends ResponseContentType$patchApiregistrationV1APIServiceStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchApiregistrationV1APIServiceStatus;
    requestBody: RequestBody$patchApiregistrationV1APIServiceStatus[T];
}
type ResponseContentType$watchApiregistrationV1APIServiceList = keyof Response$watchApiregistrationV1APIServiceList$Status$200;
interface Params$watchApiregistrationV1APIServiceList<U extends ResponseContentType$watchApiregistrationV1APIServiceList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchApiregistrationV1APIServiceList;
}
type ResponseContentType$watchApiregistrationV1APIService = keyof Response$watchApiregistrationV1APIService$Status$200;
interface Params$watchApiregistrationV1APIService<U extends ResponseContentType$watchApiregistrationV1APIService> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchApiregistrationV1APIService;
}
type ResponseContentType$getAppsAPIGroup = keyof Response$getAppsAPIGroup$Status$200;
interface Params$getAppsAPIGroup<U extends ResponseContentType$getAppsAPIGroup> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getAppsV1APIResources = keyof Response$getAppsV1APIResources$Status$200;
interface Params$getAppsV1APIResources<U extends ResponseContentType$getAppsV1APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listAppsV1ControllerRevisionForAllNamespaces = keyof Response$listAppsV1ControllerRevisionForAllNamespaces$Status$200;
interface Params$listAppsV1ControllerRevisionForAllNamespaces<U extends ResponseContentType$listAppsV1ControllerRevisionForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAppsV1ControllerRevisionForAllNamespaces;
}
type ResponseContentType$listAppsV1DaemonSetForAllNamespaces = keyof Response$listAppsV1DaemonSetForAllNamespaces$Status$200;
interface Params$listAppsV1DaemonSetForAllNamespaces<U extends ResponseContentType$listAppsV1DaemonSetForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAppsV1DaemonSetForAllNamespaces;
}
type ResponseContentType$listAppsV1DeploymentForAllNamespaces = keyof Response$listAppsV1DeploymentForAllNamespaces$Status$200;
interface Params$listAppsV1DeploymentForAllNamespaces<U extends ResponseContentType$listAppsV1DeploymentForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAppsV1DeploymentForAllNamespaces;
}
type ResponseContentType$listAppsV1NamespacedControllerRevision = keyof Response$listAppsV1NamespacedControllerRevision$Status$200;
interface Params$listAppsV1NamespacedControllerRevision<U extends ResponseContentType$listAppsV1NamespacedControllerRevision> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAppsV1NamespacedControllerRevision;
}
type RequestContentType$createAppsV1NamespacedControllerRevision = keyof RequestBody$createAppsV1NamespacedControllerRevision;
type ResponseContentType$createAppsV1NamespacedControllerRevision = keyof Response$createAppsV1NamespacedControllerRevision$Status$200 | keyof Response$createAppsV1NamespacedControllerRevision$Status$201 | keyof Response$createAppsV1NamespacedControllerRevision$Status$202;
interface Params$createAppsV1NamespacedControllerRevision<U extends ResponseContentType$createAppsV1NamespacedControllerRevision> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAppsV1NamespacedControllerRevision;
    requestBody: RequestBody$createAppsV1NamespacedControllerRevision["*/*"];
}
type RequestContentType$deleteAppsV1CollectionNamespacedControllerRevision = keyof RequestBody$deleteAppsV1CollectionNamespacedControllerRevision;
type ResponseContentType$deleteAppsV1CollectionNamespacedControllerRevision = keyof Response$deleteAppsV1CollectionNamespacedControllerRevision$Status$200;
interface Params$deleteAppsV1CollectionNamespacedControllerRevision<U extends ResponseContentType$deleteAppsV1CollectionNamespacedControllerRevision> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAppsV1CollectionNamespacedControllerRevision;
    requestBody: RequestBody$deleteAppsV1CollectionNamespacedControllerRevision["*/*"];
}
type ResponseContentType$readAppsV1NamespacedControllerRevision = keyof Response$readAppsV1NamespacedControllerRevision$Status$200;
interface Params$readAppsV1NamespacedControllerRevision<U extends ResponseContentType$readAppsV1NamespacedControllerRevision> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedControllerRevision;
}
type RequestContentType$replaceAppsV1NamespacedControllerRevision = keyof RequestBody$replaceAppsV1NamespacedControllerRevision;
type ResponseContentType$replaceAppsV1NamespacedControllerRevision = keyof Response$replaceAppsV1NamespacedControllerRevision$Status$200 | keyof Response$replaceAppsV1NamespacedControllerRevision$Status$201;
interface Params$replaceAppsV1NamespacedControllerRevision<U extends ResponseContentType$replaceAppsV1NamespacedControllerRevision> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedControllerRevision;
    requestBody: RequestBody$replaceAppsV1NamespacedControllerRevision["*/*"];
}
type RequestContentType$deleteAppsV1NamespacedControllerRevision = keyof RequestBody$deleteAppsV1NamespacedControllerRevision;
type ResponseContentType$deleteAppsV1NamespacedControllerRevision = keyof Response$deleteAppsV1NamespacedControllerRevision$Status$200 | keyof Response$deleteAppsV1NamespacedControllerRevision$Status$202;
interface Params$deleteAppsV1NamespacedControllerRevision<U extends ResponseContentType$deleteAppsV1NamespacedControllerRevision> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAppsV1NamespacedControllerRevision;
    requestBody: RequestBody$deleteAppsV1NamespacedControllerRevision["*/*"];
}
type RequestContentType$patchAppsV1NamespacedControllerRevision = keyof RequestBody$patchAppsV1NamespacedControllerRevision;
type ResponseContentType$patchAppsV1NamespacedControllerRevision = keyof Response$patchAppsV1NamespacedControllerRevision$Status$200 | keyof Response$patchAppsV1NamespacedControllerRevision$Status$201;
interface Params$patchAppsV1NamespacedControllerRevision<T extends RequestContentType$patchAppsV1NamespacedControllerRevision, U extends ResponseContentType$patchAppsV1NamespacedControllerRevision> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedControllerRevision;
    requestBody: RequestBody$patchAppsV1NamespacedControllerRevision[T];
}
type ResponseContentType$listAppsV1NamespacedDaemonSet = keyof Response$listAppsV1NamespacedDaemonSet$Status$200;
interface Params$listAppsV1NamespacedDaemonSet<U extends ResponseContentType$listAppsV1NamespacedDaemonSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAppsV1NamespacedDaemonSet;
}
type RequestContentType$createAppsV1NamespacedDaemonSet = keyof RequestBody$createAppsV1NamespacedDaemonSet;
type ResponseContentType$createAppsV1NamespacedDaemonSet = keyof Response$createAppsV1NamespacedDaemonSet$Status$200 | keyof Response$createAppsV1NamespacedDaemonSet$Status$201 | keyof Response$createAppsV1NamespacedDaemonSet$Status$202;
interface Params$createAppsV1NamespacedDaemonSet<U extends ResponseContentType$createAppsV1NamespacedDaemonSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAppsV1NamespacedDaemonSet;
    requestBody: RequestBody$createAppsV1NamespacedDaemonSet["*/*"];
}
type RequestContentType$deleteAppsV1CollectionNamespacedDaemonSet = keyof RequestBody$deleteAppsV1CollectionNamespacedDaemonSet;
type ResponseContentType$deleteAppsV1CollectionNamespacedDaemonSet = keyof Response$deleteAppsV1CollectionNamespacedDaemonSet$Status$200;
interface Params$deleteAppsV1CollectionNamespacedDaemonSet<U extends ResponseContentType$deleteAppsV1CollectionNamespacedDaemonSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAppsV1CollectionNamespacedDaemonSet;
    requestBody: RequestBody$deleteAppsV1CollectionNamespacedDaemonSet["*/*"];
}
type ResponseContentType$readAppsV1NamespacedDaemonSet = keyof Response$readAppsV1NamespacedDaemonSet$Status$200;
interface Params$readAppsV1NamespacedDaemonSet<U extends ResponseContentType$readAppsV1NamespacedDaemonSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedDaemonSet;
}
type RequestContentType$replaceAppsV1NamespacedDaemonSet = keyof RequestBody$replaceAppsV1NamespacedDaemonSet;
type ResponseContentType$replaceAppsV1NamespacedDaemonSet = keyof Response$replaceAppsV1NamespacedDaemonSet$Status$200 | keyof Response$replaceAppsV1NamespacedDaemonSet$Status$201;
interface Params$replaceAppsV1NamespacedDaemonSet<U extends ResponseContentType$replaceAppsV1NamespacedDaemonSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedDaemonSet;
    requestBody: RequestBody$replaceAppsV1NamespacedDaemonSet["*/*"];
}
type RequestContentType$deleteAppsV1NamespacedDaemonSet = keyof RequestBody$deleteAppsV1NamespacedDaemonSet;
type ResponseContentType$deleteAppsV1NamespacedDaemonSet = keyof Response$deleteAppsV1NamespacedDaemonSet$Status$200 | keyof Response$deleteAppsV1NamespacedDaemonSet$Status$202;
interface Params$deleteAppsV1NamespacedDaemonSet<U extends ResponseContentType$deleteAppsV1NamespacedDaemonSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAppsV1NamespacedDaemonSet;
    requestBody: RequestBody$deleteAppsV1NamespacedDaemonSet["*/*"];
}
type RequestContentType$patchAppsV1NamespacedDaemonSet = keyof RequestBody$patchAppsV1NamespacedDaemonSet;
type ResponseContentType$patchAppsV1NamespacedDaemonSet = keyof Response$patchAppsV1NamespacedDaemonSet$Status$200 | keyof Response$patchAppsV1NamespacedDaemonSet$Status$201;
interface Params$patchAppsV1NamespacedDaemonSet<T extends RequestContentType$patchAppsV1NamespacedDaemonSet, U extends ResponseContentType$patchAppsV1NamespacedDaemonSet> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedDaemonSet;
    requestBody: RequestBody$patchAppsV1NamespacedDaemonSet[T];
}
type ResponseContentType$readAppsV1NamespacedDaemonSetStatus = keyof Response$readAppsV1NamespacedDaemonSetStatus$Status$200;
interface Params$readAppsV1NamespacedDaemonSetStatus<U extends ResponseContentType$readAppsV1NamespacedDaemonSetStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedDaemonSetStatus;
}
type RequestContentType$replaceAppsV1NamespacedDaemonSetStatus = keyof RequestBody$replaceAppsV1NamespacedDaemonSetStatus;
type ResponseContentType$replaceAppsV1NamespacedDaemonSetStatus = keyof Response$replaceAppsV1NamespacedDaemonSetStatus$Status$200 | keyof Response$replaceAppsV1NamespacedDaemonSetStatus$Status$201;
interface Params$replaceAppsV1NamespacedDaemonSetStatus<U extends ResponseContentType$replaceAppsV1NamespacedDaemonSetStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedDaemonSetStatus;
    requestBody: RequestBody$replaceAppsV1NamespacedDaemonSetStatus["*/*"];
}
type RequestContentType$patchAppsV1NamespacedDaemonSetStatus = keyof RequestBody$patchAppsV1NamespacedDaemonSetStatus;
type ResponseContentType$patchAppsV1NamespacedDaemonSetStatus = keyof Response$patchAppsV1NamespacedDaemonSetStatus$Status$200 | keyof Response$patchAppsV1NamespacedDaemonSetStatus$Status$201;
interface Params$patchAppsV1NamespacedDaemonSetStatus<T extends RequestContentType$patchAppsV1NamespacedDaemonSetStatus, U extends ResponseContentType$patchAppsV1NamespacedDaemonSetStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedDaemonSetStatus;
    requestBody: RequestBody$patchAppsV1NamespacedDaemonSetStatus[T];
}
type ResponseContentType$listAppsV1NamespacedDeployment = keyof Response$listAppsV1NamespacedDeployment$Status$200;
interface Params$listAppsV1NamespacedDeployment<U extends ResponseContentType$listAppsV1NamespacedDeployment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAppsV1NamespacedDeployment;
}
type RequestContentType$createAppsV1NamespacedDeployment = keyof RequestBody$createAppsV1NamespacedDeployment;
type ResponseContentType$createAppsV1NamespacedDeployment = keyof Response$createAppsV1NamespacedDeployment$Status$200 | keyof Response$createAppsV1NamespacedDeployment$Status$201 | keyof Response$createAppsV1NamespacedDeployment$Status$202;
interface Params$createAppsV1NamespacedDeployment<U extends ResponseContentType$createAppsV1NamespacedDeployment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAppsV1NamespacedDeployment;
    requestBody: RequestBody$createAppsV1NamespacedDeployment["*/*"];
}
type RequestContentType$deleteAppsV1CollectionNamespacedDeployment = keyof RequestBody$deleteAppsV1CollectionNamespacedDeployment;
type ResponseContentType$deleteAppsV1CollectionNamespacedDeployment = keyof Response$deleteAppsV1CollectionNamespacedDeployment$Status$200;
interface Params$deleteAppsV1CollectionNamespacedDeployment<U extends ResponseContentType$deleteAppsV1CollectionNamespacedDeployment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAppsV1CollectionNamespacedDeployment;
    requestBody: RequestBody$deleteAppsV1CollectionNamespacedDeployment["*/*"];
}
type ResponseContentType$readAppsV1NamespacedDeployment = keyof Response$readAppsV1NamespacedDeployment$Status$200;
interface Params$readAppsV1NamespacedDeployment<U extends ResponseContentType$readAppsV1NamespacedDeployment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedDeployment;
}
type RequestContentType$replaceAppsV1NamespacedDeployment = keyof RequestBody$replaceAppsV1NamespacedDeployment;
type ResponseContentType$replaceAppsV1NamespacedDeployment = keyof Response$replaceAppsV1NamespacedDeployment$Status$200 | keyof Response$replaceAppsV1NamespacedDeployment$Status$201;
interface Params$replaceAppsV1NamespacedDeployment<U extends ResponseContentType$replaceAppsV1NamespacedDeployment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedDeployment;
    requestBody: RequestBody$replaceAppsV1NamespacedDeployment["*/*"];
}
type RequestContentType$deleteAppsV1NamespacedDeployment = keyof RequestBody$deleteAppsV1NamespacedDeployment;
type ResponseContentType$deleteAppsV1NamespacedDeployment = keyof Response$deleteAppsV1NamespacedDeployment$Status$200 | keyof Response$deleteAppsV1NamespacedDeployment$Status$202;
interface Params$deleteAppsV1NamespacedDeployment<U extends ResponseContentType$deleteAppsV1NamespacedDeployment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAppsV1NamespacedDeployment;
    requestBody: RequestBody$deleteAppsV1NamespacedDeployment["*/*"];
}
type RequestContentType$patchAppsV1NamespacedDeployment = keyof RequestBody$patchAppsV1NamespacedDeployment;
type ResponseContentType$patchAppsV1NamespacedDeployment = keyof Response$patchAppsV1NamespacedDeployment$Status$200 | keyof Response$patchAppsV1NamespacedDeployment$Status$201;
interface Params$patchAppsV1NamespacedDeployment<T extends RequestContentType$patchAppsV1NamespacedDeployment, U extends ResponseContentType$patchAppsV1NamespacedDeployment> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedDeployment;
    requestBody: RequestBody$patchAppsV1NamespacedDeployment[T];
}
type ResponseContentType$readAppsV1NamespacedDeploymentScale = keyof Response$readAppsV1NamespacedDeploymentScale$Status$200;
interface Params$readAppsV1NamespacedDeploymentScale<U extends ResponseContentType$readAppsV1NamespacedDeploymentScale> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedDeploymentScale;
}
type RequestContentType$replaceAppsV1NamespacedDeploymentScale = keyof RequestBody$replaceAppsV1NamespacedDeploymentScale;
type ResponseContentType$replaceAppsV1NamespacedDeploymentScale = keyof Response$replaceAppsV1NamespacedDeploymentScale$Status$200 | keyof Response$replaceAppsV1NamespacedDeploymentScale$Status$201;
interface Params$replaceAppsV1NamespacedDeploymentScale<U extends ResponseContentType$replaceAppsV1NamespacedDeploymentScale> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedDeploymentScale;
    requestBody: RequestBody$replaceAppsV1NamespacedDeploymentScale["*/*"];
}
type RequestContentType$patchAppsV1NamespacedDeploymentScale = keyof RequestBody$patchAppsV1NamespacedDeploymentScale;
type ResponseContentType$patchAppsV1NamespacedDeploymentScale = keyof Response$patchAppsV1NamespacedDeploymentScale$Status$200 | keyof Response$patchAppsV1NamespacedDeploymentScale$Status$201;
interface Params$patchAppsV1NamespacedDeploymentScale<T extends RequestContentType$patchAppsV1NamespacedDeploymentScale, U extends ResponseContentType$patchAppsV1NamespacedDeploymentScale> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedDeploymentScale;
    requestBody: RequestBody$patchAppsV1NamespacedDeploymentScale[T];
}
type ResponseContentType$readAppsV1NamespacedDeploymentStatus = keyof Response$readAppsV1NamespacedDeploymentStatus$Status$200;
interface Params$readAppsV1NamespacedDeploymentStatus<U extends ResponseContentType$readAppsV1NamespacedDeploymentStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedDeploymentStatus;
}
type RequestContentType$replaceAppsV1NamespacedDeploymentStatus = keyof RequestBody$replaceAppsV1NamespacedDeploymentStatus;
type ResponseContentType$replaceAppsV1NamespacedDeploymentStatus = keyof Response$replaceAppsV1NamespacedDeploymentStatus$Status$200 | keyof Response$replaceAppsV1NamespacedDeploymentStatus$Status$201;
interface Params$replaceAppsV1NamespacedDeploymentStatus<U extends ResponseContentType$replaceAppsV1NamespacedDeploymentStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedDeploymentStatus;
    requestBody: RequestBody$replaceAppsV1NamespacedDeploymentStatus["*/*"];
}
type RequestContentType$patchAppsV1NamespacedDeploymentStatus = keyof RequestBody$patchAppsV1NamespacedDeploymentStatus;
type ResponseContentType$patchAppsV1NamespacedDeploymentStatus = keyof Response$patchAppsV1NamespacedDeploymentStatus$Status$200 | keyof Response$patchAppsV1NamespacedDeploymentStatus$Status$201;
interface Params$patchAppsV1NamespacedDeploymentStatus<T extends RequestContentType$patchAppsV1NamespacedDeploymentStatus, U extends ResponseContentType$patchAppsV1NamespacedDeploymentStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedDeploymentStatus;
    requestBody: RequestBody$patchAppsV1NamespacedDeploymentStatus[T];
}
type ResponseContentType$listAppsV1NamespacedReplicaSet = keyof Response$listAppsV1NamespacedReplicaSet$Status$200;
interface Params$listAppsV1NamespacedReplicaSet<U extends ResponseContentType$listAppsV1NamespacedReplicaSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAppsV1NamespacedReplicaSet;
}
type RequestContentType$createAppsV1NamespacedReplicaSet = keyof RequestBody$createAppsV1NamespacedReplicaSet;
type ResponseContentType$createAppsV1NamespacedReplicaSet = keyof Response$createAppsV1NamespacedReplicaSet$Status$200 | keyof Response$createAppsV1NamespacedReplicaSet$Status$201 | keyof Response$createAppsV1NamespacedReplicaSet$Status$202;
interface Params$createAppsV1NamespacedReplicaSet<U extends ResponseContentType$createAppsV1NamespacedReplicaSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAppsV1NamespacedReplicaSet;
    requestBody: RequestBody$createAppsV1NamespacedReplicaSet["*/*"];
}
type RequestContentType$deleteAppsV1CollectionNamespacedReplicaSet = keyof RequestBody$deleteAppsV1CollectionNamespacedReplicaSet;
type ResponseContentType$deleteAppsV1CollectionNamespacedReplicaSet = keyof Response$deleteAppsV1CollectionNamespacedReplicaSet$Status$200;
interface Params$deleteAppsV1CollectionNamespacedReplicaSet<U extends ResponseContentType$deleteAppsV1CollectionNamespacedReplicaSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAppsV1CollectionNamespacedReplicaSet;
    requestBody: RequestBody$deleteAppsV1CollectionNamespacedReplicaSet["*/*"];
}
type ResponseContentType$readAppsV1NamespacedReplicaSet = keyof Response$readAppsV1NamespacedReplicaSet$Status$200;
interface Params$readAppsV1NamespacedReplicaSet<U extends ResponseContentType$readAppsV1NamespacedReplicaSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedReplicaSet;
}
type RequestContentType$replaceAppsV1NamespacedReplicaSet = keyof RequestBody$replaceAppsV1NamespacedReplicaSet;
type ResponseContentType$replaceAppsV1NamespacedReplicaSet = keyof Response$replaceAppsV1NamespacedReplicaSet$Status$200 | keyof Response$replaceAppsV1NamespacedReplicaSet$Status$201;
interface Params$replaceAppsV1NamespacedReplicaSet<U extends ResponseContentType$replaceAppsV1NamespacedReplicaSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedReplicaSet;
    requestBody: RequestBody$replaceAppsV1NamespacedReplicaSet["*/*"];
}
type RequestContentType$deleteAppsV1NamespacedReplicaSet = keyof RequestBody$deleteAppsV1NamespacedReplicaSet;
type ResponseContentType$deleteAppsV1NamespacedReplicaSet = keyof Response$deleteAppsV1NamespacedReplicaSet$Status$200 | keyof Response$deleteAppsV1NamespacedReplicaSet$Status$202;
interface Params$deleteAppsV1NamespacedReplicaSet<U extends ResponseContentType$deleteAppsV1NamespacedReplicaSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAppsV1NamespacedReplicaSet;
    requestBody: RequestBody$deleteAppsV1NamespacedReplicaSet["*/*"];
}
type RequestContentType$patchAppsV1NamespacedReplicaSet = keyof RequestBody$patchAppsV1NamespacedReplicaSet;
type ResponseContentType$patchAppsV1NamespacedReplicaSet = keyof Response$patchAppsV1NamespacedReplicaSet$Status$200 | keyof Response$patchAppsV1NamespacedReplicaSet$Status$201;
interface Params$patchAppsV1NamespacedReplicaSet<T extends RequestContentType$patchAppsV1NamespacedReplicaSet, U extends ResponseContentType$patchAppsV1NamespacedReplicaSet> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedReplicaSet;
    requestBody: RequestBody$patchAppsV1NamespacedReplicaSet[T];
}
type ResponseContentType$readAppsV1NamespacedReplicaSetScale = keyof Response$readAppsV1NamespacedReplicaSetScale$Status$200;
interface Params$readAppsV1NamespacedReplicaSetScale<U extends ResponseContentType$readAppsV1NamespacedReplicaSetScale> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedReplicaSetScale;
}
type RequestContentType$replaceAppsV1NamespacedReplicaSetScale = keyof RequestBody$replaceAppsV1NamespacedReplicaSetScale;
type ResponseContentType$replaceAppsV1NamespacedReplicaSetScale = keyof Response$replaceAppsV1NamespacedReplicaSetScale$Status$200 | keyof Response$replaceAppsV1NamespacedReplicaSetScale$Status$201;
interface Params$replaceAppsV1NamespacedReplicaSetScale<U extends ResponseContentType$replaceAppsV1NamespacedReplicaSetScale> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedReplicaSetScale;
    requestBody: RequestBody$replaceAppsV1NamespacedReplicaSetScale["*/*"];
}
type RequestContentType$patchAppsV1NamespacedReplicaSetScale = keyof RequestBody$patchAppsV1NamespacedReplicaSetScale;
type ResponseContentType$patchAppsV1NamespacedReplicaSetScale = keyof Response$patchAppsV1NamespacedReplicaSetScale$Status$200 | keyof Response$patchAppsV1NamespacedReplicaSetScale$Status$201;
interface Params$patchAppsV1NamespacedReplicaSetScale<T extends RequestContentType$patchAppsV1NamespacedReplicaSetScale, U extends ResponseContentType$patchAppsV1NamespacedReplicaSetScale> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedReplicaSetScale;
    requestBody: RequestBody$patchAppsV1NamespacedReplicaSetScale[T];
}
type ResponseContentType$readAppsV1NamespacedReplicaSetStatus = keyof Response$readAppsV1NamespacedReplicaSetStatus$Status$200;
interface Params$readAppsV1NamespacedReplicaSetStatus<U extends ResponseContentType$readAppsV1NamespacedReplicaSetStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedReplicaSetStatus;
}
type RequestContentType$replaceAppsV1NamespacedReplicaSetStatus = keyof RequestBody$replaceAppsV1NamespacedReplicaSetStatus;
type ResponseContentType$replaceAppsV1NamespacedReplicaSetStatus = keyof Response$replaceAppsV1NamespacedReplicaSetStatus$Status$200 | keyof Response$replaceAppsV1NamespacedReplicaSetStatus$Status$201;
interface Params$replaceAppsV1NamespacedReplicaSetStatus<U extends ResponseContentType$replaceAppsV1NamespacedReplicaSetStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedReplicaSetStatus;
    requestBody: RequestBody$replaceAppsV1NamespacedReplicaSetStatus["*/*"];
}
type RequestContentType$patchAppsV1NamespacedReplicaSetStatus = keyof RequestBody$patchAppsV1NamespacedReplicaSetStatus;
type ResponseContentType$patchAppsV1NamespacedReplicaSetStatus = keyof Response$patchAppsV1NamespacedReplicaSetStatus$Status$200 | keyof Response$patchAppsV1NamespacedReplicaSetStatus$Status$201;
interface Params$patchAppsV1NamespacedReplicaSetStatus<T extends RequestContentType$patchAppsV1NamespacedReplicaSetStatus, U extends ResponseContentType$patchAppsV1NamespacedReplicaSetStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedReplicaSetStatus;
    requestBody: RequestBody$patchAppsV1NamespacedReplicaSetStatus[T];
}
type ResponseContentType$listAppsV1NamespacedStatefulSet = keyof Response$listAppsV1NamespacedStatefulSet$Status$200;
interface Params$listAppsV1NamespacedStatefulSet<U extends ResponseContentType$listAppsV1NamespacedStatefulSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAppsV1NamespacedStatefulSet;
}
type RequestContentType$createAppsV1NamespacedStatefulSet = keyof RequestBody$createAppsV1NamespacedStatefulSet;
type ResponseContentType$createAppsV1NamespacedStatefulSet = keyof Response$createAppsV1NamespacedStatefulSet$Status$200 | keyof Response$createAppsV1NamespacedStatefulSet$Status$201 | keyof Response$createAppsV1NamespacedStatefulSet$Status$202;
interface Params$createAppsV1NamespacedStatefulSet<U extends ResponseContentType$createAppsV1NamespacedStatefulSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAppsV1NamespacedStatefulSet;
    requestBody: RequestBody$createAppsV1NamespacedStatefulSet["*/*"];
}
type RequestContentType$deleteAppsV1CollectionNamespacedStatefulSet = keyof RequestBody$deleteAppsV1CollectionNamespacedStatefulSet;
type ResponseContentType$deleteAppsV1CollectionNamespacedStatefulSet = keyof Response$deleteAppsV1CollectionNamespacedStatefulSet$Status$200;
interface Params$deleteAppsV1CollectionNamespacedStatefulSet<U extends ResponseContentType$deleteAppsV1CollectionNamespacedStatefulSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAppsV1CollectionNamespacedStatefulSet;
    requestBody: RequestBody$deleteAppsV1CollectionNamespacedStatefulSet["*/*"];
}
type ResponseContentType$readAppsV1NamespacedStatefulSet = keyof Response$readAppsV1NamespacedStatefulSet$Status$200;
interface Params$readAppsV1NamespacedStatefulSet<U extends ResponseContentType$readAppsV1NamespacedStatefulSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedStatefulSet;
}
type RequestContentType$replaceAppsV1NamespacedStatefulSet = keyof RequestBody$replaceAppsV1NamespacedStatefulSet;
type ResponseContentType$replaceAppsV1NamespacedStatefulSet = keyof Response$replaceAppsV1NamespacedStatefulSet$Status$200 | keyof Response$replaceAppsV1NamespacedStatefulSet$Status$201;
interface Params$replaceAppsV1NamespacedStatefulSet<U extends ResponseContentType$replaceAppsV1NamespacedStatefulSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedStatefulSet;
    requestBody: RequestBody$replaceAppsV1NamespacedStatefulSet["*/*"];
}
type RequestContentType$deleteAppsV1NamespacedStatefulSet = keyof RequestBody$deleteAppsV1NamespacedStatefulSet;
type ResponseContentType$deleteAppsV1NamespacedStatefulSet = keyof Response$deleteAppsV1NamespacedStatefulSet$Status$200 | keyof Response$deleteAppsV1NamespacedStatefulSet$Status$202;
interface Params$deleteAppsV1NamespacedStatefulSet<U extends ResponseContentType$deleteAppsV1NamespacedStatefulSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAppsV1NamespacedStatefulSet;
    requestBody: RequestBody$deleteAppsV1NamespacedStatefulSet["*/*"];
}
type RequestContentType$patchAppsV1NamespacedStatefulSet = keyof RequestBody$patchAppsV1NamespacedStatefulSet;
type ResponseContentType$patchAppsV1NamespacedStatefulSet = keyof Response$patchAppsV1NamespacedStatefulSet$Status$200 | keyof Response$patchAppsV1NamespacedStatefulSet$Status$201;
interface Params$patchAppsV1NamespacedStatefulSet<T extends RequestContentType$patchAppsV1NamespacedStatefulSet, U extends ResponseContentType$patchAppsV1NamespacedStatefulSet> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedStatefulSet;
    requestBody: RequestBody$patchAppsV1NamespacedStatefulSet[T];
}
type ResponseContentType$readAppsV1NamespacedStatefulSetScale = keyof Response$readAppsV1NamespacedStatefulSetScale$Status$200;
interface Params$readAppsV1NamespacedStatefulSetScale<U extends ResponseContentType$readAppsV1NamespacedStatefulSetScale> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedStatefulSetScale;
}
type RequestContentType$replaceAppsV1NamespacedStatefulSetScale = keyof RequestBody$replaceAppsV1NamespacedStatefulSetScale;
type ResponseContentType$replaceAppsV1NamespacedStatefulSetScale = keyof Response$replaceAppsV1NamespacedStatefulSetScale$Status$200 | keyof Response$replaceAppsV1NamespacedStatefulSetScale$Status$201;
interface Params$replaceAppsV1NamespacedStatefulSetScale<U extends ResponseContentType$replaceAppsV1NamespacedStatefulSetScale> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedStatefulSetScale;
    requestBody: RequestBody$replaceAppsV1NamespacedStatefulSetScale["*/*"];
}
type RequestContentType$patchAppsV1NamespacedStatefulSetScale = keyof RequestBody$patchAppsV1NamespacedStatefulSetScale;
type ResponseContentType$patchAppsV1NamespacedStatefulSetScale = keyof Response$patchAppsV1NamespacedStatefulSetScale$Status$200 | keyof Response$patchAppsV1NamespacedStatefulSetScale$Status$201;
interface Params$patchAppsV1NamespacedStatefulSetScale<T extends RequestContentType$patchAppsV1NamespacedStatefulSetScale, U extends ResponseContentType$patchAppsV1NamespacedStatefulSetScale> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedStatefulSetScale;
    requestBody: RequestBody$patchAppsV1NamespacedStatefulSetScale[T];
}
type ResponseContentType$readAppsV1NamespacedStatefulSetStatus = keyof Response$readAppsV1NamespacedStatefulSetStatus$Status$200;
interface Params$readAppsV1NamespacedStatefulSetStatus<U extends ResponseContentType$readAppsV1NamespacedStatefulSetStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAppsV1NamespacedStatefulSetStatus;
}
type RequestContentType$replaceAppsV1NamespacedStatefulSetStatus = keyof RequestBody$replaceAppsV1NamespacedStatefulSetStatus;
type ResponseContentType$replaceAppsV1NamespacedStatefulSetStatus = keyof Response$replaceAppsV1NamespacedStatefulSetStatus$Status$200 | keyof Response$replaceAppsV1NamespacedStatefulSetStatus$Status$201;
interface Params$replaceAppsV1NamespacedStatefulSetStatus<U extends ResponseContentType$replaceAppsV1NamespacedStatefulSetStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAppsV1NamespacedStatefulSetStatus;
    requestBody: RequestBody$replaceAppsV1NamespacedStatefulSetStatus["*/*"];
}
type RequestContentType$patchAppsV1NamespacedStatefulSetStatus = keyof RequestBody$patchAppsV1NamespacedStatefulSetStatus;
type ResponseContentType$patchAppsV1NamespacedStatefulSetStatus = keyof Response$patchAppsV1NamespacedStatefulSetStatus$Status$200 | keyof Response$patchAppsV1NamespacedStatefulSetStatus$Status$201;
interface Params$patchAppsV1NamespacedStatefulSetStatus<T extends RequestContentType$patchAppsV1NamespacedStatefulSetStatus, U extends ResponseContentType$patchAppsV1NamespacedStatefulSetStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAppsV1NamespacedStatefulSetStatus;
    requestBody: RequestBody$patchAppsV1NamespacedStatefulSetStatus[T];
}
type ResponseContentType$listAppsV1ReplicaSetForAllNamespaces = keyof Response$listAppsV1ReplicaSetForAllNamespaces$Status$200;
interface Params$listAppsV1ReplicaSetForAllNamespaces<U extends ResponseContentType$listAppsV1ReplicaSetForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAppsV1ReplicaSetForAllNamespaces;
}
type ResponseContentType$listAppsV1StatefulSetForAllNamespaces = keyof Response$listAppsV1StatefulSetForAllNamespaces$Status$200;
interface Params$listAppsV1StatefulSetForAllNamespaces<U extends ResponseContentType$listAppsV1StatefulSetForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAppsV1StatefulSetForAllNamespaces;
}
type ResponseContentType$watchAppsV1ControllerRevisionListForAllNamespaces = keyof Response$watchAppsV1ControllerRevisionListForAllNamespaces$Status$200;
interface Params$watchAppsV1ControllerRevisionListForAllNamespaces<U extends ResponseContentType$watchAppsV1ControllerRevisionListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1ControllerRevisionListForAllNamespaces;
}
type ResponseContentType$watchAppsV1DaemonSetListForAllNamespaces = keyof Response$watchAppsV1DaemonSetListForAllNamespaces$Status$200;
interface Params$watchAppsV1DaemonSetListForAllNamespaces<U extends ResponseContentType$watchAppsV1DaemonSetListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1DaemonSetListForAllNamespaces;
}
type ResponseContentType$watchAppsV1DeploymentListForAllNamespaces = keyof Response$watchAppsV1DeploymentListForAllNamespaces$Status$200;
interface Params$watchAppsV1DeploymentListForAllNamespaces<U extends ResponseContentType$watchAppsV1DeploymentListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1DeploymentListForAllNamespaces;
}
type ResponseContentType$watchAppsV1NamespacedControllerRevisionList = keyof Response$watchAppsV1NamespacedControllerRevisionList$Status$200;
interface Params$watchAppsV1NamespacedControllerRevisionList<U extends ResponseContentType$watchAppsV1NamespacedControllerRevisionList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1NamespacedControllerRevisionList;
}
type ResponseContentType$watchAppsV1NamespacedControllerRevision = keyof Response$watchAppsV1NamespacedControllerRevision$Status$200;
interface Params$watchAppsV1NamespacedControllerRevision<U extends ResponseContentType$watchAppsV1NamespacedControllerRevision> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1NamespacedControllerRevision;
}
type ResponseContentType$watchAppsV1NamespacedDaemonSetList = keyof Response$watchAppsV1NamespacedDaemonSetList$Status$200;
interface Params$watchAppsV1NamespacedDaemonSetList<U extends ResponseContentType$watchAppsV1NamespacedDaemonSetList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1NamespacedDaemonSetList;
}
type ResponseContentType$watchAppsV1NamespacedDaemonSet = keyof Response$watchAppsV1NamespacedDaemonSet$Status$200;
interface Params$watchAppsV1NamespacedDaemonSet<U extends ResponseContentType$watchAppsV1NamespacedDaemonSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1NamespacedDaemonSet;
}
type ResponseContentType$watchAppsV1NamespacedDeploymentList = keyof Response$watchAppsV1NamespacedDeploymentList$Status$200;
interface Params$watchAppsV1NamespacedDeploymentList<U extends ResponseContentType$watchAppsV1NamespacedDeploymentList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1NamespacedDeploymentList;
}
type ResponseContentType$watchAppsV1NamespacedDeployment = keyof Response$watchAppsV1NamespacedDeployment$Status$200;
interface Params$watchAppsV1NamespacedDeployment<U extends ResponseContentType$watchAppsV1NamespacedDeployment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1NamespacedDeployment;
}
type ResponseContentType$watchAppsV1NamespacedReplicaSetList = keyof Response$watchAppsV1NamespacedReplicaSetList$Status$200;
interface Params$watchAppsV1NamespacedReplicaSetList<U extends ResponseContentType$watchAppsV1NamespacedReplicaSetList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1NamespacedReplicaSetList;
}
type ResponseContentType$watchAppsV1NamespacedReplicaSet = keyof Response$watchAppsV1NamespacedReplicaSet$Status$200;
interface Params$watchAppsV1NamespacedReplicaSet<U extends ResponseContentType$watchAppsV1NamespacedReplicaSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1NamespacedReplicaSet;
}
type ResponseContentType$watchAppsV1NamespacedStatefulSetList = keyof Response$watchAppsV1NamespacedStatefulSetList$Status$200;
interface Params$watchAppsV1NamespacedStatefulSetList<U extends ResponseContentType$watchAppsV1NamespacedStatefulSetList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1NamespacedStatefulSetList;
}
type ResponseContentType$watchAppsV1NamespacedStatefulSet = keyof Response$watchAppsV1NamespacedStatefulSet$Status$200;
interface Params$watchAppsV1NamespacedStatefulSet<U extends ResponseContentType$watchAppsV1NamespacedStatefulSet> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1NamespacedStatefulSet;
}
type ResponseContentType$watchAppsV1ReplicaSetListForAllNamespaces = keyof Response$watchAppsV1ReplicaSetListForAllNamespaces$Status$200;
interface Params$watchAppsV1ReplicaSetListForAllNamespaces<U extends ResponseContentType$watchAppsV1ReplicaSetListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1ReplicaSetListForAllNamespaces;
}
type ResponseContentType$watchAppsV1StatefulSetListForAllNamespaces = keyof Response$watchAppsV1StatefulSetListForAllNamespaces$Status$200;
interface Params$watchAppsV1StatefulSetListForAllNamespaces<U extends ResponseContentType$watchAppsV1StatefulSetListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAppsV1StatefulSetListForAllNamespaces;
}
type ResponseContentType$getAuthenticationAPIGroup = keyof Response$getAuthenticationAPIGroup$Status$200;
interface Params$getAuthenticationAPIGroup<U extends ResponseContentType$getAuthenticationAPIGroup> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getAuthenticationV1APIResources = keyof Response$getAuthenticationV1APIResources$Status$200;
interface Params$getAuthenticationV1APIResources<U extends ResponseContentType$getAuthenticationV1APIResources> {
    headers: {
        Accept: U;
    };
}
type RequestContentType$createAuthenticationV1TokenReview = keyof RequestBody$createAuthenticationV1TokenReview;
type ResponseContentType$createAuthenticationV1TokenReview = keyof Response$createAuthenticationV1TokenReview$Status$200 | keyof Response$createAuthenticationV1TokenReview$Status$201 | keyof Response$createAuthenticationV1TokenReview$Status$202;
interface Params$createAuthenticationV1TokenReview<U extends ResponseContentType$createAuthenticationV1TokenReview> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAuthenticationV1TokenReview;
    requestBody: RequestBody$createAuthenticationV1TokenReview["*/*"];
}
type ResponseContentType$getAuthenticationV1alpha1APIResources = keyof Response$getAuthenticationV1alpha1APIResources$Status$200;
interface Params$getAuthenticationV1alpha1APIResources<U extends ResponseContentType$getAuthenticationV1alpha1APIResources> {
    headers: {
        Accept: U;
    };
}
type RequestContentType$createAuthenticationV1alpha1SelfSubjectReview = keyof RequestBody$createAuthenticationV1alpha1SelfSubjectReview;
type ResponseContentType$createAuthenticationV1alpha1SelfSubjectReview = keyof Response$createAuthenticationV1alpha1SelfSubjectReview$Status$200 | keyof Response$createAuthenticationV1alpha1SelfSubjectReview$Status$201 | keyof Response$createAuthenticationV1alpha1SelfSubjectReview$Status$202;
interface Params$createAuthenticationV1alpha1SelfSubjectReview<U extends ResponseContentType$createAuthenticationV1alpha1SelfSubjectReview> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAuthenticationV1alpha1SelfSubjectReview;
    requestBody: RequestBody$createAuthenticationV1alpha1SelfSubjectReview["*/*"];
}
type ResponseContentType$getAuthenticationV1beta1APIResources = keyof Response$getAuthenticationV1beta1APIResources$Status$200;
interface Params$getAuthenticationV1beta1APIResources<U extends ResponseContentType$getAuthenticationV1beta1APIResources> {
    headers: {
        Accept: U;
    };
}
type RequestContentType$createAuthenticationV1beta1SelfSubjectReview = keyof RequestBody$createAuthenticationV1beta1SelfSubjectReview;
type ResponseContentType$createAuthenticationV1beta1SelfSubjectReview = keyof Response$createAuthenticationV1beta1SelfSubjectReview$Status$200 | keyof Response$createAuthenticationV1beta1SelfSubjectReview$Status$201 | keyof Response$createAuthenticationV1beta1SelfSubjectReview$Status$202;
interface Params$createAuthenticationV1beta1SelfSubjectReview<U extends ResponseContentType$createAuthenticationV1beta1SelfSubjectReview> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAuthenticationV1beta1SelfSubjectReview;
    requestBody: RequestBody$createAuthenticationV1beta1SelfSubjectReview["*/*"];
}
type ResponseContentType$getAuthorizationAPIGroup = keyof Response$getAuthorizationAPIGroup$Status$200;
interface Params$getAuthorizationAPIGroup<U extends ResponseContentType$getAuthorizationAPIGroup> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getAuthorizationV1APIResources = keyof Response$getAuthorizationV1APIResources$Status$200;
interface Params$getAuthorizationV1APIResources<U extends ResponseContentType$getAuthorizationV1APIResources> {
    headers: {
        Accept: U;
    };
}
type RequestContentType$createAuthorizationV1NamespacedLocalSubjectAccessReview = keyof RequestBody$createAuthorizationV1NamespacedLocalSubjectAccessReview;
type ResponseContentType$createAuthorizationV1NamespacedLocalSubjectAccessReview = keyof Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$200 | keyof Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$201 | keyof Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$202;
interface Params$createAuthorizationV1NamespacedLocalSubjectAccessReview<U extends ResponseContentType$createAuthorizationV1NamespacedLocalSubjectAccessReview> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAuthorizationV1NamespacedLocalSubjectAccessReview;
    requestBody: RequestBody$createAuthorizationV1NamespacedLocalSubjectAccessReview["*/*"];
}
type RequestContentType$createAuthorizationV1SelfSubjectAccessReview = keyof RequestBody$createAuthorizationV1SelfSubjectAccessReview;
type ResponseContentType$createAuthorizationV1SelfSubjectAccessReview = keyof Response$createAuthorizationV1SelfSubjectAccessReview$Status$200 | keyof Response$createAuthorizationV1SelfSubjectAccessReview$Status$201 | keyof Response$createAuthorizationV1SelfSubjectAccessReview$Status$202;
interface Params$createAuthorizationV1SelfSubjectAccessReview<U extends ResponseContentType$createAuthorizationV1SelfSubjectAccessReview> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAuthorizationV1SelfSubjectAccessReview;
    requestBody: RequestBody$createAuthorizationV1SelfSubjectAccessReview["*/*"];
}
type RequestContentType$createAuthorizationV1SelfSubjectRulesReview = keyof RequestBody$createAuthorizationV1SelfSubjectRulesReview;
type ResponseContentType$createAuthorizationV1SelfSubjectRulesReview = keyof Response$createAuthorizationV1SelfSubjectRulesReview$Status$200 | keyof Response$createAuthorizationV1SelfSubjectRulesReview$Status$201 | keyof Response$createAuthorizationV1SelfSubjectRulesReview$Status$202;
interface Params$createAuthorizationV1SelfSubjectRulesReview<U extends ResponseContentType$createAuthorizationV1SelfSubjectRulesReview> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAuthorizationV1SelfSubjectRulesReview;
    requestBody: RequestBody$createAuthorizationV1SelfSubjectRulesReview["*/*"];
}
type RequestContentType$createAuthorizationV1SubjectAccessReview = keyof RequestBody$createAuthorizationV1SubjectAccessReview;
type ResponseContentType$createAuthorizationV1SubjectAccessReview = keyof Response$createAuthorizationV1SubjectAccessReview$Status$200 | keyof Response$createAuthorizationV1SubjectAccessReview$Status$201 | keyof Response$createAuthorizationV1SubjectAccessReview$Status$202;
interface Params$createAuthorizationV1SubjectAccessReview<U extends ResponseContentType$createAuthorizationV1SubjectAccessReview> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAuthorizationV1SubjectAccessReview;
    requestBody: RequestBody$createAuthorizationV1SubjectAccessReview["*/*"];
}
type ResponseContentType$getAutoscalingAPIGroup = keyof Response$getAutoscalingAPIGroup$Status$200;
interface Params$getAutoscalingAPIGroup<U extends ResponseContentType$getAutoscalingAPIGroup> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getAutoscalingV1APIResources = keyof Response$getAutoscalingV1APIResources$Status$200;
interface Params$getAutoscalingV1APIResources<U extends ResponseContentType$getAutoscalingV1APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces = keyof Response$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces$Status$200;
interface Params$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces<U extends ResponseContentType$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces;
}
type ResponseContentType$listAutoscalingV1NamespacedHorizontalPodAutoscaler = keyof Response$listAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200;
interface Params$listAutoscalingV1NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$listAutoscalingV1NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAutoscalingV1NamespacedHorizontalPodAutoscaler;
}
type RequestContentType$createAutoscalingV1NamespacedHorizontalPodAutoscaler = keyof RequestBody$createAutoscalingV1NamespacedHorizontalPodAutoscaler;
type ResponseContentType$createAutoscalingV1NamespacedHorizontalPodAutoscaler = keyof Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201 | keyof Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$202;
interface Params$createAutoscalingV1NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$createAutoscalingV1NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAutoscalingV1NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$createAutoscalingV1NamespacedHorizontalPodAutoscaler["*/*"];
}
type RequestContentType$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler = keyof RequestBody$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler;
type ResponseContentType$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler = keyof Response$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler$Status$200;
interface Params$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler<U extends ResponseContentType$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler["*/*"];
}
type ResponseContentType$readAutoscalingV1NamespacedHorizontalPodAutoscaler = keyof Response$readAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200;
interface Params$readAutoscalingV1NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$readAutoscalingV1NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAutoscalingV1NamespacedHorizontalPodAutoscaler;
}
type RequestContentType$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler = keyof RequestBody$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler;
type ResponseContentType$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler = keyof Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201;
interface Params$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler["*/*"];
}
type RequestContentType$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler = keyof RequestBody$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler;
type ResponseContentType$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler = keyof Response$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$202;
interface Params$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler["*/*"];
}
type RequestContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscaler = keyof RequestBody$patchAutoscalingV1NamespacedHorizontalPodAutoscaler;
type ResponseContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscaler = keyof Response$patchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$patchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201;
interface Params$patchAutoscalingV1NamespacedHorizontalPodAutoscaler<T extends RequestContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscaler, U extends ResponseContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscaler> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAutoscalingV1NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$patchAutoscalingV1NamespacedHorizontalPodAutoscaler[T];
}
type ResponseContentType$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus = keyof Response$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200;
interface Params$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus<U extends ResponseContentType$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus;
}
type RequestContentType$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus = keyof RequestBody$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus;
type ResponseContentType$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus = keyof Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200 | keyof Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$201;
interface Params$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus<U extends ResponseContentType$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus;
    requestBody: RequestBody$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus["*/*"];
}
type RequestContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus = keyof RequestBody$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus;
type ResponseContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus = keyof Response$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200 | keyof Response$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$201;
interface Params$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus<T extends RequestContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus, U extends ResponseContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus;
    requestBody: RequestBody$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus[T];
}
type ResponseContentType$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces = keyof Response$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces$Status$200;
interface Params$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces<U extends ResponseContentType$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces;
}
type ResponseContentType$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList = keyof Response$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList$Status$200;
interface Params$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList<U extends ResponseContentType$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList;
}
type ResponseContentType$watchAutoscalingV1NamespacedHorizontalPodAutoscaler = keyof Response$watchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200;
interface Params$watchAutoscalingV1NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$watchAutoscalingV1NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAutoscalingV1NamespacedHorizontalPodAutoscaler;
}
type ResponseContentType$getAutoscalingV2APIResources = keyof Response$getAutoscalingV2APIResources$Status$200;
interface Params$getAutoscalingV2APIResources<U extends ResponseContentType$getAutoscalingV2APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces = keyof Response$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces$Status$200;
interface Params$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces<U extends ResponseContentType$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces;
}
type ResponseContentType$listAutoscalingV2NamespacedHorizontalPodAutoscaler = keyof Response$listAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200;
interface Params$listAutoscalingV2NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$listAutoscalingV2NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listAutoscalingV2NamespacedHorizontalPodAutoscaler;
}
type RequestContentType$createAutoscalingV2NamespacedHorizontalPodAutoscaler = keyof RequestBody$createAutoscalingV2NamespacedHorizontalPodAutoscaler;
type ResponseContentType$createAutoscalingV2NamespacedHorizontalPodAutoscaler = keyof Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201 | keyof Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$202;
interface Params$createAutoscalingV2NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$createAutoscalingV2NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createAutoscalingV2NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$createAutoscalingV2NamespacedHorizontalPodAutoscaler["*/*"];
}
type RequestContentType$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler = keyof RequestBody$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler;
type ResponseContentType$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler = keyof Response$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler$Status$200;
interface Params$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler<U extends ResponseContentType$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler["*/*"];
}
type ResponseContentType$readAutoscalingV2NamespacedHorizontalPodAutoscaler = keyof Response$readAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200;
interface Params$readAutoscalingV2NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$readAutoscalingV2NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAutoscalingV2NamespacedHorizontalPodAutoscaler;
}
type RequestContentType$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler = keyof RequestBody$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler;
type ResponseContentType$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler = keyof Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201;
interface Params$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler["*/*"];
}
type RequestContentType$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler = keyof RequestBody$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler;
type ResponseContentType$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler = keyof Response$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$202;
interface Params$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler["*/*"];
}
type RequestContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscaler = keyof RequestBody$patchAutoscalingV2NamespacedHorizontalPodAutoscaler;
type ResponseContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscaler = keyof Response$patchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | keyof Response$patchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201;
interface Params$patchAutoscalingV2NamespacedHorizontalPodAutoscaler<T extends RequestContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscaler, U extends ResponseContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscaler> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAutoscalingV2NamespacedHorizontalPodAutoscaler;
    requestBody: RequestBody$patchAutoscalingV2NamespacedHorizontalPodAutoscaler[T];
}
type ResponseContentType$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus = keyof Response$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200;
interface Params$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus<U extends ResponseContentType$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus;
}
type RequestContentType$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus = keyof RequestBody$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus;
type ResponseContentType$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus = keyof Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200 | keyof Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$201;
interface Params$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus<U extends ResponseContentType$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus;
    requestBody: RequestBody$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus["*/*"];
}
type RequestContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus = keyof RequestBody$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus;
type ResponseContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus = keyof Response$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200 | keyof Response$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$201;
interface Params$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus<T extends RequestContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus, U extends ResponseContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus;
    requestBody: RequestBody$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus[T];
}
type ResponseContentType$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces = keyof Response$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces$Status$200;
interface Params$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces<U extends ResponseContentType$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces;
}
type ResponseContentType$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList = keyof Response$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList$Status$200;
interface Params$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList<U extends ResponseContentType$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList;
}
type ResponseContentType$watchAutoscalingV2NamespacedHorizontalPodAutoscaler = keyof Response$watchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200;
interface Params$watchAutoscalingV2NamespacedHorizontalPodAutoscaler<U extends ResponseContentType$watchAutoscalingV2NamespacedHorizontalPodAutoscaler> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchAutoscalingV2NamespacedHorizontalPodAutoscaler;
}
type ResponseContentType$getBatchAPIGroup = keyof Response$getBatchAPIGroup$Status$200;
interface Params$getBatchAPIGroup<U extends ResponseContentType$getBatchAPIGroup> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getBatchV1APIResources = keyof Response$getBatchV1APIResources$Status$200;
interface Params$getBatchV1APIResources<U extends ResponseContentType$getBatchV1APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listBatchV1CronJobForAllNamespaces = keyof Response$listBatchV1CronJobForAllNamespaces$Status$200;
interface Params$listBatchV1CronJobForAllNamespaces<U extends ResponseContentType$listBatchV1CronJobForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listBatchV1CronJobForAllNamespaces;
}
type ResponseContentType$listBatchV1JobForAllNamespaces = keyof Response$listBatchV1JobForAllNamespaces$Status$200;
interface Params$listBatchV1JobForAllNamespaces<U extends ResponseContentType$listBatchV1JobForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listBatchV1JobForAllNamespaces;
}
type ResponseContentType$listBatchV1NamespacedCronJob = keyof Response$listBatchV1NamespacedCronJob$Status$200;
interface Params$listBatchV1NamespacedCronJob<U extends ResponseContentType$listBatchV1NamespacedCronJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listBatchV1NamespacedCronJob;
}
type RequestContentType$createBatchV1NamespacedCronJob = keyof RequestBody$createBatchV1NamespacedCronJob;
type ResponseContentType$createBatchV1NamespacedCronJob = keyof Response$createBatchV1NamespacedCronJob$Status$200 | keyof Response$createBatchV1NamespacedCronJob$Status$201 | keyof Response$createBatchV1NamespacedCronJob$Status$202;
interface Params$createBatchV1NamespacedCronJob<U extends ResponseContentType$createBatchV1NamespacedCronJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createBatchV1NamespacedCronJob;
    requestBody: RequestBody$createBatchV1NamespacedCronJob["*/*"];
}
type RequestContentType$deleteBatchV1CollectionNamespacedCronJob = keyof RequestBody$deleteBatchV1CollectionNamespacedCronJob;
type ResponseContentType$deleteBatchV1CollectionNamespacedCronJob = keyof Response$deleteBatchV1CollectionNamespacedCronJob$Status$200;
interface Params$deleteBatchV1CollectionNamespacedCronJob<U extends ResponseContentType$deleteBatchV1CollectionNamespacedCronJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteBatchV1CollectionNamespacedCronJob;
    requestBody: RequestBody$deleteBatchV1CollectionNamespacedCronJob["*/*"];
}
type ResponseContentType$readBatchV1NamespacedCronJob = keyof Response$readBatchV1NamespacedCronJob$Status$200;
interface Params$readBatchV1NamespacedCronJob<U extends ResponseContentType$readBatchV1NamespacedCronJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readBatchV1NamespacedCronJob;
}
type RequestContentType$replaceBatchV1NamespacedCronJob = keyof RequestBody$replaceBatchV1NamespacedCronJob;
type ResponseContentType$replaceBatchV1NamespacedCronJob = keyof Response$replaceBatchV1NamespacedCronJob$Status$200 | keyof Response$replaceBatchV1NamespacedCronJob$Status$201;
interface Params$replaceBatchV1NamespacedCronJob<U extends ResponseContentType$replaceBatchV1NamespacedCronJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceBatchV1NamespacedCronJob;
    requestBody: RequestBody$replaceBatchV1NamespacedCronJob["*/*"];
}
type RequestContentType$deleteBatchV1NamespacedCronJob = keyof RequestBody$deleteBatchV1NamespacedCronJob;
type ResponseContentType$deleteBatchV1NamespacedCronJob = keyof Response$deleteBatchV1NamespacedCronJob$Status$200 | keyof Response$deleteBatchV1NamespacedCronJob$Status$202;
interface Params$deleteBatchV1NamespacedCronJob<U extends ResponseContentType$deleteBatchV1NamespacedCronJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteBatchV1NamespacedCronJob;
    requestBody: RequestBody$deleteBatchV1NamespacedCronJob["*/*"];
}
type RequestContentType$patchBatchV1NamespacedCronJob = keyof RequestBody$patchBatchV1NamespacedCronJob;
type ResponseContentType$patchBatchV1NamespacedCronJob = keyof Response$patchBatchV1NamespacedCronJob$Status$200 | keyof Response$patchBatchV1NamespacedCronJob$Status$201;
interface Params$patchBatchV1NamespacedCronJob<T extends RequestContentType$patchBatchV1NamespacedCronJob, U extends ResponseContentType$patchBatchV1NamespacedCronJob> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchBatchV1NamespacedCronJob;
    requestBody: RequestBody$patchBatchV1NamespacedCronJob[T];
}
type ResponseContentType$readBatchV1NamespacedCronJobStatus = keyof Response$readBatchV1NamespacedCronJobStatus$Status$200;
interface Params$readBatchV1NamespacedCronJobStatus<U extends ResponseContentType$readBatchV1NamespacedCronJobStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readBatchV1NamespacedCronJobStatus;
}
type RequestContentType$replaceBatchV1NamespacedCronJobStatus = keyof RequestBody$replaceBatchV1NamespacedCronJobStatus;
type ResponseContentType$replaceBatchV1NamespacedCronJobStatus = keyof Response$replaceBatchV1NamespacedCronJobStatus$Status$200 | keyof Response$replaceBatchV1NamespacedCronJobStatus$Status$201;
interface Params$replaceBatchV1NamespacedCronJobStatus<U extends ResponseContentType$replaceBatchV1NamespacedCronJobStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceBatchV1NamespacedCronJobStatus;
    requestBody: RequestBody$replaceBatchV1NamespacedCronJobStatus["*/*"];
}
type RequestContentType$patchBatchV1NamespacedCronJobStatus = keyof RequestBody$patchBatchV1NamespacedCronJobStatus;
type ResponseContentType$patchBatchV1NamespacedCronJobStatus = keyof Response$patchBatchV1NamespacedCronJobStatus$Status$200 | keyof Response$patchBatchV1NamespacedCronJobStatus$Status$201;
interface Params$patchBatchV1NamespacedCronJobStatus<T extends RequestContentType$patchBatchV1NamespacedCronJobStatus, U extends ResponseContentType$patchBatchV1NamespacedCronJobStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchBatchV1NamespacedCronJobStatus;
    requestBody: RequestBody$patchBatchV1NamespacedCronJobStatus[T];
}
type ResponseContentType$listBatchV1NamespacedJob = keyof Response$listBatchV1NamespacedJob$Status$200;
interface Params$listBatchV1NamespacedJob<U extends ResponseContentType$listBatchV1NamespacedJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listBatchV1NamespacedJob;
}
type RequestContentType$createBatchV1NamespacedJob = keyof RequestBody$createBatchV1NamespacedJob;
type ResponseContentType$createBatchV1NamespacedJob = keyof Response$createBatchV1NamespacedJob$Status$200 | keyof Response$createBatchV1NamespacedJob$Status$201 | keyof Response$createBatchV1NamespacedJob$Status$202;
interface Params$createBatchV1NamespacedJob<U extends ResponseContentType$createBatchV1NamespacedJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createBatchV1NamespacedJob;
    requestBody: RequestBody$createBatchV1NamespacedJob["*/*"];
}
type RequestContentType$deleteBatchV1CollectionNamespacedJob = keyof RequestBody$deleteBatchV1CollectionNamespacedJob;
type ResponseContentType$deleteBatchV1CollectionNamespacedJob = keyof Response$deleteBatchV1CollectionNamespacedJob$Status$200;
interface Params$deleteBatchV1CollectionNamespacedJob<U extends ResponseContentType$deleteBatchV1CollectionNamespacedJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteBatchV1CollectionNamespacedJob;
    requestBody: RequestBody$deleteBatchV1CollectionNamespacedJob["*/*"];
}
type ResponseContentType$readBatchV1NamespacedJob = keyof Response$readBatchV1NamespacedJob$Status$200;
interface Params$readBatchV1NamespacedJob<U extends ResponseContentType$readBatchV1NamespacedJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readBatchV1NamespacedJob;
}
type RequestContentType$replaceBatchV1NamespacedJob = keyof RequestBody$replaceBatchV1NamespacedJob;
type ResponseContentType$replaceBatchV1NamespacedJob = keyof Response$replaceBatchV1NamespacedJob$Status$200 | keyof Response$replaceBatchV1NamespacedJob$Status$201;
interface Params$replaceBatchV1NamespacedJob<U extends ResponseContentType$replaceBatchV1NamespacedJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceBatchV1NamespacedJob;
    requestBody: RequestBody$replaceBatchV1NamespacedJob["*/*"];
}
type RequestContentType$deleteBatchV1NamespacedJob = keyof RequestBody$deleteBatchV1NamespacedJob;
type ResponseContentType$deleteBatchV1NamespacedJob = keyof Response$deleteBatchV1NamespacedJob$Status$200 | keyof Response$deleteBatchV1NamespacedJob$Status$202;
interface Params$deleteBatchV1NamespacedJob<U extends ResponseContentType$deleteBatchV1NamespacedJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteBatchV1NamespacedJob;
    requestBody: RequestBody$deleteBatchV1NamespacedJob["*/*"];
}
type RequestContentType$patchBatchV1NamespacedJob = keyof RequestBody$patchBatchV1NamespacedJob;
type ResponseContentType$patchBatchV1NamespacedJob = keyof Response$patchBatchV1NamespacedJob$Status$200 | keyof Response$patchBatchV1NamespacedJob$Status$201;
interface Params$patchBatchV1NamespacedJob<T extends RequestContentType$patchBatchV1NamespacedJob, U extends ResponseContentType$patchBatchV1NamespacedJob> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchBatchV1NamespacedJob;
    requestBody: RequestBody$patchBatchV1NamespacedJob[T];
}
type ResponseContentType$readBatchV1NamespacedJobStatus = keyof Response$readBatchV1NamespacedJobStatus$Status$200;
interface Params$readBatchV1NamespacedJobStatus<U extends ResponseContentType$readBatchV1NamespacedJobStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readBatchV1NamespacedJobStatus;
}
type RequestContentType$replaceBatchV1NamespacedJobStatus = keyof RequestBody$replaceBatchV1NamespacedJobStatus;
type ResponseContentType$replaceBatchV1NamespacedJobStatus = keyof Response$replaceBatchV1NamespacedJobStatus$Status$200 | keyof Response$replaceBatchV1NamespacedJobStatus$Status$201;
interface Params$replaceBatchV1NamespacedJobStatus<U extends ResponseContentType$replaceBatchV1NamespacedJobStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceBatchV1NamespacedJobStatus;
    requestBody: RequestBody$replaceBatchV1NamespacedJobStatus["*/*"];
}
type RequestContentType$patchBatchV1NamespacedJobStatus = keyof RequestBody$patchBatchV1NamespacedJobStatus;
type ResponseContentType$patchBatchV1NamespacedJobStatus = keyof Response$patchBatchV1NamespacedJobStatus$Status$200 | keyof Response$patchBatchV1NamespacedJobStatus$Status$201;
interface Params$patchBatchV1NamespacedJobStatus<T extends RequestContentType$patchBatchV1NamespacedJobStatus, U extends ResponseContentType$patchBatchV1NamespacedJobStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchBatchV1NamespacedJobStatus;
    requestBody: RequestBody$patchBatchV1NamespacedJobStatus[T];
}
type ResponseContentType$watchBatchV1CronJobListForAllNamespaces = keyof Response$watchBatchV1CronJobListForAllNamespaces$Status$200;
interface Params$watchBatchV1CronJobListForAllNamespaces<U extends ResponseContentType$watchBatchV1CronJobListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchBatchV1CronJobListForAllNamespaces;
}
type ResponseContentType$watchBatchV1JobListForAllNamespaces = keyof Response$watchBatchV1JobListForAllNamespaces$Status$200;
interface Params$watchBatchV1JobListForAllNamespaces<U extends ResponseContentType$watchBatchV1JobListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchBatchV1JobListForAllNamespaces;
}
type ResponseContentType$watchBatchV1NamespacedCronJobList = keyof Response$watchBatchV1NamespacedCronJobList$Status$200;
interface Params$watchBatchV1NamespacedCronJobList<U extends ResponseContentType$watchBatchV1NamespacedCronJobList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchBatchV1NamespacedCronJobList;
}
type ResponseContentType$watchBatchV1NamespacedCronJob = keyof Response$watchBatchV1NamespacedCronJob$Status$200;
interface Params$watchBatchV1NamespacedCronJob<U extends ResponseContentType$watchBatchV1NamespacedCronJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchBatchV1NamespacedCronJob;
}
type ResponseContentType$watchBatchV1NamespacedJobList = keyof Response$watchBatchV1NamespacedJobList$Status$200;
interface Params$watchBatchV1NamespacedJobList<U extends ResponseContentType$watchBatchV1NamespacedJobList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchBatchV1NamespacedJobList;
}
type ResponseContentType$watchBatchV1NamespacedJob = keyof Response$watchBatchV1NamespacedJob$Status$200;
interface Params$watchBatchV1NamespacedJob<U extends ResponseContentType$watchBatchV1NamespacedJob> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchBatchV1NamespacedJob;
}
type ResponseContentType$getCertificatesAPIGroup = keyof Response$getCertificatesAPIGroup$Status$200;
interface Params$getCertificatesAPIGroup<U extends ResponseContentType$getCertificatesAPIGroup> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getCertificatesV1APIResources = keyof Response$getCertificatesV1APIResources$Status$200;
interface Params$getCertificatesV1APIResources<U extends ResponseContentType$getCertificatesV1APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listCertificatesV1CertificateSigningRequest = keyof Response$listCertificatesV1CertificateSigningRequest$Status$200;
interface Params$listCertificatesV1CertificateSigningRequest<U extends ResponseContentType$listCertificatesV1CertificateSigningRequest> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCertificatesV1CertificateSigningRequest;
}
type RequestContentType$createCertificatesV1CertificateSigningRequest = keyof RequestBody$createCertificatesV1CertificateSigningRequest;
type ResponseContentType$createCertificatesV1CertificateSigningRequest = keyof Response$createCertificatesV1CertificateSigningRequest$Status$200 | keyof Response$createCertificatesV1CertificateSigningRequest$Status$201 | keyof Response$createCertificatesV1CertificateSigningRequest$Status$202;
interface Params$createCertificatesV1CertificateSigningRequest<U extends ResponseContentType$createCertificatesV1CertificateSigningRequest> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCertificatesV1CertificateSigningRequest;
    requestBody: RequestBody$createCertificatesV1CertificateSigningRequest["*/*"];
}
type RequestContentType$deleteCertificatesV1CollectionCertificateSigningRequest = keyof RequestBody$deleteCertificatesV1CollectionCertificateSigningRequest;
type ResponseContentType$deleteCertificatesV1CollectionCertificateSigningRequest = keyof Response$deleteCertificatesV1CollectionCertificateSigningRequest$Status$200;
interface Params$deleteCertificatesV1CollectionCertificateSigningRequest<U extends ResponseContentType$deleteCertificatesV1CollectionCertificateSigningRequest> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCertificatesV1CollectionCertificateSigningRequest;
    requestBody: RequestBody$deleteCertificatesV1CollectionCertificateSigningRequest["*/*"];
}
type ResponseContentType$readCertificatesV1CertificateSigningRequest = keyof Response$readCertificatesV1CertificateSigningRequest$Status$200;
interface Params$readCertificatesV1CertificateSigningRequest<U extends ResponseContentType$readCertificatesV1CertificateSigningRequest> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCertificatesV1CertificateSigningRequest;
}
type RequestContentType$replaceCertificatesV1CertificateSigningRequest = keyof RequestBody$replaceCertificatesV1CertificateSigningRequest;
type ResponseContentType$replaceCertificatesV1CertificateSigningRequest = keyof Response$replaceCertificatesV1CertificateSigningRequest$Status$200 | keyof Response$replaceCertificatesV1CertificateSigningRequest$Status$201;
interface Params$replaceCertificatesV1CertificateSigningRequest<U extends ResponseContentType$replaceCertificatesV1CertificateSigningRequest> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCertificatesV1CertificateSigningRequest;
    requestBody: RequestBody$replaceCertificatesV1CertificateSigningRequest["*/*"];
}
type RequestContentType$deleteCertificatesV1CertificateSigningRequest = keyof RequestBody$deleteCertificatesV1CertificateSigningRequest;
type ResponseContentType$deleteCertificatesV1CertificateSigningRequest = keyof Response$deleteCertificatesV1CertificateSigningRequest$Status$200 | keyof Response$deleteCertificatesV1CertificateSigningRequest$Status$202;
interface Params$deleteCertificatesV1CertificateSigningRequest<U extends ResponseContentType$deleteCertificatesV1CertificateSigningRequest> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCertificatesV1CertificateSigningRequest;
    requestBody: RequestBody$deleteCertificatesV1CertificateSigningRequest["*/*"];
}
type RequestContentType$patchCertificatesV1CertificateSigningRequest = keyof RequestBody$patchCertificatesV1CertificateSigningRequest;
type ResponseContentType$patchCertificatesV1CertificateSigningRequest = keyof Response$patchCertificatesV1CertificateSigningRequest$Status$200 | keyof Response$patchCertificatesV1CertificateSigningRequest$Status$201;
interface Params$patchCertificatesV1CertificateSigningRequest<T extends RequestContentType$patchCertificatesV1CertificateSigningRequest, U extends ResponseContentType$patchCertificatesV1CertificateSigningRequest> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCertificatesV1CertificateSigningRequest;
    requestBody: RequestBody$patchCertificatesV1CertificateSigningRequest[T];
}
type ResponseContentType$readCertificatesV1CertificateSigningRequestApproval = keyof Response$readCertificatesV1CertificateSigningRequestApproval$Status$200;
interface Params$readCertificatesV1CertificateSigningRequestApproval<U extends ResponseContentType$readCertificatesV1CertificateSigningRequestApproval> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCertificatesV1CertificateSigningRequestApproval;
}
type RequestContentType$replaceCertificatesV1CertificateSigningRequestApproval = keyof RequestBody$replaceCertificatesV1CertificateSigningRequestApproval;
type ResponseContentType$replaceCertificatesV1CertificateSigningRequestApproval = keyof Response$replaceCertificatesV1CertificateSigningRequestApproval$Status$200 | keyof Response$replaceCertificatesV1CertificateSigningRequestApproval$Status$201;
interface Params$replaceCertificatesV1CertificateSigningRequestApproval<U extends ResponseContentType$replaceCertificatesV1CertificateSigningRequestApproval> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCertificatesV1CertificateSigningRequestApproval;
    requestBody: RequestBody$replaceCertificatesV1CertificateSigningRequestApproval["*/*"];
}
type RequestContentType$patchCertificatesV1CertificateSigningRequestApproval = keyof RequestBody$patchCertificatesV1CertificateSigningRequestApproval;
type ResponseContentType$patchCertificatesV1CertificateSigningRequestApproval = keyof Response$patchCertificatesV1CertificateSigningRequestApproval$Status$200 | keyof Response$patchCertificatesV1CertificateSigningRequestApproval$Status$201;
interface Params$patchCertificatesV1CertificateSigningRequestApproval<T extends RequestContentType$patchCertificatesV1CertificateSigningRequestApproval, U extends ResponseContentType$patchCertificatesV1CertificateSigningRequestApproval> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCertificatesV1CertificateSigningRequestApproval;
    requestBody: RequestBody$patchCertificatesV1CertificateSigningRequestApproval[T];
}
type ResponseContentType$readCertificatesV1CertificateSigningRequestStatus = keyof Response$readCertificatesV1CertificateSigningRequestStatus$Status$200;
interface Params$readCertificatesV1CertificateSigningRequestStatus<U extends ResponseContentType$readCertificatesV1CertificateSigningRequestStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCertificatesV1CertificateSigningRequestStatus;
}
type RequestContentType$replaceCertificatesV1CertificateSigningRequestStatus = keyof RequestBody$replaceCertificatesV1CertificateSigningRequestStatus;
type ResponseContentType$replaceCertificatesV1CertificateSigningRequestStatus = keyof Response$replaceCertificatesV1CertificateSigningRequestStatus$Status$200 | keyof Response$replaceCertificatesV1CertificateSigningRequestStatus$Status$201;
interface Params$replaceCertificatesV1CertificateSigningRequestStatus<U extends ResponseContentType$replaceCertificatesV1CertificateSigningRequestStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCertificatesV1CertificateSigningRequestStatus;
    requestBody: RequestBody$replaceCertificatesV1CertificateSigningRequestStatus["*/*"];
}
type RequestContentType$patchCertificatesV1CertificateSigningRequestStatus = keyof RequestBody$patchCertificatesV1CertificateSigningRequestStatus;
type ResponseContentType$patchCertificatesV1CertificateSigningRequestStatus = keyof Response$patchCertificatesV1CertificateSigningRequestStatus$Status$200 | keyof Response$patchCertificatesV1CertificateSigningRequestStatus$Status$201;
interface Params$patchCertificatesV1CertificateSigningRequestStatus<T extends RequestContentType$patchCertificatesV1CertificateSigningRequestStatus, U extends ResponseContentType$patchCertificatesV1CertificateSigningRequestStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCertificatesV1CertificateSigningRequestStatus;
    requestBody: RequestBody$patchCertificatesV1CertificateSigningRequestStatus[T];
}
type ResponseContentType$watchCertificatesV1CertificateSigningRequestList = keyof Response$watchCertificatesV1CertificateSigningRequestList$Status$200;
interface Params$watchCertificatesV1CertificateSigningRequestList<U extends ResponseContentType$watchCertificatesV1CertificateSigningRequestList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCertificatesV1CertificateSigningRequestList;
}
type ResponseContentType$watchCertificatesV1CertificateSigningRequest = keyof Response$watchCertificatesV1CertificateSigningRequest$Status$200;
interface Params$watchCertificatesV1CertificateSigningRequest<U extends ResponseContentType$watchCertificatesV1CertificateSigningRequest> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCertificatesV1CertificateSigningRequest;
}
type ResponseContentType$getCertificatesV1alpha1APIResources = keyof Response$getCertificatesV1alpha1APIResources$Status$200;
interface Params$getCertificatesV1alpha1APIResources<U extends ResponseContentType$getCertificatesV1alpha1APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listCertificatesV1alpha1ClusterTrustBundle = keyof Response$listCertificatesV1alpha1ClusterTrustBundle$Status$200;
interface Params$listCertificatesV1alpha1ClusterTrustBundle<U extends ResponseContentType$listCertificatesV1alpha1ClusterTrustBundle> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCertificatesV1alpha1ClusterTrustBundle;
}
type RequestContentType$createCertificatesV1alpha1ClusterTrustBundle = keyof RequestBody$createCertificatesV1alpha1ClusterTrustBundle;
type ResponseContentType$createCertificatesV1alpha1ClusterTrustBundle = keyof Response$createCertificatesV1alpha1ClusterTrustBundle$Status$200 | keyof Response$createCertificatesV1alpha1ClusterTrustBundle$Status$201 | keyof Response$createCertificatesV1alpha1ClusterTrustBundle$Status$202;
interface Params$createCertificatesV1alpha1ClusterTrustBundle<U extends ResponseContentType$createCertificatesV1alpha1ClusterTrustBundle> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCertificatesV1alpha1ClusterTrustBundle;
    requestBody: RequestBody$createCertificatesV1alpha1ClusterTrustBundle["*/*"];
}
type RequestContentType$deleteCertificatesV1alpha1CollectionClusterTrustBundle = keyof RequestBody$deleteCertificatesV1alpha1CollectionClusterTrustBundle;
type ResponseContentType$deleteCertificatesV1alpha1CollectionClusterTrustBundle = keyof Response$deleteCertificatesV1alpha1CollectionClusterTrustBundle$Status$200;
interface Params$deleteCertificatesV1alpha1CollectionClusterTrustBundle<U extends ResponseContentType$deleteCertificatesV1alpha1CollectionClusterTrustBundle> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCertificatesV1alpha1CollectionClusterTrustBundle;
    requestBody: RequestBody$deleteCertificatesV1alpha1CollectionClusterTrustBundle["*/*"];
}
type ResponseContentType$readCertificatesV1alpha1ClusterTrustBundle = keyof Response$readCertificatesV1alpha1ClusterTrustBundle$Status$200;
interface Params$readCertificatesV1alpha1ClusterTrustBundle<U extends ResponseContentType$readCertificatesV1alpha1ClusterTrustBundle> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCertificatesV1alpha1ClusterTrustBundle;
}
type RequestContentType$replaceCertificatesV1alpha1ClusterTrustBundle = keyof RequestBody$replaceCertificatesV1alpha1ClusterTrustBundle;
type ResponseContentType$replaceCertificatesV1alpha1ClusterTrustBundle = keyof Response$replaceCertificatesV1alpha1ClusterTrustBundle$Status$200 | keyof Response$replaceCertificatesV1alpha1ClusterTrustBundle$Status$201;
interface Params$replaceCertificatesV1alpha1ClusterTrustBundle<U extends ResponseContentType$replaceCertificatesV1alpha1ClusterTrustBundle> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCertificatesV1alpha1ClusterTrustBundle;
    requestBody: RequestBody$replaceCertificatesV1alpha1ClusterTrustBundle["*/*"];
}
type RequestContentType$deleteCertificatesV1alpha1ClusterTrustBundle = keyof RequestBody$deleteCertificatesV1alpha1ClusterTrustBundle;
type ResponseContentType$deleteCertificatesV1alpha1ClusterTrustBundle = keyof Response$deleteCertificatesV1alpha1ClusterTrustBundle$Status$200 | keyof Response$deleteCertificatesV1alpha1ClusterTrustBundle$Status$202;
interface Params$deleteCertificatesV1alpha1ClusterTrustBundle<U extends ResponseContentType$deleteCertificatesV1alpha1ClusterTrustBundle> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCertificatesV1alpha1ClusterTrustBundle;
    requestBody: RequestBody$deleteCertificatesV1alpha1ClusterTrustBundle["*/*"];
}
type RequestContentType$patchCertificatesV1alpha1ClusterTrustBundle = keyof RequestBody$patchCertificatesV1alpha1ClusterTrustBundle;
type ResponseContentType$patchCertificatesV1alpha1ClusterTrustBundle = keyof Response$patchCertificatesV1alpha1ClusterTrustBundle$Status$200 | keyof Response$patchCertificatesV1alpha1ClusterTrustBundle$Status$201;
interface Params$patchCertificatesV1alpha1ClusterTrustBundle<T extends RequestContentType$patchCertificatesV1alpha1ClusterTrustBundle, U extends ResponseContentType$patchCertificatesV1alpha1ClusterTrustBundle> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCertificatesV1alpha1ClusterTrustBundle;
    requestBody: RequestBody$patchCertificatesV1alpha1ClusterTrustBundle[T];
}
type ResponseContentType$watchCertificatesV1alpha1ClusterTrustBundleList = keyof Response$watchCertificatesV1alpha1ClusterTrustBundleList$Status$200;
interface Params$watchCertificatesV1alpha1ClusterTrustBundleList<U extends ResponseContentType$watchCertificatesV1alpha1ClusterTrustBundleList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCertificatesV1alpha1ClusterTrustBundleList;
}
type ResponseContentType$watchCertificatesV1alpha1ClusterTrustBundle = keyof Response$watchCertificatesV1alpha1ClusterTrustBundle$Status$200;
interface Params$watchCertificatesV1alpha1ClusterTrustBundle<U extends ResponseContentType$watchCertificatesV1alpha1ClusterTrustBundle> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCertificatesV1alpha1ClusterTrustBundle;
}
type ResponseContentType$getCoordinationAPIGroup = keyof Response$getCoordinationAPIGroup$Status$200;
interface Params$getCoordinationAPIGroup<U extends ResponseContentType$getCoordinationAPIGroup> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getCoordinationV1APIResources = keyof Response$getCoordinationV1APIResources$Status$200;
interface Params$getCoordinationV1APIResources<U extends ResponseContentType$getCoordinationV1APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listCoordinationV1LeaseForAllNamespaces = keyof Response$listCoordinationV1LeaseForAllNamespaces$Status$200;
interface Params$listCoordinationV1LeaseForAllNamespaces<U extends ResponseContentType$listCoordinationV1LeaseForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoordinationV1LeaseForAllNamespaces;
}
type ResponseContentType$listCoordinationV1NamespacedLease = keyof Response$listCoordinationV1NamespacedLease$Status$200;
interface Params$listCoordinationV1NamespacedLease<U extends ResponseContentType$listCoordinationV1NamespacedLease> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listCoordinationV1NamespacedLease;
}
type RequestContentType$createCoordinationV1NamespacedLease = keyof RequestBody$createCoordinationV1NamespacedLease;
type ResponseContentType$createCoordinationV1NamespacedLease = keyof Response$createCoordinationV1NamespacedLease$Status$200 | keyof Response$createCoordinationV1NamespacedLease$Status$201 | keyof Response$createCoordinationV1NamespacedLease$Status$202;
interface Params$createCoordinationV1NamespacedLease<U extends ResponseContentType$createCoordinationV1NamespacedLease> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createCoordinationV1NamespacedLease;
    requestBody: RequestBody$createCoordinationV1NamespacedLease["*/*"];
}
type RequestContentType$deleteCoordinationV1CollectionNamespacedLease = keyof RequestBody$deleteCoordinationV1CollectionNamespacedLease;
type ResponseContentType$deleteCoordinationV1CollectionNamespacedLease = keyof Response$deleteCoordinationV1CollectionNamespacedLease$Status$200;
interface Params$deleteCoordinationV1CollectionNamespacedLease<U extends ResponseContentType$deleteCoordinationV1CollectionNamespacedLease> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoordinationV1CollectionNamespacedLease;
    requestBody: RequestBody$deleteCoordinationV1CollectionNamespacedLease["*/*"];
}
type ResponseContentType$readCoordinationV1NamespacedLease = keyof Response$readCoordinationV1NamespacedLease$Status$200;
interface Params$readCoordinationV1NamespacedLease<U extends ResponseContentType$readCoordinationV1NamespacedLease> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readCoordinationV1NamespacedLease;
}
type RequestContentType$replaceCoordinationV1NamespacedLease = keyof RequestBody$replaceCoordinationV1NamespacedLease;
type ResponseContentType$replaceCoordinationV1NamespacedLease = keyof Response$replaceCoordinationV1NamespacedLease$Status$200 | keyof Response$replaceCoordinationV1NamespacedLease$Status$201;
interface Params$replaceCoordinationV1NamespacedLease<U extends ResponseContentType$replaceCoordinationV1NamespacedLease> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceCoordinationV1NamespacedLease;
    requestBody: RequestBody$replaceCoordinationV1NamespacedLease["*/*"];
}
type RequestContentType$deleteCoordinationV1NamespacedLease = keyof RequestBody$deleteCoordinationV1NamespacedLease;
type ResponseContentType$deleteCoordinationV1NamespacedLease = keyof Response$deleteCoordinationV1NamespacedLease$Status$200 | keyof Response$deleteCoordinationV1NamespacedLease$Status$202;
interface Params$deleteCoordinationV1NamespacedLease<U extends ResponseContentType$deleteCoordinationV1NamespacedLease> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteCoordinationV1NamespacedLease;
    requestBody: RequestBody$deleteCoordinationV1NamespacedLease["*/*"];
}
type RequestContentType$patchCoordinationV1NamespacedLease = keyof RequestBody$patchCoordinationV1NamespacedLease;
type ResponseContentType$patchCoordinationV1NamespacedLease = keyof Response$patchCoordinationV1NamespacedLease$Status$200 | keyof Response$patchCoordinationV1NamespacedLease$Status$201;
interface Params$patchCoordinationV1NamespacedLease<T extends RequestContentType$patchCoordinationV1NamespacedLease, U extends ResponseContentType$patchCoordinationV1NamespacedLease> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchCoordinationV1NamespacedLease;
    requestBody: RequestBody$patchCoordinationV1NamespacedLease[T];
}
type ResponseContentType$watchCoordinationV1LeaseListForAllNamespaces = keyof Response$watchCoordinationV1LeaseListForAllNamespaces$Status$200;
interface Params$watchCoordinationV1LeaseListForAllNamespaces<U extends ResponseContentType$watchCoordinationV1LeaseListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoordinationV1LeaseListForAllNamespaces;
}
type ResponseContentType$watchCoordinationV1NamespacedLeaseList = keyof Response$watchCoordinationV1NamespacedLeaseList$Status$200;
interface Params$watchCoordinationV1NamespacedLeaseList<U extends ResponseContentType$watchCoordinationV1NamespacedLeaseList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoordinationV1NamespacedLeaseList;
}
type ResponseContentType$watchCoordinationV1NamespacedLease = keyof Response$watchCoordinationV1NamespacedLease$Status$200;
interface Params$watchCoordinationV1NamespacedLease<U extends ResponseContentType$watchCoordinationV1NamespacedLease> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchCoordinationV1NamespacedLease;
}
type ResponseContentType$getDiscoveryAPIGroup = keyof Response$getDiscoveryAPIGroup$Status$200;
interface Params$getDiscoveryAPIGroup<U extends ResponseContentType$getDiscoveryAPIGroup> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getDiscoveryV1APIResources = keyof Response$getDiscoveryV1APIResources$Status$200;
interface Params$getDiscoveryV1APIResources<U extends ResponseContentType$getDiscoveryV1APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listDiscoveryV1EndpointSliceForAllNamespaces = keyof Response$listDiscoveryV1EndpointSliceForAllNamespaces$Status$200;
interface Params$listDiscoveryV1EndpointSliceForAllNamespaces<U extends ResponseContentType$listDiscoveryV1EndpointSliceForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listDiscoveryV1EndpointSliceForAllNamespaces;
}
type ResponseContentType$listDiscoveryV1NamespacedEndpointSlice = keyof Response$listDiscoveryV1NamespacedEndpointSlice$Status$200;
interface Params$listDiscoveryV1NamespacedEndpointSlice<U extends ResponseContentType$listDiscoveryV1NamespacedEndpointSlice> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listDiscoveryV1NamespacedEndpointSlice;
}
type RequestContentType$createDiscoveryV1NamespacedEndpointSlice = keyof RequestBody$createDiscoveryV1NamespacedEndpointSlice;
type ResponseContentType$createDiscoveryV1NamespacedEndpointSlice = keyof Response$createDiscoveryV1NamespacedEndpointSlice$Status$200 | keyof Response$createDiscoveryV1NamespacedEndpointSlice$Status$201 | keyof Response$createDiscoveryV1NamespacedEndpointSlice$Status$202;
interface Params$createDiscoveryV1NamespacedEndpointSlice<U extends ResponseContentType$createDiscoveryV1NamespacedEndpointSlice> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createDiscoveryV1NamespacedEndpointSlice;
    requestBody: RequestBody$createDiscoveryV1NamespacedEndpointSlice["*/*"];
}
type RequestContentType$deleteDiscoveryV1CollectionNamespacedEndpointSlice = keyof RequestBody$deleteDiscoveryV1CollectionNamespacedEndpointSlice;
type ResponseContentType$deleteDiscoveryV1CollectionNamespacedEndpointSlice = keyof Response$deleteDiscoveryV1CollectionNamespacedEndpointSlice$Status$200;
interface Params$deleteDiscoveryV1CollectionNamespacedEndpointSlice<U extends ResponseContentType$deleteDiscoveryV1CollectionNamespacedEndpointSlice> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteDiscoveryV1CollectionNamespacedEndpointSlice;
    requestBody: RequestBody$deleteDiscoveryV1CollectionNamespacedEndpointSlice["*/*"];
}
type ResponseContentType$readDiscoveryV1NamespacedEndpointSlice = keyof Response$readDiscoveryV1NamespacedEndpointSlice$Status$200;
interface Params$readDiscoveryV1NamespacedEndpointSlice<U extends ResponseContentType$readDiscoveryV1NamespacedEndpointSlice> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readDiscoveryV1NamespacedEndpointSlice;
}
type RequestContentType$replaceDiscoveryV1NamespacedEndpointSlice = keyof RequestBody$replaceDiscoveryV1NamespacedEndpointSlice;
type ResponseContentType$replaceDiscoveryV1NamespacedEndpointSlice = keyof Response$replaceDiscoveryV1NamespacedEndpointSlice$Status$200 | keyof Response$replaceDiscoveryV1NamespacedEndpointSlice$Status$201;
interface Params$replaceDiscoveryV1NamespacedEndpointSlice<U extends ResponseContentType$replaceDiscoveryV1NamespacedEndpointSlice> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceDiscoveryV1NamespacedEndpointSlice;
    requestBody: RequestBody$replaceDiscoveryV1NamespacedEndpointSlice["*/*"];
}
type RequestContentType$deleteDiscoveryV1NamespacedEndpointSlice = keyof RequestBody$deleteDiscoveryV1NamespacedEndpointSlice;
type ResponseContentType$deleteDiscoveryV1NamespacedEndpointSlice = keyof Response$deleteDiscoveryV1NamespacedEndpointSlice$Status$200 | keyof Response$deleteDiscoveryV1NamespacedEndpointSlice$Status$202;
interface Params$deleteDiscoveryV1NamespacedEndpointSlice<U extends ResponseContentType$deleteDiscoveryV1NamespacedEndpointSlice> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteDiscoveryV1NamespacedEndpointSlice;
    requestBody: RequestBody$deleteDiscoveryV1NamespacedEndpointSlice["*/*"];
}
type RequestContentType$patchDiscoveryV1NamespacedEndpointSlice = keyof RequestBody$patchDiscoveryV1NamespacedEndpointSlice;
type ResponseContentType$patchDiscoveryV1NamespacedEndpointSlice = keyof Response$patchDiscoveryV1NamespacedEndpointSlice$Status$200 | keyof Response$patchDiscoveryV1NamespacedEndpointSlice$Status$201;
interface Params$patchDiscoveryV1NamespacedEndpointSlice<T extends RequestContentType$patchDiscoveryV1NamespacedEndpointSlice, U extends ResponseContentType$patchDiscoveryV1NamespacedEndpointSlice> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchDiscoveryV1NamespacedEndpointSlice;
    requestBody: RequestBody$patchDiscoveryV1NamespacedEndpointSlice[T];
}
type ResponseContentType$watchDiscoveryV1EndpointSliceListForAllNamespaces = keyof Response$watchDiscoveryV1EndpointSliceListForAllNamespaces$Status$200;
interface Params$watchDiscoveryV1EndpointSliceListForAllNamespaces<U extends ResponseContentType$watchDiscoveryV1EndpointSliceListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchDiscoveryV1EndpointSliceListForAllNamespaces;
}
type ResponseContentType$watchDiscoveryV1NamespacedEndpointSliceList = keyof Response$watchDiscoveryV1NamespacedEndpointSliceList$Status$200;
interface Params$watchDiscoveryV1NamespacedEndpointSliceList<U extends ResponseContentType$watchDiscoveryV1NamespacedEndpointSliceList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchDiscoveryV1NamespacedEndpointSliceList;
}
type ResponseContentType$watchDiscoveryV1NamespacedEndpointSlice = keyof Response$watchDiscoveryV1NamespacedEndpointSlice$Status$200;
interface Params$watchDiscoveryV1NamespacedEndpointSlice<U extends ResponseContentType$watchDiscoveryV1NamespacedEndpointSlice> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchDiscoveryV1NamespacedEndpointSlice;
}
type ResponseContentType$getEventsAPIGroup = keyof Response$getEventsAPIGroup$Status$200;
interface Params$getEventsAPIGroup<U extends ResponseContentType$getEventsAPIGroup> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getEventsV1APIResources = keyof Response$getEventsV1APIResources$Status$200;
interface Params$getEventsV1APIResources<U extends ResponseContentType$getEventsV1APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listEventsV1EventForAllNamespaces = keyof Response$listEventsV1EventForAllNamespaces$Status$200;
interface Params$listEventsV1EventForAllNamespaces<U extends ResponseContentType$listEventsV1EventForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listEventsV1EventForAllNamespaces;
}
type ResponseContentType$listEventsV1NamespacedEvent = keyof Response$listEventsV1NamespacedEvent$Status$200;
interface Params$listEventsV1NamespacedEvent<U extends ResponseContentType$listEventsV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listEventsV1NamespacedEvent;
}
type RequestContentType$createEventsV1NamespacedEvent = keyof RequestBody$createEventsV1NamespacedEvent;
type ResponseContentType$createEventsV1NamespacedEvent = keyof Response$createEventsV1NamespacedEvent$Status$200 | keyof Response$createEventsV1NamespacedEvent$Status$201 | keyof Response$createEventsV1NamespacedEvent$Status$202;
interface Params$createEventsV1NamespacedEvent<U extends ResponseContentType$createEventsV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createEventsV1NamespacedEvent;
    requestBody: RequestBody$createEventsV1NamespacedEvent["*/*"];
}
type RequestContentType$deleteEventsV1CollectionNamespacedEvent = keyof RequestBody$deleteEventsV1CollectionNamespacedEvent;
type ResponseContentType$deleteEventsV1CollectionNamespacedEvent = keyof Response$deleteEventsV1CollectionNamespacedEvent$Status$200;
interface Params$deleteEventsV1CollectionNamespacedEvent<U extends ResponseContentType$deleteEventsV1CollectionNamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteEventsV1CollectionNamespacedEvent;
    requestBody: RequestBody$deleteEventsV1CollectionNamespacedEvent["*/*"];
}
type ResponseContentType$readEventsV1NamespacedEvent = keyof Response$readEventsV1NamespacedEvent$Status$200;
interface Params$readEventsV1NamespacedEvent<U extends ResponseContentType$readEventsV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readEventsV1NamespacedEvent;
}
type RequestContentType$replaceEventsV1NamespacedEvent = keyof RequestBody$replaceEventsV1NamespacedEvent;
type ResponseContentType$replaceEventsV1NamespacedEvent = keyof Response$replaceEventsV1NamespacedEvent$Status$200 | keyof Response$replaceEventsV1NamespacedEvent$Status$201;
interface Params$replaceEventsV1NamespacedEvent<U extends ResponseContentType$replaceEventsV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceEventsV1NamespacedEvent;
    requestBody: RequestBody$replaceEventsV1NamespacedEvent["*/*"];
}
type RequestContentType$deleteEventsV1NamespacedEvent = keyof RequestBody$deleteEventsV1NamespacedEvent;
type ResponseContentType$deleteEventsV1NamespacedEvent = keyof Response$deleteEventsV1NamespacedEvent$Status$200 | keyof Response$deleteEventsV1NamespacedEvent$Status$202;
interface Params$deleteEventsV1NamespacedEvent<U extends ResponseContentType$deleteEventsV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteEventsV1NamespacedEvent;
    requestBody: RequestBody$deleteEventsV1NamespacedEvent["*/*"];
}
type RequestContentType$patchEventsV1NamespacedEvent = keyof RequestBody$patchEventsV1NamespacedEvent;
type ResponseContentType$patchEventsV1NamespacedEvent = keyof Response$patchEventsV1NamespacedEvent$Status$200 | keyof Response$patchEventsV1NamespacedEvent$Status$201;
interface Params$patchEventsV1NamespacedEvent<T extends RequestContentType$patchEventsV1NamespacedEvent, U extends ResponseContentType$patchEventsV1NamespacedEvent> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchEventsV1NamespacedEvent;
    requestBody: RequestBody$patchEventsV1NamespacedEvent[T];
}
type ResponseContentType$watchEventsV1EventListForAllNamespaces = keyof Response$watchEventsV1EventListForAllNamespaces$Status$200;
interface Params$watchEventsV1EventListForAllNamespaces<U extends ResponseContentType$watchEventsV1EventListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchEventsV1EventListForAllNamespaces;
}
type ResponseContentType$watchEventsV1NamespacedEventList = keyof Response$watchEventsV1NamespacedEventList$Status$200;
interface Params$watchEventsV1NamespacedEventList<U extends ResponseContentType$watchEventsV1NamespacedEventList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchEventsV1NamespacedEventList;
}
type ResponseContentType$watchEventsV1NamespacedEvent = keyof Response$watchEventsV1NamespacedEvent$Status$200;
interface Params$watchEventsV1NamespacedEvent<U extends ResponseContentType$watchEventsV1NamespacedEvent> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchEventsV1NamespacedEvent;
}
type ResponseContentType$getFlowcontrolApiserverAPIGroup = keyof Response$getFlowcontrolApiserverAPIGroup$Status$200;
interface Params$getFlowcontrolApiserverAPIGroup<U extends ResponseContentType$getFlowcontrolApiserverAPIGroup> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getFlowcontrolApiserverV1beta2APIResources = keyof Response$getFlowcontrolApiserverV1beta2APIResources$Status$200;
interface Params$getFlowcontrolApiserverV1beta2APIResources<U extends ResponseContentType$getFlowcontrolApiserverV1beta2APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listFlowcontrolApiserverV1beta2FlowSchema = keyof Response$listFlowcontrolApiserverV1beta2FlowSchema$Status$200;
interface Params$listFlowcontrolApiserverV1beta2FlowSchema<U extends ResponseContentType$listFlowcontrolApiserverV1beta2FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listFlowcontrolApiserverV1beta2FlowSchema;
}
type RequestContentType$createFlowcontrolApiserverV1beta2FlowSchema = keyof RequestBody$createFlowcontrolApiserverV1beta2FlowSchema;
type ResponseContentType$createFlowcontrolApiserverV1beta2FlowSchema = keyof Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$200 | keyof Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$201 | keyof Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$202;
interface Params$createFlowcontrolApiserverV1beta2FlowSchema<U extends ResponseContentType$createFlowcontrolApiserverV1beta2FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createFlowcontrolApiserverV1beta2FlowSchema;
    requestBody: RequestBody$createFlowcontrolApiserverV1beta2FlowSchema["*/*"];
}
type RequestContentType$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema = keyof RequestBody$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema;
type ResponseContentType$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema = keyof Response$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema$Status$200;
interface Params$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema<U extends ResponseContentType$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema;
    requestBody: RequestBody$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema["*/*"];
}
type ResponseContentType$readFlowcontrolApiserverV1beta2FlowSchema = keyof Response$readFlowcontrolApiserverV1beta2FlowSchema$Status$200;
interface Params$readFlowcontrolApiserverV1beta2FlowSchema<U extends ResponseContentType$readFlowcontrolApiserverV1beta2FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readFlowcontrolApiserverV1beta2FlowSchema;
}
type RequestContentType$replaceFlowcontrolApiserverV1beta2FlowSchema = keyof RequestBody$replaceFlowcontrolApiserverV1beta2FlowSchema;
type ResponseContentType$replaceFlowcontrolApiserverV1beta2FlowSchema = keyof Response$replaceFlowcontrolApiserverV1beta2FlowSchema$Status$200 | keyof Response$replaceFlowcontrolApiserverV1beta2FlowSchema$Status$201;
interface Params$replaceFlowcontrolApiserverV1beta2FlowSchema<U extends ResponseContentType$replaceFlowcontrolApiserverV1beta2FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceFlowcontrolApiserverV1beta2FlowSchema;
    requestBody: RequestBody$replaceFlowcontrolApiserverV1beta2FlowSchema["*/*"];
}
type RequestContentType$deleteFlowcontrolApiserverV1beta2FlowSchema = keyof RequestBody$deleteFlowcontrolApiserverV1beta2FlowSchema;
type ResponseContentType$deleteFlowcontrolApiserverV1beta2FlowSchema = keyof Response$deleteFlowcontrolApiserverV1beta2FlowSchema$Status$200 | keyof Response$deleteFlowcontrolApiserverV1beta2FlowSchema$Status$202;
interface Params$deleteFlowcontrolApiserverV1beta2FlowSchema<U extends ResponseContentType$deleteFlowcontrolApiserverV1beta2FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteFlowcontrolApiserverV1beta2FlowSchema;
    requestBody: RequestBody$deleteFlowcontrolApiserverV1beta2FlowSchema["*/*"];
}
type RequestContentType$patchFlowcontrolApiserverV1beta2FlowSchema = keyof RequestBody$patchFlowcontrolApiserverV1beta2FlowSchema;
type ResponseContentType$patchFlowcontrolApiserverV1beta2FlowSchema = keyof Response$patchFlowcontrolApiserverV1beta2FlowSchema$Status$200 | keyof Response$patchFlowcontrolApiserverV1beta2FlowSchema$Status$201;
interface Params$patchFlowcontrolApiserverV1beta2FlowSchema<T extends RequestContentType$patchFlowcontrolApiserverV1beta2FlowSchema, U extends ResponseContentType$patchFlowcontrolApiserverV1beta2FlowSchema> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchFlowcontrolApiserverV1beta2FlowSchema;
    requestBody: RequestBody$patchFlowcontrolApiserverV1beta2FlowSchema[T];
}
type ResponseContentType$readFlowcontrolApiserverV1beta2FlowSchemaStatus = keyof Response$readFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200;
interface Params$readFlowcontrolApiserverV1beta2FlowSchemaStatus<U extends ResponseContentType$readFlowcontrolApiserverV1beta2FlowSchemaStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readFlowcontrolApiserverV1beta2FlowSchemaStatus;
}
type RequestContentType$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus = keyof RequestBody$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus;
type ResponseContentType$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus = keyof Response$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200 | keyof Response$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$201;
interface Params$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus<U extends ResponseContentType$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus;
    requestBody: RequestBody$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus["*/*"];
}
type RequestContentType$patchFlowcontrolApiserverV1beta2FlowSchemaStatus = keyof RequestBody$patchFlowcontrolApiserverV1beta2FlowSchemaStatus;
type ResponseContentType$patchFlowcontrolApiserverV1beta2FlowSchemaStatus = keyof Response$patchFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200 | keyof Response$patchFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$201;
interface Params$patchFlowcontrolApiserverV1beta2FlowSchemaStatus<T extends RequestContentType$patchFlowcontrolApiserverV1beta2FlowSchemaStatus, U extends ResponseContentType$patchFlowcontrolApiserverV1beta2FlowSchemaStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchFlowcontrolApiserverV1beta2FlowSchemaStatus;
    requestBody: RequestBody$patchFlowcontrolApiserverV1beta2FlowSchemaStatus[T];
}
type ResponseContentType$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration = keyof Response$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200;
interface Params$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration<U extends ResponseContentType$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration;
}
type RequestContentType$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration = keyof RequestBody$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration;
type ResponseContentType$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration = keyof Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | keyof Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201 | keyof Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$202;
interface Params$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration<U extends ResponseContentType$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration;
    requestBody: RequestBody$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration["*/*"];
}
type RequestContentType$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration = keyof RequestBody$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration;
type ResponseContentType$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration = keyof Response$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration$Status$200;
interface Params$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration<U extends ResponseContentType$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration;
    requestBody: RequestBody$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration["*/*"];
}
type ResponseContentType$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration = keyof Response$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200;
interface Params$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration<U extends ResponseContentType$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration;
}
type RequestContentType$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration = keyof RequestBody$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration;
type ResponseContentType$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration = keyof Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | keyof Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201;
interface Params$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration<U extends ResponseContentType$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration;
    requestBody: RequestBody$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration["*/*"];
}
type RequestContentType$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration = keyof RequestBody$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration;
type ResponseContentType$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration = keyof Response$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | keyof Response$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$202;
interface Params$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration<U extends ResponseContentType$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration;
    requestBody: RequestBody$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration["*/*"];
}
type RequestContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration = keyof RequestBody$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration;
type ResponseContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration = keyof Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | keyof Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201;
interface Params$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration<T extends RequestContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration, U extends ResponseContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration;
    requestBody: RequestBody$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration[T];
}
type ResponseContentType$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus = keyof Response$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200;
interface Params$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus<U extends ResponseContentType$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus;
}
type RequestContentType$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus = keyof RequestBody$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus;
type ResponseContentType$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus = keyof Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200 | keyof Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$201;
interface Params$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus<U extends ResponseContentType$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus;
    requestBody: RequestBody$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus["*/*"];
}
type RequestContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus = keyof RequestBody$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus;
type ResponseContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus = keyof Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200 | keyof Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$201;
interface Params$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus<T extends RequestContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus, U extends ResponseContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus;
    requestBody: RequestBody$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus[T];
}
type ResponseContentType$watchFlowcontrolApiserverV1beta2FlowSchemaList = keyof Response$watchFlowcontrolApiserverV1beta2FlowSchemaList$Status$200;
interface Params$watchFlowcontrolApiserverV1beta2FlowSchemaList<U extends ResponseContentType$watchFlowcontrolApiserverV1beta2FlowSchemaList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchFlowcontrolApiserverV1beta2FlowSchemaList;
}
type ResponseContentType$watchFlowcontrolApiserverV1beta2FlowSchema = keyof Response$watchFlowcontrolApiserverV1beta2FlowSchema$Status$200;
interface Params$watchFlowcontrolApiserverV1beta2FlowSchema<U extends ResponseContentType$watchFlowcontrolApiserverV1beta2FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchFlowcontrolApiserverV1beta2FlowSchema;
}
type ResponseContentType$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList = keyof Response$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList$Status$200;
interface Params$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList<U extends ResponseContentType$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList;
}
type ResponseContentType$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration = keyof Response$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200;
interface Params$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration<U extends ResponseContentType$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration;
}
type ResponseContentType$getFlowcontrolApiserverV1beta3APIResources = keyof Response$getFlowcontrolApiserverV1beta3APIResources$Status$200;
interface Params$getFlowcontrolApiserverV1beta3APIResources<U extends ResponseContentType$getFlowcontrolApiserverV1beta3APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listFlowcontrolApiserverV1beta3FlowSchema = keyof Response$listFlowcontrolApiserverV1beta3FlowSchema$Status$200;
interface Params$listFlowcontrolApiserverV1beta3FlowSchema<U extends ResponseContentType$listFlowcontrolApiserverV1beta3FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listFlowcontrolApiserverV1beta3FlowSchema;
}
type RequestContentType$createFlowcontrolApiserverV1beta3FlowSchema = keyof RequestBody$createFlowcontrolApiserverV1beta3FlowSchema;
type ResponseContentType$createFlowcontrolApiserverV1beta3FlowSchema = keyof Response$createFlowcontrolApiserverV1beta3FlowSchema$Status$200 | keyof Response$createFlowcontrolApiserverV1beta3FlowSchema$Status$201 | keyof Response$createFlowcontrolApiserverV1beta3FlowSchema$Status$202;
interface Params$createFlowcontrolApiserverV1beta3FlowSchema<U extends ResponseContentType$createFlowcontrolApiserverV1beta3FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createFlowcontrolApiserverV1beta3FlowSchema;
    requestBody: RequestBody$createFlowcontrolApiserverV1beta3FlowSchema["*/*"];
}
type RequestContentType$deleteFlowcontrolApiserverV1beta3CollectionFlowSchema = keyof RequestBody$deleteFlowcontrolApiserverV1beta3CollectionFlowSchema;
type ResponseContentType$deleteFlowcontrolApiserverV1beta3CollectionFlowSchema = keyof Response$deleteFlowcontrolApiserverV1beta3CollectionFlowSchema$Status$200;
interface Params$deleteFlowcontrolApiserverV1beta3CollectionFlowSchema<U extends ResponseContentType$deleteFlowcontrolApiserverV1beta3CollectionFlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteFlowcontrolApiserverV1beta3CollectionFlowSchema;
    requestBody: RequestBody$deleteFlowcontrolApiserverV1beta3CollectionFlowSchema["*/*"];
}
type ResponseContentType$readFlowcontrolApiserverV1beta3FlowSchema = keyof Response$readFlowcontrolApiserverV1beta3FlowSchema$Status$200;
interface Params$readFlowcontrolApiserverV1beta3FlowSchema<U extends ResponseContentType$readFlowcontrolApiserverV1beta3FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readFlowcontrolApiserverV1beta3FlowSchema;
}
type RequestContentType$replaceFlowcontrolApiserverV1beta3FlowSchema = keyof RequestBody$replaceFlowcontrolApiserverV1beta3FlowSchema;
type ResponseContentType$replaceFlowcontrolApiserverV1beta3FlowSchema = keyof Response$replaceFlowcontrolApiserverV1beta3FlowSchema$Status$200 | keyof Response$replaceFlowcontrolApiserverV1beta3FlowSchema$Status$201;
interface Params$replaceFlowcontrolApiserverV1beta3FlowSchema<U extends ResponseContentType$replaceFlowcontrolApiserverV1beta3FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceFlowcontrolApiserverV1beta3FlowSchema;
    requestBody: RequestBody$replaceFlowcontrolApiserverV1beta3FlowSchema["*/*"];
}
type RequestContentType$deleteFlowcontrolApiserverV1beta3FlowSchema = keyof RequestBody$deleteFlowcontrolApiserverV1beta3FlowSchema;
type ResponseContentType$deleteFlowcontrolApiserverV1beta3FlowSchema = keyof Response$deleteFlowcontrolApiserverV1beta3FlowSchema$Status$200 | keyof Response$deleteFlowcontrolApiserverV1beta3FlowSchema$Status$202;
interface Params$deleteFlowcontrolApiserverV1beta3FlowSchema<U extends ResponseContentType$deleteFlowcontrolApiserverV1beta3FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteFlowcontrolApiserverV1beta3FlowSchema;
    requestBody: RequestBody$deleteFlowcontrolApiserverV1beta3FlowSchema["*/*"];
}
type RequestContentType$patchFlowcontrolApiserverV1beta3FlowSchema = keyof RequestBody$patchFlowcontrolApiserverV1beta3FlowSchema;
type ResponseContentType$patchFlowcontrolApiserverV1beta3FlowSchema = keyof Response$patchFlowcontrolApiserverV1beta3FlowSchema$Status$200 | keyof Response$patchFlowcontrolApiserverV1beta3FlowSchema$Status$201;
interface Params$patchFlowcontrolApiserverV1beta3FlowSchema<T extends RequestContentType$patchFlowcontrolApiserverV1beta3FlowSchema, U extends ResponseContentType$patchFlowcontrolApiserverV1beta3FlowSchema> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchFlowcontrolApiserverV1beta3FlowSchema;
    requestBody: RequestBody$patchFlowcontrolApiserverV1beta3FlowSchema[T];
}
type ResponseContentType$readFlowcontrolApiserverV1beta3FlowSchemaStatus = keyof Response$readFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$200;
interface Params$readFlowcontrolApiserverV1beta3FlowSchemaStatus<U extends ResponseContentType$readFlowcontrolApiserverV1beta3FlowSchemaStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readFlowcontrolApiserverV1beta3FlowSchemaStatus;
}
type RequestContentType$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus = keyof RequestBody$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus;
type ResponseContentType$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus = keyof Response$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$200 | keyof Response$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$201;
interface Params$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus<U extends ResponseContentType$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus;
    requestBody: RequestBody$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus["*/*"];
}
type RequestContentType$patchFlowcontrolApiserverV1beta3FlowSchemaStatus = keyof RequestBody$patchFlowcontrolApiserverV1beta3FlowSchemaStatus;
type ResponseContentType$patchFlowcontrolApiserverV1beta3FlowSchemaStatus = keyof Response$patchFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$200 | keyof Response$patchFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$201;
interface Params$patchFlowcontrolApiserverV1beta3FlowSchemaStatus<T extends RequestContentType$patchFlowcontrolApiserverV1beta3FlowSchemaStatus, U extends ResponseContentType$patchFlowcontrolApiserverV1beta3FlowSchemaStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchFlowcontrolApiserverV1beta3FlowSchemaStatus;
    requestBody: RequestBody$patchFlowcontrolApiserverV1beta3FlowSchemaStatus[T];
}
type ResponseContentType$listFlowcontrolApiserverV1beta3PriorityLevelConfiguration = keyof Response$listFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200;
interface Params$listFlowcontrolApiserverV1beta3PriorityLevelConfiguration<U extends ResponseContentType$listFlowcontrolApiserverV1beta3PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listFlowcontrolApiserverV1beta3PriorityLevelConfiguration;
}
type RequestContentType$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration = keyof RequestBody$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration;
type ResponseContentType$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration = keyof Response$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200 | keyof Response$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$201 | keyof Response$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$202;
interface Params$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration<U extends ResponseContentType$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration;
    requestBody: RequestBody$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration["*/*"];
}
type RequestContentType$deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration = keyof RequestBody$deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration;
type ResponseContentType$deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration = keyof Response$deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration$Status$200;
interface Params$deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration<U extends ResponseContentType$deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration;
    requestBody: RequestBody$deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration["*/*"];
}
type ResponseContentType$readFlowcontrolApiserverV1beta3PriorityLevelConfiguration = keyof Response$readFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200;
interface Params$readFlowcontrolApiserverV1beta3PriorityLevelConfiguration<U extends ResponseContentType$readFlowcontrolApiserverV1beta3PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readFlowcontrolApiserverV1beta3PriorityLevelConfiguration;
}
type RequestContentType$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration = keyof RequestBody$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration;
type ResponseContentType$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration = keyof Response$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200 | keyof Response$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$201;
interface Params$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration<U extends ResponseContentType$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration;
    requestBody: RequestBody$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration["*/*"];
}
type RequestContentType$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration = keyof RequestBody$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration;
type ResponseContentType$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration = keyof Response$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200 | keyof Response$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$202;
interface Params$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration<U extends ResponseContentType$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration;
    requestBody: RequestBody$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration["*/*"];
}
type RequestContentType$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration = keyof RequestBody$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration;
type ResponseContentType$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration = keyof Response$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200 | keyof Response$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$201;
interface Params$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration<T extends RequestContentType$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration, U extends ResponseContentType$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration;
    requestBody: RequestBody$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration[T];
}
type ResponseContentType$readFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus = keyof Response$readFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$200;
interface Params$readFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus<U extends ResponseContentType$readFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus;
}
type RequestContentType$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus = keyof RequestBody$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus;
type ResponseContentType$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus = keyof Response$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$200 | keyof Response$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$201;
interface Params$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus<U extends ResponseContentType$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus;
    requestBody: RequestBody$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus["*/*"];
}
type RequestContentType$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus = keyof RequestBody$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus;
type ResponseContentType$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus = keyof Response$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$200 | keyof Response$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$201;
interface Params$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus<T extends RequestContentType$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus, U extends ResponseContentType$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus;
    requestBody: RequestBody$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus[T];
}
type ResponseContentType$watchFlowcontrolApiserverV1beta3FlowSchemaList = keyof Response$watchFlowcontrolApiserverV1beta3FlowSchemaList$Status$200;
interface Params$watchFlowcontrolApiserverV1beta3FlowSchemaList<U extends ResponseContentType$watchFlowcontrolApiserverV1beta3FlowSchemaList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchFlowcontrolApiserverV1beta3FlowSchemaList;
}
type ResponseContentType$watchFlowcontrolApiserverV1beta3FlowSchema = keyof Response$watchFlowcontrolApiserverV1beta3FlowSchema$Status$200;
interface Params$watchFlowcontrolApiserverV1beta3FlowSchema<U extends ResponseContentType$watchFlowcontrolApiserverV1beta3FlowSchema> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchFlowcontrolApiserverV1beta3FlowSchema;
}
type ResponseContentType$watchFlowcontrolApiserverV1beta3PriorityLevelConfigurationList = keyof Response$watchFlowcontrolApiserverV1beta3PriorityLevelConfigurationList$Status$200;
interface Params$watchFlowcontrolApiserverV1beta3PriorityLevelConfigurationList<U extends ResponseContentType$watchFlowcontrolApiserverV1beta3PriorityLevelConfigurationList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchFlowcontrolApiserverV1beta3PriorityLevelConfigurationList;
}
type ResponseContentType$watchFlowcontrolApiserverV1beta3PriorityLevelConfiguration = keyof Response$watchFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200;
interface Params$watchFlowcontrolApiserverV1beta3PriorityLevelConfiguration<U extends ResponseContentType$watchFlowcontrolApiserverV1beta3PriorityLevelConfiguration> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchFlowcontrolApiserverV1beta3PriorityLevelConfiguration;
}
type ResponseContentType$getInternalApiserverAPIGroup = keyof Response$getInternalApiserverAPIGroup$Status$200;
interface Params$getInternalApiserverAPIGroup<U extends ResponseContentType$getInternalApiserverAPIGroup> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getInternalApiserverV1alpha1APIResources = keyof Response$getInternalApiserverV1alpha1APIResources$Status$200;
interface Params$getInternalApiserverV1alpha1APIResources<U extends ResponseContentType$getInternalApiserverV1alpha1APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listInternalApiserverV1alpha1StorageVersion = keyof Response$listInternalApiserverV1alpha1StorageVersion$Status$200;
interface Params$listInternalApiserverV1alpha1StorageVersion<U extends ResponseContentType$listInternalApiserverV1alpha1StorageVersion> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listInternalApiserverV1alpha1StorageVersion;
}
type RequestContentType$createInternalApiserverV1alpha1StorageVersion = keyof RequestBody$createInternalApiserverV1alpha1StorageVersion;
type ResponseContentType$createInternalApiserverV1alpha1StorageVersion = keyof Response$createInternalApiserverV1alpha1StorageVersion$Status$200 | keyof Response$createInternalApiserverV1alpha1StorageVersion$Status$201 | keyof Response$createInternalApiserverV1alpha1StorageVersion$Status$202;
interface Params$createInternalApiserverV1alpha1StorageVersion<U extends ResponseContentType$createInternalApiserverV1alpha1StorageVersion> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createInternalApiserverV1alpha1StorageVersion;
    requestBody: RequestBody$createInternalApiserverV1alpha1StorageVersion["*/*"];
}
type RequestContentType$deleteInternalApiserverV1alpha1CollectionStorageVersion = keyof RequestBody$deleteInternalApiserverV1alpha1CollectionStorageVersion;
type ResponseContentType$deleteInternalApiserverV1alpha1CollectionStorageVersion = keyof Response$deleteInternalApiserverV1alpha1CollectionStorageVersion$Status$200;
interface Params$deleteInternalApiserverV1alpha1CollectionStorageVersion<U extends ResponseContentType$deleteInternalApiserverV1alpha1CollectionStorageVersion> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteInternalApiserverV1alpha1CollectionStorageVersion;
    requestBody: RequestBody$deleteInternalApiserverV1alpha1CollectionStorageVersion["*/*"];
}
type ResponseContentType$readInternalApiserverV1alpha1StorageVersion = keyof Response$readInternalApiserverV1alpha1StorageVersion$Status$200;
interface Params$readInternalApiserverV1alpha1StorageVersion<U extends ResponseContentType$readInternalApiserverV1alpha1StorageVersion> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readInternalApiserverV1alpha1StorageVersion;
}
type RequestContentType$replaceInternalApiserverV1alpha1StorageVersion = keyof RequestBody$replaceInternalApiserverV1alpha1StorageVersion;
type ResponseContentType$replaceInternalApiserverV1alpha1StorageVersion = keyof Response$replaceInternalApiserverV1alpha1StorageVersion$Status$200 | keyof Response$replaceInternalApiserverV1alpha1StorageVersion$Status$201;
interface Params$replaceInternalApiserverV1alpha1StorageVersion<U extends ResponseContentType$replaceInternalApiserverV1alpha1StorageVersion> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceInternalApiserverV1alpha1StorageVersion;
    requestBody: RequestBody$replaceInternalApiserverV1alpha1StorageVersion["*/*"];
}
type RequestContentType$deleteInternalApiserverV1alpha1StorageVersion = keyof RequestBody$deleteInternalApiserverV1alpha1StorageVersion;
type ResponseContentType$deleteInternalApiserverV1alpha1StorageVersion = keyof Response$deleteInternalApiserverV1alpha1StorageVersion$Status$200 | keyof Response$deleteInternalApiserverV1alpha1StorageVersion$Status$202;
interface Params$deleteInternalApiserverV1alpha1StorageVersion<U extends ResponseContentType$deleteInternalApiserverV1alpha1StorageVersion> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteInternalApiserverV1alpha1StorageVersion;
    requestBody: RequestBody$deleteInternalApiserverV1alpha1StorageVersion["*/*"];
}
type RequestContentType$patchInternalApiserverV1alpha1StorageVersion = keyof RequestBody$patchInternalApiserverV1alpha1StorageVersion;
type ResponseContentType$patchInternalApiserverV1alpha1StorageVersion = keyof Response$patchInternalApiserverV1alpha1StorageVersion$Status$200 | keyof Response$patchInternalApiserverV1alpha1StorageVersion$Status$201;
interface Params$patchInternalApiserverV1alpha1StorageVersion<T extends RequestContentType$patchInternalApiserverV1alpha1StorageVersion, U extends ResponseContentType$patchInternalApiserverV1alpha1StorageVersion> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchInternalApiserverV1alpha1StorageVersion;
    requestBody: RequestBody$patchInternalApiserverV1alpha1StorageVersion[T];
}
type ResponseContentType$readInternalApiserverV1alpha1StorageVersionStatus = keyof Response$readInternalApiserverV1alpha1StorageVersionStatus$Status$200;
interface Params$readInternalApiserverV1alpha1StorageVersionStatus<U extends ResponseContentType$readInternalApiserverV1alpha1StorageVersionStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readInternalApiserverV1alpha1StorageVersionStatus;
}
type RequestContentType$replaceInternalApiserverV1alpha1StorageVersionStatus = keyof RequestBody$replaceInternalApiserverV1alpha1StorageVersionStatus;
type ResponseContentType$replaceInternalApiserverV1alpha1StorageVersionStatus = keyof Response$replaceInternalApiserverV1alpha1StorageVersionStatus$Status$200 | keyof Response$replaceInternalApiserverV1alpha1StorageVersionStatus$Status$201;
interface Params$replaceInternalApiserverV1alpha1StorageVersionStatus<U extends ResponseContentType$replaceInternalApiserverV1alpha1StorageVersionStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceInternalApiserverV1alpha1StorageVersionStatus;
    requestBody: RequestBody$replaceInternalApiserverV1alpha1StorageVersionStatus["*/*"];
}
type RequestContentType$patchInternalApiserverV1alpha1StorageVersionStatus = keyof RequestBody$patchInternalApiserverV1alpha1StorageVersionStatus;
type ResponseContentType$patchInternalApiserverV1alpha1StorageVersionStatus = keyof Response$patchInternalApiserverV1alpha1StorageVersionStatus$Status$200 | keyof Response$patchInternalApiserverV1alpha1StorageVersionStatus$Status$201;
interface Params$patchInternalApiserverV1alpha1StorageVersionStatus<T extends RequestContentType$patchInternalApiserverV1alpha1StorageVersionStatus, U extends ResponseContentType$patchInternalApiserverV1alpha1StorageVersionStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchInternalApiserverV1alpha1StorageVersionStatus;
    requestBody: RequestBody$patchInternalApiserverV1alpha1StorageVersionStatus[T];
}
type ResponseContentType$watchInternalApiserverV1alpha1StorageVersionList = keyof Response$watchInternalApiserverV1alpha1StorageVersionList$Status$200;
interface Params$watchInternalApiserverV1alpha1StorageVersionList<U extends ResponseContentType$watchInternalApiserverV1alpha1StorageVersionList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchInternalApiserverV1alpha1StorageVersionList;
}
type ResponseContentType$watchInternalApiserverV1alpha1StorageVersion = keyof Response$watchInternalApiserverV1alpha1StorageVersion$Status$200;
interface Params$watchInternalApiserverV1alpha1StorageVersion<U extends ResponseContentType$watchInternalApiserverV1alpha1StorageVersion> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchInternalApiserverV1alpha1StorageVersion;
}
type ResponseContentType$getNetworkingAPIGroup = keyof Response$getNetworkingAPIGroup$Status$200;
interface Params$getNetworkingAPIGroup<U extends ResponseContentType$getNetworkingAPIGroup> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getNetworkingV1APIResources = keyof Response$getNetworkingV1APIResources$Status$200;
interface Params$getNetworkingV1APIResources<U extends ResponseContentType$getNetworkingV1APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listNetworkingV1IngressClass = keyof Response$listNetworkingV1IngressClass$Status$200;
interface Params$listNetworkingV1IngressClass<U extends ResponseContentType$listNetworkingV1IngressClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listNetworkingV1IngressClass;
}
type RequestContentType$createNetworkingV1IngressClass = keyof RequestBody$createNetworkingV1IngressClass;
type ResponseContentType$createNetworkingV1IngressClass = keyof Response$createNetworkingV1IngressClass$Status$200 | keyof Response$createNetworkingV1IngressClass$Status$201 | keyof Response$createNetworkingV1IngressClass$Status$202;
interface Params$createNetworkingV1IngressClass<U extends ResponseContentType$createNetworkingV1IngressClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createNetworkingV1IngressClass;
    requestBody: RequestBody$createNetworkingV1IngressClass["*/*"];
}
type RequestContentType$deleteNetworkingV1CollectionIngressClass = keyof RequestBody$deleteNetworkingV1CollectionIngressClass;
type ResponseContentType$deleteNetworkingV1CollectionIngressClass = keyof Response$deleteNetworkingV1CollectionIngressClass$Status$200;
interface Params$deleteNetworkingV1CollectionIngressClass<U extends ResponseContentType$deleteNetworkingV1CollectionIngressClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNetworkingV1CollectionIngressClass;
    requestBody: RequestBody$deleteNetworkingV1CollectionIngressClass["*/*"];
}
type ResponseContentType$readNetworkingV1IngressClass = keyof Response$readNetworkingV1IngressClass$Status$200;
interface Params$readNetworkingV1IngressClass<U extends ResponseContentType$readNetworkingV1IngressClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readNetworkingV1IngressClass;
}
type RequestContentType$replaceNetworkingV1IngressClass = keyof RequestBody$replaceNetworkingV1IngressClass;
type ResponseContentType$replaceNetworkingV1IngressClass = keyof Response$replaceNetworkingV1IngressClass$Status$200 | keyof Response$replaceNetworkingV1IngressClass$Status$201;
interface Params$replaceNetworkingV1IngressClass<U extends ResponseContentType$replaceNetworkingV1IngressClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceNetworkingV1IngressClass;
    requestBody: RequestBody$replaceNetworkingV1IngressClass["*/*"];
}
type RequestContentType$deleteNetworkingV1IngressClass = keyof RequestBody$deleteNetworkingV1IngressClass;
type ResponseContentType$deleteNetworkingV1IngressClass = keyof Response$deleteNetworkingV1IngressClass$Status$200 | keyof Response$deleteNetworkingV1IngressClass$Status$202;
interface Params$deleteNetworkingV1IngressClass<U extends ResponseContentType$deleteNetworkingV1IngressClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNetworkingV1IngressClass;
    requestBody: RequestBody$deleteNetworkingV1IngressClass["*/*"];
}
type RequestContentType$patchNetworkingV1IngressClass = keyof RequestBody$patchNetworkingV1IngressClass;
type ResponseContentType$patchNetworkingV1IngressClass = keyof Response$patchNetworkingV1IngressClass$Status$200 | keyof Response$patchNetworkingV1IngressClass$Status$201;
interface Params$patchNetworkingV1IngressClass<T extends RequestContentType$patchNetworkingV1IngressClass, U extends ResponseContentType$patchNetworkingV1IngressClass> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchNetworkingV1IngressClass;
    requestBody: RequestBody$patchNetworkingV1IngressClass[T];
}
type ResponseContentType$listNetworkingV1IngressForAllNamespaces = keyof Response$listNetworkingV1IngressForAllNamespaces$Status$200;
interface Params$listNetworkingV1IngressForAllNamespaces<U extends ResponseContentType$listNetworkingV1IngressForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listNetworkingV1IngressForAllNamespaces;
}
type ResponseContentType$listNetworkingV1NamespacedIngress = keyof Response$listNetworkingV1NamespacedIngress$Status$200;
interface Params$listNetworkingV1NamespacedIngress<U extends ResponseContentType$listNetworkingV1NamespacedIngress> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listNetworkingV1NamespacedIngress;
}
type RequestContentType$createNetworkingV1NamespacedIngress = keyof RequestBody$createNetworkingV1NamespacedIngress;
type ResponseContentType$createNetworkingV1NamespacedIngress = keyof Response$createNetworkingV1NamespacedIngress$Status$200 | keyof Response$createNetworkingV1NamespacedIngress$Status$201 | keyof Response$createNetworkingV1NamespacedIngress$Status$202;
interface Params$createNetworkingV1NamespacedIngress<U extends ResponseContentType$createNetworkingV1NamespacedIngress> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createNetworkingV1NamespacedIngress;
    requestBody: RequestBody$createNetworkingV1NamespacedIngress["*/*"];
}
type RequestContentType$deleteNetworkingV1CollectionNamespacedIngress = keyof RequestBody$deleteNetworkingV1CollectionNamespacedIngress;
type ResponseContentType$deleteNetworkingV1CollectionNamespacedIngress = keyof Response$deleteNetworkingV1CollectionNamespacedIngress$Status$200;
interface Params$deleteNetworkingV1CollectionNamespacedIngress<U extends ResponseContentType$deleteNetworkingV1CollectionNamespacedIngress> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNetworkingV1CollectionNamespacedIngress;
    requestBody: RequestBody$deleteNetworkingV1CollectionNamespacedIngress["*/*"];
}
type ResponseContentType$readNetworkingV1NamespacedIngress = keyof Response$readNetworkingV1NamespacedIngress$Status$200;
interface Params$readNetworkingV1NamespacedIngress<U extends ResponseContentType$readNetworkingV1NamespacedIngress> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readNetworkingV1NamespacedIngress;
}
type RequestContentType$replaceNetworkingV1NamespacedIngress = keyof RequestBody$replaceNetworkingV1NamespacedIngress;
type ResponseContentType$replaceNetworkingV1NamespacedIngress = keyof Response$replaceNetworkingV1NamespacedIngress$Status$200 | keyof Response$replaceNetworkingV1NamespacedIngress$Status$201;
interface Params$replaceNetworkingV1NamespacedIngress<U extends ResponseContentType$replaceNetworkingV1NamespacedIngress> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceNetworkingV1NamespacedIngress;
    requestBody: RequestBody$replaceNetworkingV1NamespacedIngress["*/*"];
}
type RequestContentType$deleteNetworkingV1NamespacedIngress = keyof RequestBody$deleteNetworkingV1NamespacedIngress;
type ResponseContentType$deleteNetworkingV1NamespacedIngress = keyof Response$deleteNetworkingV1NamespacedIngress$Status$200 | keyof Response$deleteNetworkingV1NamespacedIngress$Status$202;
interface Params$deleteNetworkingV1NamespacedIngress<U extends ResponseContentType$deleteNetworkingV1NamespacedIngress> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNetworkingV1NamespacedIngress;
    requestBody: RequestBody$deleteNetworkingV1NamespacedIngress["*/*"];
}
type RequestContentType$patchNetworkingV1NamespacedIngress = keyof RequestBody$patchNetworkingV1NamespacedIngress;
type ResponseContentType$patchNetworkingV1NamespacedIngress = keyof Response$patchNetworkingV1NamespacedIngress$Status$200 | keyof Response$patchNetworkingV1NamespacedIngress$Status$201;
interface Params$patchNetworkingV1NamespacedIngress<T extends RequestContentType$patchNetworkingV1NamespacedIngress, U extends ResponseContentType$patchNetworkingV1NamespacedIngress> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchNetworkingV1NamespacedIngress;
    requestBody: RequestBody$patchNetworkingV1NamespacedIngress[T];
}
type ResponseContentType$readNetworkingV1NamespacedIngressStatus = keyof Response$readNetworkingV1NamespacedIngressStatus$Status$200;
interface Params$readNetworkingV1NamespacedIngressStatus<U extends ResponseContentType$readNetworkingV1NamespacedIngressStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readNetworkingV1NamespacedIngressStatus;
}
type RequestContentType$replaceNetworkingV1NamespacedIngressStatus = keyof RequestBody$replaceNetworkingV1NamespacedIngressStatus;
type ResponseContentType$replaceNetworkingV1NamespacedIngressStatus = keyof Response$replaceNetworkingV1NamespacedIngressStatus$Status$200 | keyof Response$replaceNetworkingV1NamespacedIngressStatus$Status$201;
interface Params$replaceNetworkingV1NamespacedIngressStatus<U extends ResponseContentType$replaceNetworkingV1NamespacedIngressStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceNetworkingV1NamespacedIngressStatus;
    requestBody: RequestBody$replaceNetworkingV1NamespacedIngressStatus["*/*"];
}
type RequestContentType$patchNetworkingV1NamespacedIngressStatus = keyof RequestBody$patchNetworkingV1NamespacedIngressStatus;
type ResponseContentType$patchNetworkingV1NamespacedIngressStatus = keyof Response$patchNetworkingV1NamespacedIngressStatus$Status$200 | keyof Response$patchNetworkingV1NamespacedIngressStatus$Status$201;
interface Params$patchNetworkingV1NamespacedIngressStatus<T extends RequestContentType$patchNetworkingV1NamespacedIngressStatus, U extends ResponseContentType$patchNetworkingV1NamespacedIngressStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchNetworkingV1NamespacedIngressStatus;
    requestBody: RequestBody$patchNetworkingV1NamespacedIngressStatus[T];
}
type ResponseContentType$listNetworkingV1NamespacedNetworkPolicy = keyof Response$listNetworkingV1NamespacedNetworkPolicy$Status$200;
interface Params$listNetworkingV1NamespacedNetworkPolicy<U extends ResponseContentType$listNetworkingV1NamespacedNetworkPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listNetworkingV1NamespacedNetworkPolicy;
}
type RequestContentType$createNetworkingV1NamespacedNetworkPolicy = keyof RequestBody$createNetworkingV1NamespacedNetworkPolicy;
type ResponseContentType$createNetworkingV1NamespacedNetworkPolicy = keyof Response$createNetworkingV1NamespacedNetworkPolicy$Status$200 | keyof Response$createNetworkingV1NamespacedNetworkPolicy$Status$201 | keyof Response$createNetworkingV1NamespacedNetworkPolicy$Status$202;
interface Params$createNetworkingV1NamespacedNetworkPolicy<U extends ResponseContentType$createNetworkingV1NamespacedNetworkPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createNetworkingV1NamespacedNetworkPolicy;
    requestBody: RequestBody$createNetworkingV1NamespacedNetworkPolicy["*/*"];
}
type RequestContentType$deleteNetworkingV1CollectionNamespacedNetworkPolicy = keyof RequestBody$deleteNetworkingV1CollectionNamespacedNetworkPolicy;
type ResponseContentType$deleteNetworkingV1CollectionNamespacedNetworkPolicy = keyof Response$deleteNetworkingV1CollectionNamespacedNetworkPolicy$Status$200;
interface Params$deleteNetworkingV1CollectionNamespacedNetworkPolicy<U extends ResponseContentType$deleteNetworkingV1CollectionNamespacedNetworkPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNetworkingV1CollectionNamespacedNetworkPolicy;
    requestBody: RequestBody$deleteNetworkingV1CollectionNamespacedNetworkPolicy["*/*"];
}
type ResponseContentType$readNetworkingV1NamespacedNetworkPolicy = keyof Response$readNetworkingV1NamespacedNetworkPolicy$Status$200;
interface Params$readNetworkingV1NamespacedNetworkPolicy<U extends ResponseContentType$readNetworkingV1NamespacedNetworkPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readNetworkingV1NamespacedNetworkPolicy;
}
type RequestContentType$replaceNetworkingV1NamespacedNetworkPolicy = keyof RequestBody$replaceNetworkingV1NamespacedNetworkPolicy;
type ResponseContentType$replaceNetworkingV1NamespacedNetworkPolicy = keyof Response$replaceNetworkingV1NamespacedNetworkPolicy$Status$200 | keyof Response$replaceNetworkingV1NamespacedNetworkPolicy$Status$201;
interface Params$replaceNetworkingV1NamespacedNetworkPolicy<U extends ResponseContentType$replaceNetworkingV1NamespacedNetworkPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceNetworkingV1NamespacedNetworkPolicy;
    requestBody: RequestBody$replaceNetworkingV1NamespacedNetworkPolicy["*/*"];
}
type RequestContentType$deleteNetworkingV1NamespacedNetworkPolicy = keyof RequestBody$deleteNetworkingV1NamespacedNetworkPolicy;
type ResponseContentType$deleteNetworkingV1NamespacedNetworkPolicy = keyof Response$deleteNetworkingV1NamespacedNetworkPolicy$Status$200 | keyof Response$deleteNetworkingV1NamespacedNetworkPolicy$Status$202;
interface Params$deleteNetworkingV1NamespacedNetworkPolicy<U extends ResponseContentType$deleteNetworkingV1NamespacedNetworkPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNetworkingV1NamespacedNetworkPolicy;
    requestBody: RequestBody$deleteNetworkingV1NamespacedNetworkPolicy["*/*"];
}
type RequestContentType$patchNetworkingV1NamespacedNetworkPolicy = keyof RequestBody$patchNetworkingV1NamespacedNetworkPolicy;
type ResponseContentType$patchNetworkingV1NamespacedNetworkPolicy = keyof Response$patchNetworkingV1NamespacedNetworkPolicy$Status$200 | keyof Response$patchNetworkingV1NamespacedNetworkPolicy$Status$201;
interface Params$patchNetworkingV1NamespacedNetworkPolicy<T extends RequestContentType$patchNetworkingV1NamespacedNetworkPolicy, U extends ResponseContentType$patchNetworkingV1NamespacedNetworkPolicy> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchNetworkingV1NamespacedNetworkPolicy;
    requestBody: RequestBody$patchNetworkingV1NamespacedNetworkPolicy[T];
}
type ResponseContentType$readNetworkingV1NamespacedNetworkPolicyStatus = keyof Response$readNetworkingV1NamespacedNetworkPolicyStatus$Status$200;
interface Params$readNetworkingV1NamespacedNetworkPolicyStatus<U extends ResponseContentType$readNetworkingV1NamespacedNetworkPolicyStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readNetworkingV1NamespacedNetworkPolicyStatus;
}
type RequestContentType$replaceNetworkingV1NamespacedNetworkPolicyStatus = keyof RequestBody$replaceNetworkingV1NamespacedNetworkPolicyStatus;
type ResponseContentType$replaceNetworkingV1NamespacedNetworkPolicyStatus = keyof Response$replaceNetworkingV1NamespacedNetworkPolicyStatus$Status$200 | keyof Response$replaceNetworkingV1NamespacedNetworkPolicyStatus$Status$201;
interface Params$replaceNetworkingV1NamespacedNetworkPolicyStatus<U extends ResponseContentType$replaceNetworkingV1NamespacedNetworkPolicyStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceNetworkingV1NamespacedNetworkPolicyStatus;
    requestBody: RequestBody$replaceNetworkingV1NamespacedNetworkPolicyStatus["*/*"];
}
type RequestContentType$patchNetworkingV1NamespacedNetworkPolicyStatus = keyof RequestBody$patchNetworkingV1NamespacedNetworkPolicyStatus;
type ResponseContentType$patchNetworkingV1NamespacedNetworkPolicyStatus = keyof Response$patchNetworkingV1NamespacedNetworkPolicyStatus$Status$200 | keyof Response$patchNetworkingV1NamespacedNetworkPolicyStatus$Status$201;
interface Params$patchNetworkingV1NamespacedNetworkPolicyStatus<T extends RequestContentType$patchNetworkingV1NamespacedNetworkPolicyStatus, U extends ResponseContentType$patchNetworkingV1NamespacedNetworkPolicyStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchNetworkingV1NamespacedNetworkPolicyStatus;
    requestBody: RequestBody$patchNetworkingV1NamespacedNetworkPolicyStatus[T];
}
type ResponseContentType$listNetworkingV1NetworkPolicyForAllNamespaces = keyof Response$listNetworkingV1NetworkPolicyForAllNamespaces$Status$200;
interface Params$listNetworkingV1NetworkPolicyForAllNamespaces<U extends ResponseContentType$listNetworkingV1NetworkPolicyForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listNetworkingV1NetworkPolicyForAllNamespaces;
}
type ResponseContentType$watchNetworkingV1IngressClassList = keyof Response$watchNetworkingV1IngressClassList$Status$200;
interface Params$watchNetworkingV1IngressClassList<U extends ResponseContentType$watchNetworkingV1IngressClassList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNetworkingV1IngressClassList;
}
type ResponseContentType$watchNetworkingV1IngressClass = keyof Response$watchNetworkingV1IngressClass$Status$200;
interface Params$watchNetworkingV1IngressClass<U extends ResponseContentType$watchNetworkingV1IngressClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNetworkingV1IngressClass;
}
type ResponseContentType$watchNetworkingV1IngressListForAllNamespaces = keyof Response$watchNetworkingV1IngressListForAllNamespaces$Status$200;
interface Params$watchNetworkingV1IngressListForAllNamespaces<U extends ResponseContentType$watchNetworkingV1IngressListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNetworkingV1IngressListForAllNamespaces;
}
type ResponseContentType$watchNetworkingV1NamespacedIngressList = keyof Response$watchNetworkingV1NamespacedIngressList$Status$200;
interface Params$watchNetworkingV1NamespacedIngressList<U extends ResponseContentType$watchNetworkingV1NamespacedIngressList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNetworkingV1NamespacedIngressList;
}
type ResponseContentType$watchNetworkingV1NamespacedIngress = keyof Response$watchNetworkingV1NamespacedIngress$Status$200;
interface Params$watchNetworkingV1NamespacedIngress<U extends ResponseContentType$watchNetworkingV1NamespacedIngress> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNetworkingV1NamespacedIngress;
}
type ResponseContentType$watchNetworkingV1NamespacedNetworkPolicyList = keyof Response$watchNetworkingV1NamespacedNetworkPolicyList$Status$200;
interface Params$watchNetworkingV1NamespacedNetworkPolicyList<U extends ResponseContentType$watchNetworkingV1NamespacedNetworkPolicyList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNetworkingV1NamespacedNetworkPolicyList;
}
type ResponseContentType$watchNetworkingV1NamespacedNetworkPolicy = keyof Response$watchNetworkingV1NamespacedNetworkPolicy$Status$200;
interface Params$watchNetworkingV1NamespacedNetworkPolicy<U extends ResponseContentType$watchNetworkingV1NamespacedNetworkPolicy> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNetworkingV1NamespacedNetworkPolicy;
}
type ResponseContentType$watchNetworkingV1NetworkPolicyListForAllNamespaces = keyof Response$watchNetworkingV1NetworkPolicyListForAllNamespaces$Status$200;
interface Params$watchNetworkingV1NetworkPolicyListForAllNamespaces<U extends ResponseContentType$watchNetworkingV1NetworkPolicyListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNetworkingV1NetworkPolicyListForAllNamespaces;
}
type ResponseContentType$getNetworkingV1alpha1APIResources = keyof Response$getNetworkingV1alpha1APIResources$Status$200;
interface Params$getNetworkingV1alpha1APIResources<U extends ResponseContentType$getNetworkingV1alpha1APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listNetworkingV1alpha1ClusterCIDR = keyof Response$listNetworkingV1alpha1ClusterCIDR$Status$200;
interface Params$listNetworkingV1alpha1ClusterCIDR<U extends ResponseContentType$listNetworkingV1alpha1ClusterCIDR> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listNetworkingV1alpha1ClusterCIDR;
}
type RequestContentType$createNetworkingV1alpha1ClusterCIDR = keyof RequestBody$createNetworkingV1alpha1ClusterCIDR;
type ResponseContentType$createNetworkingV1alpha1ClusterCIDR = keyof Response$createNetworkingV1alpha1ClusterCIDR$Status$200 | keyof Response$createNetworkingV1alpha1ClusterCIDR$Status$201 | keyof Response$createNetworkingV1alpha1ClusterCIDR$Status$202;
interface Params$createNetworkingV1alpha1ClusterCIDR<U extends ResponseContentType$createNetworkingV1alpha1ClusterCIDR> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createNetworkingV1alpha1ClusterCIDR;
    requestBody: RequestBody$createNetworkingV1alpha1ClusterCIDR["*/*"];
}
type RequestContentType$deleteNetworkingV1alpha1CollectionClusterCIDR = keyof RequestBody$deleteNetworkingV1alpha1CollectionClusterCIDR;
type ResponseContentType$deleteNetworkingV1alpha1CollectionClusterCIDR = keyof Response$deleteNetworkingV1alpha1CollectionClusterCIDR$Status$200;
interface Params$deleteNetworkingV1alpha1CollectionClusterCIDR<U extends ResponseContentType$deleteNetworkingV1alpha1CollectionClusterCIDR> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNetworkingV1alpha1CollectionClusterCIDR;
    requestBody: RequestBody$deleteNetworkingV1alpha1CollectionClusterCIDR["*/*"];
}
type ResponseContentType$readNetworkingV1alpha1ClusterCIDR = keyof Response$readNetworkingV1alpha1ClusterCIDR$Status$200;
interface Params$readNetworkingV1alpha1ClusterCIDR<U extends ResponseContentType$readNetworkingV1alpha1ClusterCIDR> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readNetworkingV1alpha1ClusterCIDR;
}
type RequestContentType$replaceNetworkingV1alpha1ClusterCIDR = keyof RequestBody$replaceNetworkingV1alpha1ClusterCIDR;
type ResponseContentType$replaceNetworkingV1alpha1ClusterCIDR = keyof Response$replaceNetworkingV1alpha1ClusterCIDR$Status$200 | keyof Response$replaceNetworkingV1alpha1ClusterCIDR$Status$201;
interface Params$replaceNetworkingV1alpha1ClusterCIDR<U extends ResponseContentType$replaceNetworkingV1alpha1ClusterCIDR> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceNetworkingV1alpha1ClusterCIDR;
    requestBody: RequestBody$replaceNetworkingV1alpha1ClusterCIDR["*/*"];
}
type RequestContentType$deleteNetworkingV1alpha1ClusterCIDR = keyof RequestBody$deleteNetworkingV1alpha1ClusterCIDR;
type ResponseContentType$deleteNetworkingV1alpha1ClusterCIDR = keyof Response$deleteNetworkingV1alpha1ClusterCIDR$Status$200 | keyof Response$deleteNetworkingV1alpha1ClusterCIDR$Status$202;
interface Params$deleteNetworkingV1alpha1ClusterCIDR<U extends ResponseContentType$deleteNetworkingV1alpha1ClusterCIDR> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNetworkingV1alpha1ClusterCIDR;
    requestBody: RequestBody$deleteNetworkingV1alpha1ClusterCIDR["*/*"];
}
type RequestContentType$patchNetworkingV1alpha1ClusterCIDR = keyof RequestBody$patchNetworkingV1alpha1ClusterCIDR;
type ResponseContentType$patchNetworkingV1alpha1ClusterCIDR = keyof Response$patchNetworkingV1alpha1ClusterCIDR$Status$200 | keyof Response$patchNetworkingV1alpha1ClusterCIDR$Status$201;
interface Params$patchNetworkingV1alpha1ClusterCIDR<T extends RequestContentType$patchNetworkingV1alpha1ClusterCIDR, U extends ResponseContentType$patchNetworkingV1alpha1ClusterCIDR> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchNetworkingV1alpha1ClusterCIDR;
    requestBody: RequestBody$patchNetworkingV1alpha1ClusterCIDR[T];
}
type ResponseContentType$listNetworkingV1alpha1IPAddress = keyof Response$listNetworkingV1alpha1IPAddress$Status$200;
interface Params$listNetworkingV1alpha1IPAddress<U extends ResponseContentType$listNetworkingV1alpha1IPAddress> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listNetworkingV1alpha1IPAddress;
}
type RequestContentType$createNetworkingV1alpha1IPAddress = keyof RequestBody$createNetworkingV1alpha1IPAddress;
type ResponseContentType$createNetworkingV1alpha1IPAddress = keyof Response$createNetworkingV1alpha1IPAddress$Status$200 | keyof Response$createNetworkingV1alpha1IPAddress$Status$201 | keyof Response$createNetworkingV1alpha1IPAddress$Status$202;
interface Params$createNetworkingV1alpha1IPAddress<U extends ResponseContentType$createNetworkingV1alpha1IPAddress> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createNetworkingV1alpha1IPAddress;
    requestBody: RequestBody$createNetworkingV1alpha1IPAddress["*/*"];
}
type RequestContentType$deleteNetworkingV1alpha1CollectionIPAddress = keyof RequestBody$deleteNetworkingV1alpha1CollectionIPAddress;
type ResponseContentType$deleteNetworkingV1alpha1CollectionIPAddress = keyof Response$deleteNetworkingV1alpha1CollectionIPAddress$Status$200;
interface Params$deleteNetworkingV1alpha1CollectionIPAddress<U extends ResponseContentType$deleteNetworkingV1alpha1CollectionIPAddress> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNetworkingV1alpha1CollectionIPAddress;
    requestBody: RequestBody$deleteNetworkingV1alpha1CollectionIPAddress["*/*"];
}
type ResponseContentType$readNetworkingV1alpha1IPAddress = keyof Response$readNetworkingV1alpha1IPAddress$Status$200;
interface Params$readNetworkingV1alpha1IPAddress<U extends ResponseContentType$readNetworkingV1alpha1IPAddress> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readNetworkingV1alpha1IPAddress;
}
type RequestContentType$replaceNetworkingV1alpha1IPAddress = keyof RequestBody$replaceNetworkingV1alpha1IPAddress;
type ResponseContentType$replaceNetworkingV1alpha1IPAddress = keyof Response$replaceNetworkingV1alpha1IPAddress$Status$200 | keyof Response$replaceNetworkingV1alpha1IPAddress$Status$201;
interface Params$replaceNetworkingV1alpha1IPAddress<U extends ResponseContentType$replaceNetworkingV1alpha1IPAddress> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceNetworkingV1alpha1IPAddress;
    requestBody: RequestBody$replaceNetworkingV1alpha1IPAddress["*/*"];
}
type RequestContentType$deleteNetworkingV1alpha1IPAddress = keyof RequestBody$deleteNetworkingV1alpha1IPAddress;
type ResponseContentType$deleteNetworkingV1alpha1IPAddress = keyof Response$deleteNetworkingV1alpha1IPAddress$Status$200 | keyof Response$deleteNetworkingV1alpha1IPAddress$Status$202;
interface Params$deleteNetworkingV1alpha1IPAddress<U extends ResponseContentType$deleteNetworkingV1alpha1IPAddress> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNetworkingV1alpha1IPAddress;
    requestBody: RequestBody$deleteNetworkingV1alpha1IPAddress["*/*"];
}
type RequestContentType$patchNetworkingV1alpha1IPAddress = keyof RequestBody$patchNetworkingV1alpha1IPAddress;
type ResponseContentType$patchNetworkingV1alpha1IPAddress = keyof Response$patchNetworkingV1alpha1IPAddress$Status$200 | keyof Response$patchNetworkingV1alpha1IPAddress$Status$201;
interface Params$patchNetworkingV1alpha1IPAddress<T extends RequestContentType$patchNetworkingV1alpha1IPAddress, U extends ResponseContentType$patchNetworkingV1alpha1IPAddress> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchNetworkingV1alpha1IPAddress;
    requestBody: RequestBody$patchNetworkingV1alpha1IPAddress[T];
}
type ResponseContentType$watchNetworkingV1alpha1ClusterCIDRList = keyof Response$watchNetworkingV1alpha1ClusterCIDRList$Status$200;
interface Params$watchNetworkingV1alpha1ClusterCIDRList<U extends ResponseContentType$watchNetworkingV1alpha1ClusterCIDRList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNetworkingV1alpha1ClusterCIDRList;
}
type ResponseContentType$watchNetworkingV1alpha1ClusterCIDR = keyof Response$watchNetworkingV1alpha1ClusterCIDR$Status$200;
interface Params$watchNetworkingV1alpha1ClusterCIDR<U extends ResponseContentType$watchNetworkingV1alpha1ClusterCIDR> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNetworkingV1alpha1ClusterCIDR;
}
type ResponseContentType$watchNetworkingV1alpha1IPAddressList = keyof Response$watchNetworkingV1alpha1IPAddressList$Status$200;
interface Params$watchNetworkingV1alpha1IPAddressList<U extends ResponseContentType$watchNetworkingV1alpha1IPAddressList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNetworkingV1alpha1IPAddressList;
}
type ResponseContentType$watchNetworkingV1alpha1IPAddress = keyof Response$watchNetworkingV1alpha1IPAddress$Status$200;
interface Params$watchNetworkingV1alpha1IPAddress<U extends ResponseContentType$watchNetworkingV1alpha1IPAddress> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNetworkingV1alpha1IPAddress;
}
type ResponseContentType$getNodeAPIGroup = keyof Response$getNodeAPIGroup$Status$200;
interface Params$getNodeAPIGroup<U extends ResponseContentType$getNodeAPIGroup> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getNodeV1APIResources = keyof Response$getNodeV1APIResources$Status$200;
interface Params$getNodeV1APIResources<U extends ResponseContentType$getNodeV1APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listNodeV1RuntimeClass = keyof Response$listNodeV1RuntimeClass$Status$200;
interface Params$listNodeV1RuntimeClass<U extends ResponseContentType$listNodeV1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listNodeV1RuntimeClass;
}
type RequestContentType$createNodeV1RuntimeClass = keyof RequestBody$createNodeV1RuntimeClass;
type ResponseContentType$createNodeV1RuntimeClass = keyof Response$createNodeV1RuntimeClass$Status$200 | keyof Response$createNodeV1RuntimeClass$Status$201 | keyof Response$createNodeV1RuntimeClass$Status$202;
interface Params$createNodeV1RuntimeClass<U extends ResponseContentType$createNodeV1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createNodeV1RuntimeClass;
    requestBody: RequestBody$createNodeV1RuntimeClass["*/*"];
}
type RequestContentType$deleteNodeV1CollectionRuntimeClass = keyof RequestBody$deleteNodeV1CollectionRuntimeClass;
type ResponseContentType$deleteNodeV1CollectionRuntimeClass = keyof Response$deleteNodeV1CollectionRuntimeClass$Status$200;
interface Params$deleteNodeV1CollectionRuntimeClass<U extends ResponseContentType$deleteNodeV1CollectionRuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNodeV1CollectionRuntimeClass;
    requestBody: RequestBody$deleteNodeV1CollectionRuntimeClass["*/*"];
}
type ResponseContentType$readNodeV1RuntimeClass = keyof Response$readNodeV1RuntimeClass$Status$200;
interface Params$readNodeV1RuntimeClass<U extends ResponseContentType$readNodeV1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readNodeV1RuntimeClass;
}
type RequestContentType$replaceNodeV1RuntimeClass = keyof RequestBody$replaceNodeV1RuntimeClass;
type ResponseContentType$replaceNodeV1RuntimeClass = keyof Response$replaceNodeV1RuntimeClass$Status$200 | keyof Response$replaceNodeV1RuntimeClass$Status$201;
interface Params$replaceNodeV1RuntimeClass<U extends ResponseContentType$replaceNodeV1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceNodeV1RuntimeClass;
    requestBody: RequestBody$replaceNodeV1RuntimeClass["*/*"];
}
type RequestContentType$deleteNodeV1RuntimeClass = keyof RequestBody$deleteNodeV1RuntimeClass;
type ResponseContentType$deleteNodeV1RuntimeClass = keyof Response$deleteNodeV1RuntimeClass$Status$200 | keyof Response$deleteNodeV1RuntimeClass$Status$202;
interface Params$deleteNodeV1RuntimeClass<U extends ResponseContentType$deleteNodeV1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteNodeV1RuntimeClass;
    requestBody: RequestBody$deleteNodeV1RuntimeClass["*/*"];
}
type RequestContentType$patchNodeV1RuntimeClass = keyof RequestBody$patchNodeV1RuntimeClass;
type ResponseContentType$patchNodeV1RuntimeClass = keyof Response$patchNodeV1RuntimeClass$Status$200 | keyof Response$patchNodeV1RuntimeClass$Status$201;
interface Params$patchNodeV1RuntimeClass<T extends RequestContentType$patchNodeV1RuntimeClass, U extends ResponseContentType$patchNodeV1RuntimeClass> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchNodeV1RuntimeClass;
    requestBody: RequestBody$patchNodeV1RuntimeClass[T];
}
type ResponseContentType$watchNodeV1RuntimeClassList = keyof Response$watchNodeV1RuntimeClassList$Status$200;
interface Params$watchNodeV1RuntimeClassList<U extends ResponseContentType$watchNodeV1RuntimeClassList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNodeV1RuntimeClassList;
}
type ResponseContentType$watchNodeV1RuntimeClass = keyof Response$watchNodeV1RuntimeClass$Status$200;
interface Params$watchNodeV1RuntimeClass<U extends ResponseContentType$watchNodeV1RuntimeClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchNodeV1RuntimeClass;
}
type ResponseContentType$getPolicyAPIGroup = keyof Response$getPolicyAPIGroup$Status$200;
interface Params$getPolicyAPIGroup<U extends ResponseContentType$getPolicyAPIGroup> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getPolicyV1APIResources = keyof Response$getPolicyV1APIResources$Status$200;
interface Params$getPolicyV1APIResources<U extends ResponseContentType$getPolicyV1APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listPolicyV1NamespacedPodDisruptionBudget = keyof Response$listPolicyV1NamespacedPodDisruptionBudget$Status$200;
interface Params$listPolicyV1NamespacedPodDisruptionBudget<U extends ResponseContentType$listPolicyV1NamespacedPodDisruptionBudget> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listPolicyV1NamespacedPodDisruptionBudget;
}
type RequestContentType$createPolicyV1NamespacedPodDisruptionBudget = keyof RequestBody$createPolicyV1NamespacedPodDisruptionBudget;
type ResponseContentType$createPolicyV1NamespacedPodDisruptionBudget = keyof Response$createPolicyV1NamespacedPodDisruptionBudget$Status$200 | keyof Response$createPolicyV1NamespacedPodDisruptionBudget$Status$201 | keyof Response$createPolicyV1NamespacedPodDisruptionBudget$Status$202;
interface Params$createPolicyV1NamespacedPodDisruptionBudget<U extends ResponseContentType$createPolicyV1NamespacedPodDisruptionBudget> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createPolicyV1NamespacedPodDisruptionBudget;
    requestBody: RequestBody$createPolicyV1NamespacedPodDisruptionBudget["*/*"];
}
type RequestContentType$deletePolicyV1CollectionNamespacedPodDisruptionBudget = keyof RequestBody$deletePolicyV1CollectionNamespacedPodDisruptionBudget;
type ResponseContentType$deletePolicyV1CollectionNamespacedPodDisruptionBudget = keyof Response$deletePolicyV1CollectionNamespacedPodDisruptionBudget$Status$200;
interface Params$deletePolicyV1CollectionNamespacedPodDisruptionBudget<U extends ResponseContentType$deletePolicyV1CollectionNamespacedPodDisruptionBudget> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deletePolicyV1CollectionNamespacedPodDisruptionBudget;
    requestBody: RequestBody$deletePolicyV1CollectionNamespacedPodDisruptionBudget["*/*"];
}
type ResponseContentType$readPolicyV1NamespacedPodDisruptionBudget = keyof Response$readPolicyV1NamespacedPodDisruptionBudget$Status$200;
interface Params$readPolicyV1NamespacedPodDisruptionBudget<U extends ResponseContentType$readPolicyV1NamespacedPodDisruptionBudget> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readPolicyV1NamespacedPodDisruptionBudget;
}
type RequestContentType$replacePolicyV1NamespacedPodDisruptionBudget = keyof RequestBody$replacePolicyV1NamespacedPodDisruptionBudget;
type ResponseContentType$replacePolicyV1NamespacedPodDisruptionBudget = keyof Response$replacePolicyV1NamespacedPodDisruptionBudget$Status$200 | keyof Response$replacePolicyV1NamespacedPodDisruptionBudget$Status$201;
interface Params$replacePolicyV1NamespacedPodDisruptionBudget<U extends ResponseContentType$replacePolicyV1NamespacedPodDisruptionBudget> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replacePolicyV1NamespacedPodDisruptionBudget;
    requestBody: RequestBody$replacePolicyV1NamespacedPodDisruptionBudget["*/*"];
}
type RequestContentType$deletePolicyV1NamespacedPodDisruptionBudget = keyof RequestBody$deletePolicyV1NamespacedPodDisruptionBudget;
type ResponseContentType$deletePolicyV1NamespacedPodDisruptionBudget = keyof Response$deletePolicyV1NamespacedPodDisruptionBudget$Status$200 | keyof Response$deletePolicyV1NamespacedPodDisruptionBudget$Status$202;
interface Params$deletePolicyV1NamespacedPodDisruptionBudget<U extends ResponseContentType$deletePolicyV1NamespacedPodDisruptionBudget> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deletePolicyV1NamespacedPodDisruptionBudget;
    requestBody: RequestBody$deletePolicyV1NamespacedPodDisruptionBudget["*/*"];
}
type RequestContentType$patchPolicyV1NamespacedPodDisruptionBudget = keyof RequestBody$patchPolicyV1NamespacedPodDisruptionBudget;
type ResponseContentType$patchPolicyV1NamespacedPodDisruptionBudget = keyof Response$patchPolicyV1NamespacedPodDisruptionBudget$Status$200 | keyof Response$patchPolicyV1NamespacedPodDisruptionBudget$Status$201;
interface Params$patchPolicyV1NamespacedPodDisruptionBudget<T extends RequestContentType$patchPolicyV1NamespacedPodDisruptionBudget, U extends ResponseContentType$patchPolicyV1NamespacedPodDisruptionBudget> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchPolicyV1NamespacedPodDisruptionBudget;
    requestBody: RequestBody$patchPolicyV1NamespacedPodDisruptionBudget[T];
}
type ResponseContentType$readPolicyV1NamespacedPodDisruptionBudgetStatus = keyof Response$readPolicyV1NamespacedPodDisruptionBudgetStatus$Status$200;
interface Params$readPolicyV1NamespacedPodDisruptionBudgetStatus<U extends ResponseContentType$readPolicyV1NamespacedPodDisruptionBudgetStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readPolicyV1NamespacedPodDisruptionBudgetStatus;
}
type RequestContentType$replacePolicyV1NamespacedPodDisruptionBudgetStatus = keyof RequestBody$replacePolicyV1NamespacedPodDisruptionBudgetStatus;
type ResponseContentType$replacePolicyV1NamespacedPodDisruptionBudgetStatus = keyof Response$replacePolicyV1NamespacedPodDisruptionBudgetStatus$Status$200 | keyof Response$replacePolicyV1NamespacedPodDisruptionBudgetStatus$Status$201;
interface Params$replacePolicyV1NamespacedPodDisruptionBudgetStatus<U extends ResponseContentType$replacePolicyV1NamespacedPodDisruptionBudgetStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replacePolicyV1NamespacedPodDisruptionBudgetStatus;
    requestBody: RequestBody$replacePolicyV1NamespacedPodDisruptionBudgetStatus["*/*"];
}
type RequestContentType$patchPolicyV1NamespacedPodDisruptionBudgetStatus = keyof RequestBody$patchPolicyV1NamespacedPodDisruptionBudgetStatus;
type ResponseContentType$patchPolicyV1NamespacedPodDisruptionBudgetStatus = keyof Response$patchPolicyV1NamespacedPodDisruptionBudgetStatus$Status$200 | keyof Response$patchPolicyV1NamespacedPodDisruptionBudgetStatus$Status$201;
interface Params$patchPolicyV1NamespacedPodDisruptionBudgetStatus<T extends RequestContentType$patchPolicyV1NamespacedPodDisruptionBudgetStatus, U extends ResponseContentType$patchPolicyV1NamespacedPodDisruptionBudgetStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchPolicyV1NamespacedPodDisruptionBudgetStatus;
    requestBody: RequestBody$patchPolicyV1NamespacedPodDisruptionBudgetStatus[T];
}
type ResponseContentType$listPolicyV1PodDisruptionBudgetForAllNamespaces = keyof Response$listPolicyV1PodDisruptionBudgetForAllNamespaces$Status$200;
interface Params$listPolicyV1PodDisruptionBudgetForAllNamespaces<U extends ResponseContentType$listPolicyV1PodDisruptionBudgetForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listPolicyV1PodDisruptionBudgetForAllNamespaces;
}
type ResponseContentType$watchPolicyV1NamespacedPodDisruptionBudgetList = keyof Response$watchPolicyV1NamespacedPodDisruptionBudgetList$Status$200;
interface Params$watchPolicyV1NamespacedPodDisruptionBudgetList<U extends ResponseContentType$watchPolicyV1NamespacedPodDisruptionBudgetList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchPolicyV1NamespacedPodDisruptionBudgetList;
}
type ResponseContentType$watchPolicyV1NamespacedPodDisruptionBudget = keyof Response$watchPolicyV1NamespacedPodDisruptionBudget$Status$200;
interface Params$watchPolicyV1NamespacedPodDisruptionBudget<U extends ResponseContentType$watchPolicyV1NamespacedPodDisruptionBudget> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchPolicyV1NamespacedPodDisruptionBudget;
}
type ResponseContentType$watchPolicyV1PodDisruptionBudgetListForAllNamespaces = keyof Response$watchPolicyV1PodDisruptionBudgetListForAllNamespaces$Status$200;
interface Params$watchPolicyV1PodDisruptionBudgetListForAllNamespaces<U extends ResponseContentType$watchPolicyV1PodDisruptionBudgetListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchPolicyV1PodDisruptionBudgetListForAllNamespaces;
}
type ResponseContentType$getRbacAuthorizationAPIGroup = keyof Response$getRbacAuthorizationAPIGroup$Status$200;
interface Params$getRbacAuthorizationAPIGroup<U extends ResponseContentType$getRbacAuthorizationAPIGroup> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getRbacAuthorizationV1APIResources = keyof Response$getRbacAuthorizationV1APIResources$Status$200;
interface Params$getRbacAuthorizationV1APIResources<U extends ResponseContentType$getRbacAuthorizationV1APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listRbacAuthorizationV1ClusterRoleBinding = keyof Response$listRbacAuthorizationV1ClusterRoleBinding$Status$200;
interface Params$listRbacAuthorizationV1ClusterRoleBinding<U extends ResponseContentType$listRbacAuthorizationV1ClusterRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listRbacAuthorizationV1ClusterRoleBinding;
}
type RequestContentType$createRbacAuthorizationV1ClusterRoleBinding = keyof RequestBody$createRbacAuthorizationV1ClusterRoleBinding;
type ResponseContentType$createRbacAuthorizationV1ClusterRoleBinding = keyof Response$createRbacAuthorizationV1ClusterRoleBinding$Status$200 | keyof Response$createRbacAuthorizationV1ClusterRoleBinding$Status$201 | keyof Response$createRbacAuthorizationV1ClusterRoleBinding$Status$202;
interface Params$createRbacAuthorizationV1ClusterRoleBinding<U extends ResponseContentType$createRbacAuthorizationV1ClusterRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createRbacAuthorizationV1ClusterRoleBinding;
    requestBody: RequestBody$createRbacAuthorizationV1ClusterRoleBinding["*/*"];
}
type RequestContentType$deleteRbacAuthorizationV1CollectionClusterRoleBinding = keyof RequestBody$deleteRbacAuthorizationV1CollectionClusterRoleBinding;
type ResponseContentType$deleteRbacAuthorizationV1CollectionClusterRoleBinding = keyof Response$deleteRbacAuthorizationV1CollectionClusterRoleBinding$Status$200;
interface Params$deleteRbacAuthorizationV1CollectionClusterRoleBinding<U extends ResponseContentType$deleteRbacAuthorizationV1CollectionClusterRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteRbacAuthorizationV1CollectionClusterRoleBinding;
    requestBody: RequestBody$deleteRbacAuthorizationV1CollectionClusterRoleBinding["*/*"];
}
type ResponseContentType$readRbacAuthorizationV1ClusterRoleBinding = keyof Response$readRbacAuthorizationV1ClusterRoleBinding$Status$200;
interface Params$readRbacAuthorizationV1ClusterRoleBinding<U extends ResponseContentType$readRbacAuthorizationV1ClusterRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readRbacAuthorizationV1ClusterRoleBinding;
}
type RequestContentType$replaceRbacAuthorizationV1ClusterRoleBinding = keyof RequestBody$replaceRbacAuthorizationV1ClusterRoleBinding;
type ResponseContentType$replaceRbacAuthorizationV1ClusterRoleBinding = keyof Response$replaceRbacAuthorizationV1ClusterRoleBinding$Status$200 | keyof Response$replaceRbacAuthorizationV1ClusterRoleBinding$Status$201;
interface Params$replaceRbacAuthorizationV1ClusterRoleBinding<U extends ResponseContentType$replaceRbacAuthorizationV1ClusterRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceRbacAuthorizationV1ClusterRoleBinding;
    requestBody: RequestBody$replaceRbacAuthorizationV1ClusterRoleBinding["*/*"];
}
type RequestContentType$deleteRbacAuthorizationV1ClusterRoleBinding = keyof RequestBody$deleteRbacAuthorizationV1ClusterRoleBinding;
type ResponseContentType$deleteRbacAuthorizationV1ClusterRoleBinding = keyof Response$deleteRbacAuthorizationV1ClusterRoleBinding$Status$200 | keyof Response$deleteRbacAuthorizationV1ClusterRoleBinding$Status$202;
interface Params$deleteRbacAuthorizationV1ClusterRoleBinding<U extends ResponseContentType$deleteRbacAuthorizationV1ClusterRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteRbacAuthorizationV1ClusterRoleBinding;
    requestBody: RequestBody$deleteRbacAuthorizationV1ClusterRoleBinding["*/*"];
}
type RequestContentType$patchRbacAuthorizationV1ClusterRoleBinding = keyof RequestBody$patchRbacAuthorizationV1ClusterRoleBinding;
type ResponseContentType$patchRbacAuthorizationV1ClusterRoleBinding = keyof Response$patchRbacAuthorizationV1ClusterRoleBinding$Status$200 | keyof Response$patchRbacAuthorizationV1ClusterRoleBinding$Status$201;
interface Params$patchRbacAuthorizationV1ClusterRoleBinding<T extends RequestContentType$patchRbacAuthorizationV1ClusterRoleBinding, U extends ResponseContentType$patchRbacAuthorizationV1ClusterRoleBinding> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchRbacAuthorizationV1ClusterRoleBinding;
    requestBody: RequestBody$patchRbacAuthorizationV1ClusterRoleBinding[T];
}
type ResponseContentType$listRbacAuthorizationV1ClusterRole = keyof Response$listRbacAuthorizationV1ClusterRole$Status$200;
interface Params$listRbacAuthorizationV1ClusterRole<U extends ResponseContentType$listRbacAuthorizationV1ClusterRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listRbacAuthorizationV1ClusterRole;
}
type RequestContentType$createRbacAuthorizationV1ClusterRole = keyof RequestBody$createRbacAuthorizationV1ClusterRole;
type ResponseContentType$createRbacAuthorizationV1ClusterRole = keyof Response$createRbacAuthorizationV1ClusterRole$Status$200 | keyof Response$createRbacAuthorizationV1ClusterRole$Status$201 | keyof Response$createRbacAuthorizationV1ClusterRole$Status$202;
interface Params$createRbacAuthorizationV1ClusterRole<U extends ResponseContentType$createRbacAuthorizationV1ClusterRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createRbacAuthorizationV1ClusterRole;
    requestBody: RequestBody$createRbacAuthorizationV1ClusterRole["*/*"];
}
type RequestContentType$deleteRbacAuthorizationV1CollectionClusterRole = keyof RequestBody$deleteRbacAuthorizationV1CollectionClusterRole;
type ResponseContentType$deleteRbacAuthorizationV1CollectionClusterRole = keyof Response$deleteRbacAuthorizationV1CollectionClusterRole$Status$200;
interface Params$deleteRbacAuthorizationV1CollectionClusterRole<U extends ResponseContentType$deleteRbacAuthorizationV1CollectionClusterRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteRbacAuthorizationV1CollectionClusterRole;
    requestBody: RequestBody$deleteRbacAuthorizationV1CollectionClusterRole["*/*"];
}
type ResponseContentType$readRbacAuthorizationV1ClusterRole = keyof Response$readRbacAuthorizationV1ClusterRole$Status$200;
interface Params$readRbacAuthorizationV1ClusterRole<U extends ResponseContentType$readRbacAuthorizationV1ClusterRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readRbacAuthorizationV1ClusterRole;
}
type RequestContentType$replaceRbacAuthorizationV1ClusterRole = keyof RequestBody$replaceRbacAuthorizationV1ClusterRole;
type ResponseContentType$replaceRbacAuthorizationV1ClusterRole = keyof Response$replaceRbacAuthorizationV1ClusterRole$Status$200 | keyof Response$replaceRbacAuthorizationV1ClusterRole$Status$201;
interface Params$replaceRbacAuthorizationV1ClusterRole<U extends ResponseContentType$replaceRbacAuthorizationV1ClusterRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceRbacAuthorizationV1ClusterRole;
    requestBody: RequestBody$replaceRbacAuthorizationV1ClusterRole["*/*"];
}
type RequestContentType$deleteRbacAuthorizationV1ClusterRole = keyof RequestBody$deleteRbacAuthorizationV1ClusterRole;
type ResponseContentType$deleteRbacAuthorizationV1ClusterRole = keyof Response$deleteRbacAuthorizationV1ClusterRole$Status$200 | keyof Response$deleteRbacAuthorizationV1ClusterRole$Status$202;
interface Params$deleteRbacAuthorizationV1ClusterRole<U extends ResponseContentType$deleteRbacAuthorizationV1ClusterRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteRbacAuthorizationV1ClusterRole;
    requestBody: RequestBody$deleteRbacAuthorizationV1ClusterRole["*/*"];
}
type RequestContentType$patchRbacAuthorizationV1ClusterRole = keyof RequestBody$patchRbacAuthorizationV1ClusterRole;
type ResponseContentType$patchRbacAuthorizationV1ClusterRole = keyof Response$patchRbacAuthorizationV1ClusterRole$Status$200 | keyof Response$patchRbacAuthorizationV1ClusterRole$Status$201;
interface Params$patchRbacAuthorizationV1ClusterRole<T extends RequestContentType$patchRbacAuthorizationV1ClusterRole, U extends ResponseContentType$patchRbacAuthorizationV1ClusterRole> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchRbacAuthorizationV1ClusterRole;
    requestBody: RequestBody$patchRbacAuthorizationV1ClusterRole[T];
}
type ResponseContentType$listRbacAuthorizationV1NamespacedRoleBinding = keyof Response$listRbacAuthorizationV1NamespacedRoleBinding$Status$200;
interface Params$listRbacAuthorizationV1NamespacedRoleBinding<U extends ResponseContentType$listRbacAuthorizationV1NamespacedRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listRbacAuthorizationV1NamespacedRoleBinding;
}
type RequestContentType$createRbacAuthorizationV1NamespacedRoleBinding = keyof RequestBody$createRbacAuthorizationV1NamespacedRoleBinding;
type ResponseContentType$createRbacAuthorizationV1NamespacedRoleBinding = keyof Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$200 | keyof Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$201 | keyof Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$202;
interface Params$createRbacAuthorizationV1NamespacedRoleBinding<U extends ResponseContentType$createRbacAuthorizationV1NamespacedRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createRbacAuthorizationV1NamespacedRoleBinding;
    requestBody: RequestBody$createRbacAuthorizationV1NamespacedRoleBinding["*/*"];
}
type RequestContentType$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding = keyof RequestBody$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding;
type ResponseContentType$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding = keyof Response$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding$Status$200;
interface Params$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding<U extends ResponseContentType$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding;
    requestBody: RequestBody$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding["*/*"];
}
type ResponseContentType$readRbacAuthorizationV1NamespacedRoleBinding = keyof Response$readRbacAuthorizationV1NamespacedRoleBinding$Status$200;
interface Params$readRbacAuthorizationV1NamespacedRoleBinding<U extends ResponseContentType$readRbacAuthorizationV1NamespacedRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readRbacAuthorizationV1NamespacedRoleBinding;
}
type RequestContentType$replaceRbacAuthorizationV1NamespacedRoleBinding = keyof RequestBody$replaceRbacAuthorizationV1NamespacedRoleBinding;
type ResponseContentType$replaceRbacAuthorizationV1NamespacedRoleBinding = keyof Response$replaceRbacAuthorizationV1NamespacedRoleBinding$Status$200 | keyof Response$replaceRbacAuthorizationV1NamespacedRoleBinding$Status$201;
interface Params$replaceRbacAuthorizationV1NamespacedRoleBinding<U extends ResponseContentType$replaceRbacAuthorizationV1NamespacedRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceRbacAuthorizationV1NamespacedRoleBinding;
    requestBody: RequestBody$replaceRbacAuthorizationV1NamespacedRoleBinding["*/*"];
}
type RequestContentType$deleteRbacAuthorizationV1NamespacedRoleBinding = keyof RequestBody$deleteRbacAuthorizationV1NamespacedRoleBinding;
type ResponseContentType$deleteRbacAuthorizationV1NamespacedRoleBinding = keyof Response$deleteRbacAuthorizationV1NamespacedRoleBinding$Status$200 | keyof Response$deleteRbacAuthorizationV1NamespacedRoleBinding$Status$202;
interface Params$deleteRbacAuthorizationV1NamespacedRoleBinding<U extends ResponseContentType$deleteRbacAuthorizationV1NamespacedRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteRbacAuthorizationV1NamespacedRoleBinding;
    requestBody: RequestBody$deleteRbacAuthorizationV1NamespacedRoleBinding["*/*"];
}
type RequestContentType$patchRbacAuthorizationV1NamespacedRoleBinding = keyof RequestBody$patchRbacAuthorizationV1NamespacedRoleBinding;
type ResponseContentType$patchRbacAuthorizationV1NamespacedRoleBinding = keyof Response$patchRbacAuthorizationV1NamespacedRoleBinding$Status$200 | keyof Response$patchRbacAuthorizationV1NamespacedRoleBinding$Status$201;
interface Params$patchRbacAuthorizationV1NamespacedRoleBinding<T extends RequestContentType$patchRbacAuthorizationV1NamespacedRoleBinding, U extends ResponseContentType$patchRbacAuthorizationV1NamespacedRoleBinding> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchRbacAuthorizationV1NamespacedRoleBinding;
    requestBody: RequestBody$patchRbacAuthorizationV1NamespacedRoleBinding[T];
}
type ResponseContentType$listRbacAuthorizationV1NamespacedRole = keyof Response$listRbacAuthorizationV1NamespacedRole$Status$200;
interface Params$listRbacAuthorizationV1NamespacedRole<U extends ResponseContentType$listRbacAuthorizationV1NamespacedRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listRbacAuthorizationV1NamespacedRole;
}
type RequestContentType$createRbacAuthorizationV1NamespacedRole = keyof RequestBody$createRbacAuthorizationV1NamespacedRole;
type ResponseContentType$createRbacAuthorizationV1NamespacedRole = keyof Response$createRbacAuthorizationV1NamespacedRole$Status$200 | keyof Response$createRbacAuthorizationV1NamespacedRole$Status$201 | keyof Response$createRbacAuthorizationV1NamespacedRole$Status$202;
interface Params$createRbacAuthorizationV1NamespacedRole<U extends ResponseContentType$createRbacAuthorizationV1NamespacedRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createRbacAuthorizationV1NamespacedRole;
    requestBody: RequestBody$createRbacAuthorizationV1NamespacedRole["*/*"];
}
type RequestContentType$deleteRbacAuthorizationV1CollectionNamespacedRole = keyof RequestBody$deleteRbacAuthorizationV1CollectionNamespacedRole;
type ResponseContentType$deleteRbacAuthorizationV1CollectionNamespacedRole = keyof Response$deleteRbacAuthorizationV1CollectionNamespacedRole$Status$200;
interface Params$deleteRbacAuthorizationV1CollectionNamespacedRole<U extends ResponseContentType$deleteRbacAuthorizationV1CollectionNamespacedRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteRbacAuthorizationV1CollectionNamespacedRole;
    requestBody: RequestBody$deleteRbacAuthorizationV1CollectionNamespacedRole["*/*"];
}
type ResponseContentType$readRbacAuthorizationV1NamespacedRole = keyof Response$readRbacAuthorizationV1NamespacedRole$Status$200;
interface Params$readRbacAuthorizationV1NamespacedRole<U extends ResponseContentType$readRbacAuthorizationV1NamespacedRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readRbacAuthorizationV1NamespacedRole;
}
type RequestContentType$replaceRbacAuthorizationV1NamespacedRole = keyof RequestBody$replaceRbacAuthorizationV1NamespacedRole;
type ResponseContentType$replaceRbacAuthorizationV1NamespacedRole = keyof Response$replaceRbacAuthorizationV1NamespacedRole$Status$200 | keyof Response$replaceRbacAuthorizationV1NamespacedRole$Status$201;
interface Params$replaceRbacAuthorizationV1NamespacedRole<U extends ResponseContentType$replaceRbacAuthorizationV1NamespacedRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceRbacAuthorizationV1NamespacedRole;
    requestBody: RequestBody$replaceRbacAuthorizationV1NamespacedRole["*/*"];
}
type RequestContentType$deleteRbacAuthorizationV1NamespacedRole = keyof RequestBody$deleteRbacAuthorizationV1NamespacedRole;
type ResponseContentType$deleteRbacAuthorizationV1NamespacedRole = keyof Response$deleteRbacAuthorizationV1NamespacedRole$Status$200 | keyof Response$deleteRbacAuthorizationV1NamespacedRole$Status$202;
interface Params$deleteRbacAuthorizationV1NamespacedRole<U extends ResponseContentType$deleteRbacAuthorizationV1NamespacedRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteRbacAuthorizationV1NamespacedRole;
    requestBody: RequestBody$deleteRbacAuthorizationV1NamespacedRole["*/*"];
}
type RequestContentType$patchRbacAuthorizationV1NamespacedRole = keyof RequestBody$patchRbacAuthorizationV1NamespacedRole;
type ResponseContentType$patchRbacAuthorizationV1NamespacedRole = keyof Response$patchRbacAuthorizationV1NamespacedRole$Status$200 | keyof Response$patchRbacAuthorizationV1NamespacedRole$Status$201;
interface Params$patchRbacAuthorizationV1NamespacedRole<T extends RequestContentType$patchRbacAuthorizationV1NamespacedRole, U extends ResponseContentType$patchRbacAuthorizationV1NamespacedRole> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchRbacAuthorizationV1NamespacedRole;
    requestBody: RequestBody$patchRbacAuthorizationV1NamespacedRole[T];
}
type ResponseContentType$listRbacAuthorizationV1RoleBindingForAllNamespaces = keyof Response$listRbacAuthorizationV1RoleBindingForAllNamespaces$Status$200;
interface Params$listRbacAuthorizationV1RoleBindingForAllNamespaces<U extends ResponseContentType$listRbacAuthorizationV1RoleBindingForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listRbacAuthorizationV1RoleBindingForAllNamespaces;
}
type ResponseContentType$listRbacAuthorizationV1RoleForAllNamespaces = keyof Response$listRbacAuthorizationV1RoleForAllNamespaces$Status$200;
interface Params$listRbacAuthorizationV1RoleForAllNamespaces<U extends ResponseContentType$listRbacAuthorizationV1RoleForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listRbacAuthorizationV1RoleForAllNamespaces;
}
type ResponseContentType$watchRbacAuthorizationV1ClusterRoleBindingList = keyof Response$watchRbacAuthorizationV1ClusterRoleBindingList$Status$200;
interface Params$watchRbacAuthorizationV1ClusterRoleBindingList<U extends ResponseContentType$watchRbacAuthorizationV1ClusterRoleBindingList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchRbacAuthorizationV1ClusterRoleBindingList;
}
type ResponseContentType$watchRbacAuthorizationV1ClusterRoleBinding = keyof Response$watchRbacAuthorizationV1ClusterRoleBinding$Status$200;
interface Params$watchRbacAuthorizationV1ClusterRoleBinding<U extends ResponseContentType$watchRbacAuthorizationV1ClusterRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchRbacAuthorizationV1ClusterRoleBinding;
}
type ResponseContentType$watchRbacAuthorizationV1ClusterRoleList = keyof Response$watchRbacAuthorizationV1ClusterRoleList$Status$200;
interface Params$watchRbacAuthorizationV1ClusterRoleList<U extends ResponseContentType$watchRbacAuthorizationV1ClusterRoleList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchRbacAuthorizationV1ClusterRoleList;
}
type ResponseContentType$watchRbacAuthorizationV1ClusterRole = keyof Response$watchRbacAuthorizationV1ClusterRole$Status$200;
interface Params$watchRbacAuthorizationV1ClusterRole<U extends ResponseContentType$watchRbacAuthorizationV1ClusterRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchRbacAuthorizationV1ClusterRole;
}
type ResponseContentType$watchRbacAuthorizationV1NamespacedRoleBindingList = keyof Response$watchRbacAuthorizationV1NamespacedRoleBindingList$Status$200;
interface Params$watchRbacAuthorizationV1NamespacedRoleBindingList<U extends ResponseContentType$watchRbacAuthorizationV1NamespacedRoleBindingList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchRbacAuthorizationV1NamespacedRoleBindingList;
}
type ResponseContentType$watchRbacAuthorizationV1NamespacedRoleBinding = keyof Response$watchRbacAuthorizationV1NamespacedRoleBinding$Status$200;
interface Params$watchRbacAuthorizationV1NamespacedRoleBinding<U extends ResponseContentType$watchRbacAuthorizationV1NamespacedRoleBinding> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchRbacAuthorizationV1NamespacedRoleBinding;
}
type ResponseContentType$watchRbacAuthorizationV1NamespacedRoleList = keyof Response$watchRbacAuthorizationV1NamespacedRoleList$Status$200;
interface Params$watchRbacAuthorizationV1NamespacedRoleList<U extends ResponseContentType$watchRbacAuthorizationV1NamespacedRoleList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchRbacAuthorizationV1NamespacedRoleList;
}
type ResponseContentType$watchRbacAuthorizationV1NamespacedRole = keyof Response$watchRbacAuthorizationV1NamespacedRole$Status$200;
interface Params$watchRbacAuthorizationV1NamespacedRole<U extends ResponseContentType$watchRbacAuthorizationV1NamespacedRole> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchRbacAuthorizationV1NamespacedRole;
}
type ResponseContentType$watchRbacAuthorizationV1RoleBindingListForAllNamespaces = keyof Response$watchRbacAuthorizationV1RoleBindingListForAllNamespaces$Status$200;
interface Params$watchRbacAuthorizationV1RoleBindingListForAllNamespaces<U extends ResponseContentType$watchRbacAuthorizationV1RoleBindingListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchRbacAuthorizationV1RoleBindingListForAllNamespaces;
}
type ResponseContentType$watchRbacAuthorizationV1RoleListForAllNamespaces = keyof Response$watchRbacAuthorizationV1RoleListForAllNamespaces$Status$200;
interface Params$watchRbacAuthorizationV1RoleListForAllNamespaces<U extends ResponseContentType$watchRbacAuthorizationV1RoleListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchRbacAuthorizationV1RoleListForAllNamespaces;
}
type ResponseContentType$getResourceAPIGroup = keyof Response$getResourceAPIGroup$Status$200;
interface Params$getResourceAPIGroup<U extends ResponseContentType$getResourceAPIGroup> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getResourceV1alpha2APIResources = keyof Response$getResourceV1alpha2APIResources$Status$200;
interface Params$getResourceV1alpha2APIResources<U extends ResponseContentType$getResourceV1alpha2APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listResourceV1alpha2NamespacedPodSchedulingContext = keyof Response$listResourceV1alpha2NamespacedPodSchedulingContext$Status$200;
interface Params$listResourceV1alpha2NamespacedPodSchedulingContext<U extends ResponseContentType$listResourceV1alpha2NamespacedPodSchedulingContext> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listResourceV1alpha2NamespacedPodSchedulingContext;
}
type RequestContentType$createResourceV1alpha2NamespacedPodSchedulingContext = keyof RequestBody$createResourceV1alpha2NamespacedPodSchedulingContext;
type ResponseContentType$createResourceV1alpha2NamespacedPodSchedulingContext = keyof Response$createResourceV1alpha2NamespacedPodSchedulingContext$Status$200 | keyof Response$createResourceV1alpha2NamespacedPodSchedulingContext$Status$201 | keyof Response$createResourceV1alpha2NamespacedPodSchedulingContext$Status$202;
interface Params$createResourceV1alpha2NamespacedPodSchedulingContext<U extends ResponseContentType$createResourceV1alpha2NamespacedPodSchedulingContext> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createResourceV1alpha2NamespacedPodSchedulingContext;
    requestBody: RequestBody$createResourceV1alpha2NamespacedPodSchedulingContext["*/*"];
}
type RequestContentType$deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext = keyof RequestBody$deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext;
type ResponseContentType$deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext = keyof Response$deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext$Status$200;
interface Params$deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext<U extends ResponseContentType$deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext;
    requestBody: RequestBody$deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext["*/*"];
}
type ResponseContentType$readResourceV1alpha2NamespacedPodSchedulingContext = keyof Response$readResourceV1alpha2NamespacedPodSchedulingContext$Status$200;
interface Params$readResourceV1alpha2NamespacedPodSchedulingContext<U extends ResponseContentType$readResourceV1alpha2NamespacedPodSchedulingContext> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readResourceV1alpha2NamespacedPodSchedulingContext;
}
type RequestContentType$replaceResourceV1alpha2NamespacedPodSchedulingContext = keyof RequestBody$replaceResourceV1alpha2NamespacedPodSchedulingContext;
type ResponseContentType$replaceResourceV1alpha2NamespacedPodSchedulingContext = keyof Response$replaceResourceV1alpha2NamespacedPodSchedulingContext$Status$200 | keyof Response$replaceResourceV1alpha2NamespacedPodSchedulingContext$Status$201;
interface Params$replaceResourceV1alpha2NamespacedPodSchedulingContext<U extends ResponseContentType$replaceResourceV1alpha2NamespacedPodSchedulingContext> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceResourceV1alpha2NamespacedPodSchedulingContext;
    requestBody: RequestBody$replaceResourceV1alpha2NamespacedPodSchedulingContext["*/*"];
}
type RequestContentType$deleteResourceV1alpha2NamespacedPodSchedulingContext = keyof RequestBody$deleteResourceV1alpha2NamespacedPodSchedulingContext;
type ResponseContentType$deleteResourceV1alpha2NamespacedPodSchedulingContext = keyof Response$deleteResourceV1alpha2NamespacedPodSchedulingContext$Status$200 | keyof Response$deleteResourceV1alpha2NamespacedPodSchedulingContext$Status$202;
interface Params$deleteResourceV1alpha2NamespacedPodSchedulingContext<U extends ResponseContentType$deleteResourceV1alpha2NamespacedPodSchedulingContext> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteResourceV1alpha2NamespacedPodSchedulingContext;
    requestBody: RequestBody$deleteResourceV1alpha2NamespacedPodSchedulingContext["*/*"];
}
type RequestContentType$patchResourceV1alpha2NamespacedPodSchedulingContext = keyof RequestBody$patchResourceV1alpha2NamespacedPodSchedulingContext;
type ResponseContentType$patchResourceV1alpha2NamespacedPodSchedulingContext = keyof Response$patchResourceV1alpha2NamespacedPodSchedulingContext$Status$200 | keyof Response$patchResourceV1alpha2NamespacedPodSchedulingContext$Status$201;
interface Params$patchResourceV1alpha2NamespacedPodSchedulingContext<T extends RequestContentType$patchResourceV1alpha2NamespacedPodSchedulingContext, U extends ResponseContentType$patchResourceV1alpha2NamespacedPodSchedulingContext> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchResourceV1alpha2NamespacedPodSchedulingContext;
    requestBody: RequestBody$patchResourceV1alpha2NamespacedPodSchedulingContext[T];
}
type ResponseContentType$readResourceV1alpha2NamespacedPodSchedulingContextStatus = keyof Response$readResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$200;
interface Params$readResourceV1alpha2NamespacedPodSchedulingContextStatus<U extends ResponseContentType$readResourceV1alpha2NamespacedPodSchedulingContextStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readResourceV1alpha2NamespacedPodSchedulingContextStatus;
}
type RequestContentType$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus = keyof RequestBody$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus;
type ResponseContentType$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus = keyof Response$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$200 | keyof Response$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$201;
interface Params$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus<U extends ResponseContentType$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus;
    requestBody: RequestBody$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus["*/*"];
}
type RequestContentType$patchResourceV1alpha2NamespacedPodSchedulingContextStatus = keyof RequestBody$patchResourceV1alpha2NamespacedPodSchedulingContextStatus;
type ResponseContentType$patchResourceV1alpha2NamespacedPodSchedulingContextStatus = keyof Response$patchResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$200 | keyof Response$patchResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$201;
interface Params$patchResourceV1alpha2NamespacedPodSchedulingContextStatus<T extends RequestContentType$patchResourceV1alpha2NamespacedPodSchedulingContextStatus, U extends ResponseContentType$patchResourceV1alpha2NamespacedPodSchedulingContextStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchResourceV1alpha2NamespacedPodSchedulingContextStatus;
    requestBody: RequestBody$patchResourceV1alpha2NamespacedPodSchedulingContextStatus[T];
}
type ResponseContentType$listResourceV1alpha2NamespacedResourceClaim = keyof Response$listResourceV1alpha2NamespacedResourceClaim$Status$200;
interface Params$listResourceV1alpha2NamespacedResourceClaim<U extends ResponseContentType$listResourceV1alpha2NamespacedResourceClaim> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listResourceV1alpha2NamespacedResourceClaim;
}
type RequestContentType$createResourceV1alpha2NamespacedResourceClaim = keyof RequestBody$createResourceV1alpha2NamespacedResourceClaim;
type ResponseContentType$createResourceV1alpha2NamespacedResourceClaim = keyof Response$createResourceV1alpha2NamespacedResourceClaim$Status$200 | keyof Response$createResourceV1alpha2NamespacedResourceClaim$Status$201 | keyof Response$createResourceV1alpha2NamespacedResourceClaim$Status$202;
interface Params$createResourceV1alpha2NamespacedResourceClaim<U extends ResponseContentType$createResourceV1alpha2NamespacedResourceClaim> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createResourceV1alpha2NamespacedResourceClaim;
    requestBody: RequestBody$createResourceV1alpha2NamespacedResourceClaim["*/*"];
}
type RequestContentType$deleteResourceV1alpha2CollectionNamespacedResourceClaim = keyof RequestBody$deleteResourceV1alpha2CollectionNamespacedResourceClaim;
type ResponseContentType$deleteResourceV1alpha2CollectionNamespacedResourceClaim = keyof Response$deleteResourceV1alpha2CollectionNamespacedResourceClaim$Status$200;
interface Params$deleteResourceV1alpha2CollectionNamespacedResourceClaim<U extends ResponseContentType$deleteResourceV1alpha2CollectionNamespacedResourceClaim> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteResourceV1alpha2CollectionNamespacedResourceClaim;
    requestBody: RequestBody$deleteResourceV1alpha2CollectionNamespacedResourceClaim["*/*"];
}
type ResponseContentType$readResourceV1alpha2NamespacedResourceClaim = keyof Response$readResourceV1alpha2NamespacedResourceClaim$Status$200;
interface Params$readResourceV1alpha2NamespacedResourceClaim<U extends ResponseContentType$readResourceV1alpha2NamespacedResourceClaim> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readResourceV1alpha2NamespacedResourceClaim;
}
type RequestContentType$replaceResourceV1alpha2NamespacedResourceClaim = keyof RequestBody$replaceResourceV1alpha2NamespacedResourceClaim;
type ResponseContentType$replaceResourceV1alpha2NamespacedResourceClaim = keyof Response$replaceResourceV1alpha2NamespacedResourceClaim$Status$200 | keyof Response$replaceResourceV1alpha2NamespacedResourceClaim$Status$201;
interface Params$replaceResourceV1alpha2NamespacedResourceClaim<U extends ResponseContentType$replaceResourceV1alpha2NamespacedResourceClaim> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceResourceV1alpha2NamespacedResourceClaim;
    requestBody: RequestBody$replaceResourceV1alpha2NamespacedResourceClaim["*/*"];
}
type RequestContentType$deleteResourceV1alpha2NamespacedResourceClaim = keyof RequestBody$deleteResourceV1alpha2NamespacedResourceClaim;
type ResponseContentType$deleteResourceV1alpha2NamespacedResourceClaim = keyof Response$deleteResourceV1alpha2NamespacedResourceClaim$Status$200 | keyof Response$deleteResourceV1alpha2NamespacedResourceClaim$Status$202;
interface Params$deleteResourceV1alpha2NamespacedResourceClaim<U extends ResponseContentType$deleteResourceV1alpha2NamespacedResourceClaim> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteResourceV1alpha2NamespacedResourceClaim;
    requestBody: RequestBody$deleteResourceV1alpha2NamespacedResourceClaim["*/*"];
}
type RequestContentType$patchResourceV1alpha2NamespacedResourceClaim = keyof RequestBody$patchResourceV1alpha2NamespacedResourceClaim;
type ResponseContentType$patchResourceV1alpha2NamespacedResourceClaim = keyof Response$patchResourceV1alpha2NamespacedResourceClaim$Status$200 | keyof Response$patchResourceV1alpha2NamespacedResourceClaim$Status$201;
interface Params$patchResourceV1alpha2NamespacedResourceClaim<T extends RequestContentType$patchResourceV1alpha2NamespacedResourceClaim, U extends ResponseContentType$patchResourceV1alpha2NamespacedResourceClaim> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchResourceV1alpha2NamespacedResourceClaim;
    requestBody: RequestBody$patchResourceV1alpha2NamespacedResourceClaim[T];
}
type ResponseContentType$readResourceV1alpha2NamespacedResourceClaimStatus = keyof Response$readResourceV1alpha2NamespacedResourceClaimStatus$Status$200;
interface Params$readResourceV1alpha2NamespacedResourceClaimStatus<U extends ResponseContentType$readResourceV1alpha2NamespacedResourceClaimStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readResourceV1alpha2NamespacedResourceClaimStatus;
}
type RequestContentType$replaceResourceV1alpha2NamespacedResourceClaimStatus = keyof RequestBody$replaceResourceV1alpha2NamespacedResourceClaimStatus;
type ResponseContentType$replaceResourceV1alpha2NamespacedResourceClaimStatus = keyof Response$replaceResourceV1alpha2NamespacedResourceClaimStatus$Status$200 | keyof Response$replaceResourceV1alpha2NamespacedResourceClaimStatus$Status$201;
interface Params$replaceResourceV1alpha2NamespacedResourceClaimStatus<U extends ResponseContentType$replaceResourceV1alpha2NamespacedResourceClaimStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceResourceV1alpha2NamespacedResourceClaimStatus;
    requestBody: RequestBody$replaceResourceV1alpha2NamespacedResourceClaimStatus["*/*"];
}
type RequestContentType$patchResourceV1alpha2NamespacedResourceClaimStatus = keyof RequestBody$patchResourceV1alpha2NamespacedResourceClaimStatus;
type ResponseContentType$patchResourceV1alpha2NamespacedResourceClaimStatus = keyof Response$patchResourceV1alpha2NamespacedResourceClaimStatus$Status$200 | keyof Response$patchResourceV1alpha2NamespacedResourceClaimStatus$Status$201;
interface Params$patchResourceV1alpha2NamespacedResourceClaimStatus<T extends RequestContentType$patchResourceV1alpha2NamespacedResourceClaimStatus, U extends ResponseContentType$patchResourceV1alpha2NamespacedResourceClaimStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchResourceV1alpha2NamespacedResourceClaimStatus;
    requestBody: RequestBody$patchResourceV1alpha2NamespacedResourceClaimStatus[T];
}
type ResponseContentType$listResourceV1alpha2NamespacedResourceClaimTemplate = keyof Response$listResourceV1alpha2NamespacedResourceClaimTemplate$Status$200;
interface Params$listResourceV1alpha2NamespacedResourceClaimTemplate<U extends ResponseContentType$listResourceV1alpha2NamespacedResourceClaimTemplate> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listResourceV1alpha2NamespacedResourceClaimTemplate;
}
type RequestContentType$createResourceV1alpha2NamespacedResourceClaimTemplate = keyof RequestBody$createResourceV1alpha2NamespacedResourceClaimTemplate;
type ResponseContentType$createResourceV1alpha2NamespacedResourceClaimTemplate = keyof Response$createResourceV1alpha2NamespacedResourceClaimTemplate$Status$200 | keyof Response$createResourceV1alpha2NamespacedResourceClaimTemplate$Status$201 | keyof Response$createResourceV1alpha2NamespacedResourceClaimTemplate$Status$202;
interface Params$createResourceV1alpha2NamespacedResourceClaimTemplate<U extends ResponseContentType$createResourceV1alpha2NamespacedResourceClaimTemplate> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createResourceV1alpha2NamespacedResourceClaimTemplate;
    requestBody: RequestBody$createResourceV1alpha2NamespacedResourceClaimTemplate["*/*"];
}
type RequestContentType$deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate = keyof RequestBody$deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate;
type ResponseContentType$deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate = keyof Response$deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate$Status$200;
interface Params$deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate<U extends ResponseContentType$deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate;
    requestBody: RequestBody$deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate["*/*"];
}
type ResponseContentType$readResourceV1alpha2NamespacedResourceClaimTemplate = keyof Response$readResourceV1alpha2NamespacedResourceClaimTemplate$Status$200;
interface Params$readResourceV1alpha2NamespacedResourceClaimTemplate<U extends ResponseContentType$readResourceV1alpha2NamespacedResourceClaimTemplate> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readResourceV1alpha2NamespacedResourceClaimTemplate;
}
type RequestContentType$replaceResourceV1alpha2NamespacedResourceClaimTemplate = keyof RequestBody$replaceResourceV1alpha2NamespacedResourceClaimTemplate;
type ResponseContentType$replaceResourceV1alpha2NamespacedResourceClaimTemplate = keyof Response$replaceResourceV1alpha2NamespacedResourceClaimTemplate$Status$200 | keyof Response$replaceResourceV1alpha2NamespacedResourceClaimTemplate$Status$201;
interface Params$replaceResourceV1alpha2NamespacedResourceClaimTemplate<U extends ResponseContentType$replaceResourceV1alpha2NamespacedResourceClaimTemplate> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceResourceV1alpha2NamespacedResourceClaimTemplate;
    requestBody: RequestBody$replaceResourceV1alpha2NamespacedResourceClaimTemplate["*/*"];
}
type RequestContentType$deleteResourceV1alpha2NamespacedResourceClaimTemplate = keyof RequestBody$deleteResourceV1alpha2NamespacedResourceClaimTemplate;
type ResponseContentType$deleteResourceV1alpha2NamespacedResourceClaimTemplate = keyof Response$deleteResourceV1alpha2NamespacedResourceClaimTemplate$Status$200 | keyof Response$deleteResourceV1alpha2NamespacedResourceClaimTemplate$Status$202;
interface Params$deleteResourceV1alpha2NamespacedResourceClaimTemplate<U extends ResponseContentType$deleteResourceV1alpha2NamespacedResourceClaimTemplate> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteResourceV1alpha2NamespacedResourceClaimTemplate;
    requestBody: RequestBody$deleteResourceV1alpha2NamespacedResourceClaimTemplate["*/*"];
}
type RequestContentType$patchResourceV1alpha2NamespacedResourceClaimTemplate = keyof RequestBody$patchResourceV1alpha2NamespacedResourceClaimTemplate;
type ResponseContentType$patchResourceV1alpha2NamespacedResourceClaimTemplate = keyof Response$patchResourceV1alpha2NamespacedResourceClaimTemplate$Status$200 | keyof Response$patchResourceV1alpha2NamespacedResourceClaimTemplate$Status$201;
interface Params$patchResourceV1alpha2NamespacedResourceClaimTemplate<T extends RequestContentType$patchResourceV1alpha2NamespacedResourceClaimTemplate, U extends ResponseContentType$patchResourceV1alpha2NamespacedResourceClaimTemplate> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchResourceV1alpha2NamespacedResourceClaimTemplate;
    requestBody: RequestBody$patchResourceV1alpha2NamespacedResourceClaimTemplate[T];
}
type ResponseContentType$listResourceV1alpha2PodSchedulingContextForAllNamespaces = keyof Response$listResourceV1alpha2PodSchedulingContextForAllNamespaces$Status$200;
interface Params$listResourceV1alpha2PodSchedulingContextForAllNamespaces<U extends ResponseContentType$listResourceV1alpha2PodSchedulingContextForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listResourceV1alpha2PodSchedulingContextForAllNamespaces;
}
type ResponseContentType$listResourceV1alpha2ResourceClaimForAllNamespaces = keyof Response$listResourceV1alpha2ResourceClaimForAllNamespaces$Status$200;
interface Params$listResourceV1alpha2ResourceClaimForAllNamespaces<U extends ResponseContentType$listResourceV1alpha2ResourceClaimForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listResourceV1alpha2ResourceClaimForAllNamespaces;
}
type ResponseContentType$listResourceV1alpha2ResourceClaimTemplateForAllNamespaces = keyof Response$listResourceV1alpha2ResourceClaimTemplateForAllNamespaces$Status$200;
interface Params$listResourceV1alpha2ResourceClaimTemplateForAllNamespaces<U extends ResponseContentType$listResourceV1alpha2ResourceClaimTemplateForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listResourceV1alpha2ResourceClaimTemplateForAllNamespaces;
}
type ResponseContentType$listResourceV1alpha2ResourceClass = keyof Response$listResourceV1alpha2ResourceClass$Status$200;
interface Params$listResourceV1alpha2ResourceClass<U extends ResponseContentType$listResourceV1alpha2ResourceClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listResourceV1alpha2ResourceClass;
}
type RequestContentType$createResourceV1alpha2ResourceClass = keyof RequestBody$createResourceV1alpha2ResourceClass;
type ResponseContentType$createResourceV1alpha2ResourceClass = keyof Response$createResourceV1alpha2ResourceClass$Status$200 | keyof Response$createResourceV1alpha2ResourceClass$Status$201 | keyof Response$createResourceV1alpha2ResourceClass$Status$202;
interface Params$createResourceV1alpha2ResourceClass<U extends ResponseContentType$createResourceV1alpha2ResourceClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createResourceV1alpha2ResourceClass;
    requestBody: RequestBody$createResourceV1alpha2ResourceClass["*/*"];
}
type RequestContentType$deleteResourceV1alpha2CollectionResourceClass = keyof RequestBody$deleteResourceV1alpha2CollectionResourceClass;
type ResponseContentType$deleteResourceV1alpha2CollectionResourceClass = keyof Response$deleteResourceV1alpha2CollectionResourceClass$Status$200;
interface Params$deleteResourceV1alpha2CollectionResourceClass<U extends ResponseContentType$deleteResourceV1alpha2CollectionResourceClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteResourceV1alpha2CollectionResourceClass;
    requestBody: RequestBody$deleteResourceV1alpha2CollectionResourceClass["*/*"];
}
type ResponseContentType$readResourceV1alpha2ResourceClass = keyof Response$readResourceV1alpha2ResourceClass$Status$200;
interface Params$readResourceV1alpha2ResourceClass<U extends ResponseContentType$readResourceV1alpha2ResourceClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readResourceV1alpha2ResourceClass;
}
type RequestContentType$replaceResourceV1alpha2ResourceClass = keyof RequestBody$replaceResourceV1alpha2ResourceClass;
type ResponseContentType$replaceResourceV1alpha2ResourceClass = keyof Response$replaceResourceV1alpha2ResourceClass$Status$200 | keyof Response$replaceResourceV1alpha2ResourceClass$Status$201;
interface Params$replaceResourceV1alpha2ResourceClass<U extends ResponseContentType$replaceResourceV1alpha2ResourceClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceResourceV1alpha2ResourceClass;
    requestBody: RequestBody$replaceResourceV1alpha2ResourceClass["*/*"];
}
type RequestContentType$deleteResourceV1alpha2ResourceClass = keyof RequestBody$deleteResourceV1alpha2ResourceClass;
type ResponseContentType$deleteResourceV1alpha2ResourceClass = keyof Response$deleteResourceV1alpha2ResourceClass$Status$200 | keyof Response$deleteResourceV1alpha2ResourceClass$Status$202;
interface Params$deleteResourceV1alpha2ResourceClass<U extends ResponseContentType$deleteResourceV1alpha2ResourceClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteResourceV1alpha2ResourceClass;
    requestBody: RequestBody$deleteResourceV1alpha2ResourceClass["*/*"];
}
type RequestContentType$patchResourceV1alpha2ResourceClass = keyof RequestBody$patchResourceV1alpha2ResourceClass;
type ResponseContentType$patchResourceV1alpha2ResourceClass = keyof Response$patchResourceV1alpha2ResourceClass$Status$200 | keyof Response$patchResourceV1alpha2ResourceClass$Status$201;
interface Params$patchResourceV1alpha2ResourceClass<T extends RequestContentType$patchResourceV1alpha2ResourceClass, U extends ResponseContentType$patchResourceV1alpha2ResourceClass> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchResourceV1alpha2ResourceClass;
    requestBody: RequestBody$patchResourceV1alpha2ResourceClass[T];
}
type ResponseContentType$watchResourceV1alpha2NamespacedPodSchedulingContextList = keyof Response$watchResourceV1alpha2NamespacedPodSchedulingContextList$Status$200;
interface Params$watchResourceV1alpha2NamespacedPodSchedulingContextList<U extends ResponseContentType$watchResourceV1alpha2NamespacedPodSchedulingContextList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchResourceV1alpha2NamespacedPodSchedulingContextList;
}
type ResponseContentType$watchResourceV1alpha2NamespacedPodSchedulingContext = keyof Response$watchResourceV1alpha2NamespacedPodSchedulingContext$Status$200;
interface Params$watchResourceV1alpha2NamespacedPodSchedulingContext<U extends ResponseContentType$watchResourceV1alpha2NamespacedPodSchedulingContext> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchResourceV1alpha2NamespacedPodSchedulingContext;
}
type ResponseContentType$watchResourceV1alpha2NamespacedResourceClaimList = keyof Response$watchResourceV1alpha2NamespacedResourceClaimList$Status$200;
interface Params$watchResourceV1alpha2NamespacedResourceClaimList<U extends ResponseContentType$watchResourceV1alpha2NamespacedResourceClaimList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchResourceV1alpha2NamespacedResourceClaimList;
}
type ResponseContentType$watchResourceV1alpha2NamespacedResourceClaim = keyof Response$watchResourceV1alpha2NamespacedResourceClaim$Status$200;
interface Params$watchResourceV1alpha2NamespacedResourceClaim<U extends ResponseContentType$watchResourceV1alpha2NamespacedResourceClaim> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchResourceV1alpha2NamespacedResourceClaim;
}
type ResponseContentType$watchResourceV1alpha2NamespacedResourceClaimTemplateList = keyof Response$watchResourceV1alpha2NamespacedResourceClaimTemplateList$Status$200;
interface Params$watchResourceV1alpha2NamespacedResourceClaimTemplateList<U extends ResponseContentType$watchResourceV1alpha2NamespacedResourceClaimTemplateList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchResourceV1alpha2NamespacedResourceClaimTemplateList;
}
type ResponseContentType$watchResourceV1alpha2NamespacedResourceClaimTemplate = keyof Response$watchResourceV1alpha2NamespacedResourceClaimTemplate$Status$200;
interface Params$watchResourceV1alpha2NamespacedResourceClaimTemplate<U extends ResponseContentType$watchResourceV1alpha2NamespacedResourceClaimTemplate> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchResourceV1alpha2NamespacedResourceClaimTemplate;
}
type ResponseContentType$watchResourceV1alpha2PodSchedulingContextListForAllNamespaces = keyof Response$watchResourceV1alpha2PodSchedulingContextListForAllNamespaces$Status$200;
interface Params$watchResourceV1alpha2PodSchedulingContextListForAllNamespaces<U extends ResponseContentType$watchResourceV1alpha2PodSchedulingContextListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchResourceV1alpha2PodSchedulingContextListForAllNamespaces;
}
type ResponseContentType$watchResourceV1alpha2ResourceClaimListForAllNamespaces = keyof Response$watchResourceV1alpha2ResourceClaimListForAllNamespaces$Status$200;
interface Params$watchResourceV1alpha2ResourceClaimListForAllNamespaces<U extends ResponseContentType$watchResourceV1alpha2ResourceClaimListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchResourceV1alpha2ResourceClaimListForAllNamespaces;
}
type ResponseContentType$watchResourceV1alpha2ResourceClaimTemplateListForAllNamespaces = keyof Response$watchResourceV1alpha2ResourceClaimTemplateListForAllNamespaces$Status$200;
interface Params$watchResourceV1alpha2ResourceClaimTemplateListForAllNamespaces<U extends ResponseContentType$watchResourceV1alpha2ResourceClaimTemplateListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchResourceV1alpha2ResourceClaimTemplateListForAllNamespaces;
}
type ResponseContentType$watchResourceV1alpha2ResourceClassList = keyof Response$watchResourceV1alpha2ResourceClassList$Status$200;
interface Params$watchResourceV1alpha2ResourceClassList<U extends ResponseContentType$watchResourceV1alpha2ResourceClassList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchResourceV1alpha2ResourceClassList;
}
type ResponseContentType$watchResourceV1alpha2ResourceClass = keyof Response$watchResourceV1alpha2ResourceClass$Status$200;
interface Params$watchResourceV1alpha2ResourceClass<U extends ResponseContentType$watchResourceV1alpha2ResourceClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchResourceV1alpha2ResourceClass;
}
type ResponseContentType$getSchedulingAPIGroup = keyof Response$getSchedulingAPIGroup$Status$200;
interface Params$getSchedulingAPIGroup<U extends ResponseContentType$getSchedulingAPIGroup> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getSchedulingV1APIResources = keyof Response$getSchedulingV1APIResources$Status$200;
interface Params$getSchedulingV1APIResources<U extends ResponseContentType$getSchedulingV1APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listSchedulingV1PriorityClass = keyof Response$listSchedulingV1PriorityClass$Status$200;
interface Params$listSchedulingV1PriorityClass<U extends ResponseContentType$listSchedulingV1PriorityClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listSchedulingV1PriorityClass;
}
type RequestContentType$createSchedulingV1PriorityClass = keyof RequestBody$createSchedulingV1PriorityClass;
type ResponseContentType$createSchedulingV1PriorityClass = keyof Response$createSchedulingV1PriorityClass$Status$200 | keyof Response$createSchedulingV1PriorityClass$Status$201 | keyof Response$createSchedulingV1PriorityClass$Status$202;
interface Params$createSchedulingV1PriorityClass<U extends ResponseContentType$createSchedulingV1PriorityClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createSchedulingV1PriorityClass;
    requestBody: RequestBody$createSchedulingV1PriorityClass["*/*"];
}
type RequestContentType$deleteSchedulingV1CollectionPriorityClass = keyof RequestBody$deleteSchedulingV1CollectionPriorityClass;
type ResponseContentType$deleteSchedulingV1CollectionPriorityClass = keyof Response$deleteSchedulingV1CollectionPriorityClass$Status$200;
interface Params$deleteSchedulingV1CollectionPriorityClass<U extends ResponseContentType$deleteSchedulingV1CollectionPriorityClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteSchedulingV1CollectionPriorityClass;
    requestBody: RequestBody$deleteSchedulingV1CollectionPriorityClass["*/*"];
}
type ResponseContentType$readSchedulingV1PriorityClass = keyof Response$readSchedulingV1PriorityClass$Status$200;
interface Params$readSchedulingV1PriorityClass<U extends ResponseContentType$readSchedulingV1PriorityClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readSchedulingV1PriorityClass;
}
type RequestContentType$replaceSchedulingV1PriorityClass = keyof RequestBody$replaceSchedulingV1PriorityClass;
type ResponseContentType$replaceSchedulingV1PriorityClass = keyof Response$replaceSchedulingV1PriorityClass$Status$200 | keyof Response$replaceSchedulingV1PriorityClass$Status$201;
interface Params$replaceSchedulingV1PriorityClass<U extends ResponseContentType$replaceSchedulingV1PriorityClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceSchedulingV1PriorityClass;
    requestBody: RequestBody$replaceSchedulingV1PriorityClass["*/*"];
}
type RequestContentType$deleteSchedulingV1PriorityClass = keyof RequestBody$deleteSchedulingV1PriorityClass;
type ResponseContentType$deleteSchedulingV1PriorityClass = keyof Response$deleteSchedulingV1PriorityClass$Status$200 | keyof Response$deleteSchedulingV1PriorityClass$Status$202;
interface Params$deleteSchedulingV1PriorityClass<U extends ResponseContentType$deleteSchedulingV1PriorityClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteSchedulingV1PriorityClass;
    requestBody: RequestBody$deleteSchedulingV1PriorityClass["*/*"];
}
type RequestContentType$patchSchedulingV1PriorityClass = keyof RequestBody$patchSchedulingV1PriorityClass;
type ResponseContentType$patchSchedulingV1PriorityClass = keyof Response$patchSchedulingV1PriorityClass$Status$200 | keyof Response$patchSchedulingV1PriorityClass$Status$201;
interface Params$patchSchedulingV1PriorityClass<T extends RequestContentType$patchSchedulingV1PriorityClass, U extends ResponseContentType$patchSchedulingV1PriorityClass> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchSchedulingV1PriorityClass;
    requestBody: RequestBody$patchSchedulingV1PriorityClass[T];
}
type ResponseContentType$watchSchedulingV1PriorityClassList = keyof Response$watchSchedulingV1PriorityClassList$Status$200;
interface Params$watchSchedulingV1PriorityClassList<U extends ResponseContentType$watchSchedulingV1PriorityClassList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchSchedulingV1PriorityClassList;
}
type ResponseContentType$watchSchedulingV1PriorityClass = keyof Response$watchSchedulingV1PriorityClass$Status$200;
interface Params$watchSchedulingV1PriorityClass<U extends ResponseContentType$watchSchedulingV1PriorityClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchSchedulingV1PriorityClass;
}
type ResponseContentType$getStorageAPIGroup = keyof Response$getStorageAPIGroup$Status$200;
interface Params$getStorageAPIGroup<U extends ResponseContentType$getStorageAPIGroup> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$getStorageV1APIResources = keyof Response$getStorageV1APIResources$Status$200;
interface Params$getStorageV1APIResources<U extends ResponseContentType$getStorageV1APIResources> {
    headers: {
        Accept: U;
    };
}
type ResponseContentType$listStorageV1CSIDriver = keyof Response$listStorageV1CSIDriver$Status$200;
interface Params$listStorageV1CSIDriver<U extends ResponseContentType$listStorageV1CSIDriver> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listStorageV1CSIDriver;
}
type RequestContentType$createStorageV1CSIDriver = keyof RequestBody$createStorageV1CSIDriver;
type ResponseContentType$createStorageV1CSIDriver = keyof Response$createStorageV1CSIDriver$Status$200 | keyof Response$createStorageV1CSIDriver$Status$201 | keyof Response$createStorageV1CSIDriver$Status$202;
interface Params$createStorageV1CSIDriver<U extends ResponseContentType$createStorageV1CSIDriver> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createStorageV1CSIDriver;
    requestBody: RequestBody$createStorageV1CSIDriver["*/*"];
}
type RequestContentType$deleteStorageV1CollectionCSIDriver = keyof RequestBody$deleteStorageV1CollectionCSIDriver;
type ResponseContentType$deleteStorageV1CollectionCSIDriver = keyof Response$deleteStorageV1CollectionCSIDriver$Status$200;
interface Params$deleteStorageV1CollectionCSIDriver<U extends ResponseContentType$deleteStorageV1CollectionCSIDriver> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteStorageV1CollectionCSIDriver;
    requestBody: RequestBody$deleteStorageV1CollectionCSIDriver["*/*"];
}
type ResponseContentType$readStorageV1CSIDriver = keyof Response$readStorageV1CSIDriver$Status$200;
interface Params$readStorageV1CSIDriver<U extends ResponseContentType$readStorageV1CSIDriver> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readStorageV1CSIDriver;
}
type RequestContentType$replaceStorageV1CSIDriver = keyof RequestBody$replaceStorageV1CSIDriver;
type ResponseContentType$replaceStorageV1CSIDriver = keyof Response$replaceStorageV1CSIDriver$Status$200 | keyof Response$replaceStorageV1CSIDriver$Status$201;
interface Params$replaceStorageV1CSIDriver<U extends ResponseContentType$replaceStorageV1CSIDriver> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceStorageV1CSIDriver;
    requestBody: RequestBody$replaceStorageV1CSIDriver["*/*"];
}
type RequestContentType$deleteStorageV1CSIDriver = keyof RequestBody$deleteStorageV1CSIDriver;
type ResponseContentType$deleteStorageV1CSIDriver = keyof Response$deleteStorageV1CSIDriver$Status$200 | keyof Response$deleteStorageV1CSIDriver$Status$202;
interface Params$deleteStorageV1CSIDriver<U extends ResponseContentType$deleteStorageV1CSIDriver> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteStorageV1CSIDriver;
    requestBody: RequestBody$deleteStorageV1CSIDriver["*/*"];
}
type RequestContentType$patchStorageV1CSIDriver = keyof RequestBody$patchStorageV1CSIDriver;
type ResponseContentType$patchStorageV1CSIDriver = keyof Response$patchStorageV1CSIDriver$Status$200 | keyof Response$patchStorageV1CSIDriver$Status$201;
interface Params$patchStorageV1CSIDriver<T extends RequestContentType$patchStorageV1CSIDriver, U extends ResponseContentType$patchStorageV1CSIDriver> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchStorageV1CSIDriver;
    requestBody: RequestBody$patchStorageV1CSIDriver[T];
}
type ResponseContentType$listStorageV1CSINode = keyof Response$listStorageV1CSINode$Status$200;
interface Params$listStorageV1CSINode<U extends ResponseContentType$listStorageV1CSINode> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listStorageV1CSINode;
}
type RequestContentType$createStorageV1CSINode = keyof RequestBody$createStorageV1CSINode;
type ResponseContentType$createStorageV1CSINode = keyof Response$createStorageV1CSINode$Status$200 | keyof Response$createStorageV1CSINode$Status$201 | keyof Response$createStorageV1CSINode$Status$202;
interface Params$createStorageV1CSINode<U extends ResponseContentType$createStorageV1CSINode> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createStorageV1CSINode;
    requestBody: RequestBody$createStorageV1CSINode["*/*"];
}
type RequestContentType$deleteStorageV1CollectionCSINode = keyof RequestBody$deleteStorageV1CollectionCSINode;
type ResponseContentType$deleteStorageV1CollectionCSINode = keyof Response$deleteStorageV1CollectionCSINode$Status$200;
interface Params$deleteStorageV1CollectionCSINode<U extends ResponseContentType$deleteStorageV1CollectionCSINode> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteStorageV1CollectionCSINode;
    requestBody: RequestBody$deleteStorageV1CollectionCSINode["*/*"];
}
type ResponseContentType$readStorageV1CSINode = keyof Response$readStorageV1CSINode$Status$200;
interface Params$readStorageV1CSINode<U extends ResponseContentType$readStorageV1CSINode> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readStorageV1CSINode;
}
type RequestContentType$replaceStorageV1CSINode = keyof RequestBody$replaceStorageV1CSINode;
type ResponseContentType$replaceStorageV1CSINode = keyof Response$replaceStorageV1CSINode$Status$200 | keyof Response$replaceStorageV1CSINode$Status$201;
interface Params$replaceStorageV1CSINode<U extends ResponseContentType$replaceStorageV1CSINode> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceStorageV1CSINode;
    requestBody: RequestBody$replaceStorageV1CSINode["*/*"];
}
type RequestContentType$deleteStorageV1CSINode = keyof RequestBody$deleteStorageV1CSINode;
type ResponseContentType$deleteStorageV1CSINode = keyof Response$deleteStorageV1CSINode$Status$200 | keyof Response$deleteStorageV1CSINode$Status$202;
interface Params$deleteStorageV1CSINode<U extends ResponseContentType$deleteStorageV1CSINode> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteStorageV1CSINode;
    requestBody: RequestBody$deleteStorageV1CSINode["*/*"];
}
type RequestContentType$patchStorageV1CSINode = keyof RequestBody$patchStorageV1CSINode;
type ResponseContentType$patchStorageV1CSINode = keyof Response$patchStorageV1CSINode$Status$200 | keyof Response$patchStorageV1CSINode$Status$201;
interface Params$patchStorageV1CSINode<T extends RequestContentType$patchStorageV1CSINode, U extends ResponseContentType$patchStorageV1CSINode> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchStorageV1CSINode;
    requestBody: RequestBody$patchStorageV1CSINode[T];
}
type ResponseContentType$listStorageV1CSIStorageCapacityForAllNamespaces = keyof Response$listStorageV1CSIStorageCapacityForAllNamespaces$Status$200;
interface Params$listStorageV1CSIStorageCapacityForAllNamespaces<U extends ResponseContentType$listStorageV1CSIStorageCapacityForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listStorageV1CSIStorageCapacityForAllNamespaces;
}
type ResponseContentType$listStorageV1NamespacedCSIStorageCapacity = keyof Response$listStorageV1NamespacedCSIStorageCapacity$Status$200;
interface Params$listStorageV1NamespacedCSIStorageCapacity<U extends ResponseContentType$listStorageV1NamespacedCSIStorageCapacity> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listStorageV1NamespacedCSIStorageCapacity;
}
type RequestContentType$createStorageV1NamespacedCSIStorageCapacity = keyof RequestBody$createStorageV1NamespacedCSIStorageCapacity;
type ResponseContentType$createStorageV1NamespacedCSIStorageCapacity = keyof Response$createStorageV1NamespacedCSIStorageCapacity$Status$200 | keyof Response$createStorageV1NamespacedCSIStorageCapacity$Status$201 | keyof Response$createStorageV1NamespacedCSIStorageCapacity$Status$202;
interface Params$createStorageV1NamespacedCSIStorageCapacity<U extends ResponseContentType$createStorageV1NamespacedCSIStorageCapacity> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createStorageV1NamespacedCSIStorageCapacity;
    requestBody: RequestBody$createStorageV1NamespacedCSIStorageCapacity["*/*"];
}
type RequestContentType$deleteStorageV1CollectionNamespacedCSIStorageCapacity = keyof RequestBody$deleteStorageV1CollectionNamespacedCSIStorageCapacity;
type ResponseContentType$deleteStorageV1CollectionNamespacedCSIStorageCapacity = keyof Response$deleteStorageV1CollectionNamespacedCSIStorageCapacity$Status$200;
interface Params$deleteStorageV1CollectionNamespacedCSIStorageCapacity<U extends ResponseContentType$deleteStorageV1CollectionNamespacedCSIStorageCapacity> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteStorageV1CollectionNamespacedCSIStorageCapacity;
    requestBody: RequestBody$deleteStorageV1CollectionNamespacedCSIStorageCapacity["*/*"];
}
type ResponseContentType$readStorageV1NamespacedCSIStorageCapacity = keyof Response$readStorageV1NamespacedCSIStorageCapacity$Status$200;
interface Params$readStorageV1NamespacedCSIStorageCapacity<U extends ResponseContentType$readStorageV1NamespacedCSIStorageCapacity> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readStorageV1NamespacedCSIStorageCapacity;
}
type RequestContentType$replaceStorageV1NamespacedCSIStorageCapacity = keyof RequestBody$replaceStorageV1NamespacedCSIStorageCapacity;
type ResponseContentType$replaceStorageV1NamespacedCSIStorageCapacity = keyof Response$replaceStorageV1NamespacedCSIStorageCapacity$Status$200 | keyof Response$replaceStorageV1NamespacedCSIStorageCapacity$Status$201;
interface Params$replaceStorageV1NamespacedCSIStorageCapacity<U extends ResponseContentType$replaceStorageV1NamespacedCSIStorageCapacity> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceStorageV1NamespacedCSIStorageCapacity;
    requestBody: RequestBody$replaceStorageV1NamespacedCSIStorageCapacity["*/*"];
}
type RequestContentType$deleteStorageV1NamespacedCSIStorageCapacity = keyof RequestBody$deleteStorageV1NamespacedCSIStorageCapacity;
type ResponseContentType$deleteStorageV1NamespacedCSIStorageCapacity = keyof Response$deleteStorageV1NamespacedCSIStorageCapacity$Status$200 | keyof Response$deleteStorageV1NamespacedCSIStorageCapacity$Status$202;
interface Params$deleteStorageV1NamespacedCSIStorageCapacity<U extends ResponseContentType$deleteStorageV1NamespacedCSIStorageCapacity> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteStorageV1NamespacedCSIStorageCapacity;
    requestBody: RequestBody$deleteStorageV1NamespacedCSIStorageCapacity["*/*"];
}
type RequestContentType$patchStorageV1NamespacedCSIStorageCapacity = keyof RequestBody$patchStorageV1NamespacedCSIStorageCapacity;
type ResponseContentType$patchStorageV1NamespacedCSIStorageCapacity = keyof Response$patchStorageV1NamespacedCSIStorageCapacity$Status$200 | keyof Response$patchStorageV1NamespacedCSIStorageCapacity$Status$201;
interface Params$patchStorageV1NamespacedCSIStorageCapacity<T extends RequestContentType$patchStorageV1NamespacedCSIStorageCapacity, U extends ResponseContentType$patchStorageV1NamespacedCSIStorageCapacity> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchStorageV1NamespacedCSIStorageCapacity;
    requestBody: RequestBody$patchStorageV1NamespacedCSIStorageCapacity[T];
}
type ResponseContentType$listStorageV1StorageClass = keyof Response$listStorageV1StorageClass$Status$200;
interface Params$listStorageV1StorageClass<U extends ResponseContentType$listStorageV1StorageClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listStorageV1StorageClass;
}
type RequestContentType$createStorageV1StorageClass = keyof RequestBody$createStorageV1StorageClass;
type ResponseContentType$createStorageV1StorageClass = keyof Response$createStorageV1StorageClass$Status$200 | keyof Response$createStorageV1StorageClass$Status$201 | keyof Response$createStorageV1StorageClass$Status$202;
interface Params$createStorageV1StorageClass<U extends ResponseContentType$createStorageV1StorageClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createStorageV1StorageClass;
    requestBody: RequestBody$createStorageV1StorageClass["*/*"];
}
type RequestContentType$deleteStorageV1CollectionStorageClass = keyof RequestBody$deleteStorageV1CollectionStorageClass;
type ResponseContentType$deleteStorageV1CollectionStorageClass = keyof Response$deleteStorageV1CollectionStorageClass$Status$200;
interface Params$deleteStorageV1CollectionStorageClass<U extends ResponseContentType$deleteStorageV1CollectionStorageClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteStorageV1CollectionStorageClass;
    requestBody: RequestBody$deleteStorageV1CollectionStorageClass["*/*"];
}
type ResponseContentType$readStorageV1StorageClass = keyof Response$readStorageV1StorageClass$Status$200;
interface Params$readStorageV1StorageClass<U extends ResponseContentType$readStorageV1StorageClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readStorageV1StorageClass;
}
type RequestContentType$replaceStorageV1StorageClass = keyof RequestBody$replaceStorageV1StorageClass;
type ResponseContentType$replaceStorageV1StorageClass = keyof Response$replaceStorageV1StorageClass$Status$200 | keyof Response$replaceStorageV1StorageClass$Status$201;
interface Params$replaceStorageV1StorageClass<U extends ResponseContentType$replaceStorageV1StorageClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceStorageV1StorageClass;
    requestBody: RequestBody$replaceStorageV1StorageClass["*/*"];
}
type RequestContentType$deleteStorageV1StorageClass = keyof RequestBody$deleteStorageV1StorageClass;
type ResponseContentType$deleteStorageV1StorageClass = keyof Response$deleteStorageV1StorageClass$Status$200 | keyof Response$deleteStorageV1StorageClass$Status$202;
interface Params$deleteStorageV1StorageClass<U extends ResponseContentType$deleteStorageV1StorageClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteStorageV1StorageClass;
    requestBody: RequestBody$deleteStorageV1StorageClass["*/*"];
}
type RequestContentType$patchStorageV1StorageClass = keyof RequestBody$patchStorageV1StorageClass;
type ResponseContentType$patchStorageV1StorageClass = keyof Response$patchStorageV1StorageClass$Status$200 | keyof Response$patchStorageV1StorageClass$Status$201;
interface Params$patchStorageV1StorageClass<T extends RequestContentType$patchStorageV1StorageClass, U extends ResponseContentType$patchStorageV1StorageClass> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchStorageV1StorageClass;
    requestBody: RequestBody$patchStorageV1StorageClass[T];
}
type ResponseContentType$listStorageV1VolumeAttachment = keyof Response$listStorageV1VolumeAttachment$Status$200;
interface Params$listStorageV1VolumeAttachment<U extends ResponseContentType$listStorageV1VolumeAttachment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$listStorageV1VolumeAttachment;
}
type RequestContentType$createStorageV1VolumeAttachment = keyof RequestBody$createStorageV1VolumeAttachment;
type ResponseContentType$createStorageV1VolumeAttachment = keyof Response$createStorageV1VolumeAttachment$Status$200 | keyof Response$createStorageV1VolumeAttachment$Status$201 | keyof Response$createStorageV1VolumeAttachment$Status$202;
interface Params$createStorageV1VolumeAttachment<U extends ResponseContentType$createStorageV1VolumeAttachment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$createStorageV1VolumeAttachment;
    requestBody: RequestBody$createStorageV1VolumeAttachment["*/*"];
}
type RequestContentType$deleteStorageV1CollectionVolumeAttachment = keyof RequestBody$deleteStorageV1CollectionVolumeAttachment;
type ResponseContentType$deleteStorageV1CollectionVolumeAttachment = keyof Response$deleteStorageV1CollectionVolumeAttachment$Status$200;
interface Params$deleteStorageV1CollectionVolumeAttachment<U extends ResponseContentType$deleteStorageV1CollectionVolumeAttachment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteStorageV1CollectionVolumeAttachment;
    requestBody: RequestBody$deleteStorageV1CollectionVolumeAttachment["*/*"];
}
type ResponseContentType$readStorageV1VolumeAttachment = keyof Response$readStorageV1VolumeAttachment$Status$200;
interface Params$readStorageV1VolumeAttachment<U extends ResponseContentType$readStorageV1VolumeAttachment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readStorageV1VolumeAttachment;
}
type RequestContentType$replaceStorageV1VolumeAttachment = keyof RequestBody$replaceStorageV1VolumeAttachment;
type ResponseContentType$replaceStorageV1VolumeAttachment = keyof Response$replaceStorageV1VolumeAttachment$Status$200 | keyof Response$replaceStorageV1VolumeAttachment$Status$201;
interface Params$replaceStorageV1VolumeAttachment<U extends ResponseContentType$replaceStorageV1VolumeAttachment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceStorageV1VolumeAttachment;
    requestBody: RequestBody$replaceStorageV1VolumeAttachment["*/*"];
}
type RequestContentType$deleteStorageV1VolumeAttachment = keyof RequestBody$deleteStorageV1VolumeAttachment;
type ResponseContentType$deleteStorageV1VolumeAttachment = keyof Response$deleteStorageV1VolumeAttachment$Status$200 | keyof Response$deleteStorageV1VolumeAttachment$Status$202;
interface Params$deleteStorageV1VolumeAttachment<U extends ResponseContentType$deleteStorageV1VolumeAttachment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$deleteStorageV1VolumeAttachment;
    requestBody: RequestBody$deleteStorageV1VolumeAttachment["*/*"];
}
type RequestContentType$patchStorageV1VolumeAttachment = keyof RequestBody$patchStorageV1VolumeAttachment;
type ResponseContentType$patchStorageV1VolumeAttachment = keyof Response$patchStorageV1VolumeAttachment$Status$200 | keyof Response$patchStorageV1VolumeAttachment$Status$201;
interface Params$patchStorageV1VolumeAttachment<T extends RequestContentType$patchStorageV1VolumeAttachment, U extends ResponseContentType$patchStorageV1VolumeAttachment> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchStorageV1VolumeAttachment;
    requestBody: RequestBody$patchStorageV1VolumeAttachment[T];
}
type ResponseContentType$readStorageV1VolumeAttachmentStatus = keyof Response$readStorageV1VolumeAttachmentStatus$Status$200;
interface Params$readStorageV1VolumeAttachmentStatus<U extends ResponseContentType$readStorageV1VolumeAttachmentStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$readStorageV1VolumeAttachmentStatus;
}
type RequestContentType$replaceStorageV1VolumeAttachmentStatus = keyof RequestBody$replaceStorageV1VolumeAttachmentStatus;
type ResponseContentType$replaceStorageV1VolumeAttachmentStatus = keyof Response$replaceStorageV1VolumeAttachmentStatus$Status$200 | keyof Response$replaceStorageV1VolumeAttachmentStatus$Status$201;
interface Params$replaceStorageV1VolumeAttachmentStatus<U extends ResponseContentType$replaceStorageV1VolumeAttachmentStatus> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$replaceStorageV1VolumeAttachmentStatus;
    requestBody: RequestBody$replaceStorageV1VolumeAttachmentStatus["*/*"];
}
type RequestContentType$patchStorageV1VolumeAttachmentStatus = keyof RequestBody$patchStorageV1VolumeAttachmentStatus;
type ResponseContentType$patchStorageV1VolumeAttachmentStatus = keyof Response$patchStorageV1VolumeAttachmentStatus$Status$200 | keyof Response$patchStorageV1VolumeAttachmentStatus$Status$201;
interface Params$patchStorageV1VolumeAttachmentStatus<T extends RequestContentType$patchStorageV1VolumeAttachmentStatus, U extends ResponseContentType$patchStorageV1VolumeAttachmentStatus> {
    headers: {
        "Content-Type": T;
        Accept: U;
    };
    parameter: Parameter$patchStorageV1VolumeAttachmentStatus;
    requestBody: RequestBody$patchStorageV1VolumeAttachmentStatus[T];
}
type ResponseContentType$watchStorageV1CSIDriverList = keyof Response$watchStorageV1CSIDriverList$Status$200;
interface Params$watchStorageV1CSIDriverList<U extends ResponseContentType$watchStorageV1CSIDriverList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1CSIDriverList;
}
type ResponseContentType$watchStorageV1CSIDriver = keyof Response$watchStorageV1CSIDriver$Status$200;
interface Params$watchStorageV1CSIDriver<U extends ResponseContentType$watchStorageV1CSIDriver> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1CSIDriver;
}
type ResponseContentType$watchStorageV1CSINodeList = keyof Response$watchStorageV1CSINodeList$Status$200;
interface Params$watchStorageV1CSINodeList<U extends ResponseContentType$watchStorageV1CSINodeList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1CSINodeList;
}
type ResponseContentType$watchStorageV1CSINode = keyof Response$watchStorageV1CSINode$Status$200;
interface Params$watchStorageV1CSINode<U extends ResponseContentType$watchStorageV1CSINode> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1CSINode;
}
type ResponseContentType$watchStorageV1CSIStorageCapacityListForAllNamespaces = keyof Response$watchStorageV1CSIStorageCapacityListForAllNamespaces$Status$200;
interface Params$watchStorageV1CSIStorageCapacityListForAllNamespaces<U extends ResponseContentType$watchStorageV1CSIStorageCapacityListForAllNamespaces> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1CSIStorageCapacityListForAllNamespaces;
}
type ResponseContentType$watchStorageV1NamespacedCSIStorageCapacityList = keyof Response$watchStorageV1NamespacedCSIStorageCapacityList$Status$200;
interface Params$watchStorageV1NamespacedCSIStorageCapacityList<U extends ResponseContentType$watchStorageV1NamespacedCSIStorageCapacityList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1NamespacedCSIStorageCapacityList;
}
type ResponseContentType$watchStorageV1NamespacedCSIStorageCapacity = keyof Response$watchStorageV1NamespacedCSIStorageCapacity$Status$200;
interface Params$watchStorageV1NamespacedCSIStorageCapacity<U extends ResponseContentType$watchStorageV1NamespacedCSIStorageCapacity> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1NamespacedCSIStorageCapacity;
}
type ResponseContentType$watchStorageV1StorageClassList = keyof Response$watchStorageV1StorageClassList$Status$200;
interface Params$watchStorageV1StorageClassList<U extends ResponseContentType$watchStorageV1StorageClassList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1StorageClassList;
}
type ResponseContentType$watchStorageV1StorageClass = keyof Response$watchStorageV1StorageClass$Status$200;
interface Params$watchStorageV1StorageClass<U extends ResponseContentType$watchStorageV1StorageClass> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1StorageClass;
}
type ResponseContentType$watchStorageV1VolumeAttachmentList = keyof Response$watchStorageV1VolumeAttachmentList$Status$200;
interface Params$watchStorageV1VolumeAttachmentList<U extends ResponseContentType$watchStorageV1VolumeAttachmentList> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1VolumeAttachmentList;
}
type ResponseContentType$watchStorageV1VolumeAttachment = keyof Response$watchStorageV1VolumeAttachment$Status$200;
interface Params$watchStorageV1VolumeAttachment<U extends ResponseContentType$watchStorageV1VolumeAttachment> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$watchStorageV1VolumeAttachment;
}
interface Params$logFileHandler {
    parameter: Parameter$logFileHandler;
}
type ResponseContentType$getServiceAccountIssuerOpenIDKeyset = keyof Response$getServiceAccountIssuerOpenIDKeyset$Status$200;
type ResponseContentType$getCodeVersion = keyof Response$getCodeVersion$Status$200;
type HttpMethod = "GET" | "PUT" | "POST" | "DELETE" | "OPTIONS" | "HEAD" | "PATCH" | "TRACE";
interface ObjectLike {
    [key: string]: any;
}
interface QueryParameter {
    value: any;
    style?: "form" | "spaceDelimited" | "pipeDelimited" | "deepObject";
    explode: boolean;
}
interface QueryParameters {
    [key: string]: QueryParameter;
}
type SuccessResponses = Response$getServiceAccountIssuerOpenIDConfiguration$Status$200 | Response$getCoreAPIVersions$Status$200 | Response$getCoreV1APIResources$Status$200 | Response$listCoreV1ComponentStatus$Status$200 | Response$readCoreV1ComponentStatus$Status$200 | Response$listCoreV1ConfigMapForAllNamespaces$Status$200 | Response$listCoreV1EndpointsForAllNamespaces$Status$200 | Response$listCoreV1EventForAllNamespaces$Status$200 | Response$listCoreV1LimitRangeForAllNamespaces$Status$200 | Response$listCoreV1Namespace$Status$200 | Response$createCoreV1Namespace$Status$200 | Response$createCoreV1Namespace$Status$201 | Response$createCoreV1Namespace$Status$202 | Response$createCoreV1NamespacedBinding$Status$200 | Response$createCoreV1NamespacedBinding$Status$201 | Response$createCoreV1NamespacedBinding$Status$202 | Response$listCoreV1NamespacedConfigMap$Status$200 | Response$createCoreV1NamespacedConfigMap$Status$200 | Response$createCoreV1NamespacedConfigMap$Status$201 | Response$createCoreV1NamespacedConfigMap$Status$202 | Response$deleteCoreV1CollectionNamespacedConfigMap$Status$200 | Response$readCoreV1NamespacedConfigMap$Status$200 | Response$replaceCoreV1NamespacedConfigMap$Status$200 | Response$replaceCoreV1NamespacedConfigMap$Status$201 | Response$deleteCoreV1NamespacedConfigMap$Status$200 | Response$deleteCoreV1NamespacedConfigMap$Status$202 | Response$patchCoreV1NamespacedConfigMap$Status$200 | Response$patchCoreV1NamespacedConfigMap$Status$201 | Response$listCoreV1NamespacedEndpoints$Status$200 | Response$createCoreV1NamespacedEndpoints$Status$200 | Response$createCoreV1NamespacedEndpoints$Status$201 | Response$createCoreV1NamespacedEndpoints$Status$202 | Response$deleteCoreV1CollectionNamespacedEndpoints$Status$200 | Response$readCoreV1NamespacedEndpoints$Status$200 | Response$replaceCoreV1NamespacedEndpoints$Status$200 | Response$replaceCoreV1NamespacedEndpoints$Status$201 | Response$deleteCoreV1NamespacedEndpoints$Status$200 | Response$deleteCoreV1NamespacedEndpoints$Status$202 | Response$patchCoreV1NamespacedEndpoints$Status$200 | Response$patchCoreV1NamespacedEndpoints$Status$201 | Response$listCoreV1NamespacedEvent$Status$200 | Response$createCoreV1NamespacedEvent$Status$200 | Response$createCoreV1NamespacedEvent$Status$201 | Response$createCoreV1NamespacedEvent$Status$202 | Response$deleteCoreV1CollectionNamespacedEvent$Status$200 | Response$readCoreV1NamespacedEvent$Status$200 | Response$replaceCoreV1NamespacedEvent$Status$200 | Response$replaceCoreV1NamespacedEvent$Status$201 | Response$deleteCoreV1NamespacedEvent$Status$200 | Response$deleteCoreV1NamespacedEvent$Status$202 | Response$patchCoreV1NamespacedEvent$Status$200 | Response$patchCoreV1NamespacedEvent$Status$201 | Response$listCoreV1NamespacedLimitRange$Status$200 | Response$createCoreV1NamespacedLimitRange$Status$200 | Response$createCoreV1NamespacedLimitRange$Status$201 | Response$createCoreV1NamespacedLimitRange$Status$202 | Response$deleteCoreV1CollectionNamespacedLimitRange$Status$200 | Response$readCoreV1NamespacedLimitRange$Status$200 | Response$replaceCoreV1NamespacedLimitRange$Status$200 | Response$replaceCoreV1NamespacedLimitRange$Status$201 | Response$deleteCoreV1NamespacedLimitRange$Status$200 | Response$deleteCoreV1NamespacedLimitRange$Status$202 | Response$patchCoreV1NamespacedLimitRange$Status$200 | Response$patchCoreV1NamespacedLimitRange$Status$201 | Response$listCoreV1NamespacedPersistentVolumeClaim$Status$200 | Response$createCoreV1NamespacedPersistentVolumeClaim$Status$200 | Response$createCoreV1NamespacedPersistentVolumeClaim$Status$201 | Response$createCoreV1NamespacedPersistentVolumeClaim$Status$202 | Response$deleteCoreV1CollectionNamespacedPersistentVolumeClaim$Status$200 | Response$readCoreV1NamespacedPersistentVolumeClaim$Status$200 | Response$replaceCoreV1NamespacedPersistentVolumeClaim$Status$200 | Response$replaceCoreV1NamespacedPersistentVolumeClaim$Status$201 | Response$deleteCoreV1NamespacedPersistentVolumeClaim$Status$200 | Response$deleteCoreV1NamespacedPersistentVolumeClaim$Status$202 | Response$patchCoreV1NamespacedPersistentVolumeClaim$Status$200 | Response$patchCoreV1NamespacedPersistentVolumeClaim$Status$201 | Response$readCoreV1NamespacedPersistentVolumeClaimStatus$Status$200 | Response$replaceCoreV1NamespacedPersistentVolumeClaimStatus$Status$200 | Response$replaceCoreV1NamespacedPersistentVolumeClaimStatus$Status$201 | Response$patchCoreV1NamespacedPersistentVolumeClaimStatus$Status$200 | Response$patchCoreV1NamespacedPersistentVolumeClaimStatus$Status$201 | Response$listCoreV1NamespacedPod$Status$200 | Response$createCoreV1NamespacedPod$Status$200 | Response$createCoreV1NamespacedPod$Status$201 | Response$createCoreV1NamespacedPod$Status$202 | Response$deleteCoreV1CollectionNamespacedPod$Status$200 | Response$readCoreV1NamespacedPod$Status$200 | Response$replaceCoreV1NamespacedPod$Status$200 | Response$replaceCoreV1NamespacedPod$Status$201 | Response$deleteCoreV1NamespacedPod$Status$200 | Response$deleteCoreV1NamespacedPod$Status$202 | Response$patchCoreV1NamespacedPod$Status$200 | Response$patchCoreV1NamespacedPod$Status$201 | Response$connectCoreV1GetNamespacedPodAttach$Status$200 | Response$connectCoreV1PostNamespacedPodAttach$Status$200 | Response$createCoreV1NamespacedPodBinding$Status$200 | Response$createCoreV1NamespacedPodBinding$Status$201 | Response$createCoreV1NamespacedPodBinding$Status$202 | Response$readCoreV1NamespacedPodEphemeralcontainers$Status$200 | Response$replaceCoreV1NamespacedPodEphemeralcontainers$Status$200 | Response$replaceCoreV1NamespacedPodEphemeralcontainers$Status$201 | Response$patchCoreV1NamespacedPodEphemeralcontainers$Status$200 | Response$patchCoreV1NamespacedPodEphemeralcontainers$Status$201 | Response$createCoreV1NamespacedPodEviction$Status$200 | Response$createCoreV1NamespacedPodEviction$Status$201 | Response$createCoreV1NamespacedPodEviction$Status$202 | Response$connectCoreV1GetNamespacedPodExec$Status$200 | Response$connectCoreV1PostNamespacedPodExec$Status$200 | Response$readCoreV1NamespacedPodLog$Status$200 | Response$connectCoreV1GetNamespacedPodPortforward$Status$200 | Response$connectCoreV1PostNamespacedPodPortforward$Status$200 | Response$connectCoreV1GetNamespacedPodProxy$Status$200 | Response$connectCoreV1PutNamespacedPodProxy$Status$200 | Response$connectCoreV1PostNamespacedPodProxy$Status$200 | Response$connectCoreV1DeleteNamespacedPodProxy$Status$200 | Response$connectCoreV1OptionsNamespacedPodProxy$Status$200 | Response$connectCoreV1HeadNamespacedPodProxy$Status$200 | Response$connectCoreV1PatchNamespacedPodProxy$Status$200 | Response$connectCoreV1GetNamespacedPodProxyWithPath$Status$200 | Response$connectCoreV1PutNamespacedPodProxyWithPath$Status$200 | Response$connectCoreV1PostNamespacedPodProxyWithPath$Status$200 | Response$connectCoreV1DeleteNamespacedPodProxyWithPath$Status$200 | Response$connectCoreV1OptionsNamespacedPodProxyWithPath$Status$200 | Response$connectCoreV1HeadNamespacedPodProxyWithPath$Status$200 | Response$connectCoreV1PatchNamespacedPodProxyWithPath$Status$200 | Response$readCoreV1NamespacedPodStatus$Status$200 | Response$replaceCoreV1NamespacedPodStatus$Status$200 | Response$replaceCoreV1NamespacedPodStatus$Status$201 | Response$patchCoreV1NamespacedPodStatus$Status$200 | Response$patchCoreV1NamespacedPodStatus$Status$201 | Response$listCoreV1NamespacedPodTemplate$Status$200 | Response$createCoreV1NamespacedPodTemplate$Status$200 | Response$createCoreV1NamespacedPodTemplate$Status$201 | Response$createCoreV1NamespacedPodTemplate$Status$202 | Response$deleteCoreV1CollectionNamespacedPodTemplate$Status$200 | Response$readCoreV1NamespacedPodTemplate$Status$200 | Response$replaceCoreV1NamespacedPodTemplate$Status$200 | Response$replaceCoreV1NamespacedPodTemplate$Status$201 | Response$deleteCoreV1NamespacedPodTemplate$Status$200 | Response$deleteCoreV1NamespacedPodTemplate$Status$202 | Response$patchCoreV1NamespacedPodTemplate$Status$200 | Response$patchCoreV1NamespacedPodTemplate$Status$201 | Response$listCoreV1NamespacedReplicationController$Status$200 | Response$createCoreV1NamespacedReplicationController$Status$200 | Response$createCoreV1NamespacedReplicationController$Status$201 | Response$createCoreV1NamespacedReplicationController$Status$202 | Response$deleteCoreV1CollectionNamespacedReplicationController$Status$200 | Response$readCoreV1NamespacedReplicationController$Status$200 | Response$replaceCoreV1NamespacedReplicationController$Status$200 | Response$replaceCoreV1NamespacedReplicationController$Status$201 | Response$deleteCoreV1NamespacedReplicationController$Status$200 | Response$deleteCoreV1NamespacedReplicationController$Status$202 | Response$patchCoreV1NamespacedReplicationController$Status$200 | Response$patchCoreV1NamespacedReplicationController$Status$201 | Response$readCoreV1NamespacedReplicationControllerScale$Status$200 | Response$replaceCoreV1NamespacedReplicationControllerScale$Status$200 | Response$replaceCoreV1NamespacedReplicationControllerScale$Status$201 | Response$patchCoreV1NamespacedReplicationControllerScale$Status$200 | Response$patchCoreV1NamespacedReplicationControllerScale$Status$201 | Response$readCoreV1NamespacedReplicationControllerStatus$Status$200 | Response$replaceCoreV1NamespacedReplicationControllerStatus$Status$200 | Response$replaceCoreV1NamespacedReplicationControllerStatus$Status$201 | Response$patchCoreV1NamespacedReplicationControllerStatus$Status$200 | Response$patchCoreV1NamespacedReplicationControllerStatus$Status$201 | Response$listCoreV1NamespacedResourceQuota$Status$200 | Response$createCoreV1NamespacedResourceQuota$Status$200 | Response$createCoreV1NamespacedResourceQuota$Status$201 | Response$createCoreV1NamespacedResourceQuota$Status$202 | Response$deleteCoreV1CollectionNamespacedResourceQuota$Status$200 | Response$readCoreV1NamespacedResourceQuota$Status$200 | Response$replaceCoreV1NamespacedResourceQuota$Status$200 | Response$replaceCoreV1NamespacedResourceQuota$Status$201 | Response$deleteCoreV1NamespacedResourceQuota$Status$200 | Response$deleteCoreV1NamespacedResourceQuota$Status$202 | Response$patchCoreV1NamespacedResourceQuota$Status$200 | Response$patchCoreV1NamespacedResourceQuota$Status$201 | Response$readCoreV1NamespacedResourceQuotaStatus$Status$200 | Response$replaceCoreV1NamespacedResourceQuotaStatus$Status$200 | Response$replaceCoreV1NamespacedResourceQuotaStatus$Status$201 | Response$patchCoreV1NamespacedResourceQuotaStatus$Status$200 | Response$patchCoreV1NamespacedResourceQuotaStatus$Status$201 | Response$listCoreV1NamespacedSecret$Status$200 | Response$createCoreV1NamespacedSecret$Status$200 | Response$createCoreV1NamespacedSecret$Status$201 | Response$createCoreV1NamespacedSecret$Status$202 | Response$deleteCoreV1CollectionNamespacedSecret$Status$200 | Response$readCoreV1NamespacedSecret$Status$200 | Response$replaceCoreV1NamespacedSecret$Status$200 | Response$replaceCoreV1NamespacedSecret$Status$201 | Response$deleteCoreV1NamespacedSecret$Status$200 | Response$deleteCoreV1NamespacedSecret$Status$202 | Response$patchCoreV1NamespacedSecret$Status$200 | Response$patchCoreV1NamespacedSecret$Status$201 | Response$listCoreV1NamespacedServiceAccount$Status$200 | Response$createCoreV1NamespacedServiceAccount$Status$200 | Response$createCoreV1NamespacedServiceAccount$Status$201 | Response$createCoreV1NamespacedServiceAccount$Status$202 | Response$deleteCoreV1CollectionNamespacedServiceAccount$Status$200 | Response$readCoreV1NamespacedServiceAccount$Status$200 | Response$replaceCoreV1NamespacedServiceAccount$Status$200 | Response$replaceCoreV1NamespacedServiceAccount$Status$201 | Response$deleteCoreV1NamespacedServiceAccount$Status$200 | Response$deleteCoreV1NamespacedServiceAccount$Status$202 | Response$patchCoreV1NamespacedServiceAccount$Status$200 | Response$patchCoreV1NamespacedServiceAccount$Status$201 | Response$createCoreV1NamespacedServiceAccountToken$Status$200 | Response$createCoreV1NamespacedServiceAccountToken$Status$201 | Response$createCoreV1NamespacedServiceAccountToken$Status$202 | Response$listCoreV1NamespacedService$Status$200 | Response$createCoreV1NamespacedService$Status$200 | Response$createCoreV1NamespacedService$Status$201 | Response$createCoreV1NamespacedService$Status$202 | Response$deleteCoreV1CollectionNamespacedService$Status$200 | Response$readCoreV1NamespacedService$Status$200 | Response$replaceCoreV1NamespacedService$Status$200 | Response$replaceCoreV1NamespacedService$Status$201 | Response$deleteCoreV1NamespacedService$Status$200 | Response$deleteCoreV1NamespacedService$Status$202 | Response$patchCoreV1NamespacedService$Status$200 | Response$patchCoreV1NamespacedService$Status$201 | Response$connectCoreV1GetNamespacedServiceProxy$Status$200 | Response$connectCoreV1PutNamespacedServiceProxy$Status$200 | Response$connectCoreV1PostNamespacedServiceProxy$Status$200 | Response$connectCoreV1DeleteNamespacedServiceProxy$Status$200 | Response$connectCoreV1OptionsNamespacedServiceProxy$Status$200 | Response$connectCoreV1HeadNamespacedServiceProxy$Status$200 | Response$connectCoreV1PatchNamespacedServiceProxy$Status$200 | Response$connectCoreV1GetNamespacedServiceProxyWithPath$Status$200 | Response$connectCoreV1PutNamespacedServiceProxyWithPath$Status$200 | Response$connectCoreV1PostNamespacedServiceProxyWithPath$Status$200 | Response$connectCoreV1DeleteNamespacedServiceProxyWithPath$Status$200 | Response$connectCoreV1OptionsNamespacedServiceProxyWithPath$Status$200 | Response$connectCoreV1HeadNamespacedServiceProxyWithPath$Status$200 | Response$connectCoreV1PatchNamespacedServiceProxyWithPath$Status$200 | Response$readCoreV1NamespacedServiceStatus$Status$200 | Response$replaceCoreV1NamespacedServiceStatus$Status$200 | Response$replaceCoreV1NamespacedServiceStatus$Status$201 | Response$patchCoreV1NamespacedServiceStatus$Status$200 | Response$patchCoreV1NamespacedServiceStatus$Status$201 | Response$readCoreV1Namespace$Status$200 | Response$replaceCoreV1Namespace$Status$200 | Response$replaceCoreV1Namespace$Status$201 | Response$deleteCoreV1Namespace$Status$200 | Response$deleteCoreV1Namespace$Status$202 | Response$patchCoreV1Namespace$Status$200 | Response$patchCoreV1Namespace$Status$201 | Response$replaceCoreV1NamespaceFinalize$Status$200 | Response$replaceCoreV1NamespaceFinalize$Status$201 | Response$readCoreV1NamespaceStatus$Status$200 | Response$replaceCoreV1NamespaceStatus$Status$200 | Response$replaceCoreV1NamespaceStatus$Status$201 | Response$patchCoreV1NamespaceStatus$Status$200 | Response$patchCoreV1NamespaceStatus$Status$201 | Response$listCoreV1Node$Status$200 | Response$createCoreV1Node$Status$200 | Response$createCoreV1Node$Status$201 | Response$createCoreV1Node$Status$202 | Response$deleteCoreV1CollectionNode$Status$200 | Response$readCoreV1Node$Status$200 | Response$replaceCoreV1Node$Status$200 | Response$replaceCoreV1Node$Status$201 | Response$deleteCoreV1Node$Status$200 | Response$deleteCoreV1Node$Status$202 | Response$patchCoreV1Node$Status$200 | Response$patchCoreV1Node$Status$201 | Response$connectCoreV1GetNodeProxy$Status$200 | Response$connectCoreV1PutNodeProxy$Status$200 | Response$connectCoreV1PostNodeProxy$Status$200 | Response$connectCoreV1DeleteNodeProxy$Status$200 | Response$connectCoreV1OptionsNodeProxy$Status$200 | Response$connectCoreV1HeadNodeProxy$Status$200 | Response$connectCoreV1PatchNodeProxy$Status$200 | Response$connectCoreV1GetNodeProxyWithPath$Status$200 | Response$connectCoreV1PutNodeProxyWithPath$Status$200 | Response$connectCoreV1PostNodeProxyWithPath$Status$200 | Response$connectCoreV1DeleteNodeProxyWithPath$Status$200 | Response$connectCoreV1OptionsNodeProxyWithPath$Status$200 | Response$connectCoreV1HeadNodeProxyWithPath$Status$200 | Response$connectCoreV1PatchNodeProxyWithPath$Status$200 | Response$readCoreV1NodeStatus$Status$200 | Response$replaceCoreV1NodeStatus$Status$200 | Response$replaceCoreV1NodeStatus$Status$201 | Response$patchCoreV1NodeStatus$Status$200 | Response$patchCoreV1NodeStatus$Status$201 | Response$listCoreV1PersistentVolumeClaimForAllNamespaces$Status$200 | Response$listCoreV1PersistentVolume$Status$200 | Response$createCoreV1PersistentVolume$Status$200 | Response$createCoreV1PersistentVolume$Status$201 | Response$createCoreV1PersistentVolume$Status$202 | Response$deleteCoreV1CollectionPersistentVolume$Status$200 | Response$readCoreV1PersistentVolume$Status$200 | Response$replaceCoreV1PersistentVolume$Status$200 | Response$replaceCoreV1PersistentVolume$Status$201 | Response$deleteCoreV1PersistentVolume$Status$200 | Response$deleteCoreV1PersistentVolume$Status$202 | Response$patchCoreV1PersistentVolume$Status$200 | Response$patchCoreV1PersistentVolume$Status$201 | Response$readCoreV1PersistentVolumeStatus$Status$200 | Response$replaceCoreV1PersistentVolumeStatus$Status$200 | Response$replaceCoreV1PersistentVolumeStatus$Status$201 | Response$patchCoreV1PersistentVolumeStatus$Status$200 | Response$patchCoreV1PersistentVolumeStatus$Status$201 | Response$listCoreV1PodForAllNamespaces$Status$200 | Response$listCoreV1PodTemplateForAllNamespaces$Status$200 | Response$listCoreV1ReplicationControllerForAllNamespaces$Status$200 | Response$listCoreV1ResourceQuotaForAllNamespaces$Status$200 | Response$listCoreV1SecretForAllNamespaces$Status$200 | Response$listCoreV1ServiceAccountForAllNamespaces$Status$200 | Response$listCoreV1ServiceForAllNamespaces$Status$200 | Response$watchCoreV1ConfigMapListForAllNamespaces$Status$200 | Response$watchCoreV1EndpointsListForAllNamespaces$Status$200 | Response$watchCoreV1EventListForAllNamespaces$Status$200 | Response$watchCoreV1LimitRangeListForAllNamespaces$Status$200 | Response$watchCoreV1NamespaceList$Status$200 | Response$watchCoreV1NamespacedConfigMapList$Status$200 | Response$watchCoreV1NamespacedConfigMap$Status$200 | Response$watchCoreV1NamespacedEndpointsList$Status$200 | Response$watchCoreV1NamespacedEndpoints$Status$200 | Response$watchCoreV1NamespacedEventList$Status$200 | Response$watchCoreV1NamespacedEvent$Status$200 | Response$watchCoreV1NamespacedLimitRangeList$Status$200 | Response$watchCoreV1NamespacedLimitRange$Status$200 | Response$watchCoreV1NamespacedPersistentVolumeClaimList$Status$200 | Response$watchCoreV1NamespacedPersistentVolumeClaim$Status$200 | Response$watchCoreV1NamespacedPodList$Status$200 | Response$watchCoreV1NamespacedPod$Status$200 | Response$watchCoreV1NamespacedPodTemplateList$Status$200 | Response$watchCoreV1NamespacedPodTemplate$Status$200 | Response$watchCoreV1NamespacedReplicationControllerList$Status$200 | Response$watchCoreV1NamespacedReplicationController$Status$200 | Response$watchCoreV1NamespacedResourceQuotaList$Status$200 | Response$watchCoreV1NamespacedResourceQuota$Status$200 | Response$watchCoreV1NamespacedSecretList$Status$200 | Response$watchCoreV1NamespacedSecret$Status$200 | Response$watchCoreV1NamespacedServiceAccountList$Status$200 | Response$watchCoreV1NamespacedServiceAccount$Status$200 | Response$watchCoreV1NamespacedServiceList$Status$200 | Response$watchCoreV1NamespacedService$Status$200 | Response$watchCoreV1Namespace$Status$200 | Response$watchCoreV1NodeList$Status$200 | Response$watchCoreV1Node$Status$200 | Response$watchCoreV1PersistentVolumeClaimListForAllNamespaces$Status$200 | Response$watchCoreV1PersistentVolumeList$Status$200 | Response$watchCoreV1PersistentVolume$Status$200 | Response$watchCoreV1PodListForAllNamespaces$Status$200 | Response$watchCoreV1PodTemplateListForAllNamespaces$Status$200 | Response$watchCoreV1ReplicationControllerListForAllNamespaces$Status$200 | Response$watchCoreV1ResourceQuotaListForAllNamespaces$Status$200 | Response$watchCoreV1SecretListForAllNamespaces$Status$200 | Response$watchCoreV1ServiceAccountListForAllNamespaces$Status$200 | Response$watchCoreV1ServiceListForAllNamespaces$Status$200 | Response$getAPIVersions$Status$200 | Response$getAdmissionregistrationAPIGroup$Status$200 | Response$getAdmissionregistrationV1APIResources$Status$200 | Response$listAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$201 | Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$202 | Response$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration$Status$200 | Response$readAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | Response$replaceAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | Response$replaceAdmissionregistrationV1MutatingWebhookConfiguration$Status$201 | Response$deleteAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | Response$deleteAdmissionregistrationV1MutatingWebhookConfiguration$Status$202 | Response$patchAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | Response$patchAdmissionregistrationV1MutatingWebhookConfiguration$Status$201 | Response$listAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201 | Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$202 | Response$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration$Status$200 | Response$readAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | Response$replaceAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | Response$replaceAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201 | Response$deleteAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | Response$deleteAdmissionregistrationV1ValidatingWebhookConfiguration$Status$202 | Response$patchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | Response$patchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201 | Response$watchAdmissionregistrationV1MutatingWebhookConfigurationList$Status$200 | Response$watchAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | Response$watchAdmissionregistrationV1ValidatingWebhookConfigurationList$Status$200 | Response$watchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | Response$getAdmissionregistrationV1alpha1APIResources$Status$200 | Response$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200 | Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200 | Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$201 | Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$202 | Response$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy$Status$200 | Response$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200 | Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200 | Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$201 | Response$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200 | Response$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$202 | Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200 | Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$201 | Response$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$200 | Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$200 | Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$201 | Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$200 | Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$201 | Response$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200 | Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200 | Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$201 | Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$202 | Response$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding$Status$200 | Response$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200 | Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200 | Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$201 | Response$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200 | Response$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$202 | Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200 | Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$201 | Response$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyList$Status$200 | Response$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200 | Response$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBindingList$Status$200 | Response$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200 | Response$getApiextensionsAPIGroup$Status$200 | Response$getApiextensionsV1APIResources$Status$200 | Response$listApiextensionsV1CustomResourceDefinition$Status$200 | Response$createApiextensionsV1CustomResourceDefinition$Status$200 | Response$createApiextensionsV1CustomResourceDefinition$Status$201 | Response$createApiextensionsV1CustomResourceDefinition$Status$202 | Response$deleteApiextensionsV1CollectionCustomResourceDefinition$Status$200 | Response$readApiextensionsV1CustomResourceDefinition$Status$200 | Response$replaceApiextensionsV1CustomResourceDefinition$Status$200 | Response$replaceApiextensionsV1CustomResourceDefinition$Status$201 | Response$deleteApiextensionsV1CustomResourceDefinition$Status$200 | Response$deleteApiextensionsV1CustomResourceDefinition$Status$202 | Response$patchApiextensionsV1CustomResourceDefinition$Status$200 | Response$patchApiextensionsV1CustomResourceDefinition$Status$201 | Response$readApiextensionsV1CustomResourceDefinitionStatus$Status$200 | Response$replaceApiextensionsV1CustomResourceDefinitionStatus$Status$200 | Response$replaceApiextensionsV1CustomResourceDefinitionStatus$Status$201 | Response$patchApiextensionsV1CustomResourceDefinitionStatus$Status$200 | Response$patchApiextensionsV1CustomResourceDefinitionStatus$Status$201 | Response$watchApiextensionsV1CustomResourceDefinitionList$Status$200 | Response$watchApiextensionsV1CustomResourceDefinition$Status$200 | Response$getApiregistrationAPIGroup$Status$200 | Response$getApiregistrationV1APIResources$Status$200 | Response$listApiregistrationV1APIService$Status$200 | Response$createApiregistrationV1APIService$Status$200 | Response$createApiregistrationV1APIService$Status$201 | Response$createApiregistrationV1APIService$Status$202 | Response$deleteApiregistrationV1CollectionAPIService$Status$200 | Response$readApiregistrationV1APIService$Status$200 | Response$replaceApiregistrationV1APIService$Status$200 | Response$replaceApiregistrationV1APIService$Status$201 | Response$deleteApiregistrationV1APIService$Status$200 | Response$deleteApiregistrationV1APIService$Status$202 | Response$patchApiregistrationV1APIService$Status$200 | Response$patchApiregistrationV1APIService$Status$201 | Response$readApiregistrationV1APIServiceStatus$Status$200 | Response$replaceApiregistrationV1APIServiceStatus$Status$200 | Response$replaceApiregistrationV1APIServiceStatus$Status$201 | Response$patchApiregistrationV1APIServiceStatus$Status$200 | Response$patchApiregistrationV1APIServiceStatus$Status$201 | Response$watchApiregistrationV1APIServiceList$Status$200 | Response$watchApiregistrationV1APIService$Status$200 | Response$getAppsAPIGroup$Status$200 | Response$getAppsV1APIResources$Status$200 | Response$listAppsV1ControllerRevisionForAllNamespaces$Status$200 | Response$listAppsV1DaemonSetForAllNamespaces$Status$200 | Response$listAppsV1DeploymentForAllNamespaces$Status$200 | Response$listAppsV1NamespacedControllerRevision$Status$200 | Response$createAppsV1NamespacedControllerRevision$Status$200 | Response$createAppsV1NamespacedControllerRevision$Status$201 | Response$createAppsV1NamespacedControllerRevision$Status$202 | Response$deleteAppsV1CollectionNamespacedControllerRevision$Status$200 | Response$readAppsV1NamespacedControllerRevision$Status$200 | Response$replaceAppsV1NamespacedControllerRevision$Status$200 | Response$replaceAppsV1NamespacedControllerRevision$Status$201 | Response$deleteAppsV1NamespacedControllerRevision$Status$200 | Response$deleteAppsV1NamespacedControllerRevision$Status$202 | Response$patchAppsV1NamespacedControllerRevision$Status$200 | Response$patchAppsV1NamespacedControllerRevision$Status$201 | Response$listAppsV1NamespacedDaemonSet$Status$200 | Response$createAppsV1NamespacedDaemonSet$Status$200 | Response$createAppsV1NamespacedDaemonSet$Status$201 | Response$createAppsV1NamespacedDaemonSet$Status$202 | Response$deleteAppsV1CollectionNamespacedDaemonSet$Status$200 | Response$readAppsV1NamespacedDaemonSet$Status$200 | Response$replaceAppsV1NamespacedDaemonSet$Status$200 | Response$replaceAppsV1NamespacedDaemonSet$Status$201 | Response$deleteAppsV1NamespacedDaemonSet$Status$200 | Response$deleteAppsV1NamespacedDaemonSet$Status$202 | Response$patchAppsV1NamespacedDaemonSet$Status$200 | Response$patchAppsV1NamespacedDaemonSet$Status$201 | Response$readAppsV1NamespacedDaemonSetStatus$Status$200 | Response$replaceAppsV1NamespacedDaemonSetStatus$Status$200 | Response$replaceAppsV1NamespacedDaemonSetStatus$Status$201 | Response$patchAppsV1NamespacedDaemonSetStatus$Status$200 | Response$patchAppsV1NamespacedDaemonSetStatus$Status$201 | Response$listAppsV1NamespacedDeployment$Status$200 | Response$createAppsV1NamespacedDeployment$Status$200 | Response$createAppsV1NamespacedDeployment$Status$201 | Response$createAppsV1NamespacedDeployment$Status$202 | Response$deleteAppsV1CollectionNamespacedDeployment$Status$200 | Response$readAppsV1NamespacedDeployment$Status$200 | Response$replaceAppsV1NamespacedDeployment$Status$200 | Response$replaceAppsV1NamespacedDeployment$Status$201 | Response$deleteAppsV1NamespacedDeployment$Status$200 | Response$deleteAppsV1NamespacedDeployment$Status$202 | Response$patchAppsV1NamespacedDeployment$Status$200 | Response$patchAppsV1NamespacedDeployment$Status$201 | Response$readAppsV1NamespacedDeploymentScale$Status$200 | Response$replaceAppsV1NamespacedDeploymentScale$Status$200 | Response$replaceAppsV1NamespacedDeploymentScale$Status$201 | Response$patchAppsV1NamespacedDeploymentScale$Status$200 | Response$patchAppsV1NamespacedDeploymentScale$Status$201 | Response$readAppsV1NamespacedDeploymentStatus$Status$200 | Response$replaceAppsV1NamespacedDeploymentStatus$Status$200 | Response$replaceAppsV1NamespacedDeploymentStatus$Status$201 | Response$patchAppsV1NamespacedDeploymentStatus$Status$200 | Response$patchAppsV1NamespacedDeploymentStatus$Status$201 | Response$listAppsV1NamespacedReplicaSet$Status$200 | Response$createAppsV1NamespacedReplicaSet$Status$200 | Response$createAppsV1NamespacedReplicaSet$Status$201 | Response$createAppsV1NamespacedReplicaSet$Status$202 | Response$deleteAppsV1CollectionNamespacedReplicaSet$Status$200 | Response$readAppsV1NamespacedReplicaSet$Status$200 | Response$replaceAppsV1NamespacedReplicaSet$Status$200 | Response$replaceAppsV1NamespacedReplicaSet$Status$201 | Response$deleteAppsV1NamespacedReplicaSet$Status$200 | Response$deleteAppsV1NamespacedReplicaSet$Status$202 | Response$patchAppsV1NamespacedReplicaSet$Status$200 | Response$patchAppsV1NamespacedReplicaSet$Status$201 | Response$readAppsV1NamespacedReplicaSetScale$Status$200 | Response$replaceAppsV1NamespacedReplicaSetScale$Status$200 | Response$replaceAppsV1NamespacedReplicaSetScale$Status$201 | Response$patchAppsV1NamespacedReplicaSetScale$Status$200 | Response$patchAppsV1NamespacedReplicaSetScale$Status$201 | Response$readAppsV1NamespacedReplicaSetStatus$Status$200 | Response$replaceAppsV1NamespacedReplicaSetStatus$Status$200 | Response$replaceAppsV1NamespacedReplicaSetStatus$Status$201 | Response$patchAppsV1NamespacedReplicaSetStatus$Status$200 | Response$patchAppsV1NamespacedReplicaSetStatus$Status$201 | Response$listAppsV1NamespacedStatefulSet$Status$200 | Response$createAppsV1NamespacedStatefulSet$Status$200 | Response$createAppsV1NamespacedStatefulSet$Status$201 | Response$createAppsV1NamespacedStatefulSet$Status$202 | Response$deleteAppsV1CollectionNamespacedStatefulSet$Status$200 | Response$readAppsV1NamespacedStatefulSet$Status$200 | Response$replaceAppsV1NamespacedStatefulSet$Status$200 | Response$replaceAppsV1NamespacedStatefulSet$Status$201 | Response$deleteAppsV1NamespacedStatefulSet$Status$200 | Response$deleteAppsV1NamespacedStatefulSet$Status$202 | Response$patchAppsV1NamespacedStatefulSet$Status$200 | Response$patchAppsV1NamespacedStatefulSet$Status$201 | Response$readAppsV1NamespacedStatefulSetScale$Status$200 | Response$replaceAppsV1NamespacedStatefulSetScale$Status$200 | Response$replaceAppsV1NamespacedStatefulSetScale$Status$201 | Response$patchAppsV1NamespacedStatefulSetScale$Status$200 | Response$patchAppsV1NamespacedStatefulSetScale$Status$201 | Response$readAppsV1NamespacedStatefulSetStatus$Status$200 | Response$replaceAppsV1NamespacedStatefulSetStatus$Status$200 | Response$replaceAppsV1NamespacedStatefulSetStatus$Status$201 | Response$patchAppsV1NamespacedStatefulSetStatus$Status$200 | Response$patchAppsV1NamespacedStatefulSetStatus$Status$201 | Response$listAppsV1ReplicaSetForAllNamespaces$Status$200 | Response$listAppsV1StatefulSetForAllNamespaces$Status$200 | Response$watchAppsV1ControllerRevisionListForAllNamespaces$Status$200 | Response$watchAppsV1DaemonSetListForAllNamespaces$Status$200 | Response$watchAppsV1DeploymentListForAllNamespaces$Status$200 | Response$watchAppsV1NamespacedControllerRevisionList$Status$200 | Response$watchAppsV1NamespacedControllerRevision$Status$200 | Response$watchAppsV1NamespacedDaemonSetList$Status$200 | Response$watchAppsV1NamespacedDaemonSet$Status$200 | Response$watchAppsV1NamespacedDeploymentList$Status$200 | Response$watchAppsV1NamespacedDeployment$Status$200 | Response$watchAppsV1NamespacedReplicaSetList$Status$200 | Response$watchAppsV1NamespacedReplicaSet$Status$200 | Response$watchAppsV1NamespacedStatefulSetList$Status$200 | Response$watchAppsV1NamespacedStatefulSet$Status$200 | Response$watchAppsV1ReplicaSetListForAllNamespaces$Status$200 | Response$watchAppsV1StatefulSetListForAllNamespaces$Status$200 | Response$getAuthenticationAPIGroup$Status$200 | Response$getAuthenticationV1APIResources$Status$200 | Response$createAuthenticationV1TokenReview$Status$200 | Response$createAuthenticationV1TokenReview$Status$201 | Response$createAuthenticationV1TokenReview$Status$202 | Response$getAuthenticationV1alpha1APIResources$Status$200 | Response$createAuthenticationV1alpha1SelfSubjectReview$Status$200 | Response$createAuthenticationV1alpha1SelfSubjectReview$Status$201 | Response$createAuthenticationV1alpha1SelfSubjectReview$Status$202 | Response$getAuthenticationV1beta1APIResources$Status$200 | Response$createAuthenticationV1beta1SelfSubjectReview$Status$200 | Response$createAuthenticationV1beta1SelfSubjectReview$Status$201 | Response$createAuthenticationV1beta1SelfSubjectReview$Status$202 | Response$getAuthorizationAPIGroup$Status$200 | Response$getAuthorizationV1APIResources$Status$200 | Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$200 | Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$201 | Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$202 | Response$createAuthorizationV1SelfSubjectAccessReview$Status$200 | Response$createAuthorizationV1SelfSubjectAccessReview$Status$201 | Response$createAuthorizationV1SelfSubjectAccessReview$Status$202 | Response$createAuthorizationV1SelfSubjectRulesReview$Status$200 | Response$createAuthorizationV1SelfSubjectRulesReview$Status$201 | Response$createAuthorizationV1SelfSubjectRulesReview$Status$202 | Response$createAuthorizationV1SubjectAccessReview$Status$200 | Response$createAuthorizationV1SubjectAccessReview$Status$201 | Response$createAuthorizationV1SubjectAccessReview$Status$202 | Response$getAutoscalingAPIGroup$Status$200 | Response$getAutoscalingV1APIResources$Status$200 | Response$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces$Status$200 | Response$listAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201 | Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$202 | Response$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler$Status$200 | Response$readAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201 | Response$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | Response$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$202 | Response$patchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | Response$patchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201 | Response$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$201 | Response$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$201 | Response$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces$Status$200 | Response$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList$Status$200 | Response$watchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | Response$getAutoscalingV2APIResources$Status$200 | Response$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces$Status$200 | Response$listAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201 | Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$202 | Response$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler$Status$200 | Response$readAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201 | Response$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | Response$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$202 | Response$patchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | Response$patchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201 | Response$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$201 | Response$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$201 | Response$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces$Status$200 | Response$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList$Status$200 | Response$watchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | Response$getBatchAPIGroup$Status$200 | Response$getBatchV1APIResources$Status$200 | Response$listBatchV1CronJobForAllNamespaces$Status$200 | Response$listBatchV1JobForAllNamespaces$Status$200 | Response$listBatchV1NamespacedCronJob$Status$200 | Response$createBatchV1NamespacedCronJob$Status$200 | Response$createBatchV1NamespacedCronJob$Status$201 | Response$createBatchV1NamespacedCronJob$Status$202 | Response$deleteBatchV1CollectionNamespacedCronJob$Status$200 | Response$readBatchV1NamespacedCronJob$Status$200 | Response$replaceBatchV1NamespacedCronJob$Status$200 | Response$replaceBatchV1NamespacedCronJob$Status$201 | Response$deleteBatchV1NamespacedCronJob$Status$200 | Response$deleteBatchV1NamespacedCronJob$Status$202 | Response$patchBatchV1NamespacedCronJob$Status$200 | Response$patchBatchV1NamespacedCronJob$Status$201 | Response$readBatchV1NamespacedCronJobStatus$Status$200 | Response$replaceBatchV1NamespacedCronJobStatus$Status$200 | Response$replaceBatchV1NamespacedCronJobStatus$Status$201 | Response$patchBatchV1NamespacedCronJobStatus$Status$200 | Response$patchBatchV1NamespacedCronJobStatus$Status$201 | Response$listBatchV1NamespacedJob$Status$200 | Response$createBatchV1NamespacedJob$Status$200 | Response$createBatchV1NamespacedJob$Status$201 | Response$createBatchV1NamespacedJob$Status$202 | Response$deleteBatchV1CollectionNamespacedJob$Status$200 | Response$readBatchV1NamespacedJob$Status$200 | Response$replaceBatchV1NamespacedJob$Status$200 | Response$replaceBatchV1NamespacedJob$Status$201 | Response$deleteBatchV1NamespacedJob$Status$200 | Response$deleteBatchV1NamespacedJob$Status$202 | Response$patchBatchV1NamespacedJob$Status$200 | Response$patchBatchV1NamespacedJob$Status$201 | Response$readBatchV1NamespacedJobStatus$Status$200 | Response$replaceBatchV1NamespacedJobStatus$Status$200 | Response$replaceBatchV1NamespacedJobStatus$Status$201 | Response$patchBatchV1NamespacedJobStatus$Status$200 | Response$patchBatchV1NamespacedJobStatus$Status$201 | Response$watchBatchV1CronJobListForAllNamespaces$Status$200 | Response$watchBatchV1JobListForAllNamespaces$Status$200 | Response$watchBatchV1NamespacedCronJobList$Status$200 | Response$watchBatchV1NamespacedCronJob$Status$200 | Response$watchBatchV1NamespacedJobList$Status$200 | Response$watchBatchV1NamespacedJob$Status$200 | Response$getCertificatesAPIGroup$Status$200 | Response$getCertificatesV1APIResources$Status$200 | Response$listCertificatesV1CertificateSigningRequest$Status$200 | Response$createCertificatesV1CertificateSigningRequest$Status$200 | Response$createCertificatesV1CertificateSigningRequest$Status$201 | Response$createCertificatesV1CertificateSigningRequest$Status$202 | Response$deleteCertificatesV1CollectionCertificateSigningRequest$Status$200 | Response$readCertificatesV1CertificateSigningRequest$Status$200 | Response$replaceCertificatesV1CertificateSigningRequest$Status$200 | Response$replaceCertificatesV1CertificateSigningRequest$Status$201 | Response$deleteCertificatesV1CertificateSigningRequest$Status$200 | Response$deleteCertificatesV1CertificateSigningRequest$Status$202 | Response$patchCertificatesV1CertificateSigningRequest$Status$200 | Response$patchCertificatesV1CertificateSigningRequest$Status$201 | Response$readCertificatesV1CertificateSigningRequestApproval$Status$200 | Response$replaceCertificatesV1CertificateSigningRequestApproval$Status$200 | Response$replaceCertificatesV1CertificateSigningRequestApproval$Status$201 | Response$patchCertificatesV1CertificateSigningRequestApproval$Status$200 | Response$patchCertificatesV1CertificateSigningRequestApproval$Status$201 | Response$readCertificatesV1CertificateSigningRequestStatus$Status$200 | Response$replaceCertificatesV1CertificateSigningRequestStatus$Status$200 | Response$replaceCertificatesV1CertificateSigningRequestStatus$Status$201 | Response$patchCertificatesV1CertificateSigningRequestStatus$Status$200 | Response$patchCertificatesV1CertificateSigningRequestStatus$Status$201 | Response$watchCertificatesV1CertificateSigningRequestList$Status$200 | Response$watchCertificatesV1CertificateSigningRequest$Status$200 | Response$getCertificatesV1alpha1APIResources$Status$200 | Response$listCertificatesV1alpha1ClusterTrustBundle$Status$200 | Response$createCertificatesV1alpha1ClusterTrustBundle$Status$200 | Response$createCertificatesV1alpha1ClusterTrustBundle$Status$201 | Response$createCertificatesV1alpha1ClusterTrustBundle$Status$202 | Response$deleteCertificatesV1alpha1CollectionClusterTrustBundle$Status$200 | Response$readCertificatesV1alpha1ClusterTrustBundle$Status$200 | Response$replaceCertificatesV1alpha1ClusterTrustBundle$Status$200 | Response$replaceCertificatesV1alpha1ClusterTrustBundle$Status$201 | Response$deleteCertificatesV1alpha1ClusterTrustBundle$Status$200 | Response$deleteCertificatesV1alpha1ClusterTrustBundle$Status$202 | Response$patchCertificatesV1alpha1ClusterTrustBundle$Status$200 | Response$patchCertificatesV1alpha1ClusterTrustBundle$Status$201 | Response$watchCertificatesV1alpha1ClusterTrustBundleList$Status$200 | Response$watchCertificatesV1alpha1ClusterTrustBundle$Status$200 | Response$getCoordinationAPIGroup$Status$200 | Response$getCoordinationV1APIResources$Status$200 | Response$listCoordinationV1LeaseForAllNamespaces$Status$200 | Response$listCoordinationV1NamespacedLease$Status$200 | Response$createCoordinationV1NamespacedLease$Status$200 | Response$createCoordinationV1NamespacedLease$Status$201 | Response$createCoordinationV1NamespacedLease$Status$202 | Response$deleteCoordinationV1CollectionNamespacedLease$Status$200 | Response$readCoordinationV1NamespacedLease$Status$200 | Response$replaceCoordinationV1NamespacedLease$Status$200 | Response$replaceCoordinationV1NamespacedLease$Status$201 | Response$deleteCoordinationV1NamespacedLease$Status$200 | Response$deleteCoordinationV1NamespacedLease$Status$202 | Response$patchCoordinationV1NamespacedLease$Status$200 | Response$patchCoordinationV1NamespacedLease$Status$201 | Response$watchCoordinationV1LeaseListForAllNamespaces$Status$200 | Response$watchCoordinationV1NamespacedLeaseList$Status$200 | Response$watchCoordinationV1NamespacedLease$Status$200 | Response$getDiscoveryAPIGroup$Status$200 | Response$getDiscoveryV1APIResources$Status$200 | Response$listDiscoveryV1EndpointSliceForAllNamespaces$Status$200 | Response$listDiscoveryV1NamespacedEndpointSlice$Status$200 | Response$createDiscoveryV1NamespacedEndpointSlice$Status$200 | Response$createDiscoveryV1NamespacedEndpointSlice$Status$201 | Response$createDiscoveryV1NamespacedEndpointSlice$Status$202 | Response$deleteDiscoveryV1CollectionNamespacedEndpointSlice$Status$200 | Response$readDiscoveryV1NamespacedEndpointSlice$Status$200 | Response$replaceDiscoveryV1NamespacedEndpointSlice$Status$200 | Response$replaceDiscoveryV1NamespacedEndpointSlice$Status$201 | Response$deleteDiscoveryV1NamespacedEndpointSlice$Status$200 | Response$deleteDiscoveryV1NamespacedEndpointSlice$Status$202 | Response$patchDiscoveryV1NamespacedEndpointSlice$Status$200 | Response$patchDiscoveryV1NamespacedEndpointSlice$Status$201 | Response$watchDiscoveryV1EndpointSliceListForAllNamespaces$Status$200 | Response$watchDiscoveryV1NamespacedEndpointSliceList$Status$200 | Response$watchDiscoveryV1NamespacedEndpointSlice$Status$200 | Response$getEventsAPIGroup$Status$200 | Response$getEventsV1APIResources$Status$200 | Response$listEventsV1EventForAllNamespaces$Status$200 | Response$listEventsV1NamespacedEvent$Status$200 | Response$createEventsV1NamespacedEvent$Status$200 | Response$createEventsV1NamespacedEvent$Status$201 | Response$createEventsV1NamespacedEvent$Status$202 | Response$deleteEventsV1CollectionNamespacedEvent$Status$200 | Response$readEventsV1NamespacedEvent$Status$200 | Response$replaceEventsV1NamespacedEvent$Status$200 | Response$replaceEventsV1NamespacedEvent$Status$201 | Response$deleteEventsV1NamespacedEvent$Status$200 | Response$deleteEventsV1NamespacedEvent$Status$202 | Response$patchEventsV1NamespacedEvent$Status$200 | Response$patchEventsV1NamespacedEvent$Status$201 | Response$watchEventsV1EventListForAllNamespaces$Status$200 | Response$watchEventsV1NamespacedEventList$Status$200 | Response$watchEventsV1NamespacedEvent$Status$200 | Response$getFlowcontrolApiserverAPIGroup$Status$200 | Response$getFlowcontrolApiserverV1beta2APIResources$Status$200 | Response$listFlowcontrolApiserverV1beta2FlowSchema$Status$200 | Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$200 | Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$201 | Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$202 | Response$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema$Status$200 | Response$readFlowcontrolApiserverV1beta2FlowSchema$Status$200 | Response$replaceFlowcontrolApiserverV1beta2FlowSchema$Status$200 | Response$replaceFlowcontrolApiserverV1beta2FlowSchema$Status$201 | Response$deleteFlowcontrolApiserverV1beta2FlowSchema$Status$200 | Response$deleteFlowcontrolApiserverV1beta2FlowSchema$Status$202 | Response$patchFlowcontrolApiserverV1beta2FlowSchema$Status$200 | Response$patchFlowcontrolApiserverV1beta2FlowSchema$Status$201 | Response$readFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$201 | Response$patchFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200 | Response$patchFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$201 | Response$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201 | Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$202 | Response$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration$Status$200 | Response$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201 | Response$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | Response$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$202 | Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201 | Response$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$201 | Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200 | Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$201 | Response$watchFlowcontrolApiserverV1beta2FlowSchemaList$Status$200 | Response$watchFlowcontrolApiserverV1beta2FlowSchema$Status$200 | Response$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList$Status$200 | Response$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | Response$getFlowcontrolApiserverV1beta3APIResources$Status$200 | Response$listFlowcontrolApiserverV1beta3FlowSchema$Status$200 | Response$createFlowcontrolApiserverV1beta3FlowSchema$Status$200 | Response$createFlowcontrolApiserverV1beta3FlowSchema$Status$201 | Response$createFlowcontrolApiserverV1beta3FlowSchema$Status$202 | Response$deleteFlowcontrolApiserverV1beta3CollectionFlowSchema$Status$200 | Response$readFlowcontrolApiserverV1beta3FlowSchema$Status$200 | Response$replaceFlowcontrolApiserverV1beta3FlowSchema$Status$200 | Response$replaceFlowcontrolApiserverV1beta3FlowSchema$Status$201 | Response$deleteFlowcontrolApiserverV1beta3FlowSchema$Status$200 | Response$deleteFlowcontrolApiserverV1beta3FlowSchema$Status$202 | Response$patchFlowcontrolApiserverV1beta3FlowSchema$Status$200 | Response$patchFlowcontrolApiserverV1beta3FlowSchema$Status$201 | Response$readFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$201 | Response$patchFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$200 | Response$patchFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$201 | Response$listFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200 | Response$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200 | Response$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$201 | Response$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$202 | Response$deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration$Status$200 | Response$readFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200 | Response$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200 | Response$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$201 | Response$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200 | Response$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$202 | Response$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200 | Response$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$201 | Response$readFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$201 | Response$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$200 | Response$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$201 | Response$watchFlowcontrolApiserverV1beta3FlowSchemaList$Status$200 | Response$watchFlowcontrolApiserverV1beta3FlowSchema$Status$200 | Response$watchFlowcontrolApiserverV1beta3PriorityLevelConfigurationList$Status$200 | Response$watchFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200 | Response$getInternalApiserverAPIGroup$Status$200 | Response$getInternalApiserverV1alpha1APIResources$Status$200 | Response$listInternalApiserverV1alpha1StorageVersion$Status$200 | Response$createInternalApiserverV1alpha1StorageVersion$Status$200 | Response$createInternalApiserverV1alpha1StorageVersion$Status$201 | Response$createInternalApiserverV1alpha1StorageVersion$Status$202 | Response$deleteInternalApiserverV1alpha1CollectionStorageVersion$Status$200 | Response$readInternalApiserverV1alpha1StorageVersion$Status$200 | Response$replaceInternalApiserverV1alpha1StorageVersion$Status$200 | Response$replaceInternalApiserverV1alpha1StorageVersion$Status$201 | Response$deleteInternalApiserverV1alpha1StorageVersion$Status$200 | Response$deleteInternalApiserverV1alpha1StorageVersion$Status$202 | Response$patchInternalApiserverV1alpha1StorageVersion$Status$200 | Response$patchInternalApiserverV1alpha1StorageVersion$Status$201 | Response$readInternalApiserverV1alpha1StorageVersionStatus$Status$200 | Response$replaceInternalApiserverV1alpha1StorageVersionStatus$Status$200 | Response$replaceInternalApiserverV1alpha1StorageVersionStatus$Status$201 | Response$patchInternalApiserverV1alpha1StorageVersionStatus$Status$200 | Response$patchInternalApiserverV1alpha1StorageVersionStatus$Status$201 | Response$watchInternalApiserverV1alpha1StorageVersionList$Status$200 | Response$watchInternalApiserverV1alpha1StorageVersion$Status$200 | Response$getNetworkingAPIGroup$Status$200 | Response$getNetworkingV1APIResources$Status$200 | Response$listNetworkingV1IngressClass$Status$200 | Response$createNetworkingV1IngressClass$Status$200 | Response$createNetworkingV1IngressClass$Status$201 | Response$createNetworkingV1IngressClass$Status$202 | Response$deleteNetworkingV1CollectionIngressClass$Status$200 | Response$readNetworkingV1IngressClass$Status$200 | Response$replaceNetworkingV1IngressClass$Status$200 | Response$replaceNetworkingV1IngressClass$Status$201 | Response$deleteNetworkingV1IngressClass$Status$200 | Response$deleteNetworkingV1IngressClass$Status$202 | Response$patchNetworkingV1IngressClass$Status$200 | Response$patchNetworkingV1IngressClass$Status$201 | Response$listNetworkingV1IngressForAllNamespaces$Status$200 | Response$listNetworkingV1NamespacedIngress$Status$200 | Response$createNetworkingV1NamespacedIngress$Status$200 | Response$createNetworkingV1NamespacedIngress$Status$201 | Response$createNetworkingV1NamespacedIngress$Status$202 | Response$deleteNetworkingV1CollectionNamespacedIngress$Status$200 | Response$readNetworkingV1NamespacedIngress$Status$200 | Response$replaceNetworkingV1NamespacedIngress$Status$200 | Response$replaceNetworkingV1NamespacedIngress$Status$201 | Response$deleteNetworkingV1NamespacedIngress$Status$200 | Response$deleteNetworkingV1NamespacedIngress$Status$202 | Response$patchNetworkingV1NamespacedIngress$Status$200 | Response$patchNetworkingV1NamespacedIngress$Status$201 | Response$readNetworkingV1NamespacedIngressStatus$Status$200 | Response$replaceNetworkingV1NamespacedIngressStatus$Status$200 | Response$replaceNetworkingV1NamespacedIngressStatus$Status$201 | Response$patchNetworkingV1NamespacedIngressStatus$Status$200 | Response$patchNetworkingV1NamespacedIngressStatus$Status$201 | Response$listNetworkingV1NamespacedNetworkPolicy$Status$200 | Response$createNetworkingV1NamespacedNetworkPolicy$Status$200 | Response$createNetworkingV1NamespacedNetworkPolicy$Status$201 | Response$createNetworkingV1NamespacedNetworkPolicy$Status$202 | Response$deleteNetworkingV1CollectionNamespacedNetworkPolicy$Status$200 | Response$readNetworkingV1NamespacedNetworkPolicy$Status$200 | Response$replaceNetworkingV1NamespacedNetworkPolicy$Status$200 | Response$replaceNetworkingV1NamespacedNetworkPolicy$Status$201 | Response$deleteNetworkingV1NamespacedNetworkPolicy$Status$200 | Response$deleteNetworkingV1NamespacedNetworkPolicy$Status$202 | Response$patchNetworkingV1NamespacedNetworkPolicy$Status$200 | Response$patchNetworkingV1NamespacedNetworkPolicy$Status$201 | Response$readNetworkingV1NamespacedNetworkPolicyStatus$Status$200 | Response$replaceNetworkingV1NamespacedNetworkPolicyStatus$Status$200 | Response$replaceNetworkingV1NamespacedNetworkPolicyStatus$Status$201 | Response$patchNetworkingV1NamespacedNetworkPolicyStatus$Status$200 | Response$patchNetworkingV1NamespacedNetworkPolicyStatus$Status$201 | Response$listNetworkingV1NetworkPolicyForAllNamespaces$Status$200 | Response$watchNetworkingV1IngressClassList$Status$200 | Response$watchNetworkingV1IngressClass$Status$200 | Response$watchNetworkingV1IngressListForAllNamespaces$Status$200 | Response$watchNetworkingV1NamespacedIngressList$Status$200 | Response$watchNetworkingV1NamespacedIngress$Status$200 | Response$watchNetworkingV1NamespacedNetworkPolicyList$Status$200 | Response$watchNetworkingV1NamespacedNetworkPolicy$Status$200 | Response$watchNetworkingV1NetworkPolicyListForAllNamespaces$Status$200 | Response$getNetworkingV1alpha1APIResources$Status$200 | Response$listNetworkingV1alpha1ClusterCIDR$Status$200 | Response$createNetworkingV1alpha1ClusterCIDR$Status$200 | Response$createNetworkingV1alpha1ClusterCIDR$Status$201 | Response$createNetworkingV1alpha1ClusterCIDR$Status$202 | Response$deleteNetworkingV1alpha1CollectionClusterCIDR$Status$200 | Response$readNetworkingV1alpha1ClusterCIDR$Status$200 | Response$replaceNetworkingV1alpha1ClusterCIDR$Status$200 | Response$replaceNetworkingV1alpha1ClusterCIDR$Status$201 | Response$deleteNetworkingV1alpha1ClusterCIDR$Status$200 | Response$deleteNetworkingV1alpha1ClusterCIDR$Status$202 | Response$patchNetworkingV1alpha1ClusterCIDR$Status$200 | Response$patchNetworkingV1alpha1ClusterCIDR$Status$201 | Response$listNetworkingV1alpha1IPAddress$Status$200 | Response$createNetworkingV1alpha1IPAddress$Status$200 | Response$createNetworkingV1alpha1IPAddress$Status$201 | Response$createNetworkingV1alpha1IPAddress$Status$202 | Response$deleteNetworkingV1alpha1CollectionIPAddress$Status$200 | Response$readNetworkingV1alpha1IPAddress$Status$200 | Response$replaceNetworkingV1alpha1IPAddress$Status$200 | Response$replaceNetworkingV1alpha1IPAddress$Status$201 | Response$deleteNetworkingV1alpha1IPAddress$Status$200 | Response$deleteNetworkingV1alpha1IPAddress$Status$202 | Response$patchNetworkingV1alpha1IPAddress$Status$200 | Response$patchNetworkingV1alpha1IPAddress$Status$201 | Response$watchNetworkingV1alpha1ClusterCIDRList$Status$200 | Response$watchNetworkingV1alpha1ClusterCIDR$Status$200 | Response$watchNetworkingV1alpha1IPAddressList$Status$200 | Response$watchNetworkingV1alpha1IPAddress$Status$200 | Response$getNodeAPIGroup$Status$200 | Response$getNodeV1APIResources$Status$200 | Response$listNodeV1RuntimeClass$Status$200 | Response$createNodeV1RuntimeClass$Status$200 | Response$createNodeV1RuntimeClass$Status$201 | Response$createNodeV1RuntimeClass$Status$202 | Response$deleteNodeV1CollectionRuntimeClass$Status$200 | Response$readNodeV1RuntimeClass$Status$200 | Response$replaceNodeV1RuntimeClass$Status$200 | Response$replaceNodeV1RuntimeClass$Status$201 | Response$deleteNodeV1RuntimeClass$Status$200 | Response$deleteNodeV1RuntimeClass$Status$202 | Response$patchNodeV1RuntimeClass$Status$200 | Response$patchNodeV1RuntimeClass$Status$201 | Response$watchNodeV1RuntimeClassList$Status$200 | Response$watchNodeV1RuntimeClass$Status$200 | Response$getPolicyAPIGroup$Status$200 | Response$getPolicyV1APIResources$Status$200 | Response$listPolicyV1NamespacedPodDisruptionBudget$Status$200 | Response$createPolicyV1NamespacedPodDisruptionBudget$Status$200 | Response$createPolicyV1NamespacedPodDisruptionBudget$Status$201 | Response$createPolicyV1NamespacedPodDisruptionBudget$Status$202 | Response$deletePolicyV1CollectionNamespacedPodDisruptionBudget$Status$200 | Response$readPolicyV1NamespacedPodDisruptionBudget$Status$200 | Response$replacePolicyV1NamespacedPodDisruptionBudget$Status$200 | Response$replacePolicyV1NamespacedPodDisruptionBudget$Status$201 | Response$deletePolicyV1NamespacedPodDisruptionBudget$Status$200 | Response$deletePolicyV1NamespacedPodDisruptionBudget$Status$202 | Response$patchPolicyV1NamespacedPodDisruptionBudget$Status$200 | Response$patchPolicyV1NamespacedPodDisruptionBudget$Status$201 | Response$readPolicyV1NamespacedPodDisruptionBudgetStatus$Status$200 | Response$replacePolicyV1NamespacedPodDisruptionBudgetStatus$Status$200 | Response$replacePolicyV1NamespacedPodDisruptionBudgetStatus$Status$201 | Response$patchPolicyV1NamespacedPodDisruptionBudgetStatus$Status$200 | Response$patchPolicyV1NamespacedPodDisruptionBudgetStatus$Status$201 | Response$listPolicyV1PodDisruptionBudgetForAllNamespaces$Status$200 | Response$watchPolicyV1NamespacedPodDisruptionBudgetList$Status$200 | Response$watchPolicyV1NamespacedPodDisruptionBudget$Status$200 | Response$watchPolicyV1PodDisruptionBudgetListForAllNamespaces$Status$200 | Response$getRbacAuthorizationAPIGroup$Status$200 | Response$getRbacAuthorizationV1APIResources$Status$200 | Response$listRbacAuthorizationV1ClusterRoleBinding$Status$200 | Response$createRbacAuthorizationV1ClusterRoleBinding$Status$200 | Response$createRbacAuthorizationV1ClusterRoleBinding$Status$201 | Response$createRbacAuthorizationV1ClusterRoleBinding$Status$202 | Response$deleteRbacAuthorizationV1CollectionClusterRoleBinding$Status$200 | Response$readRbacAuthorizationV1ClusterRoleBinding$Status$200 | Response$replaceRbacAuthorizationV1ClusterRoleBinding$Status$200 | Response$replaceRbacAuthorizationV1ClusterRoleBinding$Status$201 | Response$deleteRbacAuthorizationV1ClusterRoleBinding$Status$200 | Response$deleteRbacAuthorizationV1ClusterRoleBinding$Status$202 | Response$patchRbacAuthorizationV1ClusterRoleBinding$Status$200 | Response$patchRbacAuthorizationV1ClusterRoleBinding$Status$201 | Response$listRbacAuthorizationV1ClusterRole$Status$200 | Response$createRbacAuthorizationV1ClusterRole$Status$200 | Response$createRbacAuthorizationV1ClusterRole$Status$201 | Response$createRbacAuthorizationV1ClusterRole$Status$202 | Response$deleteRbacAuthorizationV1CollectionClusterRole$Status$200 | Response$readRbacAuthorizationV1ClusterRole$Status$200 | Response$replaceRbacAuthorizationV1ClusterRole$Status$200 | Response$replaceRbacAuthorizationV1ClusterRole$Status$201 | Response$deleteRbacAuthorizationV1ClusterRole$Status$200 | Response$deleteRbacAuthorizationV1ClusterRole$Status$202 | Response$patchRbacAuthorizationV1ClusterRole$Status$200 | Response$patchRbacAuthorizationV1ClusterRole$Status$201 | Response$listRbacAuthorizationV1NamespacedRoleBinding$Status$200 | Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$200 | Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$201 | Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$202 | Response$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding$Status$200 | Response$readRbacAuthorizationV1NamespacedRoleBinding$Status$200 | Response$replaceRbacAuthorizationV1NamespacedRoleBinding$Status$200 | Response$replaceRbacAuthorizationV1NamespacedRoleBinding$Status$201 | Response$deleteRbacAuthorizationV1NamespacedRoleBinding$Status$200 | Response$deleteRbacAuthorizationV1NamespacedRoleBinding$Status$202 | Response$patchRbacAuthorizationV1NamespacedRoleBinding$Status$200 | Response$patchRbacAuthorizationV1NamespacedRoleBinding$Status$201 | Response$listRbacAuthorizationV1NamespacedRole$Status$200 | Response$createRbacAuthorizationV1NamespacedRole$Status$200 | Response$createRbacAuthorizationV1NamespacedRole$Status$201 | Response$createRbacAuthorizationV1NamespacedRole$Status$202 | Response$deleteRbacAuthorizationV1CollectionNamespacedRole$Status$200 | Response$readRbacAuthorizationV1NamespacedRole$Status$200 | Response$replaceRbacAuthorizationV1NamespacedRole$Status$200 | Response$replaceRbacAuthorizationV1NamespacedRole$Status$201 | Response$deleteRbacAuthorizationV1NamespacedRole$Status$200 | Response$deleteRbacAuthorizationV1NamespacedRole$Status$202 | Response$patchRbacAuthorizationV1NamespacedRole$Status$200 | Response$patchRbacAuthorizationV1NamespacedRole$Status$201 | Response$listRbacAuthorizationV1RoleBindingForAllNamespaces$Status$200 | Response$listRbacAuthorizationV1RoleForAllNamespaces$Status$200 | Response$watchRbacAuthorizationV1ClusterRoleBindingList$Status$200 | Response$watchRbacAuthorizationV1ClusterRoleBinding$Status$200 | Response$watchRbacAuthorizationV1ClusterRoleList$Status$200 | Response$watchRbacAuthorizationV1ClusterRole$Status$200 | Response$watchRbacAuthorizationV1NamespacedRoleBindingList$Status$200 | Response$watchRbacAuthorizationV1NamespacedRoleBinding$Status$200 | Response$watchRbacAuthorizationV1NamespacedRoleList$Status$200 | Response$watchRbacAuthorizationV1NamespacedRole$Status$200 | Response$watchRbacAuthorizationV1RoleBindingListForAllNamespaces$Status$200 | Response$watchRbacAuthorizationV1RoleListForAllNamespaces$Status$200 | Response$getResourceAPIGroup$Status$200 | Response$getResourceV1alpha2APIResources$Status$200 | Response$listResourceV1alpha2NamespacedPodSchedulingContext$Status$200 | Response$createResourceV1alpha2NamespacedPodSchedulingContext$Status$200 | Response$createResourceV1alpha2NamespacedPodSchedulingContext$Status$201 | Response$createResourceV1alpha2NamespacedPodSchedulingContext$Status$202 | Response$deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext$Status$200 | Response$readResourceV1alpha2NamespacedPodSchedulingContext$Status$200 | Response$replaceResourceV1alpha2NamespacedPodSchedulingContext$Status$200 | Response$replaceResourceV1alpha2NamespacedPodSchedulingContext$Status$201 | Response$deleteResourceV1alpha2NamespacedPodSchedulingContext$Status$200 | Response$deleteResourceV1alpha2NamespacedPodSchedulingContext$Status$202 | Response$patchResourceV1alpha2NamespacedPodSchedulingContext$Status$200 | Response$patchResourceV1alpha2NamespacedPodSchedulingContext$Status$201 | Response$readResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$200 | Response$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$200 | Response$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$201 | Response$patchResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$200 | Response$patchResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$201 | Response$listResourceV1alpha2NamespacedResourceClaim$Status$200 | Response$createResourceV1alpha2NamespacedResourceClaim$Status$200 | Response$createResourceV1alpha2NamespacedResourceClaim$Status$201 | Response$createResourceV1alpha2NamespacedResourceClaim$Status$202 | Response$deleteResourceV1alpha2CollectionNamespacedResourceClaim$Status$200 | Response$readResourceV1alpha2NamespacedResourceClaim$Status$200 | Response$replaceResourceV1alpha2NamespacedResourceClaim$Status$200 | Response$replaceResourceV1alpha2NamespacedResourceClaim$Status$201 | Response$deleteResourceV1alpha2NamespacedResourceClaim$Status$200 | Response$deleteResourceV1alpha2NamespacedResourceClaim$Status$202 | Response$patchResourceV1alpha2NamespacedResourceClaim$Status$200 | Response$patchResourceV1alpha2NamespacedResourceClaim$Status$201 | Response$readResourceV1alpha2NamespacedResourceClaimStatus$Status$200 | Response$replaceResourceV1alpha2NamespacedResourceClaimStatus$Status$200 | Response$replaceResourceV1alpha2NamespacedResourceClaimStatus$Status$201 | Response$patchResourceV1alpha2NamespacedResourceClaimStatus$Status$200 | Response$patchResourceV1alpha2NamespacedResourceClaimStatus$Status$201 | Response$listResourceV1alpha2NamespacedResourceClaimTemplate$Status$200 | Response$createResourceV1alpha2NamespacedResourceClaimTemplate$Status$200 | Response$createResourceV1alpha2NamespacedResourceClaimTemplate$Status$201 | Response$createResourceV1alpha2NamespacedResourceClaimTemplate$Status$202 | Response$deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate$Status$200 | Response$readResourceV1alpha2NamespacedResourceClaimTemplate$Status$200 | Response$replaceResourceV1alpha2NamespacedResourceClaimTemplate$Status$200 | Response$replaceResourceV1alpha2NamespacedResourceClaimTemplate$Status$201 | Response$deleteResourceV1alpha2NamespacedResourceClaimTemplate$Status$200 | Response$deleteResourceV1alpha2NamespacedResourceClaimTemplate$Status$202 | Response$patchResourceV1alpha2NamespacedResourceClaimTemplate$Status$200 | Response$patchResourceV1alpha2NamespacedResourceClaimTemplate$Status$201 | Response$listResourceV1alpha2PodSchedulingContextForAllNamespaces$Status$200 | Response$listResourceV1alpha2ResourceClaimForAllNamespaces$Status$200 | Response$listResourceV1alpha2ResourceClaimTemplateForAllNamespaces$Status$200 | Response$listResourceV1alpha2ResourceClass$Status$200 | Response$createResourceV1alpha2ResourceClass$Status$200 | Response$createResourceV1alpha2ResourceClass$Status$201 | Response$createResourceV1alpha2ResourceClass$Status$202 | Response$deleteResourceV1alpha2CollectionResourceClass$Status$200 | Response$readResourceV1alpha2ResourceClass$Status$200 | Response$replaceResourceV1alpha2ResourceClass$Status$200 | Response$replaceResourceV1alpha2ResourceClass$Status$201 | Response$deleteResourceV1alpha2ResourceClass$Status$200 | Response$deleteResourceV1alpha2ResourceClass$Status$202 | Response$patchResourceV1alpha2ResourceClass$Status$200 | Response$patchResourceV1alpha2ResourceClass$Status$201 | Response$watchResourceV1alpha2NamespacedPodSchedulingContextList$Status$200 | Response$watchResourceV1alpha2NamespacedPodSchedulingContext$Status$200 | Response$watchResourceV1alpha2NamespacedResourceClaimList$Status$200 | Response$watchResourceV1alpha2NamespacedResourceClaim$Status$200 | Response$watchResourceV1alpha2NamespacedResourceClaimTemplateList$Status$200 | Response$watchResourceV1alpha2NamespacedResourceClaimTemplate$Status$200 | Response$watchResourceV1alpha2PodSchedulingContextListForAllNamespaces$Status$200 | Response$watchResourceV1alpha2ResourceClaimListForAllNamespaces$Status$200 | Response$watchResourceV1alpha2ResourceClaimTemplateListForAllNamespaces$Status$200 | Response$watchResourceV1alpha2ResourceClassList$Status$200 | Response$watchResourceV1alpha2ResourceClass$Status$200 | Response$getSchedulingAPIGroup$Status$200 | Response$getSchedulingV1APIResources$Status$200 | Response$listSchedulingV1PriorityClass$Status$200 | Response$createSchedulingV1PriorityClass$Status$200 | Response$createSchedulingV1PriorityClass$Status$201 | Response$createSchedulingV1PriorityClass$Status$202 | Response$deleteSchedulingV1CollectionPriorityClass$Status$200 | Response$readSchedulingV1PriorityClass$Status$200 | Response$replaceSchedulingV1PriorityClass$Status$200 | Response$replaceSchedulingV1PriorityClass$Status$201 | Response$deleteSchedulingV1PriorityClass$Status$200 | Response$deleteSchedulingV1PriorityClass$Status$202 | Response$patchSchedulingV1PriorityClass$Status$200 | Response$patchSchedulingV1PriorityClass$Status$201 | Response$watchSchedulingV1PriorityClassList$Status$200 | Response$watchSchedulingV1PriorityClass$Status$200 | Response$getStorageAPIGroup$Status$200 | Response$getStorageV1APIResources$Status$200 | Response$listStorageV1CSIDriver$Status$200 | Response$createStorageV1CSIDriver$Status$200 | Response$createStorageV1CSIDriver$Status$201 | Response$createStorageV1CSIDriver$Status$202 | Response$deleteStorageV1CollectionCSIDriver$Status$200 | Response$readStorageV1CSIDriver$Status$200 | Response$replaceStorageV1CSIDriver$Status$200 | Response$replaceStorageV1CSIDriver$Status$201 | Response$deleteStorageV1CSIDriver$Status$200 | Response$deleteStorageV1CSIDriver$Status$202 | Response$patchStorageV1CSIDriver$Status$200 | Response$patchStorageV1CSIDriver$Status$201 | Response$listStorageV1CSINode$Status$200 | Response$createStorageV1CSINode$Status$200 | Response$createStorageV1CSINode$Status$201 | Response$createStorageV1CSINode$Status$202 | Response$deleteStorageV1CollectionCSINode$Status$200 | Response$readStorageV1CSINode$Status$200 | Response$replaceStorageV1CSINode$Status$200 | Response$replaceStorageV1CSINode$Status$201 | Response$deleteStorageV1CSINode$Status$200 | Response$deleteStorageV1CSINode$Status$202 | Response$patchStorageV1CSINode$Status$200 | Response$patchStorageV1CSINode$Status$201 | Response$listStorageV1CSIStorageCapacityForAllNamespaces$Status$200 | Response$listStorageV1NamespacedCSIStorageCapacity$Status$200 | Response$createStorageV1NamespacedCSIStorageCapacity$Status$200 | Response$createStorageV1NamespacedCSIStorageCapacity$Status$201 | Response$createStorageV1NamespacedCSIStorageCapacity$Status$202 | Response$deleteStorageV1CollectionNamespacedCSIStorageCapacity$Status$200 | Response$readStorageV1NamespacedCSIStorageCapacity$Status$200 | Response$replaceStorageV1NamespacedCSIStorageCapacity$Status$200 | Response$replaceStorageV1NamespacedCSIStorageCapacity$Status$201 | Response$deleteStorageV1NamespacedCSIStorageCapacity$Status$200 | Response$deleteStorageV1NamespacedCSIStorageCapacity$Status$202 | Response$patchStorageV1NamespacedCSIStorageCapacity$Status$200 | Response$patchStorageV1NamespacedCSIStorageCapacity$Status$201 | Response$listStorageV1StorageClass$Status$200 | Response$createStorageV1StorageClass$Status$200 | Response$createStorageV1StorageClass$Status$201 | Response$createStorageV1StorageClass$Status$202 | Response$deleteStorageV1CollectionStorageClass$Status$200 | Response$readStorageV1StorageClass$Status$200 | Response$replaceStorageV1StorageClass$Status$200 | Response$replaceStorageV1StorageClass$Status$201 | Response$deleteStorageV1StorageClass$Status$200 | Response$deleteStorageV1StorageClass$Status$202 | Response$patchStorageV1StorageClass$Status$200 | Response$patchStorageV1StorageClass$Status$201 | Response$listStorageV1VolumeAttachment$Status$200 | Response$createStorageV1VolumeAttachment$Status$200 | Response$createStorageV1VolumeAttachment$Status$201 | Response$createStorageV1VolumeAttachment$Status$202 | Response$deleteStorageV1CollectionVolumeAttachment$Status$200 | Response$readStorageV1VolumeAttachment$Status$200 | Response$replaceStorageV1VolumeAttachment$Status$200 | Response$replaceStorageV1VolumeAttachment$Status$201 | Response$deleteStorageV1VolumeAttachment$Status$200 | Response$deleteStorageV1VolumeAttachment$Status$202 | Response$patchStorageV1VolumeAttachment$Status$200 | Response$patchStorageV1VolumeAttachment$Status$201 | Response$readStorageV1VolumeAttachmentStatus$Status$200 | Response$replaceStorageV1VolumeAttachmentStatus$Status$200 | Response$replaceStorageV1VolumeAttachmentStatus$Status$201 | Response$patchStorageV1VolumeAttachmentStatus$Status$200 | Response$patchStorageV1VolumeAttachmentStatus$Status$201 | Response$watchStorageV1CSIDriverList$Status$200 | Response$watchStorageV1CSIDriver$Status$200 | Response$watchStorageV1CSINodeList$Status$200 | Response$watchStorageV1CSINode$Status$200 | Response$watchStorageV1CSIStorageCapacityListForAllNamespaces$Status$200 | Response$watchStorageV1NamespacedCSIStorageCapacityList$Status$200 | Response$watchStorageV1NamespacedCSIStorageCapacity$Status$200 | Response$watchStorageV1StorageClassList$Status$200 | Response$watchStorageV1StorageClass$Status$200 | Response$watchStorageV1VolumeAttachmentList$Status$200 | Response$watchStorageV1VolumeAttachment$Status$200 | Response$getServiceAccountIssuerOpenIDKeyset$Status$200 | Response$getCodeVersion$Status$200;
declare namespace ErrorResponse {
    type getServiceAccountIssuerOpenIDConfiguration = void;
    type getCoreAPIVersions = void;
    type getCoreV1APIResources = void;
    type listCoreV1ComponentStatus = void;
    type readCoreV1ComponentStatus = void;
    type listCoreV1ConfigMapForAllNamespaces = void;
    type listCoreV1EndpointsForAllNamespaces = void;
    type listCoreV1EventForAllNamespaces = void;
    type listCoreV1LimitRangeForAllNamespaces = void;
    type listCoreV1Namespace = void;
    type createCoreV1Namespace = void;
    type createCoreV1NamespacedBinding = void;
    type listCoreV1NamespacedConfigMap = void;
    type createCoreV1NamespacedConfigMap = void;
    type deleteCoreV1CollectionNamespacedConfigMap = void;
    type readCoreV1NamespacedConfigMap = void;
    type replaceCoreV1NamespacedConfigMap = void;
    type deleteCoreV1NamespacedConfigMap = void;
    type patchCoreV1NamespacedConfigMap = void;
    type listCoreV1NamespacedEndpoints = void;
    type createCoreV1NamespacedEndpoints = void;
    type deleteCoreV1CollectionNamespacedEndpoints = void;
    type readCoreV1NamespacedEndpoints = void;
    type replaceCoreV1NamespacedEndpoints = void;
    type deleteCoreV1NamespacedEndpoints = void;
    type patchCoreV1NamespacedEndpoints = void;
    type listCoreV1NamespacedEvent = void;
    type createCoreV1NamespacedEvent = void;
    type deleteCoreV1CollectionNamespacedEvent = void;
    type readCoreV1NamespacedEvent = void;
    type replaceCoreV1NamespacedEvent = void;
    type deleteCoreV1NamespacedEvent = void;
    type patchCoreV1NamespacedEvent = void;
    type listCoreV1NamespacedLimitRange = void;
    type createCoreV1NamespacedLimitRange = void;
    type deleteCoreV1CollectionNamespacedLimitRange = void;
    type readCoreV1NamespacedLimitRange = void;
    type replaceCoreV1NamespacedLimitRange = void;
    type deleteCoreV1NamespacedLimitRange = void;
    type patchCoreV1NamespacedLimitRange = void;
    type listCoreV1NamespacedPersistentVolumeClaim = void;
    type createCoreV1NamespacedPersistentVolumeClaim = void;
    type deleteCoreV1CollectionNamespacedPersistentVolumeClaim = void;
    type readCoreV1NamespacedPersistentVolumeClaim = void;
    type replaceCoreV1NamespacedPersistentVolumeClaim = void;
    type deleteCoreV1NamespacedPersistentVolumeClaim = void;
    type patchCoreV1NamespacedPersistentVolumeClaim = void;
    type readCoreV1NamespacedPersistentVolumeClaimStatus = void;
    type replaceCoreV1NamespacedPersistentVolumeClaimStatus = void;
    type patchCoreV1NamespacedPersistentVolumeClaimStatus = void;
    type listCoreV1NamespacedPod = void;
    type createCoreV1NamespacedPod = void;
    type deleteCoreV1CollectionNamespacedPod = void;
    type readCoreV1NamespacedPod = void;
    type replaceCoreV1NamespacedPod = void;
    type deleteCoreV1NamespacedPod = void;
    type patchCoreV1NamespacedPod = void;
    type connectCoreV1GetNamespacedPodAttach = void;
    type connectCoreV1PostNamespacedPodAttach = void;
    type createCoreV1NamespacedPodBinding = void;
    type readCoreV1NamespacedPodEphemeralcontainers = void;
    type replaceCoreV1NamespacedPodEphemeralcontainers = void;
    type patchCoreV1NamespacedPodEphemeralcontainers = void;
    type createCoreV1NamespacedPodEviction = void;
    type connectCoreV1GetNamespacedPodExec = void;
    type connectCoreV1PostNamespacedPodExec = void;
    type readCoreV1NamespacedPodLog = void;
    type connectCoreV1GetNamespacedPodPortforward = void;
    type connectCoreV1PostNamespacedPodPortforward = void;
    type connectCoreV1GetNamespacedPodProxy = void;
    type connectCoreV1PutNamespacedPodProxy = void;
    type connectCoreV1PostNamespacedPodProxy = void;
    type connectCoreV1DeleteNamespacedPodProxy = void;
    type connectCoreV1OptionsNamespacedPodProxy = void;
    type connectCoreV1HeadNamespacedPodProxy = void;
    type connectCoreV1PatchNamespacedPodProxy = void;
    type connectCoreV1GetNamespacedPodProxyWithPath = void;
    type connectCoreV1PutNamespacedPodProxyWithPath = void;
    type connectCoreV1PostNamespacedPodProxyWithPath = void;
    type connectCoreV1DeleteNamespacedPodProxyWithPath = void;
    type connectCoreV1OptionsNamespacedPodProxyWithPath = void;
    type connectCoreV1HeadNamespacedPodProxyWithPath = void;
    type connectCoreV1PatchNamespacedPodProxyWithPath = void;
    type readCoreV1NamespacedPodStatus = void;
    type replaceCoreV1NamespacedPodStatus = void;
    type patchCoreV1NamespacedPodStatus = void;
    type listCoreV1NamespacedPodTemplate = void;
    type createCoreV1NamespacedPodTemplate = void;
    type deleteCoreV1CollectionNamespacedPodTemplate = void;
    type readCoreV1NamespacedPodTemplate = void;
    type replaceCoreV1NamespacedPodTemplate = void;
    type deleteCoreV1NamespacedPodTemplate = void;
    type patchCoreV1NamespacedPodTemplate = void;
    type listCoreV1NamespacedReplicationController = void;
    type createCoreV1NamespacedReplicationController = void;
    type deleteCoreV1CollectionNamespacedReplicationController = void;
    type readCoreV1NamespacedReplicationController = void;
    type replaceCoreV1NamespacedReplicationController = void;
    type deleteCoreV1NamespacedReplicationController = void;
    type patchCoreV1NamespacedReplicationController = void;
    type readCoreV1NamespacedReplicationControllerScale = void;
    type replaceCoreV1NamespacedReplicationControllerScale = void;
    type patchCoreV1NamespacedReplicationControllerScale = void;
    type readCoreV1NamespacedReplicationControllerStatus = void;
    type replaceCoreV1NamespacedReplicationControllerStatus = void;
    type patchCoreV1NamespacedReplicationControllerStatus = void;
    type listCoreV1NamespacedResourceQuota = void;
    type createCoreV1NamespacedResourceQuota = void;
    type deleteCoreV1CollectionNamespacedResourceQuota = void;
    type readCoreV1NamespacedResourceQuota = void;
    type replaceCoreV1NamespacedResourceQuota = void;
    type deleteCoreV1NamespacedResourceQuota = void;
    type patchCoreV1NamespacedResourceQuota = void;
    type readCoreV1NamespacedResourceQuotaStatus = void;
    type replaceCoreV1NamespacedResourceQuotaStatus = void;
    type patchCoreV1NamespacedResourceQuotaStatus = void;
    type listCoreV1NamespacedSecret = void;
    type createCoreV1NamespacedSecret = void;
    type deleteCoreV1CollectionNamespacedSecret = void;
    type readCoreV1NamespacedSecret = void;
    type replaceCoreV1NamespacedSecret = void;
    type deleteCoreV1NamespacedSecret = void;
    type patchCoreV1NamespacedSecret = void;
    type listCoreV1NamespacedServiceAccount = void;
    type createCoreV1NamespacedServiceAccount = void;
    type deleteCoreV1CollectionNamespacedServiceAccount = void;
    type readCoreV1NamespacedServiceAccount = void;
    type replaceCoreV1NamespacedServiceAccount = void;
    type deleteCoreV1NamespacedServiceAccount = void;
    type patchCoreV1NamespacedServiceAccount = void;
    type createCoreV1NamespacedServiceAccountToken = void;
    type listCoreV1NamespacedService = void;
    type createCoreV1NamespacedService = void;
    type deleteCoreV1CollectionNamespacedService = void;
    type readCoreV1NamespacedService = void;
    type replaceCoreV1NamespacedService = void;
    type deleteCoreV1NamespacedService = void;
    type patchCoreV1NamespacedService = void;
    type connectCoreV1GetNamespacedServiceProxy = void;
    type connectCoreV1PutNamespacedServiceProxy = void;
    type connectCoreV1PostNamespacedServiceProxy = void;
    type connectCoreV1DeleteNamespacedServiceProxy = void;
    type connectCoreV1OptionsNamespacedServiceProxy = void;
    type connectCoreV1HeadNamespacedServiceProxy = void;
    type connectCoreV1PatchNamespacedServiceProxy = void;
    type connectCoreV1GetNamespacedServiceProxyWithPath = void;
    type connectCoreV1PutNamespacedServiceProxyWithPath = void;
    type connectCoreV1PostNamespacedServiceProxyWithPath = void;
    type connectCoreV1DeleteNamespacedServiceProxyWithPath = void;
    type connectCoreV1OptionsNamespacedServiceProxyWithPath = void;
    type connectCoreV1HeadNamespacedServiceProxyWithPath = void;
    type connectCoreV1PatchNamespacedServiceProxyWithPath = void;
    type readCoreV1NamespacedServiceStatus = void;
    type replaceCoreV1NamespacedServiceStatus = void;
    type patchCoreV1NamespacedServiceStatus = void;
    type readCoreV1Namespace = void;
    type replaceCoreV1Namespace = void;
    type deleteCoreV1Namespace = void;
    type patchCoreV1Namespace = void;
    type replaceCoreV1NamespaceFinalize = void;
    type readCoreV1NamespaceStatus = void;
    type replaceCoreV1NamespaceStatus = void;
    type patchCoreV1NamespaceStatus = void;
    type listCoreV1Node = void;
    type createCoreV1Node = void;
    type deleteCoreV1CollectionNode = void;
    type readCoreV1Node = void;
    type replaceCoreV1Node = void;
    type deleteCoreV1Node = void;
    type patchCoreV1Node = void;
    type connectCoreV1GetNodeProxy = void;
    type connectCoreV1PutNodeProxy = void;
    type connectCoreV1PostNodeProxy = void;
    type connectCoreV1DeleteNodeProxy = void;
    type connectCoreV1OptionsNodeProxy = void;
    type connectCoreV1HeadNodeProxy = void;
    type connectCoreV1PatchNodeProxy = void;
    type connectCoreV1GetNodeProxyWithPath = void;
    type connectCoreV1PutNodeProxyWithPath = void;
    type connectCoreV1PostNodeProxyWithPath = void;
    type connectCoreV1DeleteNodeProxyWithPath = void;
    type connectCoreV1OptionsNodeProxyWithPath = void;
    type connectCoreV1HeadNodeProxyWithPath = void;
    type connectCoreV1PatchNodeProxyWithPath = void;
    type readCoreV1NodeStatus = void;
    type replaceCoreV1NodeStatus = void;
    type patchCoreV1NodeStatus = void;
    type listCoreV1PersistentVolumeClaimForAllNamespaces = void;
    type listCoreV1PersistentVolume = void;
    type createCoreV1PersistentVolume = void;
    type deleteCoreV1CollectionPersistentVolume = void;
    type readCoreV1PersistentVolume = void;
    type replaceCoreV1PersistentVolume = void;
    type deleteCoreV1PersistentVolume = void;
    type patchCoreV1PersistentVolume = void;
    type readCoreV1PersistentVolumeStatus = void;
    type replaceCoreV1PersistentVolumeStatus = void;
    type patchCoreV1PersistentVolumeStatus = void;
    type listCoreV1PodForAllNamespaces = void;
    type listCoreV1PodTemplateForAllNamespaces = void;
    type listCoreV1ReplicationControllerForAllNamespaces = void;
    type listCoreV1ResourceQuotaForAllNamespaces = void;
    type listCoreV1SecretForAllNamespaces = void;
    type listCoreV1ServiceAccountForAllNamespaces = void;
    type listCoreV1ServiceForAllNamespaces = void;
    type watchCoreV1ConfigMapListForAllNamespaces = void;
    type watchCoreV1EndpointsListForAllNamespaces = void;
    type watchCoreV1EventListForAllNamespaces = void;
    type watchCoreV1LimitRangeListForAllNamespaces = void;
    type watchCoreV1NamespaceList = void;
    type watchCoreV1NamespacedConfigMapList = void;
    type watchCoreV1NamespacedConfigMap = void;
    type watchCoreV1NamespacedEndpointsList = void;
    type watchCoreV1NamespacedEndpoints = void;
    type watchCoreV1NamespacedEventList = void;
    type watchCoreV1NamespacedEvent = void;
    type watchCoreV1NamespacedLimitRangeList = void;
    type watchCoreV1NamespacedLimitRange = void;
    type watchCoreV1NamespacedPersistentVolumeClaimList = void;
    type watchCoreV1NamespacedPersistentVolumeClaim = void;
    type watchCoreV1NamespacedPodList = void;
    type watchCoreV1NamespacedPod = void;
    type watchCoreV1NamespacedPodTemplateList = void;
    type watchCoreV1NamespacedPodTemplate = void;
    type watchCoreV1NamespacedReplicationControllerList = void;
    type watchCoreV1NamespacedReplicationController = void;
    type watchCoreV1NamespacedResourceQuotaList = void;
    type watchCoreV1NamespacedResourceQuota = void;
    type watchCoreV1NamespacedSecretList = void;
    type watchCoreV1NamespacedSecret = void;
    type watchCoreV1NamespacedServiceAccountList = void;
    type watchCoreV1NamespacedServiceAccount = void;
    type watchCoreV1NamespacedServiceList = void;
    type watchCoreV1NamespacedService = void;
    type watchCoreV1Namespace = void;
    type watchCoreV1NodeList = void;
    type watchCoreV1Node = void;
    type watchCoreV1PersistentVolumeClaimListForAllNamespaces = void;
    type watchCoreV1PersistentVolumeList = void;
    type watchCoreV1PersistentVolume = void;
    type watchCoreV1PodListForAllNamespaces = void;
    type watchCoreV1PodTemplateListForAllNamespaces = void;
    type watchCoreV1ReplicationControllerListForAllNamespaces = void;
    type watchCoreV1ResourceQuotaListForAllNamespaces = void;
    type watchCoreV1SecretListForAllNamespaces = void;
    type watchCoreV1ServiceAccountListForAllNamespaces = void;
    type watchCoreV1ServiceListForAllNamespaces = void;
    type getAPIVersions = void;
    type getAdmissionregistrationAPIGroup = void;
    type getAdmissionregistrationV1APIResources = void;
    type listAdmissionregistrationV1MutatingWebhookConfiguration = void;
    type createAdmissionregistrationV1MutatingWebhookConfiguration = void;
    type deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration = void;
    type readAdmissionregistrationV1MutatingWebhookConfiguration = void;
    type replaceAdmissionregistrationV1MutatingWebhookConfiguration = void;
    type deleteAdmissionregistrationV1MutatingWebhookConfiguration = void;
    type patchAdmissionregistrationV1MutatingWebhookConfiguration = void;
    type listAdmissionregistrationV1ValidatingWebhookConfiguration = void;
    type createAdmissionregistrationV1ValidatingWebhookConfiguration = void;
    type deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration = void;
    type readAdmissionregistrationV1ValidatingWebhookConfiguration = void;
    type replaceAdmissionregistrationV1ValidatingWebhookConfiguration = void;
    type deleteAdmissionregistrationV1ValidatingWebhookConfiguration = void;
    type patchAdmissionregistrationV1ValidatingWebhookConfiguration = void;
    type watchAdmissionregistrationV1MutatingWebhookConfigurationList = void;
    type watchAdmissionregistrationV1MutatingWebhookConfiguration = void;
    type watchAdmissionregistrationV1ValidatingWebhookConfigurationList = void;
    type watchAdmissionregistrationV1ValidatingWebhookConfiguration = void;
    type getAdmissionregistrationV1alpha1APIResources = void;
    type listAdmissionregistrationV1alpha1ValidatingAdmissionPolicy = void;
    type createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy = void;
    type deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy = void;
    type readAdmissionregistrationV1alpha1ValidatingAdmissionPolicy = void;
    type replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy = void;
    type deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy = void;
    type patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy = void;
    type readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus = void;
    type replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus = void;
    type patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus = void;
    type listAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding = void;
    type createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding = void;
    type deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding = void;
    type readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding = void;
    type replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding = void;
    type deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding = void;
    type patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding = void;
    type watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyList = void;
    type watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy = void;
    type watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBindingList = void;
    type watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding = void;
    type getApiextensionsAPIGroup = void;
    type getApiextensionsV1APIResources = void;
    type listApiextensionsV1CustomResourceDefinition = void;
    type createApiextensionsV1CustomResourceDefinition = void;
    type deleteApiextensionsV1CollectionCustomResourceDefinition = void;
    type readApiextensionsV1CustomResourceDefinition = void;
    type replaceApiextensionsV1CustomResourceDefinition = void;
    type deleteApiextensionsV1CustomResourceDefinition = void;
    type patchApiextensionsV1CustomResourceDefinition = void;
    type readApiextensionsV1CustomResourceDefinitionStatus = void;
    type replaceApiextensionsV1CustomResourceDefinitionStatus = void;
    type patchApiextensionsV1CustomResourceDefinitionStatus = void;
    type watchApiextensionsV1CustomResourceDefinitionList = void;
    type watchApiextensionsV1CustomResourceDefinition = void;
    type getApiregistrationAPIGroup = void;
    type getApiregistrationV1APIResources = void;
    type listApiregistrationV1APIService = void;
    type createApiregistrationV1APIService = void;
    type deleteApiregistrationV1CollectionAPIService = void;
    type readApiregistrationV1APIService = void;
    type replaceApiregistrationV1APIService = void;
    type deleteApiregistrationV1APIService = void;
    type patchApiregistrationV1APIService = void;
    type readApiregistrationV1APIServiceStatus = void;
    type replaceApiregistrationV1APIServiceStatus = void;
    type patchApiregistrationV1APIServiceStatus = void;
    type watchApiregistrationV1APIServiceList = void;
    type watchApiregistrationV1APIService = void;
    type getAppsAPIGroup = void;
    type getAppsV1APIResources = void;
    type listAppsV1ControllerRevisionForAllNamespaces = void;
    type listAppsV1DaemonSetForAllNamespaces = void;
    type listAppsV1DeploymentForAllNamespaces = void;
    type listAppsV1NamespacedControllerRevision = void;
    type createAppsV1NamespacedControllerRevision = void;
    type deleteAppsV1CollectionNamespacedControllerRevision = void;
    type readAppsV1NamespacedControllerRevision = void;
    type replaceAppsV1NamespacedControllerRevision = void;
    type deleteAppsV1NamespacedControllerRevision = void;
    type patchAppsV1NamespacedControllerRevision = void;
    type listAppsV1NamespacedDaemonSet = void;
    type createAppsV1NamespacedDaemonSet = void;
    type deleteAppsV1CollectionNamespacedDaemonSet = void;
    type readAppsV1NamespacedDaemonSet = void;
    type replaceAppsV1NamespacedDaemonSet = void;
    type deleteAppsV1NamespacedDaemonSet = void;
    type patchAppsV1NamespacedDaemonSet = void;
    type readAppsV1NamespacedDaemonSetStatus = void;
    type replaceAppsV1NamespacedDaemonSetStatus = void;
    type patchAppsV1NamespacedDaemonSetStatus = void;
    type listAppsV1NamespacedDeployment = void;
    type createAppsV1NamespacedDeployment = void;
    type deleteAppsV1CollectionNamespacedDeployment = void;
    type readAppsV1NamespacedDeployment = void;
    type replaceAppsV1NamespacedDeployment = void;
    type deleteAppsV1NamespacedDeployment = void;
    type patchAppsV1NamespacedDeployment = void;
    type readAppsV1NamespacedDeploymentScale = void;
    type replaceAppsV1NamespacedDeploymentScale = void;
    type patchAppsV1NamespacedDeploymentScale = void;
    type readAppsV1NamespacedDeploymentStatus = void;
    type replaceAppsV1NamespacedDeploymentStatus = void;
    type patchAppsV1NamespacedDeploymentStatus = void;
    type listAppsV1NamespacedReplicaSet = void;
    type createAppsV1NamespacedReplicaSet = void;
    type deleteAppsV1CollectionNamespacedReplicaSet = void;
    type readAppsV1NamespacedReplicaSet = void;
    type replaceAppsV1NamespacedReplicaSet = void;
    type deleteAppsV1NamespacedReplicaSet = void;
    type patchAppsV1NamespacedReplicaSet = void;
    type readAppsV1NamespacedReplicaSetScale = void;
    type replaceAppsV1NamespacedReplicaSetScale = void;
    type patchAppsV1NamespacedReplicaSetScale = void;
    type readAppsV1NamespacedReplicaSetStatus = void;
    type replaceAppsV1NamespacedReplicaSetStatus = void;
    type patchAppsV1NamespacedReplicaSetStatus = void;
    type listAppsV1NamespacedStatefulSet = void;
    type createAppsV1NamespacedStatefulSet = void;
    type deleteAppsV1CollectionNamespacedStatefulSet = void;
    type readAppsV1NamespacedStatefulSet = void;
    type replaceAppsV1NamespacedStatefulSet = void;
    type deleteAppsV1NamespacedStatefulSet = void;
    type patchAppsV1NamespacedStatefulSet = void;
    type readAppsV1NamespacedStatefulSetScale = void;
    type replaceAppsV1NamespacedStatefulSetScale = void;
    type patchAppsV1NamespacedStatefulSetScale = void;
    type readAppsV1NamespacedStatefulSetStatus = void;
    type replaceAppsV1NamespacedStatefulSetStatus = void;
    type patchAppsV1NamespacedStatefulSetStatus = void;
    type listAppsV1ReplicaSetForAllNamespaces = void;
    type listAppsV1StatefulSetForAllNamespaces = void;
    type watchAppsV1ControllerRevisionListForAllNamespaces = void;
    type watchAppsV1DaemonSetListForAllNamespaces = void;
    type watchAppsV1DeploymentListForAllNamespaces = void;
    type watchAppsV1NamespacedControllerRevisionList = void;
    type watchAppsV1NamespacedControllerRevision = void;
    type watchAppsV1NamespacedDaemonSetList = void;
    type watchAppsV1NamespacedDaemonSet = void;
    type watchAppsV1NamespacedDeploymentList = void;
    type watchAppsV1NamespacedDeployment = void;
    type watchAppsV1NamespacedReplicaSetList = void;
    type watchAppsV1NamespacedReplicaSet = void;
    type watchAppsV1NamespacedStatefulSetList = void;
    type watchAppsV1NamespacedStatefulSet = void;
    type watchAppsV1ReplicaSetListForAllNamespaces = void;
    type watchAppsV1StatefulSetListForAllNamespaces = void;
    type getAuthenticationAPIGroup = void;
    type getAuthenticationV1APIResources = void;
    type createAuthenticationV1TokenReview = void;
    type getAuthenticationV1alpha1APIResources = void;
    type createAuthenticationV1alpha1SelfSubjectReview = void;
    type getAuthenticationV1beta1APIResources = void;
    type createAuthenticationV1beta1SelfSubjectReview = void;
    type getAuthorizationAPIGroup = void;
    type getAuthorizationV1APIResources = void;
    type createAuthorizationV1NamespacedLocalSubjectAccessReview = void;
    type createAuthorizationV1SelfSubjectAccessReview = void;
    type createAuthorizationV1SelfSubjectRulesReview = void;
    type createAuthorizationV1SubjectAccessReview = void;
    type getAutoscalingAPIGroup = void;
    type getAutoscalingV1APIResources = void;
    type listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces = void;
    type listAutoscalingV1NamespacedHorizontalPodAutoscaler = void;
    type createAutoscalingV1NamespacedHorizontalPodAutoscaler = void;
    type deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler = void;
    type readAutoscalingV1NamespacedHorizontalPodAutoscaler = void;
    type replaceAutoscalingV1NamespacedHorizontalPodAutoscaler = void;
    type deleteAutoscalingV1NamespacedHorizontalPodAutoscaler = void;
    type patchAutoscalingV1NamespacedHorizontalPodAutoscaler = void;
    type readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus = void;
    type replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus = void;
    type patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus = void;
    type watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces = void;
    type watchAutoscalingV1NamespacedHorizontalPodAutoscalerList = void;
    type watchAutoscalingV1NamespacedHorizontalPodAutoscaler = void;
    type getAutoscalingV2APIResources = void;
    type listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces = void;
    type listAutoscalingV2NamespacedHorizontalPodAutoscaler = void;
    type createAutoscalingV2NamespacedHorizontalPodAutoscaler = void;
    type deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler = void;
    type readAutoscalingV2NamespacedHorizontalPodAutoscaler = void;
    type replaceAutoscalingV2NamespacedHorizontalPodAutoscaler = void;
    type deleteAutoscalingV2NamespacedHorizontalPodAutoscaler = void;
    type patchAutoscalingV2NamespacedHorizontalPodAutoscaler = void;
    type readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus = void;
    type replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus = void;
    type patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus = void;
    type watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces = void;
    type watchAutoscalingV2NamespacedHorizontalPodAutoscalerList = void;
    type watchAutoscalingV2NamespacedHorizontalPodAutoscaler = void;
    type getBatchAPIGroup = void;
    type getBatchV1APIResources = void;
    type listBatchV1CronJobForAllNamespaces = void;
    type listBatchV1JobForAllNamespaces = void;
    type listBatchV1NamespacedCronJob = void;
    type createBatchV1NamespacedCronJob = void;
    type deleteBatchV1CollectionNamespacedCronJob = void;
    type readBatchV1NamespacedCronJob = void;
    type replaceBatchV1NamespacedCronJob = void;
    type deleteBatchV1NamespacedCronJob = void;
    type patchBatchV1NamespacedCronJob = void;
    type readBatchV1NamespacedCronJobStatus = void;
    type replaceBatchV1NamespacedCronJobStatus = void;
    type patchBatchV1NamespacedCronJobStatus = void;
    type listBatchV1NamespacedJob = void;
    type createBatchV1NamespacedJob = void;
    type deleteBatchV1CollectionNamespacedJob = void;
    type readBatchV1NamespacedJob = void;
    type replaceBatchV1NamespacedJob = void;
    type deleteBatchV1NamespacedJob = void;
    type patchBatchV1NamespacedJob = void;
    type readBatchV1NamespacedJobStatus = void;
    type replaceBatchV1NamespacedJobStatus = void;
    type patchBatchV1NamespacedJobStatus = void;
    type watchBatchV1CronJobListForAllNamespaces = void;
    type watchBatchV1JobListForAllNamespaces = void;
    type watchBatchV1NamespacedCronJobList = void;
    type watchBatchV1NamespacedCronJob = void;
    type watchBatchV1NamespacedJobList = void;
    type watchBatchV1NamespacedJob = void;
    type getCertificatesAPIGroup = void;
    type getCertificatesV1APIResources = void;
    type listCertificatesV1CertificateSigningRequest = void;
    type createCertificatesV1CertificateSigningRequest = void;
    type deleteCertificatesV1CollectionCertificateSigningRequest = void;
    type readCertificatesV1CertificateSigningRequest = void;
    type replaceCertificatesV1CertificateSigningRequest = void;
    type deleteCertificatesV1CertificateSigningRequest = void;
    type patchCertificatesV1CertificateSigningRequest = void;
    type readCertificatesV1CertificateSigningRequestApproval = void;
    type replaceCertificatesV1CertificateSigningRequestApproval = void;
    type patchCertificatesV1CertificateSigningRequestApproval = void;
    type readCertificatesV1CertificateSigningRequestStatus = void;
    type replaceCertificatesV1CertificateSigningRequestStatus = void;
    type patchCertificatesV1CertificateSigningRequestStatus = void;
    type watchCertificatesV1CertificateSigningRequestList = void;
    type watchCertificatesV1CertificateSigningRequest = void;
    type getCertificatesV1alpha1APIResources = void;
    type listCertificatesV1alpha1ClusterTrustBundle = void;
    type createCertificatesV1alpha1ClusterTrustBundle = void;
    type deleteCertificatesV1alpha1CollectionClusterTrustBundle = void;
    type readCertificatesV1alpha1ClusterTrustBundle = void;
    type replaceCertificatesV1alpha1ClusterTrustBundle = void;
    type deleteCertificatesV1alpha1ClusterTrustBundle = void;
    type patchCertificatesV1alpha1ClusterTrustBundle = void;
    type watchCertificatesV1alpha1ClusterTrustBundleList = void;
    type watchCertificatesV1alpha1ClusterTrustBundle = void;
    type getCoordinationAPIGroup = void;
    type getCoordinationV1APIResources = void;
    type listCoordinationV1LeaseForAllNamespaces = void;
    type listCoordinationV1NamespacedLease = void;
    type createCoordinationV1NamespacedLease = void;
    type deleteCoordinationV1CollectionNamespacedLease = void;
    type readCoordinationV1NamespacedLease = void;
    type replaceCoordinationV1NamespacedLease = void;
    type deleteCoordinationV1NamespacedLease = void;
    type patchCoordinationV1NamespacedLease = void;
    type watchCoordinationV1LeaseListForAllNamespaces = void;
    type watchCoordinationV1NamespacedLeaseList = void;
    type watchCoordinationV1NamespacedLease = void;
    type getDiscoveryAPIGroup = void;
    type getDiscoveryV1APIResources = void;
    type listDiscoveryV1EndpointSliceForAllNamespaces = void;
    type listDiscoveryV1NamespacedEndpointSlice = void;
    type createDiscoveryV1NamespacedEndpointSlice = void;
    type deleteDiscoveryV1CollectionNamespacedEndpointSlice = void;
    type readDiscoveryV1NamespacedEndpointSlice = void;
    type replaceDiscoveryV1NamespacedEndpointSlice = void;
    type deleteDiscoveryV1NamespacedEndpointSlice = void;
    type patchDiscoveryV1NamespacedEndpointSlice = void;
    type watchDiscoveryV1EndpointSliceListForAllNamespaces = void;
    type watchDiscoveryV1NamespacedEndpointSliceList = void;
    type watchDiscoveryV1NamespacedEndpointSlice = void;
    type getEventsAPIGroup = void;
    type getEventsV1APIResources = void;
    type listEventsV1EventForAllNamespaces = void;
    type listEventsV1NamespacedEvent = void;
    type createEventsV1NamespacedEvent = void;
    type deleteEventsV1CollectionNamespacedEvent = void;
    type readEventsV1NamespacedEvent = void;
    type replaceEventsV1NamespacedEvent = void;
    type deleteEventsV1NamespacedEvent = void;
    type patchEventsV1NamespacedEvent = void;
    type watchEventsV1EventListForAllNamespaces = void;
    type watchEventsV1NamespacedEventList = void;
    type watchEventsV1NamespacedEvent = void;
    type getFlowcontrolApiserverAPIGroup = void;
    type getFlowcontrolApiserverV1beta2APIResources = void;
    type listFlowcontrolApiserverV1beta2FlowSchema = void;
    type createFlowcontrolApiserverV1beta2FlowSchema = void;
    type deleteFlowcontrolApiserverV1beta2CollectionFlowSchema = void;
    type readFlowcontrolApiserverV1beta2FlowSchema = void;
    type replaceFlowcontrolApiserverV1beta2FlowSchema = void;
    type deleteFlowcontrolApiserverV1beta2FlowSchema = void;
    type patchFlowcontrolApiserverV1beta2FlowSchema = void;
    type readFlowcontrolApiserverV1beta2FlowSchemaStatus = void;
    type replaceFlowcontrolApiserverV1beta2FlowSchemaStatus = void;
    type patchFlowcontrolApiserverV1beta2FlowSchemaStatus = void;
    type listFlowcontrolApiserverV1beta2PriorityLevelConfiguration = void;
    type createFlowcontrolApiserverV1beta2PriorityLevelConfiguration = void;
    type deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration = void;
    type readFlowcontrolApiserverV1beta2PriorityLevelConfiguration = void;
    type replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration = void;
    type deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration = void;
    type patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration = void;
    type readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus = void;
    type replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus = void;
    type patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus = void;
    type watchFlowcontrolApiserverV1beta2FlowSchemaList = void;
    type watchFlowcontrolApiserverV1beta2FlowSchema = void;
    type watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList = void;
    type watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration = void;
    type getFlowcontrolApiserverV1beta3APIResources = void;
    type listFlowcontrolApiserverV1beta3FlowSchema = void;
    type createFlowcontrolApiserverV1beta3FlowSchema = void;
    type deleteFlowcontrolApiserverV1beta3CollectionFlowSchema = void;
    type readFlowcontrolApiserverV1beta3FlowSchema = void;
    type replaceFlowcontrolApiserverV1beta3FlowSchema = void;
    type deleteFlowcontrolApiserverV1beta3FlowSchema = void;
    type patchFlowcontrolApiserverV1beta3FlowSchema = void;
    type readFlowcontrolApiserverV1beta3FlowSchemaStatus = void;
    type replaceFlowcontrolApiserverV1beta3FlowSchemaStatus = void;
    type patchFlowcontrolApiserverV1beta3FlowSchemaStatus = void;
    type listFlowcontrolApiserverV1beta3PriorityLevelConfiguration = void;
    type createFlowcontrolApiserverV1beta3PriorityLevelConfiguration = void;
    type deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration = void;
    type readFlowcontrolApiserverV1beta3PriorityLevelConfiguration = void;
    type replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration = void;
    type deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration = void;
    type patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration = void;
    type readFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus = void;
    type replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus = void;
    type patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus = void;
    type watchFlowcontrolApiserverV1beta3FlowSchemaList = void;
    type watchFlowcontrolApiserverV1beta3FlowSchema = void;
    type watchFlowcontrolApiserverV1beta3PriorityLevelConfigurationList = void;
    type watchFlowcontrolApiserverV1beta3PriorityLevelConfiguration = void;
    type getInternalApiserverAPIGroup = void;
    type getInternalApiserverV1alpha1APIResources = void;
    type listInternalApiserverV1alpha1StorageVersion = void;
    type createInternalApiserverV1alpha1StorageVersion = void;
    type deleteInternalApiserverV1alpha1CollectionStorageVersion = void;
    type readInternalApiserverV1alpha1StorageVersion = void;
    type replaceInternalApiserverV1alpha1StorageVersion = void;
    type deleteInternalApiserverV1alpha1StorageVersion = void;
    type patchInternalApiserverV1alpha1StorageVersion = void;
    type readInternalApiserverV1alpha1StorageVersionStatus = void;
    type replaceInternalApiserverV1alpha1StorageVersionStatus = void;
    type patchInternalApiserverV1alpha1StorageVersionStatus = void;
    type watchInternalApiserverV1alpha1StorageVersionList = void;
    type watchInternalApiserverV1alpha1StorageVersion = void;
    type getNetworkingAPIGroup = void;
    type getNetworkingV1APIResources = void;
    type listNetworkingV1IngressClass = void;
    type createNetworkingV1IngressClass = void;
    type deleteNetworkingV1CollectionIngressClass = void;
    type readNetworkingV1IngressClass = void;
    type replaceNetworkingV1IngressClass = void;
    type deleteNetworkingV1IngressClass = void;
    type patchNetworkingV1IngressClass = void;
    type listNetworkingV1IngressForAllNamespaces = void;
    type listNetworkingV1NamespacedIngress = void;
    type createNetworkingV1NamespacedIngress = void;
    type deleteNetworkingV1CollectionNamespacedIngress = void;
    type readNetworkingV1NamespacedIngress = void;
    type replaceNetworkingV1NamespacedIngress = void;
    type deleteNetworkingV1NamespacedIngress = void;
    type patchNetworkingV1NamespacedIngress = void;
    type readNetworkingV1NamespacedIngressStatus = void;
    type replaceNetworkingV1NamespacedIngressStatus = void;
    type patchNetworkingV1NamespacedIngressStatus = void;
    type listNetworkingV1NamespacedNetworkPolicy = void;
    type createNetworkingV1NamespacedNetworkPolicy = void;
    type deleteNetworkingV1CollectionNamespacedNetworkPolicy = void;
    type readNetworkingV1NamespacedNetworkPolicy = void;
    type replaceNetworkingV1NamespacedNetworkPolicy = void;
    type deleteNetworkingV1NamespacedNetworkPolicy = void;
    type patchNetworkingV1NamespacedNetworkPolicy = void;
    type readNetworkingV1NamespacedNetworkPolicyStatus = void;
    type replaceNetworkingV1NamespacedNetworkPolicyStatus = void;
    type patchNetworkingV1NamespacedNetworkPolicyStatus = void;
    type listNetworkingV1NetworkPolicyForAllNamespaces = void;
    type watchNetworkingV1IngressClassList = void;
    type watchNetworkingV1IngressClass = void;
    type watchNetworkingV1IngressListForAllNamespaces = void;
    type watchNetworkingV1NamespacedIngressList = void;
    type watchNetworkingV1NamespacedIngress = void;
    type watchNetworkingV1NamespacedNetworkPolicyList = void;
    type watchNetworkingV1NamespacedNetworkPolicy = void;
    type watchNetworkingV1NetworkPolicyListForAllNamespaces = void;
    type getNetworkingV1alpha1APIResources = void;
    type listNetworkingV1alpha1ClusterCIDR = void;
    type createNetworkingV1alpha1ClusterCIDR = void;
    type deleteNetworkingV1alpha1CollectionClusterCIDR = void;
    type readNetworkingV1alpha1ClusterCIDR = void;
    type replaceNetworkingV1alpha1ClusterCIDR = void;
    type deleteNetworkingV1alpha1ClusterCIDR = void;
    type patchNetworkingV1alpha1ClusterCIDR = void;
    type listNetworkingV1alpha1IPAddress = void;
    type createNetworkingV1alpha1IPAddress = void;
    type deleteNetworkingV1alpha1CollectionIPAddress = void;
    type readNetworkingV1alpha1IPAddress = void;
    type replaceNetworkingV1alpha1IPAddress = void;
    type deleteNetworkingV1alpha1IPAddress = void;
    type patchNetworkingV1alpha1IPAddress = void;
    type watchNetworkingV1alpha1ClusterCIDRList = void;
    type watchNetworkingV1alpha1ClusterCIDR = void;
    type watchNetworkingV1alpha1IPAddressList = void;
    type watchNetworkingV1alpha1IPAddress = void;
    type getNodeAPIGroup = void;
    type getNodeV1APIResources = void;
    type listNodeV1RuntimeClass = void;
    type createNodeV1RuntimeClass = void;
    type deleteNodeV1CollectionRuntimeClass = void;
    type readNodeV1RuntimeClass = void;
    type replaceNodeV1RuntimeClass = void;
    type deleteNodeV1RuntimeClass = void;
    type patchNodeV1RuntimeClass = void;
    type watchNodeV1RuntimeClassList = void;
    type watchNodeV1RuntimeClass = void;
    type getPolicyAPIGroup = void;
    type getPolicyV1APIResources = void;
    type listPolicyV1NamespacedPodDisruptionBudget = void;
    type createPolicyV1NamespacedPodDisruptionBudget = void;
    type deletePolicyV1CollectionNamespacedPodDisruptionBudget = void;
    type readPolicyV1NamespacedPodDisruptionBudget = void;
    type replacePolicyV1NamespacedPodDisruptionBudget = void;
    type deletePolicyV1NamespacedPodDisruptionBudget = void;
    type patchPolicyV1NamespacedPodDisruptionBudget = void;
    type readPolicyV1NamespacedPodDisruptionBudgetStatus = void;
    type replacePolicyV1NamespacedPodDisruptionBudgetStatus = void;
    type patchPolicyV1NamespacedPodDisruptionBudgetStatus = void;
    type listPolicyV1PodDisruptionBudgetForAllNamespaces = void;
    type watchPolicyV1NamespacedPodDisruptionBudgetList = void;
    type watchPolicyV1NamespacedPodDisruptionBudget = void;
    type watchPolicyV1PodDisruptionBudgetListForAllNamespaces = void;
    type getRbacAuthorizationAPIGroup = void;
    type getRbacAuthorizationV1APIResources = void;
    type listRbacAuthorizationV1ClusterRoleBinding = void;
    type createRbacAuthorizationV1ClusterRoleBinding = void;
    type deleteRbacAuthorizationV1CollectionClusterRoleBinding = void;
    type readRbacAuthorizationV1ClusterRoleBinding = void;
    type replaceRbacAuthorizationV1ClusterRoleBinding = void;
    type deleteRbacAuthorizationV1ClusterRoleBinding = void;
    type patchRbacAuthorizationV1ClusterRoleBinding = void;
    type listRbacAuthorizationV1ClusterRole = void;
    type createRbacAuthorizationV1ClusterRole = void;
    type deleteRbacAuthorizationV1CollectionClusterRole = void;
    type readRbacAuthorizationV1ClusterRole = void;
    type replaceRbacAuthorizationV1ClusterRole = void;
    type deleteRbacAuthorizationV1ClusterRole = void;
    type patchRbacAuthorizationV1ClusterRole = void;
    type listRbacAuthorizationV1NamespacedRoleBinding = void;
    type createRbacAuthorizationV1NamespacedRoleBinding = void;
    type deleteRbacAuthorizationV1CollectionNamespacedRoleBinding = void;
    type readRbacAuthorizationV1NamespacedRoleBinding = void;
    type replaceRbacAuthorizationV1NamespacedRoleBinding = void;
    type deleteRbacAuthorizationV1NamespacedRoleBinding = void;
    type patchRbacAuthorizationV1NamespacedRoleBinding = void;
    type listRbacAuthorizationV1NamespacedRole = void;
    type createRbacAuthorizationV1NamespacedRole = void;
    type deleteRbacAuthorizationV1CollectionNamespacedRole = void;
    type readRbacAuthorizationV1NamespacedRole = void;
    type replaceRbacAuthorizationV1NamespacedRole = void;
    type deleteRbacAuthorizationV1NamespacedRole = void;
    type patchRbacAuthorizationV1NamespacedRole = void;
    type listRbacAuthorizationV1RoleBindingForAllNamespaces = void;
    type listRbacAuthorizationV1RoleForAllNamespaces = void;
    type watchRbacAuthorizationV1ClusterRoleBindingList = void;
    type watchRbacAuthorizationV1ClusterRoleBinding = void;
    type watchRbacAuthorizationV1ClusterRoleList = void;
    type watchRbacAuthorizationV1ClusterRole = void;
    type watchRbacAuthorizationV1NamespacedRoleBindingList = void;
    type watchRbacAuthorizationV1NamespacedRoleBinding = void;
    type watchRbacAuthorizationV1NamespacedRoleList = void;
    type watchRbacAuthorizationV1NamespacedRole = void;
    type watchRbacAuthorizationV1RoleBindingListForAllNamespaces = void;
    type watchRbacAuthorizationV1RoleListForAllNamespaces = void;
    type getResourceAPIGroup = void;
    type getResourceV1alpha2APIResources = void;
    type listResourceV1alpha2NamespacedPodSchedulingContext = void;
    type createResourceV1alpha2NamespacedPodSchedulingContext = void;
    type deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext = void;
    type readResourceV1alpha2NamespacedPodSchedulingContext = void;
    type replaceResourceV1alpha2NamespacedPodSchedulingContext = void;
    type deleteResourceV1alpha2NamespacedPodSchedulingContext = void;
    type patchResourceV1alpha2NamespacedPodSchedulingContext = void;
    type readResourceV1alpha2NamespacedPodSchedulingContextStatus = void;
    type replaceResourceV1alpha2NamespacedPodSchedulingContextStatus = void;
    type patchResourceV1alpha2NamespacedPodSchedulingContextStatus = void;
    type listResourceV1alpha2NamespacedResourceClaim = void;
    type createResourceV1alpha2NamespacedResourceClaim = void;
    type deleteResourceV1alpha2CollectionNamespacedResourceClaim = void;
    type readResourceV1alpha2NamespacedResourceClaim = void;
    type replaceResourceV1alpha2NamespacedResourceClaim = void;
    type deleteResourceV1alpha2NamespacedResourceClaim = void;
    type patchResourceV1alpha2NamespacedResourceClaim = void;
    type readResourceV1alpha2NamespacedResourceClaimStatus = void;
    type replaceResourceV1alpha2NamespacedResourceClaimStatus = void;
    type patchResourceV1alpha2NamespacedResourceClaimStatus = void;
    type listResourceV1alpha2NamespacedResourceClaimTemplate = void;
    type createResourceV1alpha2NamespacedResourceClaimTemplate = void;
    type deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate = void;
    type readResourceV1alpha2NamespacedResourceClaimTemplate = void;
    type replaceResourceV1alpha2NamespacedResourceClaimTemplate = void;
    type deleteResourceV1alpha2NamespacedResourceClaimTemplate = void;
    type patchResourceV1alpha2NamespacedResourceClaimTemplate = void;
    type listResourceV1alpha2PodSchedulingContextForAllNamespaces = void;
    type listResourceV1alpha2ResourceClaimForAllNamespaces = void;
    type listResourceV1alpha2ResourceClaimTemplateForAllNamespaces = void;
    type listResourceV1alpha2ResourceClass = void;
    type createResourceV1alpha2ResourceClass = void;
    type deleteResourceV1alpha2CollectionResourceClass = void;
    type readResourceV1alpha2ResourceClass = void;
    type replaceResourceV1alpha2ResourceClass = void;
    type deleteResourceV1alpha2ResourceClass = void;
    type patchResourceV1alpha2ResourceClass = void;
    type watchResourceV1alpha2NamespacedPodSchedulingContextList = void;
    type watchResourceV1alpha2NamespacedPodSchedulingContext = void;
    type watchResourceV1alpha2NamespacedResourceClaimList = void;
    type watchResourceV1alpha2NamespacedResourceClaim = void;
    type watchResourceV1alpha2NamespacedResourceClaimTemplateList = void;
    type watchResourceV1alpha2NamespacedResourceClaimTemplate = void;
    type watchResourceV1alpha2PodSchedulingContextListForAllNamespaces = void;
    type watchResourceV1alpha2ResourceClaimListForAllNamespaces = void;
    type watchResourceV1alpha2ResourceClaimTemplateListForAllNamespaces = void;
    type watchResourceV1alpha2ResourceClassList = void;
    type watchResourceV1alpha2ResourceClass = void;
    type getSchedulingAPIGroup = void;
    type getSchedulingV1APIResources = void;
    type listSchedulingV1PriorityClass = void;
    type createSchedulingV1PriorityClass = void;
    type deleteSchedulingV1CollectionPriorityClass = void;
    type readSchedulingV1PriorityClass = void;
    type replaceSchedulingV1PriorityClass = void;
    type deleteSchedulingV1PriorityClass = void;
    type patchSchedulingV1PriorityClass = void;
    type watchSchedulingV1PriorityClassList = void;
    type watchSchedulingV1PriorityClass = void;
    type getStorageAPIGroup = void;
    type getStorageV1APIResources = void;
    type listStorageV1CSIDriver = void;
    type createStorageV1CSIDriver = void;
    type deleteStorageV1CollectionCSIDriver = void;
    type readStorageV1CSIDriver = void;
    type replaceStorageV1CSIDriver = void;
    type deleteStorageV1CSIDriver = void;
    type patchStorageV1CSIDriver = void;
    type listStorageV1CSINode = void;
    type createStorageV1CSINode = void;
    type deleteStorageV1CollectionCSINode = void;
    type readStorageV1CSINode = void;
    type replaceStorageV1CSINode = void;
    type deleteStorageV1CSINode = void;
    type patchStorageV1CSINode = void;
    type listStorageV1CSIStorageCapacityForAllNamespaces = void;
    type listStorageV1NamespacedCSIStorageCapacity = void;
    type createStorageV1NamespacedCSIStorageCapacity = void;
    type deleteStorageV1CollectionNamespacedCSIStorageCapacity = void;
    type readStorageV1NamespacedCSIStorageCapacity = void;
    type replaceStorageV1NamespacedCSIStorageCapacity = void;
    type deleteStorageV1NamespacedCSIStorageCapacity = void;
    type patchStorageV1NamespacedCSIStorageCapacity = void;
    type listStorageV1StorageClass = void;
    type createStorageV1StorageClass = void;
    type deleteStorageV1CollectionStorageClass = void;
    type readStorageV1StorageClass = void;
    type replaceStorageV1StorageClass = void;
    type deleteStorageV1StorageClass = void;
    type patchStorageV1StorageClass = void;
    type listStorageV1VolumeAttachment = void;
    type createStorageV1VolumeAttachment = void;
    type deleteStorageV1CollectionVolumeAttachment = void;
    type readStorageV1VolumeAttachment = void;
    type replaceStorageV1VolumeAttachment = void;
    type deleteStorageV1VolumeAttachment = void;
    type patchStorageV1VolumeAttachment = void;
    type readStorageV1VolumeAttachmentStatus = void;
    type replaceStorageV1VolumeAttachmentStatus = void;
    type patchStorageV1VolumeAttachmentStatus = void;
    type watchStorageV1CSIDriverList = void;
    type watchStorageV1CSIDriver = void;
    type watchStorageV1CSINodeList = void;
    type watchStorageV1CSINode = void;
    type watchStorageV1CSIStorageCapacityListForAllNamespaces = void;
    type watchStorageV1NamespacedCSIStorageCapacityList = void;
    type watchStorageV1NamespacedCSIStorageCapacity = void;
    type watchStorageV1StorageClassList = void;
    type watchStorageV1StorageClass = void;
    type watchStorageV1VolumeAttachmentList = void;
    type watchStorageV1VolumeAttachment = void;
    type logFileListHandler = void;
    type logFileHandler = void;
    type getServiceAccountIssuerOpenIDKeyset = void;
    type getCodeVersion = void;
}
interface Encoding {
    readonly contentType?: string;
    headers?: Record<string, any>;
    readonly style?: "form" | "spaceDelimited" | "pipeDelimited" | "deepObject";
    readonly explode?: boolean;
    readonly allowReserved?: boolean;
}
interface RequestArgs {
    readonly httpMethod: HttpMethod;
    readonly url: string;
    headers: ObjectLike | any;
    requestBody?: ObjectLike | any;
    requestBodyEncoding?: Record<string, Encoding>;
    queryParameters?: QueryParameters | undefined;
}
interface ApiClient<RequestOption> {
    request: <T = SuccessResponses>(requestArgs: RequestArgs, options?: RequestOption) => Promise<T>;
}
declare class Client<RequestOption> {
    private apiClient;
    private baseUrl;
    constructor(apiClient: ApiClient<RequestOption>, baseUrl: string);
    /**
     * get service account issuer OpenID configuration, also known as the 'OIDC discovery doc'
     * operationId: getServiceAccountIssuerOpenIDConfiguration
     * Request URI: /.well-known/openid-configuration/
     */
    getServiceAccountIssuerOpenIDConfiguration(option?: RequestOption): Promise<Response$getServiceAccountIssuerOpenIDConfiguration$Status$200["application/json"]>;
    /**
     * get available API versions
     * operationId: getCoreAPIVersions
     * Request URI: /api/
     */
    getCoreAPIVersions<ResponseContentType extends ResponseContentType$getCoreAPIVersions>(params: Params$getCoreAPIVersions<ResponseContentType>, option?: RequestOption): Promise<Response$getCoreAPIVersions$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getCoreV1APIResources
     * Request URI: /api/v1/
     */
    getCoreV1APIResources<ResponseContentType extends ResponseContentType$getCoreV1APIResources>(params: Params$getCoreV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getCoreV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list objects of kind ComponentStatus
     * operationId: listCoreV1ComponentStatus
     * Request URI: /api/v1/componentstatuses
     */
    listCoreV1ComponentStatus<ResponseContentType extends ResponseContentType$listCoreV1ComponentStatus>(params: Params$listCoreV1ComponentStatus<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1ComponentStatus$Status$200[ResponseContentType]>;
    /**
     * read the specified ComponentStatus
     * operationId: readCoreV1ComponentStatus
     * Request URI: /api/v1/componentstatuses/{name}
     */
    readCoreV1ComponentStatus<ResponseContentType extends ResponseContentType$readCoreV1ComponentStatus>(params: Params$readCoreV1ComponentStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1ComponentStatus$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind ConfigMap
     * operationId: listCoreV1ConfigMapForAllNamespaces
     * Request URI: /api/v1/configmaps
     */
    listCoreV1ConfigMapForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1ConfigMapForAllNamespaces>(params: Params$listCoreV1ConfigMapForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1ConfigMapForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Endpoints
     * operationId: listCoreV1EndpointsForAllNamespaces
     * Request URI: /api/v1/endpoints
     */
    listCoreV1EndpointsForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1EndpointsForAllNamespaces>(params: Params$listCoreV1EndpointsForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1EndpointsForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Event
     * operationId: listCoreV1EventForAllNamespaces
     * Request URI: /api/v1/events
     */
    listCoreV1EventForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1EventForAllNamespaces>(params: Params$listCoreV1EventForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1EventForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind LimitRange
     * operationId: listCoreV1LimitRangeForAllNamespaces
     * Request URI: /api/v1/limitranges
     */
    listCoreV1LimitRangeForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1LimitRangeForAllNamespaces>(params: Params$listCoreV1LimitRangeForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1LimitRangeForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Namespace
     * operationId: listCoreV1Namespace
     * Request URI: /api/v1/namespaces
     */
    listCoreV1Namespace<ResponseContentType extends ResponseContentType$listCoreV1Namespace>(params: Params$listCoreV1Namespace<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1Namespace$Status$200[ResponseContentType]>;
    /**
     * create a Namespace
     * operationId: createCoreV1Namespace
     * Request URI: /api/v1/namespaces
     */
    createCoreV1Namespace<ResponseContentType extends ResponseContentType$createCoreV1Namespace>(params: Params$createCoreV1Namespace<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1Namespace$Status$200 | Response$createCoreV1Namespace$Status$201 | Response$createCoreV1Namespace$Status$202)[ResponseContentType]>;
    /**
     * create a Binding
     * operationId: createCoreV1NamespacedBinding
     * Request URI: /api/v1/namespaces/{namespace}/bindings
     */
    createCoreV1NamespacedBinding<ResponseContentType extends ResponseContentType$createCoreV1NamespacedBinding>(params: Params$createCoreV1NamespacedBinding<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedBinding$Status$200 | Response$createCoreV1NamespacedBinding$Status$201 | Response$createCoreV1NamespacedBinding$Status$202)[ResponseContentType]>;
    /**
     * list or watch objects of kind ConfigMap
     * operationId: listCoreV1NamespacedConfigMap
     * Request URI: /api/v1/namespaces/{namespace}/configmaps
     */
    listCoreV1NamespacedConfigMap<ResponseContentType extends ResponseContentType$listCoreV1NamespacedConfigMap>(params: Params$listCoreV1NamespacedConfigMap<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedConfigMap$Status$200[ResponseContentType]>;
    /**
     * create a ConfigMap
     * operationId: createCoreV1NamespacedConfigMap
     * Request URI: /api/v1/namespaces/{namespace}/configmaps
     */
    createCoreV1NamespacedConfigMap<ResponseContentType extends ResponseContentType$createCoreV1NamespacedConfigMap>(params: Params$createCoreV1NamespacedConfigMap<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedConfigMap$Status$200 | Response$createCoreV1NamespacedConfigMap$Status$201 | Response$createCoreV1NamespacedConfigMap$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ConfigMap
     * operationId: deleteCoreV1CollectionNamespacedConfigMap
     * Request URI: /api/v1/namespaces/{namespace}/configmaps
     */
    deleteCoreV1CollectionNamespacedConfigMap<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedConfigMap>(params: Params$deleteCoreV1CollectionNamespacedConfigMap<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedConfigMap$Status$200[ResponseContentType]>;
    /**
     * read the specified ConfigMap
     * operationId: readCoreV1NamespacedConfigMap
     * Request URI: /api/v1/namespaces/{namespace}/configmaps/{name}
     */
    readCoreV1NamespacedConfigMap<ResponseContentType extends ResponseContentType$readCoreV1NamespacedConfigMap>(params: Params$readCoreV1NamespacedConfigMap<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedConfigMap$Status$200[ResponseContentType]>;
    /**
     * replace the specified ConfigMap
     * operationId: replaceCoreV1NamespacedConfigMap
     * Request URI: /api/v1/namespaces/{namespace}/configmaps/{name}
     */
    replaceCoreV1NamespacedConfigMap<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedConfigMap>(params: Params$replaceCoreV1NamespacedConfigMap<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedConfigMap$Status$200 | Response$replaceCoreV1NamespacedConfigMap$Status$201)[ResponseContentType]>;
    /**
     * delete a ConfigMap
     * operationId: deleteCoreV1NamespacedConfigMap
     * Request URI: /api/v1/namespaces/{namespace}/configmaps/{name}
     */
    deleteCoreV1NamespacedConfigMap<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedConfigMap>(params: Params$deleteCoreV1NamespacedConfigMap<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedConfigMap$Status$200 | Response$deleteCoreV1NamespacedConfigMap$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ConfigMap
     * operationId: patchCoreV1NamespacedConfigMap
     * Request URI: /api/v1/namespaces/{namespace}/configmaps/{name}
     */
    patchCoreV1NamespacedConfigMap<RequestContentType extends RequestContentType$patchCoreV1NamespacedConfigMap, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedConfigMap>(params: Params$patchCoreV1NamespacedConfigMap<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedConfigMap$Status$200 | Response$patchCoreV1NamespacedConfigMap$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind Endpoints
     * operationId: listCoreV1NamespacedEndpoints
     * Request URI: /api/v1/namespaces/{namespace}/endpoints
     */
    listCoreV1NamespacedEndpoints<ResponseContentType extends ResponseContentType$listCoreV1NamespacedEndpoints>(params: Params$listCoreV1NamespacedEndpoints<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedEndpoints$Status$200[ResponseContentType]>;
    /**
     * create Endpoints
     * operationId: createCoreV1NamespacedEndpoints
     * Request URI: /api/v1/namespaces/{namespace}/endpoints
     */
    createCoreV1NamespacedEndpoints<ResponseContentType extends ResponseContentType$createCoreV1NamespacedEndpoints>(params: Params$createCoreV1NamespacedEndpoints<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedEndpoints$Status$200 | Response$createCoreV1NamespacedEndpoints$Status$201 | Response$createCoreV1NamespacedEndpoints$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Endpoints
     * operationId: deleteCoreV1CollectionNamespacedEndpoints
     * Request URI: /api/v1/namespaces/{namespace}/endpoints
     */
    deleteCoreV1CollectionNamespacedEndpoints<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedEndpoints>(params: Params$deleteCoreV1CollectionNamespacedEndpoints<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedEndpoints$Status$200[ResponseContentType]>;
    /**
     * read the specified Endpoints
     * operationId: readCoreV1NamespacedEndpoints
     * Request URI: /api/v1/namespaces/{namespace}/endpoints/{name}
     */
    readCoreV1NamespacedEndpoints<ResponseContentType extends ResponseContentType$readCoreV1NamespacedEndpoints>(params: Params$readCoreV1NamespacedEndpoints<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedEndpoints$Status$200[ResponseContentType]>;
    /**
     * replace the specified Endpoints
     * operationId: replaceCoreV1NamespacedEndpoints
     * Request URI: /api/v1/namespaces/{namespace}/endpoints/{name}
     */
    replaceCoreV1NamespacedEndpoints<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedEndpoints>(params: Params$replaceCoreV1NamespacedEndpoints<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedEndpoints$Status$200 | Response$replaceCoreV1NamespacedEndpoints$Status$201)[ResponseContentType]>;
    /**
     * delete Endpoints
     * operationId: deleteCoreV1NamespacedEndpoints
     * Request URI: /api/v1/namespaces/{namespace}/endpoints/{name}
     */
    deleteCoreV1NamespacedEndpoints<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedEndpoints>(params: Params$deleteCoreV1NamespacedEndpoints<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedEndpoints$Status$200 | Response$deleteCoreV1NamespacedEndpoints$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Endpoints
     * operationId: patchCoreV1NamespacedEndpoints
     * Request URI: /api/v1/namespaces/{namespace}/endpoints/{name}
     */
    patchCoreV1NamespacedEndpoints<RequestContentType extends RequestContentType$patchCoreV1NamespacedEndpoints, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedEndpoints>(params: Params$patchCoreV1NamespacedEndpoints<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedEndpoints$Status$200 | Response$patchCoreV1NamespacedEndpoints$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind Event
     * operationId: listCoreV1NamespacedEvent
     * Request URI: /api/v1/namespaces/{namespace}/events
     */
    listCoreV1NamespacedEvent<ResponseContentType extends ResponseContentType$listCoreV1NamespacedEvent>(params: Params$listCoreV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedEvent$Status$200[ResponseContentType]>;
    /**
     * create an Event
     * operationId: createCoreV1NamespacedEvent
     * Request URI: /api/v1/namespaces/{namespace}/events
     */
    createCoreV1NamespacedEvent<ResponseContentType extends ResponseContentType$createCoreV1NamespacedEvent>(params: Params$createCoreV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedEvent$Status$200 | Response$createCoreV1NamespacedEvent$Status$201 | Response$createCoreV1NamespacedEvent$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Event
     * operationId: deleteCoreV1CollectionNamespacedEvent
     * Request URI: /api/v1/namespaces/{namespace}/events
     */
    deleteCoreV1CollectionNamespacedEvent<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedEvent>(params: Params$deleteCoreV1CollectionNamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedEvent$Status$200[ResponseContentType]>;
    /**
     * read the specified Event
     * operationId: readCoreV1NamespacedEvent
     * Request URI: /api/v1/namespaces/{namespace}/events/{name}
     */
    readCoreV1NamespacedEvent<ResponseContentType extends ResponseContentType$readCoreV1NamespacedEvent>(params: Params$readCoreV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedEvent$Status$200[ResponseContentType]>;
    /**
     * replace the specified Event
     * operationId: replaceCoreV1NamespacedEvent
     * Request URI: /api/v1/namespaces/{namespace}/events/{name}
     */
    replaceCoreV1NamespacedEvent<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedEvent>(params: Params$replaceCoreV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedEvent$Status$200 | Response$replaceCoreV1NamespacedEvent$Status$201)[ResponseContentType]>;
    /**
     * delete an Event
     * operationId: deleteCoreV1NamespacedEvent
     * Request URI: /api/v1/namespaces/{namespace}/events/{name}
     */
    deleteCoreV1NamespacedEvent<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedEvent>(params: Params$deleteCoreV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedEvent$Status$200 | Response$deleteCoreV1NamespacedEvent$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Event
     * operationId: patchCoreV1NamespacedEvent
     * Request URI: /api/v1/namespaces/{namespace}/events/{name}
     */
    patchCoreV1NamespacedEvent<RequestContentType extends RequestContentType$patchCoreV1NamespacedEvent, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedEvent>(params: Params$patchCoreV1NamespacedEvent<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedEvent$Status$200 | Response$patchCoreV1NamespacedEvent$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind LimitRange
     * operationId: listCoreV1NamespacedLimitRange
     * Request URI: /api/v1/namespaces/{namespace}/limitranges
     */
    listCoreV1NamespacedLimitRange<ResponseContentType extends ResponseContentType$listCoreV1NamespacedLimitRange>(params: Params$listCoreV1NamespacedLimitRange<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedLimitRange$Status$200[ResponseContentType]>;
    /**
     * create a LimitRange
     * operationId: createCoreV1NamespacedLimitRange
     * Request URI: /api/v1/namespaces/{namespace}/limitranges
     */
    createCoreV1NamespacedLimitRange<ResponseContentType extends ResponseContentType$createCoreV1NamespacedLimitRange>(params: Params$createCoreV1NamespacedLimitRange<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedLimitRange$Status$200 | Response$createCoreV1NamespacedLimitRange$Status$201 | Response$createCoreV1NamespacedLimitRange$Status$202)[ResponseContentType]>;
    /**
     * delete collection of LimitRange
     * operationId: deleteCoreV1CollectionNamespacedLimitRange
     * Request URI: /api/v1/namespaces/{namespace}/limitranges
     */
    deleteCoreV1CollectionNamespacedLimitRange<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedLimitRange>(params: Params$deleteCoreV1CollectionNamespacedLimitRange<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedLimitRange$Status$200[ResponseContentType]>;
    /**
     * read the specified LimitRange
     * operationId: readCoreV1NamespacedLimitRange
     * Request URI: /api/v1/namespaces/{namespace}/limitranges/{name}
     */
    readCoreV1NamespacedLimitRange<ResponseContentType extends ResponseContentType$readCoreV1NamespacedLimitRange>(params: Params$readCoreV1NamespacedLimitRange<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedLimitRange$Status$200[ResponseContentType]>;
    /**
     * replace the specified LimitRange
     * operationId: replaceCoreV1NamespacedLimitRange
     * Request URI: /api/v1/namespaces/{namespace}/limitranges/{name}
     */
    replaceCoreV1NamespacedLimitRange<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedLimitRange>(params: Params$replaceCoreV1NamespacedLimitRange<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedLimitRange$Status$200 | Response$replaceCoreV1NamespacedLimitRange$Status$201)[ResponseContentType]>;
    /**
     * delete a LimitRange
     * operationId: deleteCoreV1NamespacedLimitRange
     * Request URI: /api/v1/namespaces/{namespace}/limitranges/{name}
     */
    deleteCoreV1NamespacedLimitRange<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedLimitRange>(params: Params$deleteCoreV1NamespacedLimitRange<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedLimitRange$Status$200 | Response$deleteCoreV1NamespacedLimitRange$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified LimitRange
     * operationId: patchCoreV1NamespacedLimitRange
     * Request URI: /api/v1/namespaces/{namespace}/limitranges/{name}
     */
    patchCoreV1NamespacedLimitRange<RequestContentType extends RequestContentType$patchCoreV1NamespacedLimitRange, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedLimitRange>(params: Params$patchCoreV1NamespacedLimitRange<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedLimitRange$Status$200 | Response$patchCoreV1NamespacedLimitRange$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind PersistentVolumeClaim
     * operationId: listCoreV1NamespacedPersistentVolumeClaim
     * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims
     */
    listCoreV1NamespacedPersistentVolumeClaim<ResponseContentType extends ResponseContentType$listCoreV1NamespacedPersistentVolumeClaim>(params: Params$listCoreV1NamespacedPersistentVolumeClaim<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedPersistentVolumeClaim$Status$200[ResponseContentType]>;
    /**
     * create a PersistentVolumeClaim
     * operationId: createCoreV1NamespacedPersistentVolumeClaim
     * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims
     */
    createCoreV1NamespacedPersistentVolumeClaim<ResponseContentType extends ResponseContentType$createCoreV1NamespacedPersistentVolumeClaim>(params: Params$createCoreV1NamespacedPersistentVolumeClaim<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedPersistentVolumeClaim$Status$200 | Response$createCoreV1NamespacedPersistentVolumeClaim$Status$201 | Response$createCoreV1NamespacedPersistentVolumeClaim$Status$202)[ResponseContentType]>;
    /**
     * delete collection of PersistentVolumeClaim
     * operationId: deleteCoreV1CollectionNamespacedPersistentVolumeClaim
     * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims
     */
    deleteCoreV1CollectionNamespacedPersistentVolumeClaim<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedPersistentVolumeClaim>(params: Params$deleteCoreV1CollectionNamespacedPersistentVolumeClaim<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedPersistentVolumeClaim$Status$200[ResponseContentType]>;
    /**
     * read the specified PersistentVolumeClaim
     * operationId: readCoreV1NamespacedPersistentVolumeClaim
     * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims/{name}
     */
    readCoreV1NamespacedPersistentVolumeClaim<ResponseContentType extends ResponseContentType$readCoreV1NamespacedPersistentVolumeClaim>(params: Params$readCoreV1NamespacedPersistentVolumeClaim<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedPersistentVolumeClaim$Status$200[ResponseContentType]>;
    /**
     * replace the specified PersistentVolumeClaim
     * operationId: replaceCoreV1NamespacedPersistentVolumeClaim
     * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims/{name}
     */
    replaceCoreV1NamespacedPersistentVolumeClaim<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedPersistentVolumeClaim>(params: Params$replaceCoreV1NamespacedPersistentVolumeClaim<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedPersistentVolumeClaim$Status$200 | Response$replaceCoreV1NamespacedPersistentVolumeClaim$Status$201)[ResponseContentType]>;
    /**
     * delete a PersistentVolumeClaim
     * operationId: deleteCoreV1NamespacedPersistentVolumeClaim
     * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims/{name}
     */
    deleteCoreV1NamespacedPersistentVolumeClaim<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedPersistentVolumeClaim>(params: Params$deleteCoreV1NamespacedPersistentVolumeClaim<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedPersistentVolumeClaim$Status$200 | Response$deleteCoreV1NamespacedPersistentVolumeClaim$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified PersistentVolumeClaim
     * operationId: patchCoreV1NamespacedPersistentVolumeClaim
     * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims/{name}
     */
    patchCoreV1NamespacedPersistentVolumeClaim<RequestContentType extends RequestContentType$patchCoreV1NamespacedPersistentVolumeClaim, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedPersistentVolumeClaim>(params: Params$patchCoreV1NamespacedPersistentVolumeClaim<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedPersistentVolumeClaim$Status$200 | Response$patchCoreV1NamespacedPersistentVolumeClaim$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified PersistentVolumeClaim
     * operationId: readCoreV1NamespacedPersistentVolumeClaimStatus
     * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims/{name}/status
     */
    readCoreV1NamespacedPersistentVolumeClaimStatus<ResponseContentType extends ResponseContentType$readCoreV1NamespacedPersistentVolumeClaimStatus>(params: Params$readCoreV1NamespacedPersistentVolumeClaimStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedPersistentVolumeClaimStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified PersistentVolumeClaim
     * operationId: replaceCoreV1NamespacedPersistentVolumeClaimStatus
     * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims/{name}/status
     */
    replaceCoreV1NamespacedPersistentVolumeClaimStatus<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedPersistentVolumeClaimStatus>(params: Params$replaceCoreV1NamespacedPersistentVolumeClaimStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedPersistentVolumeClaimStatus$Status$200 | Response$replaceCoreV1NamespacedPersistentVolumeClaimStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified PersistentVolumeClaim
     * operationId: patchCoreV1NamespacedPersistentVolumeClaimStatus
     * Request URI: /api/v1/namespaces/{namespace}/persistentvolumeclaims/{name}/status
     */
    patchCoreV1NamespacedPersistentVolumeClaimStatus<RequestContentType extends RequestContentType$patchCoreV1NamespacedPersistentVolumeClaimStatus, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedPersistentVolumeClaimStatus>(params: Params$patchCoreV1NamespacedPersistentVolumeClaimStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedPersistentVolumeClaimStatus$Status$200 | Response$patchCoreV1NamespacedPersistentVolumeClaimStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind Pod
     * operationId: listCoreV1NamespacedPod
     * Request URI: /api/v1/namespaces/{namespace}/pods
     */
    listCoreV1NamespacedPod<ResponseContentType extends ResponseContentType$listCoreV1NamespacedPod>(params: Params$listCoreV1NamespacedPod<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedPod$Status$200[ResponseContentType]>;
    /**
     * create a Pod
     * operationId: createCoreV1NamespacedPod
     * Request URI: /api/v1/namespaces/{namespace}/pods
     */
    createCoreV1NamespacedPod<ResponseContentType extends ResponseContentType$createCoreV1NamespacedPod>(params: Params$createCoreV1NamespacedPod<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedPod$Status$200 | Response$createCoreV1NamespacedPod$Status$201 | Response$createCoreV1NamespacedPod$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Pod
     * operationId: deleteCoreV1CollectionNamespacedPod
     * Request URI: /api/v1/namespaces/{namespace}/pods
     */
    deleteCoreV1CollectionNamespacedPod<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedPod>(params: Params$deleteCoreV1CollectionNamespacedPod<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedPod$Status$200[ResponseContentType]>;
    /**
     * read the specified Pod
     * operationId: readCoreV1NamespacedPod
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}
     */
    readCoreV1NamespacedPod<ResponseContentType extends ResponseContentType$readCoreV1NamespacedPod>(params: Params$readCoreV1NamespacedPod<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedPod$Status$200[ResponseContentType]>;
    /**
     * replace the specified Pod
     * operationId: replaceCoreV1NamespacedPod
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}
     */
    replaceCoreV1NamespacedPod<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedPod>(params: Params$replaceCoreV1NamespacedPod<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedPod$Status$200 | Response$replaceCoreV1NamespacedPod$Status$201)[ResponseContentType]>;
    /**
     * delete a Pod
     * operationId: deleteCoreV1NamespacedPod
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}
     */
    deleteCoreV1NamespacedPod<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedPod>(params: Params$deleteCoreV1NamespacedPod<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedPod$Status$200 | Response$deleteCoreV1NamespacedPod$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Pod
     * operationId: patchCoreV1NamespacedPod
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}
     */
    patchCoreV1NamespacedPod<RequestContentType extends RequestContentType$patchCoreV1NamespacedPod, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedPod>(params: Params$patchCoreV1NamespacedPod<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedPod$Status$200 | Response$patchCoreV1NamespacedPod$Status$201)[ResponseContentType]>;
    /**
     * connect GET requests to attach of Pod
     * operationId: connectCoreV1GetNamespacedPodAttach
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/attach
     */
    connectCoreV1GetNamespacedPodAttach(params: Params$connectCoreV1GetNamespacedPodAttach, option?: RequestOption): Promise<Response$connectCoreV1GetNamespacedPodAttach$Status$200["*/*"]>;
    /**
     * connect POST requests to attach of Pod
     * operationId: connectCoreV1PostNamespacedPodAttach
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/attach
     */
    connectCoreV1PostNamespacedPodAttach(params: Params$connectCoreV1PostNamespacedPodAttach, option?: RequestOption): Promise<Response$connectCoreV1PostNamespacedPodAttach$Status$200["*/*"]>;
    /**
     * create binding of a Pod
     * operationId: createCoreV1NamespacedPodBinding
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/binding
     */
    createCoreV1NamespacedPodBinding<ResponseContentType extends ResponseContentType$createCoreV1NamespacedPodBinding>(params: Params$createCoreV1NamespacedPodBinding<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedPodBinding$Status$200 | Response$createCoreV1NamespacedPodBinding$Status$201 | Response$createCoreV1NamespacedPodBinding$Status$202)[ResponseContentType]>;
    /**
     * read ephemeralcontainers of the specified Pod
     * operationId: readCoreV1NamespacedPodEphemeralcontainers
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/ephemeralcontainers
     */
    readCoreV1NamespacedPodEphemeralcontainers<ResponseContentType extends ResponseContentType$readCoreV1NamespacedPodEphemeralcontainers>(params: Params$readCoreV1NamespacedPodEphemeralcontainers<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedPodEphemeralcontainers$Status$200[ResponseContentType]>;
    /**
     * replace ephemeralcontainers of the specified Pod
     * operationId: replaceCoreV1NamespacedPodEphemeralcontainers
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/ephemeralcontainers
     */
    replaceCoreV1NamespacedPodEphemeralcontainers<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedPodEphemeralcontainers>(params: Params$replaceCoreV1NamespacedPodEphemeralcontainers<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedPodEphemeralcontainers$Status$200 | Response$replaceCoreV1NamespacedPodEphemeralcontainers$Status$201)[ResponseContentType]>;
    /**
     * partially update ephemeralcontainers of the specified Pod
     * operationId: patchCoreV1NamespacedPodEphemeralcontainers
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/ephemeralcontainers
     */
    patchCoreV1NamespacedPodEphemeralcontainers<RequestContentType extends RequestContentType$patchCoreV1NamespacedPodEphemeralcontainers, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedPodEphemeralcontainers>(params: Params$patchCoreV1NamespacedPodEphemeralcontainers<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedPodEphemeralcontainers$Status$200 | Response$patchCoreV1NamespacedPodEphemeralcontainers$Status$201)[ResponseContentType]>;
    /**
     * create eviction of a Pod
     * operationId: createCoreV1NamespacedPodEviction
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/eviction
     */
    createCoreV1NamespacedPodEviction<ResponseContentType extends ResponseContentType$createCoreV1NamespacedPodEviction>(params: Params$createCoreV1NamespacedPodEviction<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedPodEviction$Status$200 | Response$createCoreV1NamespacedPodEviction$Status$201 | Response$createCoreV1NamespacedPodEviction$Status$202)[ResponseContentType]>;
    /**
     * connect GET requests to exec of Pod
     * operationId: connectCoreV1GetNamespacedPodExec
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/exec
     */
    connectCoreV1GetNamespacedPodExec(params: Params$connectCoreV1GetNamespacedPodExec, option?: RequestOption): Promise<Response$connectCoreV1GetNamespacedPodExec$Status$200["*/*"]>;
    /**
     * connect POST requests to exec of Pod
     * operationId: connectCoreV1PostNamespacedPodExec
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/exec
     */
    connectCoreV1PostNamespacedPodExec(params: Params$connectCoreV1PostNamespacedPodExec, option?: RequestOption): Promise<Response$connectCoreV1PostNamespacedPodExec$Status$200["*/*"]>;
    /**
     * read log of the specified Pod
     * operationId: readCoreV1NamespacedPodLog
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/log
     */
    readCoreV1NamespacedPodLog<ResponseContentType extends ResponseContentType$readCoreV1NamespacedPodLog>(params: Params$readCoreV1NamespacedPodLog<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedPodLog$Status$200[ResponseContentType]>;
    /**
     * connect GET requests to portforward of Pod
     * operationId: connectCoreV1GetNamespacedPodPortforward
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/portforward
     */
    connectCoreV1GetNamespacedPodPortforward(params: Params$connectCoreV1GetNamespacedPodPortforward, option?: RequestOption): Promise<Response$connectCoreV1GetNamespacedPodPortforward$Status$200["*/*"]>;
    /**
     * connect POST requests to portforward of Pod
     * operationId: connectCoreV1PostNamespacedPodPortforward
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/portforward
     */
    connectCoreV1PostNamespacedPodPortforward(params: Params$connectCoreV1PostNamespacedPodPortforward, option?: RequestOption): Promise<Response$connectCoreV1PostNamespacedPodPortforward$Status$200["*/*"]>;
    /**
     * connect GET requests to proxy of Pod
     * operationId: connectCoreV1GetNamespacedPodProxy
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy
     */
    connectCoreV1GetNamespacedPodProxy(params: Params$connectCoreV1GetNamespacedPodProxy, option?: RequestOption): Promise<Response$connectCoreV1GetNamespacedPodProxy$Status$200["*/*"]>;
    /**
     * connect PUT requests to proxy of Pod
     * operationId: connectCoreV1PutNamespacedPodProxy
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy
     */
    connectCoreV1PutNamespacedPodProxy(params: Params$connectCoreV1PutNamespacedPodProxy, option?: RequestOption): Promise<Response$connectCoreV1PutNamespacedPodProxy$Status$200["*/*"]>;
    /**
     * connect POST requests to proxy of Pod
     * operationId: connectCoreV1PostNamespacedPodProxy
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy
     */
    connectCoreV1PostNamespacedPodProxy(params: Params$connectCoreV1PostNamespacedPodProxy, option?: RequestOption): Promise<Response$connectCoreV1PostNamespacedPodProxy$Status$200["*/*"]>;
    /**
     * connect DELETE requests to proxy of Pod
     * operationId: connectCoreV1DeleteNamespacedPodProxy
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy
     */
    connectCoreV1DeleteNamespacedPodProxy(params: Params$connectCoreV1DeleteNamespacedPodProxy, option?: RequestOption): Promise<Response$connectCoreV1DeleteNamespacedPodProxy$Status$200["*/*"]>;
    /**
     * connect OPTIONS requests to proxy of Pod
     * operationId: connectCoreV1OptionsNamespacedPodProxy
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy
     */
    connectCoreV1OptionsNamespacedPodProxy(params: Params$connectCoreV1OptionsNamespacedPodProxy, option?: RequestOption): Promise<Response$connectCoreV1OptionsNamespacedPodProxy$Status$200["*/*"]>;
    /**
     * connect HEAD requests to proxy of Pod
     * operationId: connectCoreV1HeadNamespacedPodProxy
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy
     */
    connectCoreV1HeadNamespacedPodProxy(params: Params$connectCoreV1HeadNamespacedPodProxy, option?: RequestOption): Promise<Response$connectCoreV1HeadNamespacedPodProxy$Status$200["*/*"]>;
    /**
     * connect PATCH requests to proxy of Pod
     * operationId: connectCoreV1PatchNamespacedPodProxy
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy
     */
    connectCoreV1PatchNamespacedPodProxy(params: Params$connectCoreV1PatchNamespacedPodProxy, option?: RequestOption): Promise<Response$connectCoreV1PatchNamespacedPodProxy$Status$200["*/*"]>;
    /**
     * connect GET requests to proxy of Pod
     * operationId: connectCoreV1GetNamespacedPodProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy/{path}
     */
    connectCoreV1GetNamespacedPodProxyWithPath(params: Params$connectCoreV1GetNamespacedPodProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1GetNamespacedPodProxyWithPath$Status$200["*/*"]>;
    /**
     * connect PUT requests to proxy of Pod
     * operationId: connectCoreV1PutNamespacedPodProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy/{path}
     */
    connectCoreV1PutNamespacedPodProxyWithPath(params: Params$connectCoreV1PutNamespacedPodProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1PutNamespacedPodProxyWithPath$Status$200["*/*"]>;
    /**
     * connect POST requests to proxy of Pod
     * operationId: connectCoreV1PostNamespacedPodProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy/{path}
     */
    connectCoreV1PostNamespacedPodProxyWithPath(params: Params$connectCoreV1PostNamespacedPodProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1PostNamespacedPodProxyWithPath$Status$200["*/*"]>;
    /**
     * connect DELETE requests to proxy of Pod
     * operationId: connectCoreV1DeleteNamespacedPodProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy/{path}
     */
    connectCoreV1DeleteNamespacedPodProxyWithPath(params: Params$connectCoreV1DeleteNamespacedPodProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1DeleteNamespacedPodProxyWithPath$Status$200["*/*"]>;
    /**
     * connect OPTIONS requests to proxy of Pod
     * operationId: connectCoreV1OptionsNamespacedPodProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy/{path}
     */
    connectCoreV1OptionsNamespacedPodProxyWithPath(params: Params$connectCoreV1OptionsNamespacedPodProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1OptionsNamespacedPodProxyWithPath$Status$200["*/*"]>;
    /**
     * connect HEAD requests to proxy of Pod
     * operationId: connectCoreV1HeadNamespacedPodProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy/{path}
     */
    connectCoreV1HeadNamespacedPodProxyWithPath(params: Params$connectCoreV1HeadNamespacedPodProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1HeadNamespacedPodProxyWithPath$Status$200["*/*"]>;
    /**
     * connect PATCH requests to proxy of Pod
     * operationId: connectCoreV1PatchNamespacedPodProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/proxy/{path}
     */
    connectCoreV1PatchNamespacedPodProxyWithPath(params: Params$connectCoreV1PatchNamespacedPodProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1PatchNamespacedPodProxyWithPath$Status$200["*/*"]>;
    /**
     * read status of the specified Pod
     * operationId: readCoreV1NamespacedPodStatus
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/status
     */
    readCoreV1NamespacedPodStatus<ResponseContentType extends ResponseContentType$readCoreV1NamespacedPodStatus>(params: Params$readCoreV1NamespacedPodStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedPodStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified Pod
     * operationId: replaceCoreV1NamespacedPodStatus
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/status
     */
    replaceCoreV1NamespacedPodStatus<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedPodStatus>(params: Params$replaceCoreV1NamespacedPodStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedPodStatus$Status$200 | Response$replaceCoreV1NamespacedPodStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified Pod
     * operationId: patchCoreV1NamespacedPodStatus
     * Request URI: /api/v1/namespaces/{namespace}/pods/{name}/status
     */
    patchCoreV1NamespacedPodStatus<RequestContentType extends RequestContentType$patchCoreV1NamespacedPodStatus, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedPodStatus>(params: Params$patchCoreV1NamespacedPodStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedPodStatus$Status$200 | Response$patchCoreV1NamespacedPodStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind PodTemplate
     * operationId: listCoreV1NamespacedPodTemplate
     * Request URI: /api/v1/namespaces/{namespace}/podtemplates
     */
    listCoreV1NamespacedPodTemplate<ResponseContentType extends ResponseContentType$listCoreV1NamespacedPodTemplate>(params: Params$listCoreV1NamespacedPodTemplate<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedPodTemplate$Status$200[ResponseContentType]>;
    /**
     * create a PodTemplate
     * operationId: createCoreV1NamespacedPodTemplate
     * Request URI: /api/v1/namespaces/{namespace}/podtemplates
     */
    createCoreV1NamespacedPodTemplate<ResponseContentType extends ResponseContentType$createCoreV1NamespacedPodTemplate>(params: Params$createCoreV1NamespacedPodTemplate<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedPodTemplate$Status$200 | Response$createCoreV1NamespacedPodTemplate$Status$201 | Response$createCoreV1NamespacedPodTemplate$Status$202)[ResponseContentType]>;
    /**
     * delete collection of PodTemplate
     * operationId: deleteCoreV1CollectionNamespacedPodTemplate
     * Request URI: /api/v1/namespaces/{namespace}/podtemplates
     */
    deleteCoreV1CollectionNamespacedPodTemplate<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedPodTemplate>(params: Params$deleteCoreV1CollectionNamespacedPodTemplate<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedPodTemplate$Status$200[ResponseContentType]>;
    /**
     * read the specified PodTemplate
     * operationId: readCoreV1NamespacedPodTemplate
     * Request URI: /api/v1/namespaces/{namespace}/podtemplates/{name}
     */
    readCoreV1NamespacedPodTemplate<ResponseContentType extends ResponseContentType$readCoreV1NamespacedPodTemplate>(params: Params$readCoreV1NamespacedPodTemplate<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedPodTemplate$Status$200[ResponseContentType]>;
    /**
     * replace the specified PodTemplate
     * operationId: replaceCoreV1NamespacedPodTemplate
     * Request URI: /api/v1/namespaces/{namespace}/podtemplates/{name}
     */
    replaceCoreV1NamespacedPodTemplate<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedPodTemplate>(params: Params$replaceCoreV1NamespacedPodTemplate<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedPodTemplate$Status$200 | Response$replaceCoreV1NamespacedPodTemplate$Status$201)[ResponseContentType]>;
    /**
     * delete a PodTemplate
     * operationId: deleteCoreV1NamespacedPodTemplate
     * Request URI: /api/v1/namespaces/{namespace}/podtemplates/{name}
     */
    deleteCoreV1NamespacedPodTemplate<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedPodTemplate>(params: Params$deleteCoreV1NamespacedPodTemplate<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedPodTemplate$Status$200 | Response$deleteCoreV1NamespacedPodTemplate$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified PodTemplate
     * operationId: patchCoreV1NamespacedPodTemplate
     * Request URI: /api/v1/namespaces/{namespace}/podtemplates/{name}
     */
    patchCoreV1NamespacedPodTemplate<RequestContentType extends RequestContentType$patchCoreV1NamespacedPodTemplate, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedPodTemplate>(params: Params$patchCoreV1NamespacedPodTemplate<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedPodTemplate$Status$200 | Response$patchCoreV1NamespacedPodTemplate$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind ReplicationController
     * operationId: listCoreV1NamespacedReplicationController
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers
     */
    listCoreV1NamespacedReplicationController<ResponseContentType extends ResponseContentType$listCoreV1NamespacedReplicationController>(params: Params$listCoreV1NamespacedReplicationController<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedReplicationController$Status$200[ResponseContentType]>;
    /**
     * create a ReplicationController
     * operationId: createCoreV1NamespacedReplicationController
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers
     */
    createCoreV1NamespacedReplicationController<ResponseContentType extends ResponseContentType$createCoreV1NamespacedReplicationController>(params: Params$createCoreV1NamespacedReplicationController<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedReplicationController$Status$200 | Response$createCoreV1NamespacedReplicationController$Status$201 | Response$createCoreV1NamespacedReplicationController$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ReplicationController
     * operationId: deleteCoreV1CollectionNamespacedReplicationController
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers
     */
    deleteCoreV1CollectionNamespacedReplicationController<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedReplicationController>(params: Params$deleteCoreV1CollectionNamespacedReplicationController<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedReplicationController$Status$200[ResponseContentType]>;
    /**
     * read the specified ReplicationController
     * operationId: readCoreV1NamespacedReplicationController
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}
     */
    readCoreV1NamespacedReplicationController<ResponseContentType extends ResponseContentType$readCoreV1NamespacedReplicationController>(params: Params$readCoreV1NamespacedReplicationController<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedReplicationController$Status$200[ResponseContentType]>;
    /**
     * replace the specified ReplicationController
     * operationId: replaceCoreV1NamespacedReplicationController
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}
     */
    replaceCoreV1NamespacedReplicationController<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedReplicationController>(params: Params$replaceCoreV1NamespacedReplicationController<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedReplicationController$Status$200 | Response$replaceCoreV1NamespacedReplicationController$Status$201)[ResponseContentType]>;
    /**
     * delete a ReplicationController
     * operationId: deleteCoreV1NamespacedReplicationController
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}
     */
    deleteCoreV1NamespacedReplicationController<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedReplicationController>(params: Params$deleteCoreV1NamespacedReplicationController<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedReplicationController$Status$200 | Response$deleteCoreV1NamespacedReplicationController$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ReplicationController
     * operationId: patchCoreV1NamespacedReplicationController
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}
     */
    patchCoreV1NamespacedReplicationController<RequestContentType extends RequestContentType$patchCoreV1NamespacedReplicationController, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedReplicationController>(params: Params$patchCoreV1NamespacedReplicationController<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedReplicationController$Status$200 | Response$patchCoreV1NamespacedReplicationController$Status$201)[ResponseContentType]>;
    /**
     * read scale of the specified ReplicationController
     * operationId: readCoreV1NamespacedReplicationControllerScale
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}/scale
     */
    readCoreV1NamespacedReplicationControllerScale<ResponseContentType extends ResponseContentType$readCoreV1NamespacedReplicationControllerScale>(params: Params$readCoreV1NamespacedReplicationControllerScale<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedReplicationControllerScale$Status$200[ResponseContentType]>;
    /**
     * replace scale of the specified ReplicationController
     * operationId: replaceCoreV1NamespacedReplicationControllerScale
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}/scale
     */
    replaceCoreV1NamespacedReplicationControllerScale<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedReplicationControllerScale>(params: Params$replaceCoreV1NamespacedReplicationControllerScale<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedReplicationControllerScale$Status$200 | Response$replaceCoreV1NamespacedReplicationControllerScale$Status$201)[ResponseContentType]>;
    /**
     * partially update scale of the specified ReplicationController
     * operationId: patchCoreV1NamespacedReplicationControllerScale
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}/scale
     */
    patchCoreV1NamespacedReplicationControllerScale<RequestContentType extends RequestContentType$patchCoreV1NamespacedReplicationControllerScale, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedReplicationControllerScale>(params: Params$patchCoreV1NamespacedReplicationControllerScale<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedReplicationControllerScale$Status$200 | Response$patchCoreV1NamespacedReplicationControllerScale$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified ReplicationController
     * operationId: readCoreV1NamespacedReplicationControllerStatus
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}/status
     */
    readCoreV1NamespacedReplicationControllerStatus<ResponseContentType extends ResponseContentType$readCoreV1NamespacedReplicationControllerStatus>(params: Params$readCoreV1NamespacedReplicationControllerStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedReplicationControllerStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified ReplicationController
     * operationId: replaceCoreV1NamespacedReplicationControllerStatus
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}/status
     */
    replaceCoreV1NamespacedReplicationControllerStatus<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedReplicationControllerStatus>(params: Params$replaceCoreV1NamespacedReplicationControllerStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedReplicationControllerStatus$Status$200 | Response$replaceCoreV1NamespacedReplicationControllerStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified ReplicationController
     * operationId: patchCoreV1NamespacedReplicationControllerStatus
     * Request URI: /api/v1/namespaces/{namespace}/replicationcontrollers/{name}/status
     */
    patchCoreV1NamespacedReplicationControllerStatus<RequestContentType extends RequestContentType$patchCoreV1NamespacedReplicationControllerStatus, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedReplicationControllerStatus>(params: Params$patchCoreV1NamespacedReplicationControllerStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedReplicationControllerStatus$Status$200 | Response$patchCoreV1NamespacedReplicationControllerStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind ResourceQuota
     * operationId: listCoreV1NamespacedResourceQuota
     * Request URI: /api/v1/namespaces/{namespace}/resourcequotas
     */
    listCoreV1NamespacedResourceQuota<ResponseContentType extends ResponseContentType$listCoreV1NamespacedResourceQuota>(params: Params$listCoreV1NamespacedResourceQuota<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedResourceQuota$Status$200[ResponseContentType]>;
    /**
     * create a ResourceQuota
     * operationId: createCoreV1NamespacedResourceQuota
     * Request URI: /api/v1/namespaces/{namespace}/resourcequotas
     */
    createCoreV1NamespacedResourceQuota<ResponseContentType extends ResponseContentType$createCoreV1NamespacedResourceQuota>(params: Params$createCoreV1NamespacedResourceQuota<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedResourceQuota$Status$200 | Response$createCoreV1NamespacedResourceQuota$Status$201 | Response$createCoreV1NamespacedResourceQuota$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ResourceQuota
     * operationId: deleteCoreV1CollectionNamespacedResourceQuota
     * Request URI: /api/v1/namespaces/{namespace}/resourcequotas
     */
    deleteCoreV1CollectionNamespacedResourceQuota<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedResourceQuota>(params: Params$deleteCoreV1CollectionNamespacedResourceQuota<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedResourceQuota$Status$200[ResponseContentType]>;
    /**
     * read the specified ResourceQuota
     * operationId: readCoreV1NamespacedResourceQuota
     * Request URI: /api/v1/namespaces/{namespace}/resourcequotas/{name}
     */
    readCoreV1NamespacedResourceQuota<ResponseContentType extends ResponseContentType$readCoreV1NamespacedResourceQuota>(params: Params$readCoreV1NamespacedResourceQuota<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedResourceQuota$Status$200[ResponseContentType]>;
    /**
     * replace the specified ResourceQuota
     * operationId: replaceCoreV1NamespacedResourceQuota
     * Request URI: /api/v1/namespaces/{namespace}/resourcequotas/{name}
     */
    replaceCoreV1NamespacedResourceQuota<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedResourceQuota>(params: Params$replaceCoreV1NamespacedResourceQuota<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedResourceQuota$Status$200 | Response$replaceCoreV1NamespacedResourceQuota$Status$201)[ResponseContentType]>;
    /**
     * delete a ResourceQuota
     * operationId: deleteCoreV1NamespacedResourceQuota
     * Request URI: /api/v1/namespaces/{namespace}/resourcequotas/{name}
     */
    deleteCoreV1NamespacedResourceQuota<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedResourceQuota>(params: Params$deleteCoreV1NamespacedResourceQuota<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedResourceQuota$Status$200 | Response$deleteCoreV1NamespacedResourceQuota$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ResourceQuota
     * operationId: patchCoreV1NamespacedResourceQuota
     * Request URI: /api/v1/namespaces/{namespace}/resourcequotas/{name}
     */
    patchCoreV1NamespacedResourceQuota<RequestContentType extends RequestContentType$patchCoreV1NamespacedResourceQuota, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedResourceQuota>(params: Params$patchCoreV1NamespacedResourceQuota<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedResourceQuota$Status$200 | Response$patchCoreV1NamespacedResourceQuota$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified ResourceQuota
     * operationId: readCoreV1NamespacedResourceQuotaStatus
     * Request URI: /api/v1/namespaces/{namespace}/resourcequotas/{name}/status
     */
    readCoreV1NamespacedResourceQuotaStatus<ResponseContentType extends ResponseContentType$readCoreV1NamespacedResourceQuotaStatus>(params: Params$readCoreV1NamespacedResourceQuotaStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedResourceQuotaStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified ResourceQuota
     * operationId: replaceCoreV1NamespacedResourceQuotaStatus
     * Request URI: /api/v1/namespaces/{namespace}/resourcequotas/{name}/status
     */
    replaceCoreV1NamespacedResourceQuotaStatus<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedResourceQuotaStatus>(params: Params$replaceCoreV1NamespacedResourceQuotaStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedResourceQuotaStatus$Status$200 | Response$replaceCoreV1NamespacedResourceQuotaStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified ResourceQuota
     * operationId: patchCoreV1NamespacedResourceQuotaStatus
     * Request URI: /api/v1/namespaces/{namespace}/resourcequotas/{name}/status
     */
    patchCoreV1NamespacedResourceQuotaStatus<RequestContentType extends RequestContentType$patchCoreV1NamespacedResourceQuotaStatus, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedResourceQuotaStatus>(params: Params$patchCoreV1NamespacedResourceQuotaStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedResourceQuotaStatus$Status$200 | Response$patchCoreV1NamespacedResourceQuotaStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind Secret
     * operationId: listCoreV1NamespacedSecret
     * Request URI: /api/v1/namespaces/{namespace}/secrets
     */
    listCoreV1NamespacedSecret<ResponseContentType extends ResponseContentType$listCoreV1NamespacedSecret>(params: Params$listCoreV1NamespacedSecret<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedSecret$Status$200[ResponseContentType]>;
    /**
     * create a Secret
     * operationId: createCoreV1NamespacedSecret
     * Request URI: /api/v1/namespaces/{namespace}/secrets
     */
    createCoreV1NamespacedSecret<ResponseContentType extends ResponseContentType$createCoreV1NamespacedSecret>(params: Params$createCoreV1NamespacedSecret<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedSecret$Status$200 | Response$createCoreV1NamespacedSecret$Status$201 | Response$createCoreV1NamespacedSecret$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Secret
     * operationId: deleteCoreV1CollectionNamespacedSecret
     * Request URI: /api/v1/namespaces/{namespace}/secrets
     */
    deleteCoreV1CollectionNamespacedSecret<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedSecret>(params: Params$deleteCoreV1CollectionNamespacedSecret<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedSecret$Status$200[ResponseContentType]>;
    /**
     * read the specified Secret
     * operationId: readCoreV1NamespacedSecret
     * Request URI: /api/v1/namespaces/{namespace}/secrets/{name}
     */
    readCoreV1NamespacedSecret<ResponseContentType extends ResponseContentType$readCoreV1NamespacedSecret>(params: Params$readCoreV1NamespacedSecret<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedSecret$Status$200[ResponseContentType]>;
    /**
     * replace the specified Secret
     * operationId: replaceCoreV1NamespacedSecret
     * Request URI: /api/v1/namespaces/{namespace}/secrets/{name}
     */
    replaceCoreV1NamespacedSecret<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedSecret>(params: Params$replaceCoreV1NamespacedSecret<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedSecret$Status$200 | Response$replaceCoreV1NamespacedSecret$Status$201)[ResponseContentType]>;
    /**
     * delete a Secret
     * operationId: deleteCoreV1NamespacedSecret
     * Request URI: /api/v1/namespaces/{namespace}/secrets/{name}
     */
    deleteCoreV1NamespacedSecret<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedSecret>(params: Params$deleteCoreV1NamespacedSecret<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedSecret$Status$200 | Response$deleteCoreV1NamespacedSecret$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Secret
     * operationId: patchCoreV1NamespacedSecret
     * Request URI: /api/v1/namespaces/{namespace}/secrets/{name}
     */
    patchCoreV1NamespacedSecret<RequestContentType extends RequestContentType$patchCoreV1NamespacedSecret, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedSecret>(params: Params$patchCoreV1NamespacedSecret<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedSecret$Status$200 | Response$patchCoreV1NamespacedSecret$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind ServiceAccount
     * operationId: listCoreV1NamespacedServiceAccount
     * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts
     */
    listCoreV1NamespacedServiceAccount<ResponseContentType extends ResponseContentType$listCoreV1NamespacedServiceAccount>(params: Params$listCoreV1NamespacedServiceAccount<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedServiceAccount$Status$200[ResponseContentType]>;
    /**
     * create a ServiceAccount
     * operationId: createCoreV1NamespacedServiceAccount
     * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts
     */
    createCoreV1NamespacedServiceAccount<ResponseContentType extends ResponseContentType$createCoreV1NamespacedServiceAccount>(params: Params$createCoreV1NamespacedServiceAccount<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedServiceAccount$Status$200 | Response$createCoreV1NamespacedServiceAccount$Status$201 | Response$createCoreV1NamespacedServiceAccount$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ServiceAccount
     * operationId: deleteCoreV1CollectionNamespacedServiceAccount
     * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts
     */
    deleteCoreV1CollectionNamespacedServiceAccount<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedServiceAccount>(params: Params$deleteCoreV1CollectionNamespacedServiceAccount<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedServiceAccount$Status$200[ResponseContentType]>;
    /**
     * read the specified ServiceAccount
     * operationId: readCoreV1NamespacedServiceAccount
     * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts/{name}
     */
    readCoreV1NamespacedServiceAccount<ResponseContentType extends ResponseContentType$readCoreV1NamespacedServiceAccount>(params: Params$readCoreV1NamespacedServiceAccount<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedServiceAccount$Status$200[ResponseContentType]>;
    /**
     * replace the specified ServiceAccount
     * operationId: replaceCoreV1NamespacedServiceAccount
     * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts/{name}
     */
    replaceCoreV1NamespacedServiceAccount<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedServiceAccount>(params: Params$replaceCoreV1NamespacedServiceAccount<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedServiceAccount$Status$200 | Response$replaceCoreV1NamespacedServiceAccount$Status$201)[ResponseContentType]>;
    /**
     * delete a ServiceAccount
     * operationId: deleteCoreV1NamespacedServiceAccount
     * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts/{name}
     */
    deleteCoreV1NamespacedServiceAccount<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedServiceAccount>(params: Params$deleteCoreV1NamespacedServiceAccount<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedServiceAccount$Status$200 | Response$deleteCoreV1NamespacedServiceAccount$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ServiceAccount
     * operationId: patchCoreV1NamespacedServiceAccount
     * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts/{name}
     */
    patchCoreV1NamespacedServiceAccount<RequestContentType extends RequestContentType$patchCoreV1NamespacedServiceAccount, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedServiceAccount>(params: Params$patchCoreV1NamespacedServiceAccount<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedServiceAccount$Status$200 | Response$patchCoreV1NamespacedServiceAccount$Status$201)[ResponseContentType]>;
    /**
     * create token of a ServiceAccount
     * operationId: createCoreV1NamespacedServiceAccountToken
     * Request URI: /api/v1/namespaces/{namespace}/serviceaccounts/{name}/token
     */
    createCoreV1NamespacedServiceAccountToken<ResponseContentType extends ResponseContentType$createCoreV1NamespacedServiceAccountToken>(params: Params$createCoreV1NamespacedServiceAccountToken<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedServiceAccountToken$Status$200 | Response$createCoreV1NamespacedServiceAccountToken$Status$201 | Response$createCoreV1NamespacedServiceAccountToken$Status$202)[ResponseContentType]>;
    /**
     * list or watch objects of kind Service
     * operationId: listCoreV1NamespacedService
     * Request URI: /api/v1/namespaces/{namespace}/services
     */
    listCoreV1NamespacedService<ResponseContentType extends ResponseContentType$listCoreV1NamespacedService>(params: Params$listCoreV1NamespacedService<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1NamespacedService$Status$200[ResponseContentType]>;
    /**
     * create a Service
     * operationId: createCoreV1NamespacedService
     * Request URI: /api/v1/namespaces/{namespace}/services
     */
    createCoreV1NamespacedService<ResponseContentType extends ResponseContentType$createCoreV1NamespacedService>(params: Params$createCoreV1NamespacedService<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1NamespacedService$Status$200 | Response$createCoreV1NamespacedService$Status$201 | Response$createCoreV1NamespacedService$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Service
     * operationId: deleteCoreV1CollectionNamespacedService
     * Request URI: /api/v1/namespaces/{namespace}/services
     */
    deleteCoreV1CollectionNamespacedService<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNamespacedService>(params: Params$deleteCoreV1CollectionNamespacedService<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNamespacedService$Status$200[ResponseContentType]>;
    /**
     * read the specified Service
     * operationId: readCoreV1NamespacedService
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}
     */
    readCoreV1NamespacedService<ResponseContentType extends ResponseContentType$readCoreV1NamespacedService>(params: Params$readCoreV1NamespacedService<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedService$Status$200[ResponseContentType]>;
    /**
     * replace the specified Service
     * operationId: replaceCoreV1NamespacedService
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}
     */
    replaceCoreV1NamespacedService<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedService>(params: Params$replaceCoreV1NamespacedService<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedService$Status$200 | Response$replaceCoreV1NamespacedService$Status$201)[ResponseContentType]>;
    /**
     * delete a Service
     * operationId: deleteCoreV1NamespacedService
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}
     */
    deleteCoreV1NamespacedService<ResponseContentType extends ResponseContentType$deleteCoreV1NamespacedService>(params: Params$deleteCoreV1NamespacedService<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1NamespacedService$Status$200 | Response$deleteCoreV1NamespacedService$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Service
     * operationId: patchCoreV1NamespacedService
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}
     */
    patchCoreV1NamespacedService<RequestContentType extends RequestContentType$patchCoreV1NamespacedService, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedService>(params: Params$patchCoreV1NamespacedService<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedService$Status$200 | Response$patchCoreV1NamespacedService$Status$201)[ResponseContentType]>;
    /**
     * connect GET requests to proxy of Service
     * operationId: connectCoreV1GetNamespacedServiceProxy
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy
     */
    connectCoreV1GetNamespacedServiceProxy(params: Params$connectCoreV1GetNamespacedServiceProxy, option?: RequestOption): Promise<Response$connectCoreV1GetNamespacedServiceProxy$Status$200["*/*"]>;
    /**
     * connect PUT requests to proxy of Service
     * operationId: connectCoreV1PutNamespacedServiceProxy
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy
     */
    connectCoreV1PutNamespacedServiceProxy(params: Params$connectCoreV1PutNamespacedServiceProxy, option?: RequestOption): Promise<Response$connectCoreV1PutNamespacedServiceProxy$Status$200["*/*"]>;
    /**
     * connect POST requests to proxy of Service
     * operationId: connectCoreV1PostNamespacedServiceProxy
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy
     */
    connectCoreV1PostNamespacedServiceProxy(params: Params$connectCoreV1PostNamespacedServiceProxy, option?: RequestOption): Promise<Response$connectCoreV1PostNamespacedServiceProxy$Status$200["*/*"]>;
    /**
     * connect DELETE requests to proxy of Service
     * operationId: connectCoreV1DeleteNamespacedServiceProxy
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy
     */
    connectCoreV1DeleteNamespacedServiceProxy(params: Params$connectCoreV1DeleteNamespacedServiceProxy, option?: RequestOption): Promise<Response$connectCoreV1DeleteNamespacedServiceProxy$Status$200["*/*"]>;
    /**
     * connect OPTIONS requests to proxy of Service
     * operationId: connectCoreV1OptionsNamespacedServiceProxy
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy
     */
    connectCoreV1OptionsNamespacedServiceProxy(params: Params$connectCoreV1OptionsNamespacedServiceProxy, option?: RequestOption): Promise<Response$connectCoreV1OptionsNamespacedServiceProxy$Status$200["*/*"]>;
    /**
     * connect HEAD requests to proxy of Service
     * operationId: connectCoreV1HeadNamespacedServiceProxy
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy
     */
    connectCoreV1HeadNamespacedServiceProxy(params: Params$connectCoreV1HeadNamespacedServiceProxy, option?: RequestOption): Promise<Response$connectCoreV1HeadNamespacedServiceProxy$Status$200["*/*"]>;
    /**
     * connect PATCH requests to proxy of Service
     * operationId: connectCoreV1PatchNamespacedServiceProxy
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy
     */
    connectCoreV1PatchNamespacedServiceProxy(params: Params$connectCoreV1PatchNamespacedServiceProxy, option?: RequestOption): Promise<Response$connectCoreV1PatchNamespacedServiceProxy$Status$200["*/*"]>;
    /**
     * connect GET requests to proxy of Service
     * operationId: connectCoreV1GetNamespacedServiceProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy/{path}
     */
    connectCoreV1GetNamespacedServiceProxyWithPath(params: Params$connectCoreV1GetNamespacedServiceProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1GetNamespacedServiceProxyWithPath$Status$200["*/*"]>;
    /**
     * connect PUT requests to proxy of Service
     * operationId: connectCoreV1PutNamespacedServiceProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy/{path}
     */
    connectCoreV1PutNamespacedServiceProxyWithPath(params: Params$connectCoreV1PutNamespacedServiceProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1PutNamespacedServiceProxyWithPath$Status$200["*/*"]>;
    /**
     * connect POST requests to proxy of Service
     * operationId: connectCoreV1PostNamespacedServiceProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy/{path}
     */
    connectCoreV1PostNamespacedServiceProxyWithPath(params: Params$connectCoreV1PostNamespacedServiceProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1PostNamespacedServiceProxyWithPath$Status$200["*/*"]>;
    /**
     * connect DELETE requests to proxy of Service
     * operationId: connectCoreV1DeleteNamespacedServiceProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy/{path}
     */
    connectCoreV1DeleteNamespacedServiceProxyWithPath(params: Params$connectCoreV1DeleteNamespacedServiceProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1DeleteNamespacedServiceProxyWithPath$Status$200["*/*"]>;
    /**
     * connect OPTIONS requests to proxy of Service
     * operationId: connectCoreV1OptionsNamespacedServiceProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy/{path}
     */
    connectCoreV1OptionsNamespacedServiceProxyWithPath(params: Params$connectCoreV1OptionsNamespacedServiceProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1OptionsNamespacedServiceProxyWithPath$Status$200["*/*"]>;
    /**
     * connect HEAD requests to proxy of Service
     * operationId: connectCoreV1HeadNamespacedServiceProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy/{path}
     */
    connectCoreV1HeadNamespacedServiceProxyWithPath(params: Params$connectCoreV1HeadNamespacedServiceProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1HeadNamespacedServiceProxyWithPath$Status$200["*/*"]>;
    /**
     * connect PATCH requests to proxy of Service
     * operationId: connectCoreV1PatchNamespacedServiceProxyWithPath
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/proxy/{path}
     */
    connectCoreV1PatchNamespacedServiceProxyWithPath(params: Params$connectCoreV1PatchNamespacedServiceProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1PatchNamespacedServiceProxyWithPath$Status$200["*/*"]>;
    /**
     * read status of the specified Service
     * operationId: readCoreV1NamespacedServiceStatus
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/status
     */
    readCoreV1NamespacedServiceStatus<ResponseContentType extends ResponseContentType$readCoreV1NamespacedServiceStatus>(params: Params$readCoreV1NamespacedServiceStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespacedServiceStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified Service
     * operationId: replaceCoreV1NamespacedServiceStatus
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/status
     */
    replaceCoreV1NamespacedServiceStatus<ResponseContentType extends ResponseContentType$replaceCoreV1NamespacedServiceStatus>(params: Params$replaceCoreV1NamespacedServiceStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespacedServiceStatus$Status$200 | Response$replaceCoreV1NamespacedServiceStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified Service
     * operationId: patchCoreV1NamespacedServiceStatus
     * Request URI: /api/v1/namespaces/{namespace}/services/{name}/status
     */
    patchCoreV1NamespacedServiceStatus<RequestContentType extends RequestContentType$patchCoreV1NamespacedServiceStatus, ResponseContentType extends ResponseContentType$patchCoreV1NamespacedServiceStatus>(params: Params$patchCoreV1NamespacedServiceStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespacedServiceStatus$Status$200 | Response$patchCoreV1NamespacedServiceStatus$Status$201)[ResponseContentType]>;
    /**
     * read the specified Namespace
     * operationId: readCoreV1Namespace
     * Request URI: /api/v1/namespaces/{name}
     */
    readCoreV1Namespace<ResponseContentType extends ResponseContentType$readCoreV1Namespace>(params: Params$readCoreV1Namespace<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1Namespace$Status$200[ResponseContentType]>;
    /**
     * replace the specified Namespace
     * operationId: replaceCoreV1Namespace
     * Request URI: /api/v1/namespaces/{name}
     */
    replaceCoreV1Namespace<ResponseContentType extends ResponseContentType$replaceCoreV1Namespace>(params: Params$replaceCoreV1Namespace<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1Namespace$Status$200 | Response$replaceCoreV1Namespace$Status$201)[ResponseContentType]>;
    /**
     * delete a Namespace
     * operationId: deleteCoreV1Namespace
     * Request URI: /api/v1/namespaces/{name}
     */
    deleteCoreV1Namespace<ResponseContentType extends ResponseContentType$deleteCoreV1Namespace>(params: Params$deleteCoreV1Namespace<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1Namespace$Status$200 | Response$deleteCoreV1Namespace$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Namespace
     * operationId: patchCoreV1Namespace
     * Request URI: /api/v1/namespaces/{name}
     */
    patchCoreV1Namespace<RequestContentType extends RequestContentType$patchCoreV1Namespace, ResponseContentType extends ResponseContentType$patchCoreV1Namespace>(params: Params$patchCoreV1Namespace<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1Namespace$Status$200 | Response$patchCoreV1Namespace$Status$201)[ResponseContentType]>;
    /**
     * replace finalize of the specified Namespace
     * operationId: replaceCoreV1NamespaceFinalize
     * Request URI: /api/v1/namespaces/{name}/finalize
     */
    replaceCoreV1NamespaceFinalize<ResponseContentType extends ResponseContentType$replaceCoreV1NamespaceFinalize>(params: Params$replaceCoreV1NamespaceFinalize<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespaceFinalize$Status$200 | Response$replaceCoreV1NamespaceFinalize$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified Namespace
     * operationId: readCoreV1NamespaceStatus
     * Request URI: /api/v1/namespaces/{name}/status
     */
    readCoreV1NamespaceStatus<ResponseContentType extends ResponseContentType$readCoreV1NamespaceStatus>(params: Params$readCoreV1NamespaceStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NamespaceStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified Namespace
     * operationId: replaceCoreV1NamespaceStatus
     * Request URI: /api/v1/namespaces/{name}/status
     */
    replaceCoreV1NamespaceStatus<ResponseContentType extends ResponseContentType$replaceCoreV1NamespaceStatus>(params: Params$replaceCoreV1NamespaceStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NamespaceStatus$Status$200 | Response$replaceCoreV1NamespaceStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified Namespace
     * operationId: patchCoreV1NamespaceStatus
     * Request URI: /api/v1/namespaces/{name}/status
     */
    patchCoreV1NamespaceStatus<RequestContentType extends RequestContentType$patchCoreV1NamespaceStatus, ResponseContentType extends ResponseContentType$patchCoreV1NamespaceStatus>(params: Params$patchCoreV1NamespaceStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NamespaceStatus$Status$200 | Response$patchCoreV1NamespaceStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind Node
     * operationId: listCoreV1Node
     * Request URI: /api/v1/nodes
     */
    listCoreV1Node<ResponseContentType extends ResponseContentType$listCoreV1Node>(params: Params$listCoreV1Node<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1Node$Status$200[ResponseContentType]>;
    /**
     * create a Node
     * operationId: createCoreV1Node
     * Request URI: /api/v1/nodes
     */
    createCoreV1Node<ResponseContentType extends ResponseContentType$createCoreV1Node>(params: Params$createCoreV1Node<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1Node$Status$200 | Response$createCoreV1Node$Status$201 | Response$createCoreV1Node$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Node
     * operationId: deleteCoreV1CollectionNode
     * Request URI: /api/v1/nodes
     */
    deleteCoreV1CollectionNode<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionNode>(params: Params$deleteCoreV1CollectionNode<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionNode$Status$200[ResponseContentType]>;
    /**
     * read the specified Node
     * operationId: readCoreV1Node
     * Request URI: /api/v1/nodes/{name}
     */
    readCoreV1Node<ResponseContentType extends ResponseContentType$readCoreV1Node>(params: Params$readCoreV1Node<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1Node$Status$200[ResponseContentType]>;
    /**
     * replace the specified Node
     * operationId: replaceCoreV1Node
     * Request URI: /api/v1/nodes/{name}
     */
    replaceCoreV1Node<ResponseContentType extends ResponseContentType$replaceCoreV1Node>(params: Params$replaceCoreV1Node<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1Node$Status$200 | Response$replaceCoreV1Node$Status$201)[ResponseContentType]>;
    /**
     * delete a Node
     * operationId: deleteCoreV1Node
     * Request URI: /api/v1/nodes/{name}
     */
    deleteCoreV1Node<ResponseContentType extends ResponseContentType$deleteCoreV1Node>(params: Params$deleteCoreV1Node<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1Node$Status$200 | Response$deleteCoreV1Node$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Node
     * operationId: patchCoreV1Node
     * Request URI: /api/v1/nodes/{name}
     */
    patchCoreV1Node<RequestContentType extends RequestContentType$patchCoreV1Node, ResponseContentType extends ResponseContentType$patchCoreV1Node>(params: Params$patchCoreV1Node<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1Node$Status$200 | Response$patchCoreV1Node$Status$201)[ResponseContentType]>;
    /**
     * connect GET requests to proxy of Node
     * operationId: connectCoreV1GetNodeProxy
     * Request URI: /api/v1/nodes/{name}/proxy
     */
    connectCoreV1GetNodeProxy(params: Params$connectCoreV1GetNodeProxy, option?: RequestOption): Promise<Response$connectCoreV1GetNodeProxy$Status$200["*/*"]>;
    /**
     * connect PUT requests to proxy of Node
     * operationId: connectCoreV1PutNodeProxy
     * Request URI: /api/v1/nodes/{name}/proxy
     */
    connectCoreV1PutNodeProxy(params: Params$connectCoreV1PutNodeProxy, option?: RequestOption): Promise<Response$connectCoreV1PutNodeProxy$Status$200["*/*"]>;
    /**
     * connect POST requests to proxy of Node
     * operationId: connectCoreV1PostNodeProxy
     * Request URI: /api/v1/nodes/{name}/proxy
     */
    connectCoreV1PostNodeProxy(params: Params$connectCoreV1PostNodeProxy, option?: RequestOption): Promise<Response$connectCoreV1PostNodeProxy$Status$200["*/*"]>;
    /**
     * connect DELETE requests to proxy of Node
     * operationId: connectCoreV1DeleteNodeProxy
     * Request URI: /api/v1/nodes/{name}/proxy
     */
    connectCoreV1DeleteNodeProxy(params: Params$connectCoreV1DeleteNodeProxy, option?: RequestOption): Promise<Response$connectCoreV1DeleteNodeProxy$Status$200["*/*"]>;
    /**
     * connect OPTIONS requests to proxy of Node
     * operationId: connectCoreV1OptionsNodeProxy
     * Request URI: /api/v1/nodes/{name}/proxy
     */
    connectCoreV1OptionsNodeProxy(params: Params$connectCoreV1OptionsNodeProxy, option?: RequestOption): Promise<Response$connectCoreV1OptionsNodeProxy$Status$200["*/*"]>;
    /**
     * connect HEAD requests to proxy of Node
     * operationId: connectCoreV1HeadNodeProxy
     * Request URI: /api/v1/nodes/{name}/proxy
     */
    connectCoreV1HeadNodeProxy(params: Params$connectCoreV1HeadNodeProxy, option?: RequestOption): Promise<Response$connectCoreV1HeadNodeProxy$Status$200["*/*"]>;
    /**
     * connect PATCH requests to proxy of Node
     * operationId: connectCoreV1PatchNodeProxy
     * Request URI: /api/v1/nodes/{name}/proxy
     */
    connectCoreV1PatchNodeProxy(params: Params$connectCoreV1PatchNodeProxy, option?: RequestOption): Promise<Response$connectCoreV1PatchNodeProxy$Status$200["*/*"]>;
    /**
     * connect GET requests to proxy of Node
     * operationId: connectCoreV1GetNodeProxyWithPath
     * Request URI: /api/v1/nodes/{name}/proxy/{path}
     */
    connectCoreV1GetNodeProxyWithPath(params: Params$connectCoreV1GetNodeProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1GetNodeProxyWithPath$Status$200["*/*"]>;
    /**
     * connect PUT requests to proxy of Node
     * operationId: connectCoreV1PutNodeProxyWithPath
     * Request URI: /api/v1/nodes/{name}/proxy/{path}
     */
    connectCoreV1PutNodeProxyWithPath(params: Params$connectCoreV1PutNodeProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1PutNodeProxyWithPath$Status$200["*/*"]>;
    /**
     * connect POST requests to proxy of Node
     * operationId: connectCoreV1PostNodeProxyWithPath
     * Request URI: /api/v1/nodes/{name}/proxy/{path}
     */
    connectCoreV1PostNodeProxyWithPath(params: Params$connectCoreV1PostNodeProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1PostNodeProxyWithPath$Status$200["*/*"]>;
    /**
     * connect DELETE requests to proxy of Node
     * operationId: connectCoreV1DeleteNodeProxyWithPath
     * Request URI: /api/v1/nodes/{name}/proxy/{path}
     */
    connectCoreV1DeleteNodeProxyWithPath(params: Params$connectCoreV1DeleteNodeProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1DeleteNodeProxyWithPath$Status$200["*/*"]>;
    /**
     * connect OPTIONS requests to proxy of Node
     * operationId: connectCoreV1OptionsNodeProxyWithPath
     * Request URI: /api/v1/nodes/{name}/proxy/{path}
     */
    connectCoreV1OptionsNodeProxyWithPath(params: Params$connectCoreV1OptionsNodeProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1OptionsNodeProxyWithPath$Status$200["*/*"]>;
    /**
     * connect HEAD requests to proxy of Node
     * operationId: connectCoreV1HeadNodeProxyWithPath
     * Request URI: /api/v1/nodes/{name}/proxy/{path}
     */
    connectCoreV1HeadNodeProxyWithPath(params: Params$connectCoreV1HeadNodeProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1HeadNodeProxyWithPath$Status$200["*/*"]>;
    /**
     * connect PATCH requests to proxy of Node
     * operationId: connectCoreV1PatchNodeProxyWithPath
     * Request URI: /api/v1/nodes/{name}/proxy/{path}
     */
    connectCoreV1PatchNodeProxyWithPath(params: Params$connectCoreV1PatchNodeProxyWithPath, option?: RequestOption): Promise<Response$connectCoreV1PatchNodeProxyWithPath$Status$200["*/*"]>;
    /**
     * read status of the specified Node
     * operationId: readCoreV1NodeStatus
     * Request URI: /api/v1/nodes/{name}/status
     */
    readCoreV1NodeStatus<ResponseContentType extends ResponseContentType$readCoreV1NodeStatus>(params: Params$readCoreV1NodeStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1NodeStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified Node
     * operationId: replaceCoreV1NodeStatus
     * Request URI: /api/v1/nodes/{name}/status
     */
    replaceCoreV1NodeStatus<ResponseContentType extends ResponseContentType$replaceCoreV1NodeStatus>(params: Params$replaceCoreV1NodeStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1NodeStatus$Status$200 | Response$replaceCoreV1NodeStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified Node
     * operationId: patchCoreV1NodeStatus
     * Request URI: /api/v1/nodes/{name}/status
     */
    patchCoreV1NodeStatus<RequestContentType extends RequestContentType$patchCoreV1NodeStatus, ResponseContentType extends ResponseContentType$patchCoreV1NodeStatus>(params: Params$patchCoreV1NodeStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1NodeStatus$Status$200 | Response$patchCoreV1NodeStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind PersistentVolumeClaim
     * operationId: listCoreV1PersistentVolumeClaimForAllNamespaces
     * Request URI: /api/v1/persistentvolumeclaims
     */
    listCoreV1PersistentVolumeClaimForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1PersistentVolumeClaimForAllNamespaces>(params: Params$listCoreV1PersistentVolumeClaimForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1PersistentVolumeClaimForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind PersistentVolume
     * operationId: listCoreV1PersistentVolume
     * Request URI: /api/v1/persistentvolumes
     */
    listCoreV1PersistentVolume<ResponseContentType extends ResponseContentType$listCoreV1PersistentVolume>(params: Params$listCoreV1PersistentVolume<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1PersistentVolume$Status$200[ResponseContentType]>;
    /**
     * create a PersistentVolume
     * operationId: createCoreV1PersistentVolume
     * Request URI: /api/v1/persistentvolumes
     */
    createCoreV1PersistentVolume<ResponseContentType extends ResponseContentType$createCoreV1PersistentVolume>(params: Params$createCoreV1PersistentVolume<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoreV1PersistentVolume$Status$200 | Response$createCoreV1PersistentVolume$Status$201 | Response$createCoreV1PersistentVolume$Status$202)[ResponseContentType]>;
    /**
     * delete collection of PersistentVolume
     * operationId: deleteCoreV1CollectionPersistentVolume
     * Request URI: /api/v1/persistentvolumes
     */
    deleteCoreV1CollectionPersistentVolume<ResponseContentType extends ResponseContentType$deleteCoreV1CollectionPersistentVolume>(params: Params$deleteCoreV1CollectionPersistentVolume<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoreV1CollectionPersistentVolume$Status$200[ResponseContentType]>;
    /**
     * read the specified PersistentVolume
     * operationId: readCoreV1PersistentVolume
     * Request URI: /api/v1/persistentvolumes/{name}
     */
    readCoreV1PersistentVolume<ResponseContentType extends ResponseContentType$readCoreV1PersistentVolume>(params: Params$readCoreV1PersistentVolume<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1PersistentVolume$Status$200[ResponseContentType]>;
    /**
     * replace the specified PersistentVolume
     * operationId: replaceCoreV1PersistentVolume
     * Request URI: /api/v1/persistentvolumes/{name}
     */
    replaceCoreV1PersistentVolume<ResponseContentType extends ResponseContentType$replaceCoreV1PersistentVolume>(params: Params$replaceCoreV1PersistentVolume<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1PersistentVolume$Status$200 | Response$replaceCoreV1PersistentVolume$Status$201)[ResponseContentType]>;
    /**
     * delete a PersistentVolume
     * operationId: deleteCoreV1PersistentVolume
     * Request URI: /api/v1/persistentvolumes/{name}
     */
    deleteCoreV1PersistentVolume<ResponseContentType extends ResponseContentType$deleteCoreV1PersistentVolume>(params: Params$deleteCoreV1PersistentVolume<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoreV1PersistentVolume$Status$200 | Response$deleteCoreV1PersistentVolume$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified PersistentVolume
     * operationId: patchCoreV1PersistentVolume
     * Request URI: /api/v1/persistentvolumes/{name}
     */
    patchCoreV1PersistentVolume<RequestContentType extends RequestContentType$patchCoreV1PersistentVolume, ResponseContentType extends ResponseContentType$patchCoreV1PersistentVolume>(params: Params$patchCoreV1PersistentVolume<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1PersistentVolume$Status$200 | Response$patchCoreV1PersistentVolume$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified PersistentVolume
     * operationId: readCoreV1PersistentVolumeStatus
     * Request URI: /api/v1/persistentvolumes/{name}/status
     */
    readCoreV1PersistentVolumeStatus<ResponseContentType extends ResponseContentType$readCoreV1PersistentVolumeStatus>(params: Params$readCoreV1PersistentVolumeStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readCoreV1PersistentVolumeStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified PersistentVolume
     * operationId: replaceCoreV1PersistentVolumeStatus
     * Request URI: /api/v1/persistentvolumes/{name}/status
     */
    replaceCoreV1PersistentVolumeStatus<ResponseContentType extends ResponseContentType$replaceCoreV1PersistentVolumeStatus>(params: Params$replaceCoreV1PersistentVolumeStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoreV1PersistentVolumeStatus$Status$200 | Response$replaceCoreV1PersistentVolumeStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified PersistentVolume
     * operationId: patchCoreV1PersistentVolumeStatus
     * Request URI: /api/v1/persistentvolumes/{name}/status
     */
    patchCoreV1PersistentVolumeStatus<RequestContentType extends RequestContentType$patchCoreV1PersistentVolumeStatus, ResponseContentType extends ResponseContentType$patchCoreV1PersistentVolumeStatus>(params: Params$patchCoreV1PersistentVolumeStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoreV1PersistentVolumeStatus$Status$200 | Response$patchCoreV1PersistentVolumeStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind Pod
     * operationId: listCoreV1PodForAllNamespaces
     * Request URI: /api/v1/pods
     */
    listCoreV1PodForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1PodForAllNamespaces>(params: Params$listCoreV1PodForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1PodForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind PodTemplate
     * operationId: listCoreV1PodTemplateForAllNamespaces
     * Request URI: /api/v1/podtemplates
     */
    listCoreV1PodTemplateForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1PodTemplateForAllNamespaces>(params: Params$listCoreV1PodTemplateForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1PodTemplateForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind ReplicationController
     * operationId: listCoreV1ReplicationControllerForAllNamespaces
     * Request URI: /api/v1/replicationcontrollers
     */
    listCoreV1ReplicationControllerForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1ReplicationControllerForAllNamespaces>(params: Params$listCoreV1ReplicationControllerForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1ReplicationControllerForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind ResourceQuota
     * operationId: listCoreV1ResourceQuotaForAllNamespaces
     * Request URI: /api/v1/resourcequotas
     */
    listCoreV1ResourceQuotaForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1ResourceQuotaForAllNamespaces>(params: Params$listCoreV1ResourceQuotaForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1ResourceQuotaForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Secret
     * operationId: listCoreV1SecretForAllNamespaces
     * Request URI: /api/v1/secrets
     */
    listCoreV1SecretForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1SecretForAllNamespaces>(params: Params$listCoreV1SecretForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1SecretForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind ServiceAccount
     * operationId: listCoreV1ServiceAccountForAllNamespaces
     * Request URI: /api/v1/serviceaccounts
     */
    listCoreV1ServiceAccountForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1ServiceAccountForAllNamespaces>(params: Params$listCoreV1ServiceAccountForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1ServiceAccountForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Service
     * operationId: listCoreV1ServiceForAllNamespaces
     * Request URI: /api/v1/services
     */
    listCoreV1ServiceForAllNamespaces<ResponseContentType extends ResponseContentType$listCoreV1ServiceForAllNamespaces>(params: Params$listCoreV1ServiceForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoreV1ServiceForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ConfigMap. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1ConfigMapListForAllNamespaces
     * Request URI: /api/v1/watch/configmaps
     */
    watchCoreV1ConfigMapListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1ConfigMapListForAllNamespaces>(params: Params$watchCoreV1ConfigMapListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1ConfigMapListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Endpoints. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1EndpointsListForAllNamespaces
     * Request URI: /api/v1/watch/endpoints
     */
    watchCoreV1EndpointsListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1EndpointsListForAllNamespaces>(params: Params$watchCoreV1EndpointsListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1EndpointsListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Event. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1EventListForAllNamespaces
     * Request URI: /api/v1/watch/events
     */
    watchCoreV1EventListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1EventListForAllNamespaces>(params: Params$watchCoreV1EventListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1EventListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of LimitRange. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1LimitRangeListForAllNamespaces
     * Request URI: /api/v1/watch/limitranges
     */
    watchCoreV1LimitRangeListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1LimitRangeListForAllNamespaces>(params: Params$watchCoreV1LimitRangeListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1LimitRangeListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Namespace. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespaceList
     * Request URI: /api/v1/watch/namespaces
     */
    watchCoreV1NamespaceList<ResponseContentType extends ResponseContentType$watchCoreV1NamespaceList>(params: Params$watchCoreV1NamespaceList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespaceList$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ConfigMap. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedConfigMapList
     * Request URI: /api/v1/watch/namespaces/{namespace}/configmaps
     */
    watchCoreV1NamespacedConfigMapList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedConfigMapList>(params: Params$watchCoreV1NamespacedConfigMapList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedConfigMapList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ConfigMap. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedConfigMap
     * Request URI: /api/v1/watch/namespaces/{namespace}/configmaps/{name}
     */
    watchCoreV1NamespacedConfigMap<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedConfigMap>(params: Params$watchCoreV1NamespacedConfigMap<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedConfigMap$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Endpoints. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedEndpointsList
     * Request URI: /api/v1/watch/namespaces/{namespace}/endpoints
     */
    watchCoreV1NamespacedEndpointsList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedEndpointsList>(params: Params$watchCoreV1NamespacedEndpointsList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedEndpointsList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Endpoints. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedEndpoints
     * Request URI: /api/v1/watch/namespaces/{namespace}/endpoints/{name}
     */
    watchCoreV1NamespacedEndpoints<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedEndpoints>(params: Params$watchCoreV1NamespacedEndpoints<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedEndpoints$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Event. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedEventList
     * Request URI: /api/v1/watch/namespaces/{namespace}/events
     */
    watchCoreV1NamespacedEventList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedEventList>(params: Params$watchCoreV1NamespacedEventList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedEventList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Event. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedEvent
     * Request URI: /api/v1/watch/namespaces/{namespace}/events/{name}
     */
    watchCoreV1NamespacedEvent<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedEvent>(params: Params$watchCoreV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedEvent$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of LimitRange. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedLimitRangeList
     * Request URI: /api/v1/watch/namespaces/{namespace}/limitranges
     */
    watchCoreV1NamespacedLimitRangeList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedLimitRangeList>(params: Params$watchCoreV1NamespacedLimitRangeList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedLimitRangeList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind LimitRange. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedLimitRange
     * Request URI: /api/v1/watch/namespaces/{namespace}/limitranges/{name}
     */
    watchCoreV1NamespacedLimitRange<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedLimitRange>(params: Params$watchCoreV1NamespacedLimitRange<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedLimitRange$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of PersistentVolumeClaim. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedPersistentVolumeClaimList
     * Request URI: /api/v1/watch/namespaces/{namespace}/persistentvolumeclaims
     */
    watchCoreV1NamespacedPersistentVolumeClaimList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedPersistentVolumeClaimList>(params: Params$watchCoreV1NamespacedPersistentVolumeClaimList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedPersistentVolumeClaimList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind PersistentVolumeClaim. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedPersistentVolumeClaim
     * Request URI: /api/v1/watch/namespaces/{namespace}/persistentvolumeclaims/{name}
     */
    watchCoreV1NamespacedPersistentVolumeClaim<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedPersistentVolumeClaim>(params: Params$watchCoreV1NamespacedPersistentVolumeClaim<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedPersistentVolumeClaim$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Pod. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedPodList
     * Request URI: /api/v1/watch/namespaces/{namespace}/pods
     */
    watchCoreV1NamespacedPodList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedPodList>(params: Params$watchCoreV1NamespacedPodList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedPodList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Pod. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedPod
     * Request URI: /api/v1/watch/namespaces/{namespace}/pods/{name}
     */
    watchCoreV1NamespacedPod<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedPod>(params: Params$watchCoreV1NamespacedPod<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedPod$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of PodTemplate. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedPodTemplateList
     * Request URI: /api/v1/watch/namespaces/{namespace}/podtemplates
     */
    watchCoreV1NamespacedPodTemplateList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedPodTemplateList>(params: Params$watchCoreV1NamespacedPodTemplateList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedPodTemplateList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind PodTemplate. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedPodTemplate
     * Request URI: /api/v1/watch/namespaces/{namespace}/podtemplates/{name}
     */
    watchCoreV1NamespacedPodTemplate<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedPodTemplate>(params: Params$watchCoreV1NamespacedPodTemplate<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedPodTemplate$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ReplicationController. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedReplicationControllerList
     * Request URI: /api/v1/watch/namespaces/{namespace}/replicationcontrollers
     */
    watchCoreV1NamespacedReplicationControllerList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedReplicationControllerList>(params: Params$watchCoreV1NamespacedReplicationControllerList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedReplicationControllerList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ReplicationController. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedReplicationController
     * Request URI: /api/v1/watch/namespaces/{namespace}/replicationcontrollers/{name}
     */
    watchCoreV1NamespacedReplicationController<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedReplicationController>(params: Params$watchCoreV1NamespacedReplicationController<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedReplicationController$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ResourceQuota. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedResourceQuotaList
     * Request URI: /api/v1/watch/namespaces/{namespace}/resourcequotas
     */
    watchCoreV1NamespacedResourceQuotaList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedResourceQuotaList>(params: Params$watchCoreV1NamespacedResourceQuotaList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedResourceQuotaList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ResourceQuota. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedResourceQuota
     * Request URI: /api/v1/watch/namespaces/{namespace}/resourcequotas/{name}
     */
    watchCoreV1NamespacedResourceQuota<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedResourceQuota>(params: Params$watchCoreV1NamespacedResourceQuota<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedResourceQuota$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Secret. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedSecretList
     * Request URI: /api/v1/watch/namespaces/{namespace}/secrets
     */
    watchCoreV1NamespacedSecretList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedSecretList>(params: Params$watchCoreV1NamespacedSecretList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedSecretList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Secret. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedSecret
     * Request URI: /api/v1/watch/namespaces/{namespace}/secrets/{name}
     */
    watchCoreV1NamespacedSecret<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedSecret>(params: Params$watchCoreV1NamespacedSecret<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedSecret$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ServiceAccount. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedServiceAccountList
     * Request URI: /api/v1/watch/namespaces/{namespace}/serviceaccounts
     */
    watchCoreV1NamespacedServiceAccountList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedServiceAccountList>(params: Params$watchCoreV1NamespacedServiceAccountList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedServiceAccountList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ServiceAccount. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedServiceAccount
     * Request URI: /api/v1/watch/namespaces/{namespace}/serviceaccounts/{name}
     */
    watchCoreV1NamespacedServiceAccount<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedServiceAccount>(params: Params$watchCoreV1NamespacedServiceAccount<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedServiceAccount$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Service. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NamespacedServiceList
     * Request URI: /api/v1/watch/namespaces/{namespace}/services
     */
    watchCoreV1NamespacedServiceList<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedServiceList>(params: Params$watchCoreV1NamespacedServiceList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedServiceList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Service. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1NamespacedService
     * Request URI: /api/v1/watch/namespaces/{namespace}/services/{name}
     */
    watchCoreV1NamespacedService<ResponseContentType extends ResponseContentType$watchCoreV1NamespacedService>(params: Params$watchCoreV1NamespacedService<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NamespacedService$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Namespace. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1Namespace
     * Request URI: /api/v1/watch/namespaces/{name}
     */
    watchCoreV1Namespace<ResponseContentType extends ResponseContentType$watchCoreV1Namespace>(params: Params$watchCoreV1Namespace<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1Namespace$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Node. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1NodeList
     * Request URI: /api/v1/watch/nodes
     */
    watchCoreV1NodeList<ResponseContentType extends ResponseContentType$watchCoreV1NodeList>(params: Params$watchCoreV1NodeList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1NodeList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Node. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1Node
     * Request URI: /api/v1/watch/nodes/{name}
     */
    watchCoreV1Node<ResponseContentType extends ResponseContentType$watchCoreV1Node>(params: Params$watchCoreV1Node<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1Node$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of PersistentVolumeClaim. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1PersistentVolumeClaimListForAllNamespaces
     * Request URI: /api/v1/watch/persistentvolumeclaims
     */
    watchCoreV1PersistentVolumeClaimListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1PersistentVolumeClaimListForAllNamespaces>(params: Params$watchCoreV1PersistentVolumeClaimListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1PersistentVolumeClaimListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of PersistentVolume. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1PersistentVolumeList
     * Request URI: /api/v1/watch/persistentvolumes
     */
    watchCoreV1PersistentVolumeList<ResponseContentType extends ResponseContentType$watchCoreV1PersistentVolumeList>(params: Params$watchCoreV1PersistentVolumeList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1PersistentVolumeList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind PersistentVolume. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoreV1PersistentVolume
     * Request URI: /api/v1/watch/persistentvolumes/{name}
     */
    watchCoreV1PersistentVolume<ResponseContentType extends ResponseContentType$watchCoreV1PersistentVolume>(params: Params$watchCoreV1PersistentVolume<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1PersistentVolume$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Pod. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1PodListForAllNamespaces
     * Request URI: /api/v1/watch/pods
     */
    watchCoreV1PodListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1PodListForAllNamespaces>(params: Params$watchCoreV1PodListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1PodListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of PodTemplate. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1PodTemplateListForAllNamespaces
     * Request URI: /api/v1/watch/podtemplates
     */
    watchCoreV1PodTemplateListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1PodTemplateListForAllNamespaces>(params: Params$watchCoreV1PodTemplateListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1PodTemplateListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ReplicationController. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1ReplicationControllerListForAllNamespaces
     * Request URI: /api/v1/watch/replicationcontrollers
     */
    watchCoreV1ReplicationControllerListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1ReplicationControllerListForAllNamespaces>(params: Params$watchCoreV1ReplicationControllerListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1ReplicationControllerListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ResourceQuota. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1ResourceQuotaListForAllNamespaces
     * Request URI: /api/v1/watch/resourcequotas
     */
    watchCoreV1ResourceQuotaListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1ResourceQuotaListForAllNamespaces>(params: Params$watchCoreV1ResourceQuotaListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1ResourceQuotaListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Secret. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1SecretListForAllNamespaces
     * Request URI: /api/v1/watch/secrets
     */
    watchCoreV1SecretListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1SecretListForAllNamespaces>(params: Params$watchCoreV1SecretListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1SecretListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ServiceAccount. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1ServiceAccountListForAllNamespaces
     * Request URI: /api/v1/watch/serviceaccounts
     */
    watchCoreV1ServiceAccountListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1ServiceAccountListForAllNamespaces>(params: Params$watchCoreV1ServiceAccountListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1ServiceAccountListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Service. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoreV1ServiceListForAllNamespaces
     * Request URI: /api/v1/watch/services
     */
    watchCoreV1ServiceListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoreV1ServiceListForAllNamespaces>(params: Params$watchCoreV1ServiceListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoreV1ServiceListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * get available API versions
     * operationId: getAPIVersions
     * Request URI: /apis/
     */
    getAPIVersions<ResponseContentType extends ResponseContentType$getAPIVersions>(params: Params$getAPIVersions<ResponseContentType>, option?: RequestOption): Promise<Response$getAPIVersions$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getAdmissionregistrationAPIGroup
     * Request URI: /apis/admissionregistration.k8s.io/
     */
    getAdmissionregistrationAPIGroup<ResponseContentType extends ResponseContentType$getAdmissionregistrationAPIGroup>(params: Params$getAdmissionregistrationAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getAdmissionregistrationAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getAdmissionregistrationV1APIResources
     * Request URI: /apis/admissionregistration.k8s.io/v1/
     */
    getAdmissionregistrationV1APIResources<ResponseContentType extends ResponseContentType$getAdmissionregistrationV1APIResources>(params: Params$getAdmissionregistrationV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getAdmissionregistrationV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind MutatingWebhookConfiguration
     * operationId: listAdmissionregistrationV1MutatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations
     */
    listAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType extends ResponseContentType$listAdmissionregistrationV1MutatingWebhookConfiguration>(params: Params$listAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$listAdmissionregistrationV1MutatingWebhookConfiguration$Status$200[ResponseContentType]>;
    /**
     * create a MutatingWebhookConfiguration
     * operationId: createAdmissionregistrationV1MutatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations
     */
    createAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType extends ResponseContentType$createAdmissionregistrationV1MutatingWebhookConfiguration>(params: Params$createAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$201 | Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$202)[ResponseContentType]>;
    /**
     * delete collection of MutatingWebhookConfiguration
     * operationId: deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations
     */
    deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration<ResponseContentType extends ResponseContentType$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration>(params: Params$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration$Status$200[ResponseContentType]>;
    /**
     * read the specified MutatingWebhookConfiguration
     * operationId: readAdmissionregistrationV1MutatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations/{name}
     */
    readAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType extends ResponseContentType$readAdmissionregistrationV1MutatingWebhookConfiguration>(params: Params$readAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$readAdmissionregistrationV1MutatingWebhookConfiguration$Status$200[ResponseContentType]>;
    /**
     * replace the specified MutatingWebhookConfiguration
     * operationId: replaceAdmissionregistrationV1MutatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations/{name}
     */
    replaceAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType extends ResponseContentType$replaceAdmissionregistrationV1MutatingWebhookConfiguration>(params: Params$replaceAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | Response$replaceAdmissionregistrationV1MutatingWebhookConfiguration$Status$201)[ResponseContentType]>;
    /**
     * delete a MutatingWebhookConfiguration
     * operationId: deleteAdmissionregistrationV1MutatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations/{name}
     */
    deleteAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType extends ResponseContentType$deleteAdmissionregistrationV1MutatingWebhookConfiguration>(params: Params$deleteAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | Response$deleteAdmissionregistrationV1MutatingWebhookConfiguration$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified MutatingWebhookConfiguration
     * operationId: patchAdmissionregistrationV1MutatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/mutatingwebhookconfigurations/{name}
     */
    patchAdmissionregistrationV1MutatingWebhookConfiguration<RequestContentType extends RequestContentType$patchAdmissionregistrationV1MutatingWebhookConfiguration, ResponseContentType extends ResponseContentType$patchAdmissionregistrationV1MutatingWebhookConfiguration>(params: Params$patchAdmissionregistrationV1MutatingWebhookConfiguration<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAdmissionregistrationV1MutatingWebhookConfiguration$Status$200 | Response$patchAdmissionregistrationV1MutatingWebhookConfiguration$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind ValidatingWebhookConfiguration
     * operationId: listAdmissionregistrationV1ValidatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations
     */
    listAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType extends ResponseContentType$listAdmissionregistrationV1ValidatingWebhookConfiguration>(params: Params$listAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$listAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200[ResponseContentType]>;
    /**
     * create a ValidatingWebhookConfiguration
     * operationId: createAdmissionregistrationV1ValidatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations
     */
    createAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType extends ResponseContentType$createAdmissionregistrationV1ValidatingWebhookConfiguration>(params: Params$createAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201 | Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ValidatingWebhookConfiguration
     * operationId: deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations
     */
    deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration<ResponseContentType extends ResponseContentType$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration>(params: Params$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration$Status$200[ResponseContentType]>;
    /**
     * read the specified ValidatingWebhookConfiguration
     * operationId: readAdmissionregistrationV1ValidatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations/{name}
     */
    readAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType extends ResponseContentType$readAdmissionregistrationV1ValidatingWebhookConfiguration>(params: Params$readAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$readAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200[ResponseContentType]>;
    /**
     * replace the specified ValidatingWebhookConfiguration
     * operationId: replaceAdmissionregistrationV1ValidatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations/{name}
     */
    replaceAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType extends ResponseContentType$replaceAdmissionregistrationV1ValidatingWebhookConfiguration>(params: Params$replaceAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | Response$replaceAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201)[ResponseContentType]>;
    /**
     * delete a ValidatingWebhookConfiguration
     * operationId: deleteAdmissionregistrationV1ValidatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations/{name}
     */
    deleteAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType extends ResponseContentType$deleteAdmissionregistrationV1ValidatingWebhookConfiguration>(params: Params$deleteAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | Response$deleteAdmissionregistrationV1ValidatingWebhookConfiguration$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ValidatingWebhookConfiguration
     * operationId: patchAdmissionregistrationV1ValidatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/validatingwebhookconfigurations/{name}
     */
    patchAdmissionregistrationV1ValidatingWebhookConfiguration<RequestContentType extends RequestContentType$patchAdmissionregistrationV1ValidatingWebhookConfiguration, ResponseContentType extends ResponseContentType$patchAdmissionregistrationV1ValidatingWebhookConfiguration>(params: Params$patchAdmissionregistrationV1ValidatingWebhookConfiguration<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200 | Response$patchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of MutatingWebhookConfiguration. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAdmissionregistrationV1MutatingWebhookConfigurationList
     * Request URI: /apis/admissionregistration.k8s.io/v1/watch/mutatingwebhookconfigurations
     */
    watchAdmissionregistrationV1MutatingWebhookConfigurationList<ResponseContentType extends ResponseContentType$watchAdmissionregistrationV1MutatingWebhookConfigurationList>(params: Params$watchAdmissionregistrationV1MutatingWebhookConfigurationList<ResponseContentType>, option?: RequestOption): Promise<Response$watchAdmissionregistrationV1MutatingWebhookConfigurationList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind MutatingWebhookConfiguration. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchAdmissionregistrationV1MutatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/watch/mutatingwebhookconfigurations/{name}
     */
    watchAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType extends ResponseContentType$watchAdmissionregistrationV1MutatingWebhookConfiguration>(params: Params$watchAdmissionregistrationV1MutatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$watchAdmissionregistrationV1MutatingWebhookConfiguration$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ValidatingWebhookConfiguration. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAdmissionregistrationV1ValidatingWebhookConfigurationList
     * Request URI: /apis/admissionregistration.k8s.io/v1/watch/validatingwebhookconfigurations
     */
    watchAdmissionregistrationV1ValidatingWebhookConfigurationList<ResponseContentType extends ResponseContentType$watchAdmissionregistrationV1ValidatingWebhookConfigurationList>(params: Params$watchAdmissionregistrationV1ValidatingWebhookConfigurationList<ResponseContentType>, option?: RequestOption): Promise<Response$watchAdmissionregistrationV1ValidatingWebhookConfigurationList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ValidatingWebhookConfiguration. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchAdmissionregistrationV1ValidatingWebhookConfiguration
     * Request URI: /apis/admissionregistration.k8s.io/v1/watch/validatingwebhookconfigurations/{name}
     */
    watchAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType extends ResponseContentType$watchAdmissionregistrationV1ValidatingWebhookConfiguration>(params: Params$watchAdmissionregistrationV1ValidatingWebhookConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$watchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getAdmissionregistrationV1alpha1APIResources
     * Request URI: /apis/admissionregistration.k8s.io/v1alpha1/
     */
    getAdmissionregistrationV1alpha1APIResources<ResponseContentType extends ResponseContentType$getAdmissionregistrationV1alpha1APIResources>(params: Params$getAdmissionregistrationV1alpha1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getAdmissionregistrationV1alpha1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind ValidatingAdmissionPolicy
     * operationId: listAdmissionregistrationV1alpha1ValidatingAdmissionPolicy
     * Request URI: /apis/admissionregistration.k8s.io/v1alpha1/validatingadmissionpolicies
     */
    listAdmissionregistrationV1alpha1ValidatingAdmissionPolicy<ResponseContentType extends ResponseContentType$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicy>(params: Params$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicy<ResponseContentType>, option?: RequestOption): Promise<Response$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200[ResponseContentType]>;
    /**
     * create a ValidatingAdmissionPolicy
     * operationId: createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy
     * Request URI: /apis/admissionregistration.k8s.io/v1alpha1/validatingadmissionpolicies
     */
    createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy<ResponseContentType extends ResponseContentType$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy>(params: Params$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy<ResponseContentType>, option?: RequestOption): Promise<(Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200 | Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$201 | Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ValidatingAdmissionPolicy
     * operationId: deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy
     * Request URI: /apis/admissionregistration.k8s.io/v1alpha1/validatingadmissionpolicies
     */
    deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy<ResponseContentType extends ResponseContentType$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy>(params: Params$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy<ResponseContentType>, option?: RequestOption): Promise<Response$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy$Status$200[ResponseContentType]>;
    /**
     * read the specified ValidatingAdmissionPolicy
     * operationId: readAdmissionregistrationV1alpha1ValidatingAdmissionPolicy
     * Request URI: /apis/admissionregistration.k8s.io/v1alpha1/validatingadmissionpolicies/{name}
     */
    readAdmissionregistrationV1alpha1ValidatingAdmissionPolicy<ResponseContentType extends ResponseContentType$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicy>(params: Params$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicy<ResponseContentType>, option?: RequestOption): Promise<Response$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200[ResponseContentType]>;
    /**
     * replace the specified ValidatingAdmissionPolicy
     * operationId: replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy
     * Request URI: /apis/admissionregistration.k8s.io/v1alpha1/validatingadmissionpolicies/{name}
     */
    replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy<ResponseContentType extends ResponseContentType$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy>(params: Params$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200 | Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$201)[ResponseContentType]>;
    /**
     * delete a ValidatingAdmissionPolicy
     * operationId: deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy
     * Request URI: /apis/admissionregistration.k8s.io/v1alpha1/validatingadmissionpolicies/{name}
     */
    deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy<ResponseContentType extends ResponseContentType$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy>(params: Params$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200 | Response$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ValidatingAdmissionPolicy
     * operationId: patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy
     * Request URI: /apis/admissionregistration.k8s.io/v1alpha1/validatingadmissionpolicies/{name}
     */
    patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy<RequestContentType extends RequestContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, ResponseContentType extends ResponseContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy>(params: Params$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200 | Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified ValidatingAdmissionPolicy
     * operationId: readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus
     * Request URI: /apis/admissionregistration.k8s.io/v1alpha1/validatingadmissionpolicies/{name}/status
     */
    readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus<ResponseContentType extends ResponseContentType$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus>(params: Params$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified ValidatingAdmissionPolicy
     * operationId: replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus
     * Request URI: /apis/admissionregistration.k8s.io/v1alpha1/validatingadmissionpolicies/{name}/status
     */
    replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus<ResponseContentType extends ResponseContentType$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus>(params: Params$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$200 | Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified ValidatingAdmissionPolicy
     * operationId: patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus
     * Request URI: /apis/admissionregistration.k8s.io/v1alpha1/validatingadmissionpolicies/{name}/status
     */
    patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus<RequestContentType extends RequestContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus, ResponseContentType extends ResponseContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus>(params: Params$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$200 | Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind ValidatingAdmissionPolicyBinding
     * operationId: listAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding
     * Request URI: /apis/admissionregistration.k8s.io/v1alpha1/validatingadmissionpolicybindings
     */
    listAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding<ResponseContentType extends ResponseContentType$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding>(params: Params$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding<ResponseContentType>, option?: RequestOption): Promise<Response$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200[ResponseContentType]>;
    /**
     * create a ValidatingAdmissionPolicyBinding
     * operationId: createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding
     * Request URI: /apis/admissionregistration.k8s.io/v1alpha1/validatingadmissionpolicybindings
     */
    createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding<ResponseContentType extends ResponseContentType$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding>(params: Params$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding<ResponseContentType>, option?: RequestOption): Promise<(Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200 | Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$201 | Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ValidatingAdmissionPolicyBinding
     * operationId: deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding
     * Request URI: /apis/admissionregistration.k8s.io/v1alpha1/validatingadmissionpolicybindings
     */
    deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding<ResponseContentType extends ResponseContentType$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding>(params: Params$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding<ResponseContentType>, option?: RequestOption): Promise<Response$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding$Status$200[ResponseContentType]>;
    /**
     * read the specified ValidatingAdmissionPolicyBinding
     * operationId: readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding
     * Request URI: /apis/admissionregistration.k8s.io/v1alpha1/validatingadmissionpolicybindings/{name}
     */
    readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding<ResponseContentType extends ResponseContentType$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding>(params: Params$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding<ResponseContentType>, option?: RequestOption): Promise<Response$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200[ResponseContentType]>;
    /**
     * replace the specified ValidatingAdmissionPolicyBinding
     * operationId: replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding
     * Request URI: /apis/admissionregistration.k8s.io/v1alpha1/validatingadmissionpolicybindings/{name}
     */
    replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding<ResponseContentType extends ResponseContentType$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding>(params: Params$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200 | Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$201)[ResponseContentType]>;
    /**
     * delete a ValidatingAdmissionPolicyBinding
     * operationId: deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding
     * Request URI: /apis/admissionregistration.k8s.io/v1alpha1/validatingadmissionpolicybindings/{name}
     */
    deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding<ResponseContentType extends ResponseContentType$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding>(params: Params$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200 | Response$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ValidatingAdmissionPolicyBinding
     * operationId: patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding
     * Request URI: /apis/admissionregistration.k8s.io/v1alpha1/validatingadmissionpolicybindings/{name}
     */
    patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding<RequestContentType extends RequestContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, ResponseContentType extends ResponseContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding>(params: Params$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200 | Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of ValidatingAdmissionPolicy. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyList
     * Request URI: /apis/admissionregistration.k8s.io/v1alpha1/watch/validatingadmissionpolicies
     */
    watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyList<ResponseContentType extends ResponseContentType$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyList>(params: Params$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyList<ResponseContentType>, option?: RequestOption): Promise<Response$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ValidatingAdmissionPolicy. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy
     * Request URI: /apis/admissionregistration.k8s.io/v1alpha1/watch/validatingadmissionpolicies/{name}
     */
    watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy<ResponseContentType extends ResponseContentType$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy>(params: Params$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy<ResponseContentType>, option?: RequestOption): Promise<Response$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ValidatingAdmissionPolicyBinding. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBindingList
     * Request URI: /apis/admissionregistration.k8s.io/v1alpha1/watch/validatingadmissionpolicybindings
     */
    watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBindingList<ResponseContentType extends ResponseContentType$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBindingList>(params: Params$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBindingList<ResponseContentType>, option?: RequestOption): Promise<Response$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBindingList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ValidatingAdmissionPolicyBinding. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding
     * Request URI: /apis/admissionregistration.k8s.io/v1alpha1/watch/validatingadmissionpolicybindings/{name}
     */
    watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding<ResponseContentType extends ResponseContentType$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding>(params: Params$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding<ResponseContentType>, option?: RequestOption): Promise<Response$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getApiextensionsAPIGroup
     * Request URI: /apis/apiextensions.k8s.io/
     */
    getApiextensionsAPIGroup<ResponseContentType extends ResponseContentType$getApiextensionsAPIGroup>(params: Params$getApiextensionsAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getApiextensionsAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getApiextensionsV1APIResources
     * Request URI: /apis/apiextensions.k8s.io/v1/
     */
    getApiextensionsV1APIResources<ResponseContentType extends ResponseContentType$getApiextensionsV1APIResources>(params: Params$getApiextensionsV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getApiextensionsV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind CustomResourceDefinition
     * operationId: listApiextensionsV1CustomResourceDefinition
     * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions
     */
    listApiextensionsV1CustomResourceDefinition<ResponseContentType extends ResponseContentType$listApiextensionsV1CustomResourceDefinition>(params: Params$listApiextensionsV1CustomResourceDefinition<ResponseContentType>, option?: RequestOption): Promise<Response$listApiextensionsV1CustomResourceDefinition$Status$200[ResponseContentType]>;
    /**
     * create a CustomResourceDefinition
     * operationId: createApiextensionsV1CustomResourceDefinition
     * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions
     */
    createApiextensionsV1CustomResourceDefinition<ResponseContentType extends ResponseContentType$createApiextensionsV1CustomResourceDefinition>(params: Params$createApiextensionsV1CustomResourceDefinition<ResponseContentType>, option?: RequestOption): Promise<(Response$createApiextensionsV1CustomResourceDefinition$Status$200 | Response$createApiextensionsV1CustomResourceDefinition$Status$201 | Response$createApiextensionsV1CustomResourceDefinition$Status$202)[ResponseContentType]>;
    /**
     * delete collection of CustomResourceDefinition
     * operationId: deleteApiextensionsV1CollectionCustomResourceDefinition
     * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions
     */
    deleteApiextensionsV1CollectionCustomResourceDefinition<ResponseContentType extends ResponseContentType$deleteApiextensionsV1CollectionCustomResourceDefinition>(params: Params$deleteApiextensionsV1CollectionCustomResourceDefinition<ResponseContentType>, option?: RequestOption): Promise<Response$deleteApiextensionsV1CollectionCustomResourceDefinition$Status$200[ResponseContentType]>;
    /**
     * read the specified CustomResourceDefinition
     * operationId: readApiextensionsV1CustomResourceDefinition
     * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions/{name}
     */
    readApiextensionsV1CustomResourceDefinition<ResponseContentType extends ResponseContentType$readApiextensionsV1CustomResourceDefinition>(params: Params$readApiextensionsV1CustomResourceDefinition<ResponseContentType>, option?: RequestOption): Promise<Response$readApiextensionsV1CustomResourceDefinition$Status$200[ResponseContentType]>;
    /**
     * replace the specified CustomResourceDefinition
     * operationId: replaceApiextensionsV1CustomResourceDefinition
     * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions/{name}
     */
    replaceApiextensionsV1CustomResourceDefinition<ResponseContentType extends ResponseContentType$replaceApiextensionsV1CustomResourceDefinition>(params: Params$replaceApiextensionsV1CustomResourceDefinition<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceApiextensionsV1CustomResourceDefinition$Status$200 | Response$replaceApiextensionsV1CustomResourceDefinition$Status$201)[ResponseContentType]>;
    /**
     * delete a CustomResourceDefinition
     * operationId: deleteApiextensionsV1CustomResourceDefinition
     * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions/{name}
     */
    deleteApiextensionsV1CustomResourceDefinition<ResponseContentType extends ResponseContentType$deleteApiextensionsV1CustomResourceDefinition>(params: Params$deleteApiextensionsV1CustomResourceDefinition<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteApiextensionsV1CustomResourceDefinition$Status$200 | Response$deleteApiextensionsV1CustomResourceDefinition$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified CustomResourceDefinition
     * operationId: patchApiextensionsV1CustomResourceDefinition
     * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions/{name}
     */
    patchApiextensionsV1CustomResourceDefinition<RequestContentType extends RequestContentType$patchApiextensionsV1CustomResourceDefinition, ResponseContentType extends ResponseContentType$patchApiextensionsV1CustomResourceDefinition>(params: Params$patchApiextensionsV1CustomResourceDefinition<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchApiextensionsV1CustomResourceDefinition$Status$200 | Response$patchApiextensionsV1CustomResourceDefinition$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified CustomResourceDefinition
     * operationId: readApiextensionsV1CustomResourceDefinitionStatus
     * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions/{name}/status
     */
    readApiextensionsV1CustomResourceDefinitionStatus<ResponseContentType extends ResponseContentType$readApiextensionsV1CustomResourceDefinitionStatus>(params: Params$readApiextensionsV1CustomResourceDefinitionStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readApiextensionsV1CustomResourceDefinitionStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified CustomResourceDefinition
     * operationId: replaceApiextensionsV1CustomResourceDefinitionStatus
     * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions/{name}/status
     */
    replaceApiextensionsV1CustomResourceDefinitionStatus<ResponseContentType extends ResponseContentType$replaceApiextensionsV1CustomResourceDefinitionStatus>(params: Params$replaceApiextensionsV1CustomResourceDefinitionStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceApiextensionsV1CustomResourceDefinitionStatus$Status$200 | Response$replaceApiextensionsV1CustomResourceDefinitionStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified CustomResourceDefinition
     * operationId: patchApiextensionsV1CustomResourceDefinitionStatus
     * Request URI: /apis/apiextensions.k8s.io/v1/customresourcedefinitions/{name}/status
     */
    patchApiextensionsV1CustomResourceDefinitionStatus<RequestContentType extends RequestContentType$patchApiextensionsV1CustomResourceDefinitionStatus, ResponseContentType extends ResponseContentType$patchApiextensionsV1CustomResourceDefinitionStatus>(params: Params$patchApiextensionsV1CustomResourceDefinitionStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchApiextensionsV1CustomResourceDefinitionStatus$Status$200 | Response$patchApiextensionsV1CustomResourceDefinitionStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of CustomResourceDefinition. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchApiextensionsV1CustomResourceDefinitionList
     * Request URI: /apis/apiextensions.k8s.io/v1/watch/customresourcedefinitions
     */
    watchApiextensionsV1CustomResourceDefinitionList<ResponseContentType extends ResponseContentType$watchApiextensionsV1CustomResourceDefinitionList>(params: Params$watchApiextensionsV1CustomResourceDefinitionList<ResponseContentType>, option?: RequestOption): Promise<Response$watchApiextensionsV1CustomResourceDefinitionList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind CustomResourceDefinition. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchApiextensionsV1CustomResourceDefinition
     * Request URI: /apis/apiextensions.k8s.io/v1/watch/customresourcedefinitions/{name}
     */
    watchApiextensionsV1CustomResourceDefinition<ResponseContentType extends ResponseContentType$watchApiextensionsV1CustomResourceDefinition>(params: Params$watchApiextensionsV1CustomResourceDefinition<ResponseContentType>, option?: RequestOption): Promise<Response$watchApiextensionsV1CustomResourceDefinition$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getApiregistrationAPIGroup
     * Request URI: /apis/apiregistration.k8s.io/
     */
    getApiregistrationAPIGroup<ResponseContentType extends ResponseContentType$getApiregistrationAPIGroup>(params: Params$getApiregistrationAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getApiregistrationAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getApiregistrationV1APIResources
     * Request URI: /apis/apiregistration.k8s.io/v1/
     */
    getApiregistrationV1APIResources<ResponseContentType extends ResponseContentType$getApiregistrationV1APIResources>(params: Params$getApiregistrationV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getApiregistrationV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind APIService
     * operationId: listApiregistrationV1APIService
     * Request URI: /apis/apiregistration.k8s.io/v1/apiservices
     */
    listApiregistrationV1APIService<ResponseContentType extends ResponseContentType$listApiregistrationV1APIService>(params: Params$listApiregistrationV1APIService<ResponseContentType>, option?: RequestOption): Promise<Response$listApiregistrationV1APIService$Status$200[ResponseContentType]>;
    /**
     * create an APIService
     * operationId: createApiregistrationV1APIService
     * Request URI: /apis/apiregistration.k8s.io/v1/apiservices
     */
    createApiregistrationV1APIService<ResponseContentType extends ResponseContentType$createApiregistrationV1APIService>(params: Params$createApiregistrationV1APIService<ResponseContentType>, option?: RequestOption): Promise<(Response$createApiregistrationV1APIService$Status$200 | Response$createApiregistrationV1APIService$Status$201 | Response$createApiregistrationV1APIService$Status$202)[ResponseContentType]>;
    /**
     * delete collection of APIService
     * operationId: deleteApiregistrationV1CollectionAPIService
     * Request URI: /apis/apiregistration.k8s.io/v1/apiservices
     */
    deleteApiregistrationV1CollectionAPIService<ResponseContentType extends ResponseContentType$deleteApiregistrationV1CollectionAPIService>(params: Params$deleteApiregistrationV1CollectionAPIService<ResponseContentType>, option?: RequestOption): Promise<Response$deleteApiregistrationV1CollectionAPIService$Status$200[ResponseContentType]>;
    /**
     * read the specified APIService
     * operationId: readApiregistrationV1APIService
     * Request URI: /apis/apiregistration.k8s.io/v1/apiservices/{name}
     */
    readApiregistrationV1APIService<ResponseContentType extends ResponseContentType$readApiregistrationV1APIService>(params: Params$readApiregistrationV1APIService<ResponseContentType>, option?: RequestOption): Promise<Response$readApiregistrationV1APIService$Status$200[ResponseContentType]>;
    /**
     * replace the specified APIService
     * operationId: replaceApiregistrationV1APIService
     * Request URI: /apis/apiregistration.k8s.io/v1/apiservices/{name}
     */
    replaceApiregistrationV1APIService<ResponseContentType extends ResponseContentType$replaceApiregistrationV1APIService>(params: Params$replaceApiregistrationV1APIService<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceApiregistrationV1APIService$Status$200 | Response$replaceApiregistrationV1APIService$Status$201)[ResponseContentType]>;
    /**
     * delete an APIService
     * operationId: deleteApiregistrationV1APIService
     * Request URI: /apis/apiregistration.k8s.io/v1/apiservices/{name}
     */
    deleteApiregistrationV1APIService<ResponseContentType extends ResponseContentType$deleteApiregistrationV1APIService>(params: Params$deleteApiregistrationV1APIService<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteApiregistrationV1APIService$Status$200 | Response$deleteApiregistrationV1APIService$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified APIService
     * operationId: patchApiregistrationV1APIService
     * Request URI: /apis/apiregistration.k8s.io/v1/apiservices/{name}
     */
    patchApiregistrationV1APIService<RequestContentType extends RequestContentType$patchApiregistrationV1APIService, ResponseContentType extends ResponseContentType$patchApiregistrationV1APIService>(params: Params$patchApiregistrationV1APIService<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchApiregistrationV1APIService$Status$200 | Response$patchApiregistrationV1APIService$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified APIService
     * operationId: readApiregistrationV1APIServiceStatus
     * Request URI: /apis/apiregistration.k8s.io/v1/apiservices/{name}/status
     */
    readApiregistrationV1APIServiceStatus<ResponseContentType extends ResponseContentType$readApiregistrationV1APIServiceStatus>(params: Params$readApiregistrationV1APIServiceStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readApiregistrationV1APIServiceStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified APIService
     * operationId: replaceApiregistrationV1APIServiceStatus
     * Request URI: /apis/apiregistration.k8s.io/v1/apiservices/{name}/status
     */
    replaceApiregistrationV1APIServiceStatus<ResponseContentType extends ResponseContentType$replaceApiregistrationV1APIServiceStatus>(params: Params$replaceApiregistrationV1APIServiceStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceApiregistrationV1APIServiceStatus$Status$200 | Response$replaceApiregistrationV1APIServiceStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified APIService
     * operationId: patchApiregistrationV1APIServiceStatus
     * Request URI: /apis/apiregistration.k8s.io/v1/apiservices/{name}/status
     */
    patchApiregistrationV1APIServiceStatus<RequestContentType extends RequestContentType$patchApiregistrationV1APIServiceStatus, ResponseContentType extends ResponseContentType$patchApiregistrationV1APIServiceStatus>(params: Params$patchApiregistrationV1APIServiceStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchApiregistrationV1APIServiceStatus$Status$200 | Response$patchApiregistrationV1APIServiceStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of APIService. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchApiregistrationV1APIServiceList
     * Request URI: /apis/apiregistration.k8s.io/v1/watch/apiservices
     */
    watchApiregistrationV1APIServiceList<ResponseContentType extends ResponseContentType$watchApiregistrationV1APIServiceList>(params: Params$watchApiregistrationV1APIServiceList<ResponseContentType>, option?: RequestOption): Promise<Response$watchApiregistrationV1APIServiceList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind APIService. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchApiregistrationV1APIService
     * Request URI: /apis/apiregistration.k8s.io/v1/watch/apiservices/{name}
     */
    watchApiregistrationV1APIService<ResponseContentType extends ResponseContentType$watchApiregistrationV1APIService>(params: Params$watchApiregistrationV1APIService<ResponseContentType>, option?: RequestOption): Promise<Response$watchApiregistrationV1APIService$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getAppsAPIGroup
     * Request URI: /apis/apps/
     */
    getAppsAPIGroup<ResponseContentType extends ResponseContentType$getAppsAPIGroup>(params: Params$getAppsAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getAppsAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getAppsV1APIResources
     * Request URI: /apis/apps/v1/
     */
    getAppsV1APIResources<ResponseContentType extends ResponseContentType$getAppsV1APIResources>(params: Params$getAppsV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getAppsV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind ControllerRevision
     * operationId: listAppsV1ControllerRevisionForAllNamespaces
     * Request URI: /apis/apps/v1/controllerrevisions
     */
    listAppsV1ControllerRevisionForAllNamespaces<ResponseContentType extends ResponseContentType$listAppsV1ControllerRevisionForAllNamespaces>(params: Params$listAppsV1ControllerRevisionForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listAppsV1ControllerRevisionForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind DaemonSet
     * operationId: listAppsV1DaemonSetForAllNamespaces
     * Request URI: /apis/apps/v1/daemonsets
     */
    listAppsV1DaemonSetForAllNamespaces<ResponseContentType extends ResponseContentType$listAppsV1DaemonSetForAllNamespaces>(params: Params$listAppsV1DaemonSetForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listAppsV1DaemonSetForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Deployment
     * operationId: listAppsV1DeploymentForAllNamespaces
     * Request URI: /apis/apps/v1/deployments
     */
    listAppsV1DeploymentForAllNamespaces<ResponseContentType extends ResponseContentType$listAppsV1DeploymentForAllNamespaces>(params: Params$listAppsV1DeploymentForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listAppsV1DeploymentForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind ControllerRevision
     * operationId: listAppsV1NamespacedControllerRevision
     * Request URI: /apis/apps/v1/namespaces/{namespace}/controllerrevisions
     */
    listAppsV1NamespacedControllerRevision<ResponseContentType extends ResponseContentType$listAppsV1NamespacedControllerRevision>(params: Params$listAppsV1NamespacedControllerRevision<ResponseContentType>, option?: RequestOption): Promise<Response$listAppsV1NamespacedControllerRevision$Status$200[ResponseContentType]>;
    /**
     * create a ControllerRevision
     * operationId: createAppsV1NamespacedControllerRevision
     * Request URI: /apis/apps/v1/namespaces/{namespace}/controllerrevisions
     */
    createAppsV1NamespacedControllerRevision<ResponseContentType extends ResponseContentType$createAppsV1NamespacedControllerRevision>(params: Params$createAppsV1NamespacedControllerRevision<ResponseContentType>, option?: RequestOption): Promise<(Response$createAppsV1NamespacedControllerRevision$Status$200 | Response$createAppsV1NamespacedControllerRevision$Status$201 | Response$createAppsV1NamespacedControllerRevision$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ControllerRevision
     * operationId: deleteAppsV1CollectionNamespacedControllerRevision
     * Request URI: /apis/apps/v1/namespaces/{namespace}/controllerrevisions
     */
    deleteAppsV1CollectionNamespacedControllerRevision<ResponseContentType extends ResponseContentType$deleteAppsV1CollectionNamespacedControllerRevision>(params: Params$deleteAppsV1CollectionNamespacedControllerRevision<ResponseContentType>, option?: RequestOption): Promise<Response$deleteAppsV1CollectionNamespacedControllerRevision$Status$200[ResponseContentType]>;
    /**
     * read the specified ControllerRevision
     * operationId: readAppsV1NamespacedControllerRevision
     * Request URI: /apis/apps/v1/namespaces/{namespace}/controllerrevisions/{name}
     */
    readAppsV1NamespacedControllerRevision<ResponseContentType extends ResponseContentType$readAppsV1NamespacedControllerRevision>(params: Params$readAppsV1NamespacedControllerRevision<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedControllerRevision$Status$200[ResponseContentType]>;
    /**
     * replace the specified ControllerRevision
     * operationId: replaceAppsV1NamespacedControllerRevision
     * Request URI: /apis/apps/v1/namespaces/{namespace}/controllerrevisions/{name}
     */
    replaceAppsV1NamespacedControllerRevision<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedControllerRevision>(params: Params$replaceAppsV1NamespacedControllerRevision<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedControllerRevision$Status$200 | Response$replaceAppsV1NamespacedControllerRevision$Status$201)[ResponseContentType]>;
    /**
     * delete a ControllerRevision
     * operationId: deleteAppsV1NamespacedControllerRevision
     * Request URI: /apis/apps/v1/namespaces/{namespace}/controllerrevisions/{name}
     */
    deleteAppsV1NamespacedControllerRevision<ResponseContentType extends ResponseContentType$deleteAppsV1NamespacedControllerRevision>(params: Params$deleteAppsV1NamespacedControllerRevision<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteAppsV1NamespacedControllerRevision$Status$200 | Response$deleteAppsV1NamespacedControllerRevision$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ControllerRevision
     * operationId: patchAppsV1NamespacedControllerRevision
     * Request URI: /apis/apps/v1/namespaces/{namespace}/controllerrevisions/{name}
     */
    patchAppsV1NamespacedControllerRevision<RequestContentType extends RequestContentType$patchAppsV1NamespacedControllerRevision, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedControllerRevision>(params: Params$patchAppsV1NamespacedControllerRevision<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedControllerRevision$Status$200 | Response$patchAppsV1NamespacedControllerRevision$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind DaemonSet
     * operationId: listAppsV1NamespacedDaemonSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets
     */
    listAppsV1NamespacedDaemonSet<ResponseContentType extends ResponseContentType$listAppsV1NamespacedDaemonSet>(params: Params$listAppsV1NamespacedDaemonSet<ResponseContentType>, option?: RequestOption): Promise<Response$listAppsV1NamespacedDaemonSet$Status$200[ResponseContentType]>;
    /**
     * create a DaemonSet
     * operationId: createAppsV1NamespacedDaemonSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets
     */
    createAppsV1NamespacedDaemonSet<ResponseContentType extends ResponseContentType$createAppsV1NamespacedDaemonSet>(params: Params$createAppsV1NamespacedDaemonSet<ResponseContentType>, option?: RequestOption): Promise<(Response$createAppsV1NamespacedDaemonSet$Status$200 | Response$createAppsV1NamespacedDaemonSet$Status$201 | Response$createAppsV1NamespacedDaemonSet$Status$202)[ResponseContentType]>;
    /**
     * delete collection of DaemonSet
     * operationId: deleteAppsV1CollectionNamespacedDaemonSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets
     */
    deleteAppsV1CollectionNamespacedDaemonSet<ResponseContentType extends ResponseContentType$deleteAppsV1CollectionNamespacedDaemonSet>(params: Params$deleteAppsV1CollectionNamespacedDaemonSet<ResponseContentType>, option?: RequestOption): Promise<Response$deleteAppsV1CollectionNamespacedDaemonSet$Status$200[ResponseContentType]>;
    /**
     * read the specified DaemonSet
     * operationId: readAppsV1NamespacedDaemonSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets/{name}
     */
    readAppsV1NamespacedDaemonSet<ResponseContentType extends ResponseContentType$readAppsV1NamespacedDaemonSet>(params: Params$readAppsV1NamespacedDaemonSet<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedDaemonSet$Status$200[ResponseContentType]>;
    /**
     * replace the specified DaemonSet
     * operationId: replaceAppsV1NamespacedDaemonSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets/{name}
     */
    replaceAppsV1NamespacedDaemonSet<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedDaemonSet>(params: Params$replaceAppsV1NamespacedDaemonSet<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedDaemonSet$Status$200 | Response$replaceAppsV1NamespacedDaemonSet$Status$201)[ResponseContentType]>;
    /**
     * delete a DaemonSet
     * operationId: deleteAppsV1NamespacedDaemonSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets/{name}
     */
    deleteAppsV1NamespacedDaemonSet<ResponseContentType extends ResponseContentType$deleteAppsV1NamespacedDaemonSet>(params: Params$deleteAppsV1NamespacedDaemonSet<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteAppsV1NamespacedDaemonSet$Status$200 | Response$deleteAppsV1NamespacedDaemonSet$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified DaemonSet
     * operationId: patchAppsV1NamespacedDaemonSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets/{name}
     */
    patchAppsV1NamespacedDaemonSet<RequestContentType extends RequestContentType$patchAppsV1NamespacedDaemonSet, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedDaemonSet>(params: Params$patchAppsV1NamespacedDaemonSet<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedDaemonSet$Status$200 | Response$patchAppsV1NamespacedDaemonSet$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified DaemonSet
     * operationId: readAppsV1NamespacedDaemonSetStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets/{name}/status
     */
    readAppsV1NamespacedDaemonSetStatus<ResponseContentType extends ResponseContentType$readAppsV1NamespacedDaemonSetStatus>(params: Params$readAppsV1NamespacedDaemonSetStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedDaemonSetStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified DaemonSet
     * operationId: replaceAppsV1NamespacedDaemonSetStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets/{name}/status
     */
    replaceAppsV1NamespacedDaemonSetStatus<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedDaemonSetStatus>(params: Params$replaceAppsV1NamespacedDaemonSetStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedDaemonSetStatus$Status$200 | Response$replaceAppsV1NamespacedDaemonSetStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified DaemonSet
     * operationId: patchAppsV1NamespacedDaemonSetStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/daemonsets/{name}/status
     */
    patchAppsV1NamespacedDaemonSetStatus<RequestContentType extends RequestContentType$patchAppsV1NamespacedDaemonSetStatus, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedDaemonSetStatus>(params: Params$patchAppsV1NamespacedDaemonSetStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedDaemonSetStatus$Status$200 | Response$patchAppsV1NamespacedDaemonSetStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind Deployment
     * operationId: listAppsV1NamespacedDeployment
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments
     */
    listAppsV1NamespacedDeployment<ResponseContentType extends ResponseContentType$listAppsV1NamespacedDeployment>(params: Params$listAppsV1NamespacedDeployment<ResponseContentType>, option?: RequestOption): Promise<Response$listAppsV1NamespacedDeployment$Status$200[ResponseContentType]>;
    /**
     * create a Deployment
     * operationId: createAppsV1NamespacedDeployment
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments
     */
    createAppsV1NamespacedDeployment<ResponseContentType extends ResponseContentType$createAppsV1NamespacedDeployment>(params: Params$createAppsV1NamespacedDeployment<ResponseContentType>, option?: RequestOption): Promise<(Response$createAppsV1NamespacedDeployment$Status$200 | Response$createAppsV1NamespacedDeployment$Status$201 | Response$createAppsV1NamespacedDeployment$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Deployment
     * operationId: deleteAppsV1CollectionNamespacedDeployment
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments
     */
    deleteAppsV1CollectionNamespacedDeployment<ResponseContentType extends ResponseContentType$deleteAppsV1CollectionNamespacedDeployment>(params: Params$deleteAppsV1CollectionNamespacedDeployment<ResponseContentType>, option?: RequestOption): Promise<Response$deleteAppsV1CollectionNamespacedDeployment$Status$200[ResponseContentType]>;
    /**
     * read the specified Deployment
     * operationId: readAppsV1NamespacedDeployment
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}
     */
    readAppsV1NamespacedDeployment<ResponseContentType extends ResponseContentType$readAppsV1NamespacedDeployment>(params: Params$readAppsV1NamespacedDeployment<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedDeployment$Status$200[ResponseContentType]>;
    /**
     * replace the specified Deployment
     * operationId: replaceAppsV1NamespacedDeployment
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}
     */
    replaceAppsV1NamespacedDeployment<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedDeployment>(params: Params$replaceAppsV1NamespacedDeployment<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedDeployment$Status$200 | Response$replaceAppsV1NamespacedDeployment$Status$201)[ResponseContentType]>;
    /**
     * delete a Deployment
     * operationId: deleteAppsV1NamespacedDeployment
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}
     */
    deleteAppsV1NamespacedDeployment<ResponseContentType extends ResponseContentType$deleteAppsV1NamespacedDeployment>(params: Params$deleteAppsV1NamespacedDeployment<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteAppsV1NamespacedDeployment$Status$200 | Response$deleteAppsV1NamespacedDeployment$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Deployment
     * operationId: patchAppsV1NamespacedDeployment
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}
     */
    patchAppsV1NamespacedDeployment<RequestContentType extends RequestContentType$patchAppsV1NamespacedDeployment, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedDeployment>(params: Params$patchAppsV1NamespacedDeployment<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedDeployment$Status$200 | Response$patchAppsV1NamespacedDeployment$Status$201)[ResponseContentType]>;
    /**
     * read scale of the specified Deployment
     * operationId: readAppsV1NamespacedDeploymentScale
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}/scale
     */
    readAppsV1NamespacedDeploymentScale<ResponseContentType extends ResponseContentType$readAppsV1NamespacedDeploymentScale>(params: Params$readAppsV1NamespacedDeploymentScale<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedDeploymentScale$Status$200[ResponseContentType]>;
    /**
     * replace scale of the specified Deployment
     * operationId: replaceAppsV1NamespacedDeploymentScale
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}/scale
     */
    replaceAppsV1NamespacedDeploymentScale<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedDeploymentScale>(params: Params$replaceAppsV1NamespacedDeploymentScale<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedDeploymentScale$Status$200 | Response$replaceAppsV1NamespacedDeploymentScale$Status$201)[ResponseContentType]>;
    /**
     * partially update scale of the specified Deployment
     * operationId: patchAppsV1NamespacedDeploymentScale
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}/scale
     */
    patchAppsV1NamespacedDeploymentScale<RequestContentType extends RequestContentType$patchAppsV1NamespacedDeploymentScale, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedDeploymentScale>(params: Params$patchAppsV1NamespacedDeploymentScale<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedDeploymentScale$Status$200 | Response$patchAppsV1NamespacedDeploymentScale$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified Deployment
     * operationId: readAppsV1NamespacedDeploymentStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}/status
     */
    readAppsV1NamespacedDeploymentStatus<ResponseContentType extends ResponseContentType$readAppsV1NamespacedDeploymentStatus>(params: Params$readAppsV1NamespacedDeploymentStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedDeploymentStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified Deployment
     * operationId: replaceAppsV1NamespacedDeploymentStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}/status
     */
    replaceAppsV1NamespacedDeploymentStatus<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedDeploymentStatus>(params: Params$replaceAppsV1NamespacedDeploymentStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedDeploymentStatus$Status$200 | Response$replaceAppsV1NamespacedDeploymentStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified Deployment
     * operationId: patchAppsV1NamespacedDeploymentStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/deployments/{name}/status
     */
    patchAppsV1NamespacedDeploymentStatus<RequestContentType extends RequestContentType$patchAppsV1NamespacedDeploymentStatus, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedDeploymentStatus>(params: Params$patchAppsV1NamespacedDeploymentStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedDeploymentStatus$Status$200 | Response$patchAppsV1NamespacedDeploymentStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind ReplicaSet
     * operationId: listAppsV1NamespacedReplicaSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets
     */
    listAppsV1NamespacedReplicaSet<ResponseContentType extends ResponseContentType$listAppsV1NamespacedReplicaSet>(params: Params$listAppsV1NamespacedReplicaSet<ResponseContentType>, option?: RequestOption): Promise<Response$listAppsV1NamespacedReplicaSet$Status$200[ResponseContentType]>;
    /**
     * create a ReplicaSet
     * operationId: createAppsV1NamespacedReplicaSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets
     */
    createAppsV1NamespacedReplicaSet<ResponseContentType extends ResponseContentType$createAppsV1NamespacedReplicaSet>(params: Params$createAppsV1NamespacedReplicaSet<ResponseContentType>, option?: RequestOption): Promise<(Response$createAppsV1NamespacedReplicaSet$Status$200 | Response$createAppsV1NamespacedReplicaSet$Status$201 | Response$createAppsV1NamespacedReplicaSet$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ReplicaSet
     * operationId: deleteAppsV1CollectionNamespacedReplicaSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets
     */
    deleteAppsV1CollectionNamespacedReplicaSet<ResponseContentType extends ResponseContentType$deleteAppsV1CollectionNamespacedReplicaSet>(params: Params$deleteAppsV1CollectionNamespacedReplicaSet<ResponseContentType>, option?: RequestOption): Promise<Response$deleteAppsV1CollectionNamespacedReplicaSet$Status$200[ResponseContentType]>;
    /**
     * read the specified ReplicaSet
     * operationId: readAppsV1NamespacedReplicaSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}
     */
    readAppsV1NamespacedReplicaSet<ResponseContentType extends ResponseContentType$readAppsV1NamespacedReplicaSet>(params: Params$readAppsV1NamespacedReplicaSet<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedReplicaSet$Status$200[ResponseContentType]>;
    /**
     * replace the specified ReplicaSet
     * operationId: replaceAppsV1NamespacedReplicaSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}
     */
    replaceAppsV1NamespacedReplicaSet<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedReplicaSet>(params: Params$replaceAppsV1NamespacedReplicaSet<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedReplicaSet$Status$200 | Response$replaceAppsV1NamespacedReplicaSet$Status$201)[ResponseContentType]>;
    /**
     * delete a ReplicaSet
     * operationId: deleteAppsV1NamespacedReplicaSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}
     */
    deleteAppsV1NamespacedReplicaSet<ResponseContentType extends ResponseContentType$deleteAppsV1NamespacedReplicaSet>(params: Params$deleteAppsV1NamespacedReplicaSet<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteAppsV1NamespacedReplicaSet$Status$200 | Response$deleteAppsV1NamespacedReplicaSet$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ReplicaSet
     * operationId: patchAppsV1NamespacedReplicaSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}
     */
    patchAppsV1NamespacedReplicaSet<RequestContentType extends RequestContentType$patchAppsV1NamespacedReplicaSet, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedReplicaSet>(params: Params$patchAppsV1NamespacedReplicaSet<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedReplicaSet$Status$200 | Response$patchAppsV1NamespacedReplicaSet$Status$201)[ResponseContentType]>;
    /**
     * read scale of the specified ReplicaSet
     * operationId: readAppsV1NamespacedReplicaSetScale
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}/scale
     */
    readAppsV1NamespacedReplicaSetScale<ResponseContentType extends ResponseContentType$readAppsV1NamespacedReplicaSetScale>(params: Params$readAppsV1NamespacedReplicaSetScale<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedReplicaSetScale$Status$200[ResponseContentType]>;
    /**
     * replace scale of the specified ReplicaSet
     * operationId: replaceAppsV1NamespacedReplicaSetScale
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}/scale
     */
    replaceAppsV1NamespacedReplicaSetScale<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedReplicaSetScale>(params: Params$replaceAppsV1NamespacedReplicaSetScale<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedReplicaSetScale$Status$200 | Response$replaceAppsV1NamespacedReplicaSetScale$Status$201)[ResponseContentType]>;
    /**
     * partially update scale of the specified ReplicaSet
     * operationId: patchAppsV1NamespacedReplicaSetScale
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}/scale
     */
    patchAppsV1NamespacedReplicaSetScale<RequestContentType extends RequestContentType$patchAppsV1NamespacedReplicaSetScale, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedReplicaSetScale>(params: Params$patchAppsV1NamespacedReplicaSetScale<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedReplicaSetScale$Status$200 | Response$patchAppsV1NamespacedReplicaSetScale$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified ReplicaSet
     * operationId: readAppsV1NamespacedReplicaSetStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}/status
     */
    readAppsV1NamespacedReplicaSetStatus<ResponseContentType extends ResponseContentType$readAppsV1NamespacedReplicaSetStatus>(params: Params$readAppsV1NamespacedReplicaSetStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedReplicaSetStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified ReplicaSet
     * operationId: replaceAppsV1NamespacedReplicaSetStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}/status
     */
    replaceAppsV1NamespacedReplicaSetStatus<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedReplicaSetStatus>(params: Params$replaceAppsV1NamespacedReplicaSetStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedReplicaSetStatus$Status$200 | Response$replaceAppsV1NamespacedReplicaSetStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified ReplicaSet
     * operationId: patchAppsV1NamespacedReplicaSetStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/replicasets/{name}/status
     */
    patchAppsV1NamespacedReplicaSetStatus<RequestContentType extends RequestContentType$patchAppsV1NamespacedReplicaSetStatus, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedReplicaSetStatus>(params: Params$patchAppsV1NamespacedReplicaSetStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedReplicaSetStatus$Status$200 | Response$patchAppsV1NamespacedReplicaSetStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind StatefulSet
     * operationId: listAppsV1NamespacedStatefulSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets
     */
    listAppsV1NamespacedStatefulSet<ResponseContentType extends ResponseContentType$listAppsV1NamespacedStatefulSet>(params: Params$listAppsV1NamespacedStatefulSet<ResponseContentType>, option?: RequestOption): Promise<Response$listAppsV1NamespacedStatefulSet$Status$200[ResponseContentType]>;
    /**
     * create a StatefulSet
     * operationId: createAppsV1NamespacedStatefulSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets
     */
    createAppsV1NamespacedStatefulSet<ResponseContentType extends ResponseContentType$createAppsV1NamespacedStatefulSet>(params: Params$createAppsV1NamespacedStatefulSet<ResponseContentType>, option?: RequestOption): Promise<(Response$createAppsV1NamespacedStatefulSet$Status$200 | Response$createAppsV1NamespacedStatefulSet$Status$201 | Response$createAppsV1NamespacedStatefulSet$Status$202)[ResponseContentType]>;
    /**
     * delete collection of StatefulSet
     * operationId: deleteAppsV1CollectionNamespacedStatefulSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets
     */
    deleteAppsV1CollectionNamespacedStatefulSet<ResponseContentType extends ResponseContentType$deleteAppsV1CollectionNamespacedStatefulSet>(params: Params$deleteAppsV1CollectionNamespacedStatefulSet<ResponseContentType>, option?: RequestOption): Promise<Response$deleteAppsV1CollectionNamespacedStatefulSet$Status$200[ResponseContentType]>;
    /**
     * read the specified StatefulSet
     * operationId: readAppsV1NamespacedStatefulSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}
     */
    readAppsV1NamespacedStatefulSet<ResponseContentType extends ResponseContentType$readAppsV1NamespacedStatefulSet>(params: Params$readAppsV1NamespacedStatefulSet<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedStatefulSet$Status$200[ResponseContentType]>;
    /**
     * replace the specified StatefulSet
     * operationId: replaceAppsV1NamespacedStatefulSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}
     */
    replaceAppsV1NamespacedStatefulSet<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedStatefulSet>(params: Params$replaceAppsV1NamespacedStatefulSet<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedStatefulSet$Status$200 | Response$replaceAppsV1NamespacedStatefulSet$Status$201)[ResponseContentType]>;
    /**
     * delete a StatefulSet
     * operationId: deleteAppsV1NamespacedStatefulSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}
     */
    deleteAppsV1NamespacedStatefulSet<ResponseContentType extends ResponseContentType$deleteAppsV1NamespacedStatefulSet>(params: Params$deleteAppsV1NamespacedStatefulSet<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteAppsV1NamespacedStatefulSet$Status$200 | Response$deleteAppsV1NamespacedStatefulSet$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified StatefulSet
     * operationId: patchAppsV1NamespacedStatefulSet
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}
     */
    patchAppsV1NamespacedStatefulSet<RequestContentType extends RequestContentType$patchAppsV1NamespacedStatefulSet, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedStatefulSet>(params: Params$patchAppsV1NamespacedStatefulSet<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedStatefulSet$Status$200 | Response$patchAppsV1NamespacedStatefulSet$Status$201)[ResponseContentType]>;
    /**
     * read scale of the specified StatefulSet
     * operationId: readAppsV1NamespacedStatefulSetScale
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}/scale
     */
    readAppsV1NamespacedStatefulSetScale<ResponseContentType extends ResponseContentType$readAppsV1NamespacedStatefulSetScale>(params: Params$readAppsV1NamespacedStatefulSetScale<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedStatefulSetScale$Status$200[ResponseContentType]>;
    /**
     * replace scale of the specified StatefulSet
     * operationId: replaceAppsV1NamespacedStatefulSetScale
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}/scale
     */
    replaceAppsV1NamespacedStatefulSetScale<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedStatefulSetScale>(params: Params$replaceAppsV1NamespacedStatefulSetScale<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedStatefulSetScale$Status$200 | Response$replaceAppsV1NamespacedStatefulSetScale$Status$201)[ResponseContentType]>;
    /**
     * partially update scale of the specified StatefulSet
     * operationId: patchAppsV1NamespacedStatefulSetScale
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}/scale
     */
    patchAppsV1NamespacedStatefulSetScale<RequestContentType extends RequestContentType$patchAppsV1NamespacedStatefulSetScale, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedStatefulSetScale>(params: Params$patchAppsV1NamespacedStatefulSetScale<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedStatefulSetScale$Status$200 | Response$patchAppsV1NamespacedStatefulSetScale$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified StatefulSet
     * operationId: readAppsV1NamespacedStatefulSetStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}/status
     */
    readAppsV1NamespacedStatefulSetStatus<ResponseContentType extends ResponseContentType$readAppsV1NamespacedStatefulSetStatus>(params: Params$readAppsV1NamespacedStatefulSetStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readAppsV1NamespacedStatefulSetStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified StatefulSet
     * operationId: replaceAppsV1NamespacedStatefulSetStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}/status
     */
    replaceAppsV1NamespacedStatefulSetStatus<ResponseContentType extends ResponseContentType$replaceAppsV1NamespacedStatefulSetStatus>(params: Params$replaceAppsV1NamespacedStatefulSetStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAppsV1NamespacedStatefulSetStatus$Status$200 | Response$replaceAppsV1NamespacedStatefulSetStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified StatefulSet
     * operationId: patchAppsV1NamespacedStatefulSetStatus
     * Request URI: /apis/apps/v1/namespaces/{namespace}/statefulsets/{name}/status
     */
    patchAppsV1NamespacedStatefulSetStatus<RequestContentType extends RequestContentType$patchAppsV1NamespacedStatefulSetStatus, ResponseContentType extends ResponseContentType$patchAppsV1NamespacedStatefulSetStatus>(params: Params$patchAppsV1NamespacedStatefulSetStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAppsV1NamespacedStatefulSetStatus$Status$200 | Response$patchAppsV1NamespacedStatefulSetStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind ReplicaSet
     * operationId: listAppsV1ReplicaSetForAllNamespaces
     * Request URI: /apis/apps/v1/replicasets
     */
    listAppsV1ReplicaSetForAllNamespaces<ResponseContentType extends ResponseContentType$listAppsV1ReplicaSetForAllNamespaces>(params: Params$listAppsV1ReplicaSetForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listAppsV1ReplicaSetForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind StatefulSet
     * operationId: listAppsV1StatefulSetForAllNamespaces
     * Request URI: /apis/apps/v1/statefulsets
     */
    listAppsV1StatefulSetForAllNamespaces<ResponseContentType extends ResponseContentType$listAppsV1StatefulSetForAllNamespaces>(params: Params$listAppsV1StatefulSetForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listAppsV1StatefulSetForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ControllerRevision. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAppsV1ControllerRevisionListForAllNamespaces
     * Request URI: /apis/apps/v1/watch/controllerrevisions
     */
    watchAppsV1ControllerRevisionListForAllNamespaces<ResponseContentType extends ResponseContentType$watchAppsV1ControllerRevisionListForAllNamespaces>(params: Params$watchAppsV1ControllerRevisionListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1ControllerRevisionListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of DaemonSet. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAppsV1DaemonSetListForAllNamespaces
     * Request URI: /apis/apps/v1/watch/daemonsets
     */
    watchAppsV1DaemonSetListForAllNamespaces<ResponseContentType extends ResponseContentType$watchAppsV1DaemonSetListForAllNamespaces>(params: Params$watchAppsV1DaemonSetListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1DaemonSetListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Deployment. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAppsV1DeploymentListForAllNamespaces
     * Request URI: /apis/apps/v1/watch/deployments
     */
    watchAppsV1DeploymentListForAllNamespaces<ResponseContentType extends ResponseContentType$watchAppsV1DeploymentListForAllNamespaces>(params: Params$watchAppsV1DeploymentListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1DeploymentListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ControllerRevision. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAppsV1NamespacedControllerRevisionList
     * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/controllerrevisions
     */
    watchAppsV1NamespacedControllerRevisionList<ResponseContentType extends ResponseContentType$watchAppsV1NamespacedControllerRevisionList>(params: Params$watchAppsV1NamespacedControllerRevisionList<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1NamespacedControllerRevisionList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ControllerRevision. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchAppsV1NamespacedControllerRevision
     * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/controllerrevisions/{name}
     */
    watchAppsV1NamespacedControllerRevision<ResponseContentType extends ResponseContentType$watchAppsV1NamespacedControllerRevision>(params: Params$watchAppsV1NamespacedControllerRevision<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1NamespacedControllerRevision$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of DaemonSet. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAppsV1NamespacedDaemonSetList
     * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/daemonsets
     */
    watchAppsV1NamespacedDaemonSetList<ResponseContentType extends ResponseContentType$watchAppsV1NamespacedDaemonSetList>(params: Params$watchAppsV1NamespacedDaemonSetList<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1NamespacedDaemonSetList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind DaemonSet. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchAppsV1NamespacedDaemonSet
     * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/daemonsets/{name}
     */
    watchAppsV1NamespacedDaemonSet<ResponseContentType extends ResponseContentType$watchAppsV1NamespacedDaemonSet>(params: Params$watchAppsV1NamespacedDaemonSet<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1NamespacedDaemonSet$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Deployment. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAppsV1NamespacedDeploymentList
     * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/deployments
     */
    watchAppsV1NamespacedDeploymentList<ResponseContentType extends ResponseContentType$watchAppsV1NamespacedDeploymentList>(params: Params$watchAppsV1NamespacedDeploymentList<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1NamespacedDeploymentList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Deployment. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchAppsV1NamespacedDeployment
     * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/deployments/{name}
     */
    watchAppsV1NamespacedDeployment<ResponseContentType extends ResponseContentType$watchAppsV1NamespacedDeployment>(params: Params$watchAppsV1NamespacedDeployment<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1NamespacedDeployment$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ReplicaSet. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAppsV1NamespacedReplicaSetList
     * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/replicasets
     */
    watchAppsV1NamespacedReplicaSetList<ResponseContentType extends ResponseContentType$watchAppsV1NamespacedReplicaSetList>(params: Params$watchAppsV1NamespacedReplicaSetList<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1NamespacedReplicaSetList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ReplicaSet. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchAppsV1NamespacedReplicaSet
     * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/replicasets/{name}
     */
    watchAppsV1NamespacedReplicaSet<ResponseContentType extends ResponseContentType$watchAppsV1NamespacedReplicaSet>(params: Params$watchAppsV1NamespacedReplicaSet<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1NamespacedReplicaSet$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of StatefulSet. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAppsV1NamespacedStatefulSetList
     * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/statefulsets
     */
    watchAppsV1NamespacedStatefulSetList<ResponseContentType extends ResponseContentType$watchAppsV1NamespacedStatefulSetList>(params: Params$watchAppsV1NamespacedStatefulSetList<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1NamespacedStatefulSetList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind StatefulSet. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchAppsV1NamespacedStatefulSet
     * Request URI: /apis/apps/v1/watch/namespaces/{namespace}/statefulsets/{name}
     */
    watchAppsV1NamespacedStatefulSet<ResponseContentType extends ResponseContentType$watchAppsV1NamespacedStatefulSet>(params: Params$watchAppsV1NamespacedStatefulSet<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1NamespacedStatefulSet$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ReplicaSet. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAppsV1ReplicaSetListForAllNamespaces
     * Request URI: /apis/apps/v1/watch/replicasets
     */
    watchAppsV1ReplicaSetListForAllNamespaces<ResponseContentType extends ResponseContentType$watchAppsV1ReplicaSetListForAllNamespaces>(params: Params$watchAppsV1ReplicaSetListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1ReplicaSetListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of StatefulSet. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAppsV1StatefulSetListForAllNamespaces
     * Request URI: /apis/apps/v1/watch/statefulsets
     */
    watchAppsV1StatefulSetListForAllNamespaces<ResponseContentType extends ResponseContentType$watchAppsV1StatefulSetListForAllNamespaces>(params: Params$watchAppsV1StatefulSetListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchAppsV1StatefulSetListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getAuthenticationAPIGroup
     * Request URI: /apis/authentication.k8s.io/
     */
    getAuthenticationAPIGroup<ResponseContentType extends ResponseContentType$getAuthenticationAPIGroup>(params: Params$getAuthenticationAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getAuthenticationAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getAuthenticationV1APIResources
     * Request URI: /apis/authentication.k8s.io/v1/
     */
    getAuthenticationV1APIResources<ResponseContentType extends ResponseContentType$getAuthenticationV1APIResources>(params: Params$getAuthenticationV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getAuthenticationV1APIResources$Status$200[ResponseContentType]>;
    /**
     * create a TokenReview
     * operationId: createAuthenticationV1TokenReview
     * Request URI: /apis/authentication.k8s.io/v1/tokenreviews
     */
    createAuthenticationV1TokenReview<ResponseContentType extends ResponseContentType$createAuthenticationV1TokenReview>(params: Params$createAuthenticationV1TokenReview<ResponseContentType>, option?: RequestOption): Promise<(Response$createAuthenticationV1TokenReview$Status$200 | Response$createAuthenticationV1TokenReview$Status$201 | Response$createAuthenticationV1TokenReview$Status$202)[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getAuthenticationV1alpha1APIResources
     * Request URI: /apis/authentication.k8s.io/v1alpha1/
     */
    getAuthenticationV1alpha1APIResources<ResponseContentType extends ResponseContentType$getAuthenticationV1alpha1APIResources>(params: Params$getAuthenticationV1alpha1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getAuthenticationV1alpha1APIResources$Status$200[ResponseContentType]>;
    /**
     * create a SelfSubjectReview
     * operationId: createAuthenticationV1alpha1SelfSubjectReview
     * Request URI: /apis/authentication.k8s.io/v1alpha1/selfsubjectreviews
     */
    createAuthenticationV1alpha1SelfSubjectReview<ResponseContentType extends ResponseContentType$createAuthenticationV1alpha1SelfSubjectReview>(params: Params$createAuthenticationV1alpha1SelfSubjectReview<ResponseContentType>, option?: RequestOption): Promise<(Response$createAuthenticationV1alpha1SelfSubjectReview$Status$200 | Response$createAuthenticationV1alpha1SelfSubjectReview$Status$201 | Response$createAuthenticationV1alpha1SelfSubjectReview$Status$202)[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getAuthenticationV1beta1APIResources
     * Request URI: /apis/authentication.k8s.io/v1beta1/
     */
    getAuthenticationV1beta1APIResources<ResponseContentType extends ResponseContentType$getAuthenticationV1beta1APIResources>(params: Params$getAuthenticationV1beta1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getAuthenticationV1beta1APIResources$Status$200[ResponseContentType]>;
    /**
     * create a SelfSubjectReview
     * operationId: createAuthenticationV1beta1SelfSubjectReview
     * Request URI: /apis/authentication.k8s.io/v1beta1/selfsubjectreviews
     */
    createAuthenticationV1beta1SelfSubjectReview<ResponseContentType extends ResponseContentType$createAuthenticationV1beta1SelfSubjectReview>(params: Params$createAuthenticationV1beta1SelfSubjectReview<ResponseContentType>, option?: RequestOption): Promise<(Response$createAuthenticationV1beta1SelfSubjectReview$Status$200 | Response$createAuthenticationV1beta1SelfSubjectReview$Status$201 | Response$createAuthenticationV1beta1SelfSubjectReview$Status$202)[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getAuthorizationAPIGroup
     * Request URI: /apis/authorization.k8s.io/
     */
    getAuthorizationAPIGroup<ResponseContentType extends ResponseContentType$getAuthorizationAPIGroup>(params: Params$getAuthorizationAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getAuthorizationAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getAuthorizationV1APIResources
     * Request URI: /apis/authorization.k8s.io/v1/
     */
    getAuthorizationV1APIResources<ResponseContentType extends ResponseContentType$getAuthorizationV1APIResources>(params: Params$getAuthorizationV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getAuthorizationV1APIResources$Status$200[ResponseContentType]>;
    /**
     * create a LocalSubjectAccessReview
     * operationId: createAuthorizationV1NamespacedLocalSubjectAccessReview
     * Request URI: /apis/authorization.k8s.io/v1/namespaces/{namespace}/localsubjectaccessreviews
     */
    createAuthorizationV1NamespacedLocalSubjectAccessReview<ResponseContentType extends ResponseContentType$createAuthorizationV1NamespacedLocalSubjectAccessReview>(params: Params$createAuthorizationV1NamespacedLocalSubjectAccessReview<ResponseContentType>, option?: RequestOption): Promise<(Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$200 | Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$201 | Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$202)[ResponseContentType]>;
    /**
     * create a SelfSubjectAccessReview
     * operationId: createAuthorizationV1SelfSubjectAccessReview
     * Request URI: /apis/authorization.k8s.io/v1/selfsubjectaccessreviews
     */
    createAuthorizationV1SelfSubjectAccessReview<ResponseContentType extends ResponseContentType$createAuthorizationV1SelfSubjectAccessReview>(params: Params$createAuthorizationV1SelfSubjectAccessReview<ResponseContentType>, option?: RequestOption): Promise<(Response$createAuthorizationV1SelfSubjectAccessReview$Status$200 | Response$createAuthorizationV1SelfSubjectAccessReview$Status$201 | Response$createAuthorizationV1SelfSubjectAccessReview$Status$202)[ResponseContentType]>;
    /**
     * create a SelfSubjectRulesReview
     * operationId: createAuthorizationV1SelfSubjectRulesReview
     * Request URI: /apis/authorization.k8s.io/v1/selfsubjectrulesreviews
     */
    createAuthorizationV1SelfSubjectRulesReview<ResponseContentType extends ResponseContentType$createAuthorizationV1SelfSubjectRulesReview>(params: Params$createAuthorizationV1SelfSubjectRulesReview<ResponseContentType>, option?: RequestOption): Promise<(Response$createAuthorizationV1SelfSubjectRulesReview$Status$200 | Response$createAuthorizationV1SelfSubjectRulesReview$Status$201 | Response$createAuthorizationV1SelfSubjectRulesReview$Status$202)[ResponseContentType]>;
    /**
     * create a SubjectAccessReview
     * operationId: createAuthorizationV1SubjectAccessReview
     * Request URI: /apis/authorization.k8s.io/v1/subjectaccessreviews
     */
    createAuthorizationV1SubjectAccessReview<ResponseContentType extends ResponseContentType$createAuthorizationV1SubjectAccessReview>(params: Params$createAuthorizationV1SubjectAccessReview<ResponseContentType>, option?: RequestOption): Promise<(Response$createAuthorizationV1SubjectAccessReview$Status$200 | Response$createAuthorizationV1SubjectAccessReview$Status$201 | Response$createAuthorizationV1SubjectAccessReview$Status$202)[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getAutoscalingAPIGroup
     * Request URI: /apis/autoscaling/
     */
    getAutoscalingAPIGroup<ResponseContentType extends ResponseContentType$getAutoscalingAPIGroup>(params: Params$getAutoscalingAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getAutoscalingAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getAutoscalingV1APIResources
     * Request URI: /apis/autoscaling/v1/
     */
    getAutoscalingV1APIResources<ResponseContentType extends ResponseContentType$getAutoscalingV1APIResources>(params: Params$getAutoscalingV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getAutoscalingV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind HorizontalPodAutoscaler
     * operationId: listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces
     * Request URI: /apis/autoscaling/v1/horizontalpodautoscalers
     */
    listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces<ResponseContentType extends ResponseContentType$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces>(params: Params$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind HorizontalPodAutoscaler
     * operationId: listAutoscalingV1NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers
     */
    listAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$listAutoscalingV1NamespacedHorizontalPodAutoscaler>(params: Params$listAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$listAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * create a HorizontalPodAutoscaler
     * operationId: createAutoscalingV1NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers
     */
    createAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$createAutoscalingV1NamespacedHorizontalPodAutoscaler>(params: Params$createAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<(Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201 | Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$202)[ResponseContentType]>;
    /**
     * delete collection of HorizontalPodAutoscaler
     * operationId: deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers
     */
    deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler>(params: Params$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * read the specified HorizontalPodAutoscaler
     * operationId: readAutoscalingV1NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    readAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$readAutoscalingV1NamespacedHorizontalPodAutoscaler>(params: Params$readAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$readAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * replace the specified HorizontalPodAutoscaler
     * operationId: replaceAutoscalingV1NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    replaceAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler>(params: Params$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201)[ResponseContentType]>;
    /**
     * delete a HorizontalPodAutoscaler
     * operationId: deleteAutoscalingV1NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    deleteAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler>(params: Params$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | Response$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified HorizontalPodAutoscaler
     * operationId: patchAutoscalingV1NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    patchAutoscalingV1NamespacedHorizontalPodAutoscaler<RequestContentType extends RequestContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscaler, ResponseContentType extends ResponseContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscaler>(params: Params$patchAutoscalingV1NamespacedHorizontalPodAutoscaler<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200 | Response$patchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified HorizontalPodAutoscaler
     * operationId: readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus
     * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
     */
    readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus<ResponseContentType extends ResponseContentType$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus>(params: Params$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified HorizontalPodAutoscaler
     * operationId: replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus
     * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
     */
    replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus<ResponseContentType extends ResponseContentType$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus>(params: Params$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified HorizontalPodAutoscaler
     * operationId: patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus
     * Request URI: /apis/autoscaling/v1/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
     */
    patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus<RequestContentType extends RequestContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus, ResponseContentType extends ResponseContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus>(params: Params$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces
     * Request URI: /apis/autoscaling/v1/watch/horizontalpodautoscalers
     */
    watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces<ResponseContentType extends ResponseContentType$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces>(params: Params$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAutoscalingV1NamespacedHorizontalPodAutoscalerList
     * Request URI: /apis/autoscaling/v1/watch/namespaces/{namespace}/horizontalpodautoscalers
     */
    watchAutoscalingV1NamespacedHorizontalPodAutoscalerList<ResponseContentType extends ResponseContentType$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList>(params: Params$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList<ResponseContentType>, option?: RequestOption): Promise<Response$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchAutoscalingV1NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v1/watch/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    watchAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$watchAutoscalingV1NamespacedHorizontalPodAutoscaler>(params: Params$watchAutoscalingV1NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$watchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getAutoscalingV2APIResources
     * Request URI: /apis/autoscaling/v2/
     */
    getAutoscalingV2APIResources<ResponseContentType extends ResponseContentType$getAutoscalingV2APIResources>(params: Params$getAutoscalingV2APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getAutoscalingV2APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind HorizontalPodAutoscaler
     * operationId: listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces
     * Request URI: /apis/autoscaling/v2/horizontalpodautoscalers
     */
    listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces<ResponseContentType extends ResponseContentType$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces>(params: Params$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind HorizontalPodAutoscaler
     * operationId: listAutoscalingV2NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2/namespaces/{namespace}/horizontalpodautoscalers
     */
    listAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$listAutoscalingV2NamespacedHorizontalPodAutoscaler>(params: Params$listAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$listAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * create a HorizontalPodAutoscaler
     * operationId: createAutoscalingV2NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2/namespaces/{namespace}/horizontalpodautoscalers
     */
    createAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$createAutoscalingV2NamespacedHorizontalPodAutoscaler>(params: Params$createAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<(Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201 | Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$202)[ResponseContentType]>;
    /**
     * delete collection of HorizontalPodAutoscaler
     * operationId: deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2/namespaces/{namespace}/horizontalpodautoscalers
     */
    deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler>(params: Params$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * read the specified HorizontalPodAutoscaler
     * operationId: readAutoscalingV2NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    readAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$readAutoscalingV2NamespacedHorizontalPodAutoscaler>(params: Params$readAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$readAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * replace the specified HorizontalPodAutoscaler
     * operationId: replaceAutoscalingV2NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    replaceAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler>(params: Params$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201)[ResponseContentType]>;
    /**
     * delete a HorizontalPodAutoscaler
     * operationId: deleteAutoscalingV2NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    deleteAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler>(params: Params$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | Response$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified HorizontalPodAutoscaler
     * operationId: patchAutoscalingV2NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    patchAutoscalingV2NamespacedHorizontalPodAutoscaler<RequestContentType extends RequestContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscaler, ResponseContentType extends ResponseContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscaler>(params: Params$patchAutoscalingV2NamespacedHorizontalPodAutoscaler<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200 | Response$patchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified HorizontalPodAutoscaler
     * operationId: readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus
     * Request URI: /apis/autoscaling/v2/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
     */
    readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus<ResponseContentType extends ResponseContentType$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus>(params: Params$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified HorizontalPodAutoscaler
     * operationId: replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus
     * Request URI: /apis/autoscaling/v2/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
     */
    replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus<ResponseContentType extends ResponseContentType$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus>(params: Params$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified HorizontalPodAutoscaler
     * operationId: patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus
     * Request URI: /apis/autoscaling/v2/namespaces/{namespace}/horizontalpodautoscalers/{name}/status
     */
    patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus<RequestContentType extends RequestContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus, ResponseContentType extends ResponseContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus>(params: Params$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200 | Response$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces
     * Request URI: /apis/autoscaling/v2/watch/horizontalpodautoscalers
     */
    watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces<ResponseContentType extends ResponseContentType$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces>(params: Params$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchAutoscalingV2NamespacedHorizontalPodAutoscalerList
     * Request URI: /apis/autoscaling/v2/watch/namespaces/{namespace}/horizontalpodautoscalers
     */
    watchAutoscalingV2NamespacedHorizontalPodAutoscalerList<ResponseContentType extends ResponseContentType$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList>(params: Params$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList<ResponseContentType>, option?: RequestOption): Promise<Response$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind HorizontalPodAutoscaler. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchAutoscalingV2NamespacedHorizontalPodAutoscaler
     * Request URI: /apis/autoscaling/v2/watch/namespaces/{namespace}/horizontalpodautoscalers/{name}
     */
    watchAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType extends ResponseContentType$watchAutoscalingV2NamespacedHorizontalPodAutoscaler>(params: Params$watchAutoscalingV2NamespacedHorizontalPodAutoscaler<ResponseContentType>, option?: RequestOption): Promise<Response$watchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getBatchAPIGroup
     * Request URI: /apis/batch/
     */
    getBatchAPIGroup<ResponseContentType extends ResponseContentType$getBatchAPIGroup>(params: Params$getBatchAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getBatchAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getBatchV1APIResources
     * Request URI: /apis/batch/v1/
     */
    getBatchV1APIResources<ResponseContentType extends ResponseContentType$getBatchV1APIResources>(params: Params$getBatchV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getBatchV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind CronJob
     * operationId: listBatchV1CronJobForAllNamespaces
     * Request URI: /apis/batch/v1/cronjobs
     */
    listBatchV1CronJobForAllNamespaces<ResponseContentType extends ResponseContentType$listBatchV1CronJobForAllNamespaces>(params: Params$listBatchV1CronJobForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listBatchV1CronJobForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Job
     * operationId: listBatchV1JobForAllNamespaces
     * Request URI: /apis/batch/v1/jobs
     */
    listBatchV1JobForAllNamespaces<ResponseContentType extends ResponseContentType$listBatchV1JobForAllNamespaces>(params: Params$listBatchV1JobForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listBatchV1JobForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind CronJob
     * operationId: listBatchV1NamespacedCronJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/cronjobs
     */
    listBatchV1NamespacedCronJob<ResponseContentType extends ResponseContentType$listBatchV1NamespacedCronJob>(params: Params$listBatchV1NamespacedCronJob<ResponseContentType>, option?: RequestOption): Promise<Response$listBatchV1NamespacedCronJob$Status$200[ResponseContentType]>;
    /**
     * create a CronJob
     * operationId: createBatchV1NamespacedCronJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/cronjobs
     */
    createBatchV1NamespacedCronJob<ResponseContentType extends ResponseContentType$createBatchV1NamespacedCronJob>(params: Params$createBatchV1NamespacedCronJob<ResponseContentType>, option?: RequestOption): Promise<(Response$createBatchV1NamespacedCronJob$Status$200 | Response$createBatchV1NamespacedCronJob$Status$201 | Response$createBatchV1NamespacedCronJob$Status$202)[ResponseContentType]>;
    /**
     * delete collection of CronJob
     * operationId: deleteBatchV1CollectionNamespacedCronJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/cronjobs
     */
    deleteBatchV1CollectionNamespacedCronJob<ResponseContentType extends ResponseContentType$deleteBatchV1CollectionNamespacedCronJob>(params: Params$deleteBatchV1CollectionNamespacedCronJob<ResponseContentType>, option?: RequestOption): Promise<Response$deleteBatchV1CollectionNamespacedCronJob$Status$200[ResponseContentType]>;
    /**
     * read the specified CronJob
     * operationId: readBatchV1NamespacedCronJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/cronjobs/{name}
     */
    readBatchV1NamespacedCronJob<ResponseContentType extends ResponseContentType$readBatchV1NamespacedCronJob>(params: Params$readBatchV1NamespacedCronJob<ResponseContentType>, option?: RequestOption): Promise<Response$readBatchV1NamespacedCronJob$Status$200[ResponseContentType]>;
    /**
     * replace the specified CronJob
     * operationId: replaceBatchV1NamespacedCronJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/cronjobs/{name}
     */
    replaceBatchV1NamespacedCronJob<ResponseContentType extends ResponseContentType$replaceBatchV1NamespacedCronJob>(params: Params$replaceBatchV1NamespacedCronJob<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceBatchV1NamespacedCronJob$Status$200 | Response$replaceBatchV1NamespacedCronJob$Status$201)[ResponseContentType]>;
    /**
     * delete a CronJob
     * operationId: deleteBatchV1NamespacedCronJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/cronjobs/{name}
     */
    deleteBatchV1NamespacedCronJob<ResponseContentType extends ResponseContentType$deleteBatchV1NamespacedCronJob>(params: Params$deleteBatchV1NamespacedCronJob<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteBatchV1NamespacedCronJob$Status$200 | Response$deleteBatchV1NamespacedCronJob$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified CronJob
     * operationId: patchBatchV1NamespacedCronJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/cronjobs/{name}
     */
    patchBatchV1NamespacedCronJob<RequestContentType extends RequestContentType$patchBatchV1NamespacedCronJob, ResponseContentType extends ResponseContentType$patchBatchV1NamespacedCronJob>(params: Params$patchBatchV1NamespacedCronJob<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchBatchV1NamespacedCronJob$Status$200 | Response$patchBatchV1NamespacedCronJob$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified CronJob
     * operationId: readBatchV1NamespacedCronJobStatus
     * Request URI: /apis/batch/v1/namespaces/{namespace}/cronjobs/{name}/status
     */
    readBatchV1NamespacedCronJobStatus<ResponseContentType extends ResponseContentType$readBatchV1NamespacedCronJobStatus>(params: Params$readBatchV1NamespacedCronJobStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readBatchV1NamespacedCronJobStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified CronJob
     * operationId: replaceBatchV1NamespacedCronJobStatus
     * Request URI: /apis/batch/v1/namespaces/{namespace}/cronjobs/{name}/status
     */
    replaceBatchV1NamespacedCronJobStatus<ResponseContentType extends ResponseContentType$replaceBatchV1NamespacedCronJobStatus>(params: Params$replaceBatchV1NamespacedCronJobStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceBatchV1NamespacedCronJobStatus$Status$200 | Response$replaceBatchV1NamespacedCronJobStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified CronJob
     * operationId: patchBatchV1NamespacedCronJobStatus
     * Request URI: /apis/batch/v1/namespaces/{namespace}/cronjobs/{name}/status
     */
    patchBatchV1NamespacedCronJobStatus<RequestContentType extends RequestContentType$patchBatchV1NamespacedCronJobStatus, ResponseContentType extends ResponseContentType$patchBatchV1NamespacedCronJobStatus>(params: Params$patchBatchV1NamespacedCronJobStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchBatchV1NamespacedCronJobStatus$Status$200 | Response$patchBatchV1NamespacedCronJobStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind Job
     * operationId: listBatchV1NamespacedJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs
     */
    listBatchV1NamespacedJob<ResponseContentType extends ResponseContentType$listBatchV1NamespacedJob>(params: Params$listBatchV1NamespacedJob<ResponseContentType>, option?: RequestOption): Promise<Response$listBatchV1NamespacedJob$Status$200[ResponseContentType]>;
    /**
     * create a Job
     * operationId: createBatchV1NamespacedJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs
     */
    createBatchV1NamespacedJob<ResponseContentType extends ResponseContentType$createBatchV1NamespacedJob>(params: Params$createBatchV1NamespacedJob<ResponseContentType>, option?: RequestOption): Promise<(Response$createBatchV1NamespacedJob$Status$200 | Response$createBatchV1NamespacedJob$Status$201 | Response$createBatchV1NamespacedJob$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Job
     * operationId: deleteBatchV1CollectionNamespacedJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs
     */
    deleteBatchV1CollectionNamespacedJob<ResponseContentType extends ResponseContentType$deleteBatchV1CollectionNamespacedJob>(params: Params$deleteBatchV1CollectionNamespacedJob<ResponseContentType>, option?: RequestOption): Promise<Response$deleteBatchV1CollectionNamespacedJob$Status$200[ResponseContentType]>;
    /**
     * read the specified Job
     * operationId: readBatchV1NamespacedJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs/{name}
     */
    readBatchV1NamespacedJob<ResponseContentType extends ResponseContentType$readBatchV1NamespacedJob>(params: Params$readBatchV1NamespacedJob<ResponseContentType>, option?: RequestOption): Promise<Response$readBatchV1NamespacedJob$Status$200[ResponseContentType]>;
    /**
     * replace the specified Job
     * operationId: replaceBatchV1NamespacedJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs/{name}
     */
    replaceBatchV1NamespacedJob<ResponseContentType extends ResponseContentType$replaceBatchV1NamespacedJob>(params: Params$replaceBatchV1NamespacedJob<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceBatchV1NamespacedJob$Status$200 | Response$replaceBatchV1NamespacedJob$Status$201)[ResponseContentType]>;
    /**
     * delete a Job
     * operationId: deleteBatchV1NamespacedJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs/{name}
     */
    deleteBatchV1NamespacedJob<ResponseContentType extends ResponseContentType$deleteBatchV1NamespacedJob>(params: Params$deleteBatchV1NamespacedJob<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteBatchV1NamespacedJob$Status$200 | Response$deleteBatchV1NamespacedJob$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Job
     * operationId: patchBatchV1NamespacedJob
     * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs/{name}
     */
    patchBatchV1NamespacedJob<RequestContentType extends RequestContentType$patchBatchV1NamespacedJob, ResponseContentType extends ResponseContentType$patchBatchV1NamespacedJob>(params: Params$patchBatchV1NamespacedJob<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchBatchV1NamespacedJob$Status$200 | Response$patchBatchV1NamespacedJob$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified Job
     * operationId: readBatchV1NamespacedJobStatus
     * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs/{name}/status
     */
    readBatchV1NamespacedJobStatus<ResponseContentType extends ResponseContentType$readBatchV1NamespacedJobStatus>(params: Params$readBatchV1NamespacedJobStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readBatchV1NamespacedJobStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified Job
     * operationId: replaceBatchV1NamespacedJobStatus
     * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs/{name}/status
     */
    replaceBatchV1NamespacedJobStatus<ResponseContentType extends ResponseContentType$replaceBatchV1NamespacedJobStatus>(params: Params$replaceBatchV1NamespacedJobStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceBatchV1NamespacedJobStatus$Status$200 | Response$replaceBatchV1NamespacedJobStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified Job
     * operationId: patchBatchV1NamespacedJobStatus
     * Request URI: /apis/batch/v1/namespaces/{namespace}/jobs/{name}/status
     */
    patchBatchV1NamespacedJobStatus<RequestContentType extends RequestContentType$patchBatchV1NamespacedJobStatus, ResponseContentType extends ResponseContentType$patchBatchV1NamespacedJobStatus>(params: Params$patchBatchV1NamespacedJobStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchBatchV1NamespacedJobStatus$Status$200 | Response$patchBatchV1NamespacedJobStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of CronJob. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchBatchV1CronJobListForAllNamespaces
     * Request URI: /apis/batch/v1/watch/cronjobs
     */
    watchBatchV1CronJobListForAllNamespaces<ResponseContentType extends ResponseContentType$watchBatchV1CronJobListForAllNamespaces>(params: Params$watchBatchV1CronJobListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchBatchV1CronJobListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Job. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchBatchV1JobListForAllNamespaces
     * Request URI: /apis/batch/v1/watch/jobs
     */
    watchBatchV1JobListForAllNamespaces<ResponseContentType extends ResponseContentType$watchBatchV1JobListForAllNamespaces>(params: Params$watchBatchV1JobListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchBatchV1JobListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of CronJob. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchBatchV1NamespacedCronJobList
     * Request URI: /apis/batch/v1/watch/namespaces/{namespace}/cronjobs
     */
    watchBatchV1NamespacedCronJobList<ResponseContentType extends ResponseContentType$watchBatchV1NamespacedCronJobList>(params: Params$watchBatchV1NamespacedCronJobList<ResponseContentType>, option?: RequestOption): Promise<Response$watchBatchV1NamespacedCronJobList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind CronJob. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchBatchV1NamespacedCronJob
     * Request URI: /apis/batch/v1/watch/namespaces/{namespace}/cronjobs/{name}
     */
    watchBatchV1NamespacedCronJob<ResponseContentType extends ResponseContentType$watchBatchV1NamespacedCronJob>(params: Params$watchBatchV1NamespacedCronJob<ResponseContentType>, option?: RequestOption): Promise<Response$watchBatchV1NamespacedCronJob$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Job. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchBatchV1NamespacedJobList
     * Request URI: /apis/batch/v1/watch/namespaces/{namespace}/jobs
     */
    watchBatchV1NamespacedJobList<ResponseContentType extends ResponseContentType$watchBatchV1NamespacedJobList>(params: Params$watchBatchV1NamespacedJobList<ResponseContentType>, option?: RequestOption): Promise<Response$watchBatchV1NamespacedJobList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Job. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchBatchV1NamespacedJob
     * Request URI: /apis/batch/v1/watch/namespaces/{namespace}/jobs/{name}
     */
    watchBatchV1NamespacedJob<ResponseContentType extends ResponseContentType$watchBatchV1NamespacedJob>(params: Params$watchBatchV1NamespacedJob<ResponseContentType>, option?: RequestOption): Promise<Response$watchBatchV1NamespacedJob$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getCertificatesAPIGroup
     * Request URI: /apis/certificates.k8s.io/
     */
    getCertificatesAPIGroup<ResponseContentType extends ResponseContentType$getCertificatesAPIGroup>(params: Params$getCertificatesAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getCertificatesAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getCertificatesV1APIResources
     * Request URI: /apis/certificates.k8s.io/v1/
     */
    getCertificatesV1APIResources<ResponseContentType extends ResponseContentType$getCertificatesV1APIResources>(params: Params$getCertificatesV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getCertificatesV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind CertificateSigningRequest
     * operationId: listCertificatesV1CertificateSigningRequest
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests
     */
    listCertificatesV1CertificateSigningRequest<ResponseContentType extends ResponseContentType$listCertificatesV1CertificateSigningRequest>(params: Params$listCertificatesV1CertificateSigningRequest<ResponseContentType>, option?: RequestOption): Promise<Response$listCertificatesV1CertificateSigningRequest$Status$200[ResponseContentType]>;
    /**
     * create a CertificateSigningRequest
     * operationId: createCertificatesV1CertificateSigningRequest
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests
     */
    createCertificatesV1CertificateSigningRequest<ResponseContentType extends ResponseContentType$createCertificatesV1CertificateSigningRequest>(params: Params$createCertificatesV1CertificateSigningRequest<ResponseContentType>, option?: RequestOption): Promise<(Response$createCertificatesV1CertificateSigningRequest$Status$200 | Response$createCertificatesV1CertificateSigningRequest$Status$201 | Response$createCertificatesV1CertificateSigningRequest$Status$202)[ResponseContentType]>;
    /**
     * delete collection of CertificateSigningRequest
     * operationId: deleteCertificatesV1CollectionCertificateSigningRequest
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests
     */
    deleteCertificatesV1CollectionCertificateSigningRequest<ResponseContentType extends ResponseContentType$deleteCertificatesV1CollectionCertificateSigningRequest>(params: Params$deleteCertificatesV1CollectionCertificateSigningRequest<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCertificatesV1CollectionCertificateSigningRequest$Status$200[ResponseContentType]>;
    /**
     * read the specified CertificateSigningRequest
     * operationId: readCertificatesV1CertificateSigningRequest
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests/{name}
     */
    readCertificatesV1CertificateSigningRequest<ResponseContentType extends ResponseContentType$readCertificatesV1CertificateSigningRequest>(params: Params$readCertificatesV1CertificateSigningRequest<ResponseContentType>, option?: RequestOption): Promise<Response$readCertificatesV1CertificateSigningRequest$Status$200[ResponseContentType]>;
    /**
     * replace the specified CertificateSigningRequest
     * operationId: replaceCertificatesV1CertificateSigningRequest
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests/{name}
     */
    replaceCertificatesV1CertificateSigningRequest<ResponseContentType extends ResponseContentType$replaceCertificatesV1CertificateSigningRequest>(params: Params$replaceCertificatesV1CertificateSigningRequest<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCertificatesV1CertificateSigningRequest$Status$200 | Response$replaceCertificatesV1CertificateSigningRequest$Status$201)[ResponseContentType]>;
    /**
     * delete a CertificateSigningRequest
     * operationId: deleteCertificatesV1CertificateSigningRequest
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests/{name}
     */
    deleteCertificatesV1CertificateSigningRequest<ResponseContentType extends ResponseContentType$deleteCertificatesV1CertificateSigningRequest>(params: Params$deleteCertificatesV1CertificateSigningRequest<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCertificatesV1CertificateSigningRequest$Status$200 | Response$deleteCertificatesV1CertificateSigningRequest$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified CertificateSigningRequest
     * operationId: patchCertificatesV1CertificateSigningRequest
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests/{name}
     */
    patchCertificatesV1CertificateSigningRequest<RequestContentType extends RequestContentType$patchCertificatesV1CertificateSigningRequest, ResponseContentType extends ResponseContentType$patchCertificatesV1CertificateSigningRequest>(params: Params$patchCertificatesV1CertificateSigningRequest<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCertificatesV1CertificateSigningRequest$Status$200 | Response$patchCertificatesV1CertificateSigningRequest$Status$201)[ResponseContentType]>;
    /**
     * read approval of the specified CertificateSigningRequest
     * operationId: readCertificatesV1CertificateSigningRequestApproval
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests/{name}/approval
     */
    readCertificatesV1CertificateSigningRequestApproval<ResponseContentType extends ResponseContentType$readCertificatesV1CertificateSigningRequestApproval>(params: Params$readCertificatesV1CertificateSigningRequestApproval<ResponseContentType>, option?: RequestOption): Promise<Response$readCertificatesV1CertificateSigningRequestApproval$Status$200[ResponseContentType]>;
    /**
     * replace approval of the specified CertificateSigningRequest
     * operationId: replaceCertificatesV1CertificateSigningRequestApproval
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests/{name}/approval
     */
    replaceCertificatesV1CertificateSigningRequestApproval<ResponseContentType extends ResponseContentType$replaceCertificatesV1CertificateSigningRequestApproval>(params: Params$replaceCertificatesV1CertificateSigningRequestApproval<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCertificatesV1CertificateSigningRequestApproval$Status$200 | Response$replaceCertificatesV1CertificateSigningRequestApproval$Status$201)[ResponseContentType]>;
    /**
     * partially update approval of the specified CertificateSigningRequest
     * operationId: patchCertificatesV1CertificateSigningRequestApproval
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests/{name}/approval
     */
    patchCertificatesV1CertificateSigningRequestApproval<RequestContentType extends RequestContentType$patchCertificatesV1CertificateSigningRequestApproval, ResponseContentType extends ResponseContentType$patchCertificatesV1CertificateSigningRequestApproval>(params: Params$patchCertificatesV1CertificateSigningRequestApproval<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCertificatesV1CertificateSigningRequestApproval$Status$200 | Response$patchCertificatesV1CertificateSigningRequestApproval$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified CertificateSigningRequest
     * operationId: readCertificatesV1CertificateSigningRequestStatus
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests/{name}/status
     */
    readCertificatesV1CertificateSigningRequestStatus<ResponseContentType extends ResponseContentType$readCertificatesV1CertificateSigningRequestStatus>(params: Params$readCertificatesV1CertificateSigningRequestStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readCertificatesV1CertificateSigningRequestStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified CertificateSigningRequest
     * operationId: replaceCertificatesV1CertificateSigningRequestStatus
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests/{name}/status
     */
    replaceCertificatesV1CertificateSigningRequestStatus<ResponseContentType extends ResponseContentType$replaceCertificatesV1CertificateSigningRequestStatus>(params: Params$replaceCertificatesV1CertificateSigningRequestStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCertificatesV1CertificateSigningRequestStatus$Status$200 | Response$replaceCertificatesV1CertificateSigningRequestStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified CertificateSigningRequest
     * operationId: patchCertificatesV1CertificateSigningRequestStatus
     * Request URI: /apis/certificates.k8s.io/v1/certificatesigningrequests/{name}/status
     */
    patchCertificatesV1CertificateSigningRequestStatus<RequestContentType extends RequestContentType$patchCertificatesV1CertificateSigningRequestStatus, ResponseContentType extends ResponseContentType$patchCertificatesV1CertificateSigningRequestStatus>(params: Params$patchCertificatesV1CertificateSigningRequestStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCertificatesV1CertificateSigningRequestStatus$Status$200 | Response$patchCertificatesV1CertificateSigningRequestStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of CertificateSigningRequest. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCertificatesV1CertificateSigningRequestList
     * Request URI: /apis/certificates.k8s.io/v1/watch/certificatesigningrequests
     */
    watchCertificatesV1CertificateSigningRequestList<ResponseContentType extends ResponseContentType$watchCertificatesV1CertificateSigningRequestList>(params: Params$watchCertificatesV1CertificateSigningRequestList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCertificatesV1CertificateSigningRequestList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind CertificateSigningRequest. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCertificatesV1CertificateSigningRequest
     * Request URI: /apis/certificates.k8s.io/v1/watch/certificatesigningrequests/{name}
     */
    watchCertificatesV1CertificateSigningRequest<ResponseContentType extends ResponseContentType$watchCertificatesV1CertificateSigningRequest>(params: Params$watchCertificatesV1CertificateSigningRequest<ResponseContentType>, option?: RequestOption): Promise<Response$watchCertificatesV1CertificateSigningRequest$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getCertificatesV1alpha1APIResources
     * Request URI: /apis/certificates.k8s.io/v1alpha1/
     */
    getCertificatesV1alpha1APIResources<ResponseContentType extends ResponseContentType$getCertificatesV1alpha1APIResources>(params: Params$getCertificatesV1alpha1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getCertificatesV1alpha1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind ClusterTrustBundle
     * operationId: listCertificatesV1alpha1ClusterTrustBundle
     * Request URI: /apis/certificates.k8s.io/v1alpha1/clustertrustbundles
     */
    listCertificatesV1alpha1ClusterTrustBundle<ResponseContentType extends ResponseContentType$listCertificatesV1alpha1ClusterTrustBundle>(params: Params$listCertificatesV1alpha1ClusterTrustBundle<ResponseContentType>, option?: RequestOption): Promise<Response$listCertificatesV1alpha1ClusterTrustBundle$Status$200[ResponseContentType]>;
    /**
     * create a ClusterTrustBundle
     * operationId: createCertificatesV1alpha1ClusterTrustBundle
     * Request URI: /apis/certificates.k8s.io/v1alpha1/clustertrustbundles
     */
    createCertificatesV1alpha1ClusterTrustBundle<ResponseContentType extends ResponseContentType$createCertificatesV1alpha1ClusterTrustBundle>(params: Params$createCertificatesV1alpha1ClusterTrustBundle<ResponseContentType>, option?: RequestOption): Promise<(Response$createCertificatesV1alpha1ClusterTrustBundle$Status$200 | Response$createCertificatesV1alpha1ClusterTrustBundle$Status$201 | Response$createCertificatesV1alpha1ClusterTrustBundle$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ClusterTrustBundle
     * operationId: deleteCertificatesV1alpha1CollectionClusterTrustBundle
     * Request URI: /apis/certificates.k8s.io/v1alpha1/clustertrustbundles
     */
    deleteCertificatesV1alpha1CollectionClusterTrustBundle<ResponseContentType extends ResponseContentType$deleteCertificatesV1alpha1CollectionClusterTrustBundle>(params: Params$deleteCertificatesV1alpha1CollectionClusterTrustBundle<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCertificatesV1alpha1CollectionClusterTrustBundle$Status$200[ResponseContentType]>;
    /**
     * read the specified ClusterTrustBundle
     * operationId: readCertificatesV1alpha1ClusterTrustBundle
     * Request URI: /apis/certificates.k8s.io/v1alpha1/clustertrustbundles/{name}
     */
    readCertificatesV1alpha1ClusterTrustBundle<ResponseContentType extends ResponseContentType$readCertificatesV1alpha1ClusterTrustBundle>(params: Params$readCertificatesV1alpha1ClusterTrustBundle<ResponseContentType>, option?: RequestOption): Promise<Response$readCertificatesV1alpha1ClusterTrustBundle$Status$200[ResponseContentType]>;
    /**
     * replace the specified ClusterTrustBundle
     * operationId: replaceCertificatesV1alpha1ClusterTrustBundle
     * Request URI: /apis/certificates.k8s.io/v1alpha1/clustertrustbundles/{name}
     */
    replaceCertificatesV1alpha1ClusterTrustBundle<ResponseContentType extends ResponseContentType$replaceCertificatesV1alpha1ClusterTrustBundle>(params: Params$replaceCertificatesV1alpha1ClusterTrustBundle<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCertificatesV1alpha1ClusterTrustBundle$Status$200 | Response$replaceCertificatesV1alpha1ClusterTrustBundle$Status$201)[ResponseContentType]>;
    /**
     * delete a ClusterTrustBundle
     * operationId: deleteCertificatesV1alpha1ClusterTrustBundle
     * Request URI: /apis/certificates.k8s.io/v1alpha1/clustertrustbundles/{name}
     */
    deleteCertificatesV1alpha1ClusterTrustBundle<ResponseContentType extends ResponseContentType$deleteCertificatesV1alpha1ClusterTrustBundle>(params: Params$deleteCertificatesV1alpha1ClusterTrustBundle<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCertificatesV1alpha1ClusterTrustBundle$Status$200 | Response$deleteCertificatesV1alpha1ClusterTrustBundle$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ClusterTrustBundle
     * operationId: patchCertificatesV1alpha1ClusterTrustBundle
     * Request URI: /apis/certificates.k8s.io/v1alpha1/clustertrustbundles/{name}
     */
    patchCertificatesV1alpha1ClusterTrustBundle<RequestContentType extends RequestContentType$patchCertificatesV1alpha1ClusterTrustBundle, ResponseContentType extends ResponseContentType$patchCertificatesV1alpha1ClusterTrustBundle>(params: Params$patchCertificatesV1alpha1ClusterTrustBundle<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCertificatesV1alpha1ClusterTrustBundle$Status$200 | Response$patchCertificatesV1alpha1ClusterTrustBundle$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of ClusterTrustBundle. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCertificatesV1alpha1ClusterTrustBundleList
     * Request URI: /apis/certificates.k8s.io/v1alpha1/watch/clustertrustbundles
     */
    watchCertificatesV1alpha1ClusterTrustBundleList<ResponseContentType extends ResponseContentType$watchCertificatesV1alpha1ClusterTrustBundleList>(params: Params$watchCertificatesV1alpha1ClusterTrustBundleList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCertificatesV1alpha1ClusterTrustBundleList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ClusterTrustBundle. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCertificatesV1alpha1ClusterTrustBundle
     * Request URI: /apis/certificates.k8s.io/v1alpha1/watch/clustertrustbundles/{name}
     */
    watchCertificatesV1alpha1ClusterTrustBundle<ResponseContentType extends ResponseContentType$watchCertificatesV1alpha1ClusterTrustBundle>(params: Params$watchCertificatesV1alpha1ClusterTrustBundle<ResponseContentType>, option?: RequestOption): Promise<Response$watchCertificatesV1alpha1ClusterTrustBundle$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getCoordinationAPIGroup
     * Request URI: /apis/coordination.k8s.io/
     */
    getCoordinationAPIGroup<ResponseContentType extends ResponseContentType$getCoordinationAPIGroup>(params: Params$getCoordinationAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getCoordinationAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getCoordinationV1APIResources
     * Request URI: /apis/coordination.k8s.io/v1/
     */
    getCoordinationV1APIResources<ResponseContentType extends ResponseContentType$getCoordinationV1APIResources>(params: Params$getCoordinationV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getCoordinationV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Lease
     * operationId: listCoordinationV1LeaseForAllNamespaces
     * Request URI: /apis/coordination.k8s.io/v1/leases
     */
    listCoordinationV1LeaseForAllNamespaces<ResponseContentType extends ResponseContentType$listCoordinationV1LeaseForAllNamespaces>(params: Params$listCoordinationV1LeaseForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listCoordinationV1LeaseForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Lease
     * operationId: listCoordinationV1NamespacedLease
     * Request URI: /apis/coordination.k8s.io/v1/namespaces/{namespace}/leases
     */
    listCoordinationV1NamespacedLease<ResponseContentType extends ResponseContentType$listCoordinationV1NamespacedLease>(params: Params$listCoordinationV1NamespacedLease<ResponseContentType>, option?: RequestOption): Promise<Response$listCoordinationV1NamespacedLease$Status$200[ResponseContentType]>;
    /**
     * create a Lease
     * operationId: createCoordinationV1NamespacedLease
     * Request URI: /apis/coordination.k8s.io/v1/namespaces/{namespace}/leases
     */
    createCoordinationV1NamespacedLease<ResponseContentType extends ResponseContentType$createCoordinationV1NamespacedLease>(params: Params$createCoordinationV1NamespacedLease<ResponseContentType>, option?: RequestOption): Promise<(Response$createCoordinationV1NamespacedLease$Status$200 | Response$createCoordinationV1NamespacedLease$Status$201 | Response$createCoordinationV1NamespacedLease$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Lease
     * operationId: deleteCoordinationV1CollectionNamespacedLease
     * Request URI: /apis/coordination.k8s.io/v1/namespaces/{namespace}/leases
     */
    deleteCoordinationV1CollectionNamespacedLease<ResponseContentType extends ResponseContentType$deleteCoordinationV1CollectionNamespacedLease>(params: Params$deleteCoordinationV1CollectionNamespacedLease<ResponseContentType>, option?: RequestOption): Promise<Response$deleteCoordinationV1CollectionNamespacedLease$Status$200[ResponseContentType]>;
    /**
     * read the specified Lease
     * operationId: readCoordinationV1NamespacedLease
     * Request URI: /apis/coordination.k8s.io/v1/namespaces/{namespace}/leases/{name}
     */
    readCoordinationV1NamespacedLease<ResponseContentType extends ResponseContentType$readCoordinationV1NamespacedLease>(params: Params$readCoordinationV1NamespacedLease<ResponseContentType>, option?: RequestOption): Promise<Response$readCoordinationV1NamespacedLease$Status$200[ResponseContentType]>;
    /**
     * replace the specified Lease
     * operationId: replaceCoordinationV1NamespacedLease
     * Request URI: /apis/coordination.k8s.io/v1/namespaces/{namespace}/leases/{name}
     */
    replaceCoordinationV1NamespacedLease<ResponseContentType extends ResponseContentType$replaceCoordinationV1NamespacedLease>(params: Params$replaceCoordinationV1NamespacedLease<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceCoordinationV1NamespacedLease$Status$200 | Response$replaceCoordinationV1NamespacedLease$Status$201)[ResponseContentType]>;
    /**
     * delete a Lease
     * operationId: deleteCoordinationV1NamespacedLease
     * Request URI: /apis/coordination.k8s.io/v1/namespaces/{namespace}/leases/{name}
     */
    deleteCoordinationV1NamespacedLease<ResponseContentType extends ResponseContentType$deleteCoordinationV1NamespacedLease>(params: Params$deleteCoordinationV1NamespacedLease<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteCoordinationV1NamespacedLease$Status$200 | Response$deleteCoordinationV1NamespacedLease$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Lease
     * operationId: patchCoordinationV1NamespacedLease
     * Request URI: /apis/coordination.k8s.io/v1/namespaces/{namespace}/leases/{name}
     */
    patchCoordinationV1NamespacedLease<RequestContentType extends RequestContentType$patchCoordinationV1NamespacedLease, ResponseContentType extends ResponseContentType$patchCoordinationV1NamespacedLease>(params: Params$patchCoordinationV1NamespacedLease<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchCoordinationV1NamespacedLease$Status$200 | Response$patchCoordinationV1NamespacedLease$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of Lease. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoordinationV1LeaseListForAllNamespaces
     * Request URI: /apis/coordination.k8s.io/v1/watch/leases
     */
    watchCoordinationV1LeaseListForAllNamespaces<ResponseContentType extends ResponseContentType$watchCoordinationV1LeaseListForAllNamespaces>(params: Params$watchCoordinationV1LeaseListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoordinationV1LeaseListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Lease. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchCoordinationV1NamespacedLeaseList
     * Request URI: /apis/coordination.k8s.io/v1/watch/namespaces/{namespace}/leases
     */
    watchCoordinationV1NamespacedLeaseList<ResponseContentType extends ResponseContentType$watchCoordinationV1NamespacedLeaseList>(params: Params$watchCoordinationV1NamespacedLeaseList<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoordinationV1NamespacedLeaseList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Lease. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchCoordinationV1NamespacedLease
     * Request URI: /apis/coordination.k8s.io/v1/watch/namespaces/{namespace}/leases/{name}
     */
    watchCoordinationV1NamespacedLease<ResponseContentType extends ResponseContentType$watchCoordinationV1NamespacedLease>(params: Params$watchCoordinationV1NamespacedLease<ResponseContentType>, option?: RequestOption): Promise<Response$watchCoordinationV1NamespacedLease$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getDiscoveryAPIGroup
     * Request URI: /apis/discovery.k8s.io/
     */
    getDiscoveryAPIGroup<ResponseContentType extends ResponseContentType$getDiscoveryAPIGroup>(params: Params$getDiscoveryAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getDiscoveryAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getDiscoveryV1APIResources
     * Request URI: /apis/discovery.k8s.io/v1/
     */
    getDiscoveryV1APIResources<ResponseContentType extends ResponseContentType$getDiscoveryV1APIResources>(params: Params$getDiscoveryV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getDiscoveryV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind EndpointSlice
     * operationId: listDiscoveryV1EndpointSliceForAllNamespaces
     * Request URI: /apis/discovery.k8s.io/v1/endpointslices
     */
    listDiscoveryV1EndpointSliceForAllNamespaces<ResponseContentType extends ResponseContentType$listDiscoveryV1EndpointSliceForAllNamespaces>(params: Params$listDiscoveryV1EndpointSliceForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listDiscoveryV1EndpointSliceForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind EndpointSlice
     * operationId: listDiscoveryV1NamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1/namespaces/{namespace}/endpointslices
     */
    listDiscoveryV1NamespacedEndpointSlice<ResponseContentType extends ResponseContentType$listDiscoveryV1NamespacedEndpointSlice>(params: Params$listDiscoveryV1NamespacedEndpointSlice<ResponseContentType>, option?: RequestOption): Promise<Response$listDiscoveryV1NamespacedEndpointSlice$Status$200[ResponseContentType]>;
    /**
     * create an EndpointSlice
     * operationId: createDiscoveryV1NamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1/namespaces/{namespace}/endpointslices
     */
    createDiscoveryV1NamespacedEndpointSlice<ResponseContentType extends ResponseContentType$createDiscoveryV1NamespacedEndpointSlice>(params: Params$createDiscoveryV1NamespacedEndpointSlice<ResponseContentType>, option?: RequestOption): Promise<(Response$createDiscoveryV1NamespacedEndpointSlice$Status$200 | Response$createDiscoveryV1NamespacedEndpointSlice$Status$201 | Response$createDiscoveryV1NamespacedEndpointSlice$Status$202)[ResponseContentType]>;
    /**
     * delete collection of EndpointSlice
     * operationId: deleteDiscoveryV1CollectionNamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1/namespaces/{namespace}/endpointslices
     */
    deleteDiscoveryV1CollectionNamespacedEndpointSlice<ResponseContentType extends ResponseContentType$deleteDiscoveryV1CollectionNamespacedEndpointSlice>(params: Params$deleteDiscoveryV1CollectionNamespacedEndpointSlice<ResponseContentType>, option?: RequestOption): Promise<Response$deleteDiscoveryV1CollectionNamespacedEndpointSlice$Status$200[ResponseContentType]>;
    /**
     * read the specified EndpointSlice
     * operationId: readDiscoveryV1NamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1/namespaces/{namespace}/endpointslices/{name}
     */
    readDiscoveryV1NamespacedEndpointSlice<ResponseContentType extends ResponseContentType$readDiscoveryV1NamespacedEndpointSlice>(params: Params$readDiscoveryV1NamespacedEndpointSlice<ResponseContentType>, option?: RequestOption): Promise<Response$readDiscoveryV1NamespacedEndpointSlice$Status$200[ResponseContentType]>;
    /**
     * replace the specified EndpointSlice
     * operationId: replaceDiscoveryV1NamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1/namespaces/{namespace}/endpointslices/{name}
     */
    replaceDiscoveryV1NamespacedEndpointSlice<ResponseContentType extends ResponseContentType$replaceDiscoveryV1NamespacedEndpointSlice>(params: Params$replaceDiscoveryV1NamespacedEndpointSlice<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceDiscoveryV1NamespacedEndpointSlice$Status$200 | Response$replaceDiscoveryV1NamespacedEndpointSlice$Status$201)[ResponseContentType]>;
    /**
     * delete an EndpointSlice
     * operationId: deleteDiscoveryV1NamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1/namespaces/{namespace}/endpointslices/{name}
     */
    deleteDiscoveryV1NamespacedEndpointSlice<ResponseContentType extends ResponseContentType$deleteDiscoveryV1NamespacedEndpointSlice>(params: Params$deleteDiscoveryV1NamespacedEndpointSlice<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteDiscoveryV1NamespacedEndpointSlice$Status$200 | Response$deleteDiscoveryV1NamespacedEndpointSlice$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified EndpointSlice
     * operationId: patchDiscoveryV1NamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1/namespaces/{namespace}/endpointslices/{name}
     */
    patchDiscoveryV1NamespacedEndpointSlice<RequestContentType extends RequestContentType$patchDiscoveryV1NamespacedEndpointSlice, ResponseContentType extends ResponseContentType$patchDiscoveryV1NamespacedEndpointSlice>(params: Params$patchDiscoveryV1NamespacedEndpointSlice<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchDiscoveryV1NamespacedEndpointSlice$Status$200 | Response$patchDiscoveryV1NamespacedEndpointSlice$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of EndpointSlice. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchDiscoveryV1EndpointSliceListForAllNamespaces
     * Request URI: /apis/discovery.k8s.io/v1/watch/endpointslices
     */
    watchDiscoveryV1EndpointSliceListForAllNamespaces<ResponseContentType extends ResponseContentType$watchDiscoveryV1EndpointSliceListForAllNamespaces>(params: Params$watchDiscoveryV1EndpointSliceListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchDiscoveryV1EndpointSliceListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of EndpointSlice. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchDiscoveryV1NamespacedEndpointSliceList
     * Request URI: /apis/discovery.k8s.io/v1/watch/namespaces/{namespace}/endpointslices
     */
    watchDiscoveryV1NamespacedEndpointSliceList<ResponseContentType extends ResponseContentType$watchDiscoveryV1NamespacedEndpointSliceList>(params: Params$watchDiscoveryV1NamespacedEndpointSliceList<ResponseContentType>, option?: RequestOption): Promise<Response$watchDiscoveryV1NamespacedEndpointSliceList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind EndpointSlice. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchDiscoveryV1NamespacedEndpointSlice
     * Request URI: /apis/discovery.k8s.io/v1/watch/namespaces/{namespace}/endpointslices/{name}
     */
    watchDiscoveryV1NamespacedEndpointSlice<ResponseContentType extends ResponseContentType$watchDiscoveryV1NamespacedEndpointSlice>(params: Params$watchDiscoveryV1NamespacedEndpointSlice<ResponseContentType>, option?: RequestOption): Promise<Response$watchDiscoveryV1NamespacedEndpointSlice$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getEventsAPIGroup
     * Request URI: /apis/events.k8s.io/
     */
    getEventsAPIGroup<ResponseContentType extends ResponseContentType$getEventsAPIGroup>(params: Params$getEventsAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getEventsAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getEventsV1APIResources
     * Request URI: /apis/events.k8s.io/v1/
     */
    getEventsV1APIResources<ResponseContentType extends ResponseContentType$getEventsV1APIResources>(params: Params$getEventsV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getEventsV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Event
     * operationId: listEventsV1EventForAllNamespaces
     * Request URI: /apis/events.k8s.io/v1/events
     */
    listEventsV1EventForAllNamespaces<ResponseContentType extends ResponseContentType$listEventsV1EventForAllNamespaces>(params: Params$listEventsV1EventForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listEventsV1EventForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Event
     * operationId: listEventsV1NamespacedEvent
     * Request URI: /apis/events.k8s.io/v1/namespaces/{namespace}/events
     */
    listEventsV1NamespacedEvent<ResponseContentType extends ResponseContentType$listEventsV1NamespacedEvent>(params: Params$listEventsV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<Response$listEventsV1NamespacedEvent$Status$200[ResponseContentType]>;
    /**
     * create an Event
     * operationId: createEventsV1NamespacedEvent
     * Request URI: /apis/events.k8s.io/v1/namespaces/{namespace}/events
     */
    createEventsV1NamespacedEvent<ResponseContentType extends ResponseContentType$createEventsV1NamespacedEvent>(params: Params$createEventsV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<(Response$createEventsV1NamespacedEvent$Status$200 | Response$createEventsV1NamespacedEvent$Status$201 | Response$createEventsV1NamespacedEvent$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Event
     * operationId: deleteEventsV1CollectionNamespacedEvent
     * Request URI: /apis/events.k8s.io/v1/namespaces/{namespace}/events
     */
    deleteEventsV1CollectionNamespacedEvent<ResponseContentType extends ResponseContentType$deleteEventsV1CollectionNamespacedEvent>(params: Params$deleteEventsV1CollectionNamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<Response$deleteEventsV1CollectionNamespacedEvent$Status$200[ResponseContentType]>;
    /**
     * read the specified Event
     * operationId: readEventsV1NamespacedEvent
     * Request URI: /apis/events.k8s.io/v1/namespaces/{namespace}/events/{name}
     */
    readEventsV1NamespacedEvent<ResponseContentType extends ResponseContentType$readEventsV1NamespacedEvent>(params: Params$readEventsV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<Response$readEventsV1NamespacedEvent$Status$200[ResponseContentType]>;
    /**
     * replace the specified Event
     * operationId: replaceEventsV1NamespacedEvent
     * Request URI: /apis/events.k8s.io/v1/namespaces/{namespace}/events/{name}
     */
    replaceEventsV1NamespacedEvent<ResponseContentType extends ResponseContentType$replaceEventsV1NamespacedEvent>(params: Params$replaceEventsV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceEventsV1NamespacedEvent$Status$200 | Response$replaceEventsV1NamespacedEvent$Status$201)[ResponseContentType]>;
    /**
     * delete an Event
     * operationId: deleteEventsV1NamespacedEvent
     * Request URI: /apis/events.k8s.io/v1/namespaces/{namespace}/events/{name}
     */
    deleteEventsV1NamespacedEvent<ResponseContentType extends ResponseContentType$deleteEventsV1NamespacedEvent>(params: Params$deleteEventsV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteEventsV1NamespacedEvent$Status$200 | Response$deleteEventsV1NamespacedEvent$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Event
     * operationId: patchEventsV1NamespacedEvent
     * Request URI: /apis/events.k8s.io/v1/namespaces/{namespace}/events/{name}
     */
    patchEventsV1NamespacedEvent<RequestContentType extends RequestContentType$patchEventsV1NamespacedEvent, ResponseContentType extends ResponseContentType$patchEventsV1NamespacedEvent>(params: Params$patchEventsV1NamespacedEvent<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchEventsV1NamespacedEvent$Status$200 | Response$patchEventsV1NamespacedEvent$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of Event. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchEventsV1EventListForAllNamespaces
     * Request URI: /apis/events.k8s.io/v1/watch/events
     */
    watchEventsV1EventListForAllNamespaces<ResponseContentType extends ResponseContentType$watchEventsV1EventListForAllNamespaces>(params: Params$watchEventsV1EventListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchEventsV1EventListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Event. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchEventsV1NamespacedEventList
     * Request URI: /apis/events.k8s.io/v1/watch/namespaces/{namespace}/events
     */
    watchEventsV1NamespacedEventList<ResponseContentType extends ResponseContentType$watchEventsV1NamespacedEventList>(params: Params$watchEventsV1NamespacedEventList<ResponseContentType>, option?: RequestOption): Promise<Response$watchEventsV1NamespacedEventList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Event. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchEventsV1NamespacedEvent
     * Request URI: /apis/events.k8s.io/v1/watch/namespaces/{namespace}/events/{name}
     */
    watchEventsV1NamespacedEvent<ResponseContentType extends ResponseContentType$watchEventsV1NamespacedEvent>(params: Params$watchEventsV1NamespacedEvent<ResponseContentType>, option?: RequestOption): Promise<Response$watchEventsV1NamespacedEvent$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getFlowcontrolApiserverAPIGroup
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/
     */
    getFlowcontrolApiserverAPIGroup<ResponseContentType extends ResponseContentType$getFlowcontrolApiserverAPIGroup>(params: Params$getFlowcontrolApiserverAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getFlowcontrolApiserverAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getFlowcontrolApiserverV1beta2APIResources
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/
     */
    getFlowcontrolApiserverV1beta2APIResources<ResponseContentType extends ResponseContentType$getFlowcontrolApiserverV1beta2APIResources>(params: Params$getFlowcontrolApiserverV1beta2APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getFlowcontrolApiserverV1beta2APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind FlowSchema
     * operationId: listFlowcontrolApiserverV1beta2FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/flowschemas
     */
    listFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType extends ResponseContentType$listFlowcontrolApiserverV1beta2FlowSchema>(params: Params$listFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType>, option?: RequestOption): Promise<Response$listFlowcontrolApiserverV1beta2FlowSchema$Status$200[ResponseContentType]>;
    /**
     * create a FlowSchema
     * operationId: createFlowcontrolApiserverV1beta2FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/flowschemas
     */
    createFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType extends ResponseContentType$createFlowcontrolApiserverV1beta2FlowSchema>(params: Params$createFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType>, option?: RequestOption): Promise<(Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$200 | Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$201 | Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$202)[ResponseContentType]>;
    /**
     * delete collection of FlowSchema
     * operationId: deleteFlowcontrolApiserverV1beta2CollectionFlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/flowschemas
     */
    deleteFlowcontrolApiserverV1beta2CollectionFlowSchema<ResponseContentType extends ResponseContentType$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema>(params: Params$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema<ResponseContentType>, option?: RequestOption): Promise<Response$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema$Status$200[ResponseContentType]>;
    /**
     * read the specified FlowSchema
     * operationId: readFlowcontrolApiserverV1beta2FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/flowschemas/{name}
     */
    readFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType extends ResponseContentType$readFlowcontrolApiserverV1beta2FlowSchema>(params: Params$readFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType>, option?: RequestOption): Promise<Response$readFlowcontrolApiserverV1beta2FlowSchema$Status$200[ResponseContentType]>;
    /**
     * replace the specified FlowSchema
     * operationId: replaceFlowcontrolApiserverV1beta2FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/flowschemas/{name}
     */
    replaceFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType extends ResponseContentType$replaceFlowcontrolApiserverV1beta2FlowSchema>(params: Params$replaceFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceFlowcontrolApiserverV1beta2FlowSchema$Status$200 | Response$replaceFlowcontrolApiserverV1beta2FlowSchema$Status$201)[ResponseContentType]>;
    /**
     * delete a FlowSchema
     * operationId: deleteFlowcontrolApiserverV1beta2FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/flowschemas/{name}
     */
    deleteFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType extends ResponseContentType$deleteFlowcontrolApiserverV1beta2FlowSchema>(params: Params$deleteFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteFlowcontrolApiserverV1beta2FlowSchema$Status$200 | Response$deleteFlowcontrolApiserverV1beta2FlowSchema$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified FlowSchema
     * operationId: patchFlowcontrolApiserverV1beta2FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/flowschemas/{name}
     */
    patchFlowcontrolApiserverV1beta2FlowSchema<RequestContentType extends RequestContentType$patchFlowcontrolApiserverV1beta2FlowSchema, ResponseContentType extends ResponseContentType$patchFlowcontrolApiserverV1beta2FlowSchema>(params: Params$patchFlowcontrolApiserverV1beta2FlowSchema<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchFlowcontrolApiserverV1beta2FlowSchema$Status$200 | Response$patchFlowcontrolApiserverV1beta2FlowSchema$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified FlowSchema
     * operationId: readFlowcontrolApiserverV1beta2FlowSchemaStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/flowschemas/{name}/status
     */
    readFlowcontrolApiserverV1beta2FlowSchemaStatus<ResponseContentType extends ResponseContentType$readFlowcontrolApiserverV1beta2FlowSchemaStatus>(params: Params$readFlowcontrolApiserverV1beta2FlowSchemaStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified FlowSchema
     * operationId: replaceFlowcontrolApiserverV1beta2FlowSchemaStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/flowschemas/{name}/status
     */
    replaceFlowcontrolApiserverV1beta2FlowSchemaStatus<ResponseContentType extends ResponseContentType$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus>(params: Params$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified FlowSchema
     * operationId: patchFlowcontrolApiserverV1beta2FlowSchemaStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/flowschemas/{name}/status
     */
    patchFlowcontrolApiserverV1beta2FlowSchemaStatus<RequestContentType extends RequestContentType$patchFlowcontrolApiserverV1beta2FlowSchemaStatus, ResponseContentType extends ResponseContentType$patchFlowcontrolApiserverV1beta2FlowSchemaStatus>(params: Params$patchFlowcontrolApiserverV1beta2FlowSchemaStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200 | Response$patchFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind PriorityLevelConfiguration
     * operationId: listFlowcontrolApiserverV1beta2PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/prioritylevelconfigurations
     */
    listFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration>(params: Params$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200[ResponseContentType]>;
    /**
     * create a PriorityLevelConfiguration
     * operationId: createFlowcontrolApiserverV1beta2PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/prioritylevelconfigurations
     */
    createFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration>(params: Params$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201 | Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$202)[ResponseContentType]>;
    /**
     * delete collection of PriorityLevelConfiguration
     * operationId: deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/prioritylevelconfigurations
     */
    deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration<ResponseContentType extends ResponseContentType$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration>(params: Params$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration$Status$200[ResponseContentType]>;
    /**
     * read the specified PriorityLevelConfiguration
     * operationId: readFlowcontrolApiserverV1beta2PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/prioritylevelconfigurations/{name}
     */
    readFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration>(params: Params$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200[ResponseContentType]>;
    /**
     * replace the specified PriorityLevelConfiguration
     * operationId: replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/prioritylevelconfigurations/{name}
     */
    replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration>(params: Params$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201)[ResponseContentType]>;
    /**
     * delete a PriorityLevelConfiguration
     * operationId: deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/prioritylevelconfigurations/{name}
     */
    deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration>(params: Params$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | Response$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified PriorityLevelConfiguration
     * operationId: patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/prioritylevelconfigurations/{name}
     */
    patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration<RequestContentType extends RequestContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration, ResponseContentType extends ResponseContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration>(params: Params$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200 | Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified PriorityLevelConfiguration
     * operationId: readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/prioritylevelconfigurations/{name}/status
     */
    readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus<ResponseContentType extends ResponseContentType$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus>(params: Params$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified PriorityLevelConfiguration
     * operationId: replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/prioritylevelconfigurations/{name}/status
     */
    replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus<ResponseContentType extends ResponseContentType$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus>(params: Params$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified PriorityLevelConfiguration
     * operationId: patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/prioritylevelconfigurations/{name}/status
     */
    patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus<RequestContentType extends RequestContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus, ResponseContentType extends ResponseContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus>(params: Params$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200 | Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of FlowSchema. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchFlowcontrolApiserverV1beta2FlowSchemaList
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/watch/flowschemas
     */
    watchFlowcontrolApiserverV1beta2FlowSchemaList<ResponseContentType extends ResponseContentType$watchFlowcontrolApiserverV1beta2FlowSchemaList>(params: Params$watchFlowcontrolApiserverV1beta2FlowSchemaList<ResponseContentType>, option?: RequestOption): Promise<Response$watchFlowcontrolApiserverV1beta2FlowSchemaList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind FlowSchema. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchFlowcontrolApiserverV1beta2FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/watch/flowschemas/{name}
     */
    watchFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType extends ResponseContentType$watchFlowcontrolApiserverV1beta2FlowSchema>(params: Params$watchFlowcontrolApiserverV1beta2FlowSchema<ResponseContentType>, option?: RequestOption): Promise<Response$watchFlowcontrolApiserverV1beta2FlowSchema$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of PriorityLevelConfiguration. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/watch/prioritylevelconfigurations
     */
    watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList<ResponseContentType extends ResponseContentType$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList>(params: Params$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList<ResponseContentType>, option?: RequestOption): Promise<Response$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind PriorityLevelConfiguration. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta2/watch/prioritylevelconfigurations/{name}
     */
    watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration>(params: Params$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getFlowcontrolApiserverV1beta3APIResources
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/
     */
    getFlowcontrolApiserverV1beta3APIResources<ResponseContentType extends ResponseContentType$getFlowcontrolApiserverV1beta3APIResources>(params: Params$getFlowcontrolApiserverV1beta3APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getFlowcontrolApiserverV1beta3APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind FlowSchema
     * operationId: listFlowcontrolApiserverV1beta3FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/flowschemas
     */
    listFlowcontrolApiserverV1beta3FlowSchema<ResponseContentType extends ResponseContentType$listFlowcontrolApiserverV1beta3FlowSchema>(params: Params$listFlowcontrolApiserverV1beta3FlowSchema<ResponseContentType>, option?: RequestOption): Promise<Response$listFlowcontrolApiserverV1beta3FlowSchema$Status$200[ResponseContentType]>;
    /**
     * create a FlowSchema
     * operationId: createFlowcontrolApiserverV1beta3FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/flowschemas
     */
    createFlowcontrolApiserverV1beta3FlowSchema<ResponseContentType extends ResponseContentType$createFlowcontrolApiserverV1beta3FlowSchema>(params: Params$createFlowcontrolApiserverV1beta3FlowSchema<ResponseContentType>, option?: RequestOption): Promise<(Response$createFlowcontrolApiserverV1beta3FlowSchema$Status$200 | Response$createFlowcontrolApiserverV1beta3FlowSchema$Status$201 | Response$createFlowcontrolApiserverV1beta3FlowSchema$Status$202)[ResponseContentType]>;
    /**
     * delete collection of FlowSchema
     * operationId: deleteFlowcontrolApiserverV1beta3CollectionFlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/flowschemas
     */
    deleteFlowcontrolApiserverV1beta3CollectionFlowSchema<ResponseContentType extends ResponseContentType$deleteFlowcontrolApiserverV1beta3CollectionFlowSchema>(params: Params$deleteFlowcontrolApiserverV1beta3CollectionFlowSchema<ResponseContentType>, option?: RequestOption): Promise<Response$deleteFlowcontrolApiserverV1beta3CollectionFlowSchema$Status$200[ResponseContentType]>;
    /**
     * read the specified FlowSchema
     * operationId: readFlowcontrolApiserverV1beta3FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/flowschemas/{name}
     */
    readFlowcontrolApiserverV1beta3FlowSchema<ResponseContentType extends ResponseContentType$readFlowcontrolApiserverV1beta3FlowSchema>(params: Params$readFlowcontrolApiserverV1beta3FlowSchema<ResponseContentType>, option?: RequestOption): Promise<Response$readFlowcontrolApiserverV1beta3FlowSchema$Status$200[ResponseContentType]>;
    /**
     * replace the specified FlowSchema
     * operationId: replaceFlowcontrolApiserverV1beta3FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/flowschemas/{name}
     */
    replaceFlowcontrolApiserverV1beta3FlowSchema<ResponseContentType extends ResponseContentType$replaceFlowcontrolApiserverV1beta3FlowSchema>(params: Params$replaceFlowcontrolApiserverV1beta3FlowSchema<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceFlowcontrolApiserverV1beta3FlowSchema$Status$200 | Response$replaceFlowcontrolApiserverV1beta3FlowSchema$Status$201)[ResponseContentType]>;
    /**
     * delete a FlowSchema
     * operationId: deleteFlowcontrolApiserverV1beta3FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/flowschemas/{name}
     */
    deleteFlowcontrolApiserverV1beta3FlowSchema<ResponseContentType extends ResponseContentType$deleteFlowcontrolApiserverV1beta3FlowSchema>(params: Params$deleteFlowcontrolApiserverV1beta3FlowSchema<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteFlowcontrolApiserverV1beta3FlowSchema$Status$200 | Response$deleteFlowcontrolApiserverV1beta3FlowSchema$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified FlowSchema
     * operationId: patchFlowcontrolApiserverV1beta3FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/flowschemas/{name}
     */
    patchFlowcontrolApiserverV1beta3FlowSchema<RequestContentType extends RequestContentType$patchFlowcontrolApiserverV1beta3FlowSchema, ResponseContentType extends ResponseContentType$patchFlowcontrolApiserverV1beta3FlowSchema>(params: Params$patchFlowcontrolApiserverV1beta3FlowSchema<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchFlowcontrolApiserverV1beta3FlowSchema$Status$200 | Response$patchFlowcontrolApiserverV1beta3FlowSchema$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified FlowSchema
     * operationId: readFlowcontrolApiserverV1beta3FlowSchemaStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/flowschemas/{name}/status
     */
    readFlowcontrolApiserverV1beta3FlowSchemaStatus<ResponseContentType extends ResponseContentType$readFlowcontrolApiserverV1beta3FlowSchemaStatus>(params: Params$readFlowcontrolApiserverV1beta3FlowSchemaStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified FlowSchema
     * operationId: replaceFlowcontrolApiserverV1beta3FlowSchemaStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/flowschemas/{name}/status
     */
    replaceFlowcontrolApiserverV1beta3FlowSchemaStatus<ResponseContentType extends ResponseContentType$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus>(params: Params$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified FlowSchema
     * operationId: patchFlowcontrolApiserverV1beta3FlowSchemaStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/flowschemas/{name}/status
     */
    patchFlowcontrolApiserverV1beta3FlowSchemaStatus<RequestContentType extends RequestContentType$patchFlowcontrolApiserverV1beta3FlowSchemaStatus, ResponseContentType extends ResponseContentType$patchFlowcontrolApiserverV1beta3FlowSchemaStatus>(params: Params$patchFlowcontrolApiserverV1beta3FlowSchemaStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$200 | Response$patchFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind PriorityLevelConfiguration
     * operationId: listFlowcontrolApiserverV1beta3PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/prioritylevelconfigurations
     */
    listFlowcontrolApiserverV1beta3PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$listFlowcontrolApiserverV1beta3PriorityLevelConfiguration>(params: Params$listFlowcontrolApiserverV1beta3PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$listFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200[ResponseContentType]>;
    /**
     * create a PriorityLevelConfiguration
     * operationId: createFlowcontrolApiserverV1beta3PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/prioritylevelconfigurations
     */
    createFlowcontrolApiserverV1beta3PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration>(params: Params$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200 | Response$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$201 | Response$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$202)[ResponseContentType]>;
    /**
     * delete collection of PriorityLevelConfiguration
     * operationId: deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/prioritylevelconfigurations
     */
    deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration<ResponseContentType extends ResponseContentType$deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration>(params: Params$deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration$Status$200[ResponseContentType]>;
    /**
     * read the specified PriorityLevelConfiguration
     * operationId: readFlowcontrolApiserverV1beta3PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/prioritylevelconfigurations/{name}
     */
    readFlowcontrolApiserverV1beta3PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$readFlowcontrolApiserverV1beta3PriorityLevelConfiguration>(params: Params$readFlowcontrolApiserverV1beta3PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$readFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200[ResponseContentType]>;
    /**
     * replace the specified PriorityLevelConfiguration
     * operationId: replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/prioritylevelconfigurations/{name}
     */
    replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration>(params: Params$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200 | Response$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$201)[ResponseContentType]>;
    /**
     * delete a PriorityLevelConfiguration
     * operationId: deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/prioritylevelconfigurations/{name}
     */
    deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration>(params: Params$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200 | Response$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified PriorityLevelConfiguration
     * operationId: patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/prioritylevelconfigurations/{name}
     */
    patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration<RequestContentType extends RequestContentType$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration, ResponseContentType extends ResponseContentType$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration>(params: Params$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200 | Response$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified PriorityLevelConfiguration
     * operationId: readFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/prioritylevelconfigurations/{name}/status
     */
    readFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus<ResponseContentType extends ResponseContentType$readFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus>(params: Params$readFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified PriorityLevelConfiguration
     * operationId: replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/prioritylevelconfigurations/{name}/status
     */
    replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus<ResponseContentType extends ResponseContentType$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus>(params: Params$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$200 | Response$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified PriorityLevelConfiguration
     * operationId: patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/prioritylevelconfigurations/{name}/status
     */
    patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus<RequestContentType extends RequestContentType$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus, ResponseContentType extends ResponseContentType$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus>(params: Params$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$200 | Response$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of FlowSchema. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchFlowcontrolApiserverV1beta3FlowSchemaList
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/watch/flowschemas
     */
    watchFlowcontrolApiserverV1beta3FlowSchemaList<ResponseContentType extends ResponseContentType$watchFlowcontrolApiserverV1beta3FlowSchemaList>(params: Params$watchFlowcontrolApiserverV1beta3FlowSchemaList<ResponseContentType>, option?: RequestOption): Promise<Response$watchFlowcontrolApiserverV1beta3FlowSchemaList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind FlowSchema. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchFlowcontrolApiserverV1beta3FlowSchema
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/watch/flowschemas/{name}
     */
    watchFlowcontrolApiserverV1beta3FlowSchema<ResponseContentType extends ResponseContentType$watchFlowcontrolApiserverV1beta3FlowSchema>(params: Params$watchFlowcontrolApiserverV1beta3FlowSchema<ResponseContentType>, option?: RequestOption): Promise<Response$watchFlowcontrolApiserverV1beta3FlowSchema$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of PriorityLevelConfiguration. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchFlowcontrolApiserverV1beta3PriorityLevelConfigurationList
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/watch/prioritylevelconfigurations
     */
    watchFlowcontrolApiserverV1beta3PriorityLevelConfigurationList<ResponseContentType extends ResponseContentType$watchFlowcontrolApiserverV1beta3PriorityLevelConfigurationList>(params: Params$watchFlowcontrolApiserverV1beta3PriorityLevelConfigurationList<ResponseContentType>, option?: RequestOption): Promise<Response$watchFlowcontrolApiserverV1beta3PriorityLevelConfigurationList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind PriorityLevelConfiguration. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchFlowcontrolApiserverV1beta3PriorityLevelConfiguration
     * Request URI: /apis/flowcontrol.apiserver.k8s.io/v1beta3/watch/prioritylevelconfigurations/{name}
     */
    watchFlowcontrolApiserverV1beta3PriorityLevelConfiguration<ResponseContentType extends ResponseContentType$watchFlowcontrolApiserverV1beta3PriorityLevelConfiguration>(params: Params$watchFlowcontrolApiserverV1beta3PriorityLevelConfiguration<ResponseContentType>, option?: RequestOption): Promise<Response$watchFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getInternalApiserverAPIGroup
     * Request URI: /apis/internal.apiserver.k8s.io/
     */
    getInternalApiserverAPIGroup<ResponseContentType extends ResponseContentType$getInternalApiserverAPIGroup>(params: Params$getInternalApiserverAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getInternalApiserverAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getInternalApiserverV1alpha1APIResources
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/
     */
    getInternalApiserverV1alpha1APIResources<ResponseContentType extends ResponseContentType$getInternalApiserverV1alpha1APIResources>(params: Params$getInternalApiserverV1alpha1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getInternalApiserverV1alpha1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind StorageVersion
     * operationId: listInternalApiserverV1alpha1StorageVersion
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/storageversions
     */
    listInternalApiserverV1alpha1StorageVersion<ResponseContentType extends ResponseContentType$listInternalApiserverV1alpha1StorageVersion>(params: Params$listInternalApiserverV1alpha1StorageVersion<ResponseContentType>, option?: RequestOption): Promise<Response$listInternalApiserverV1alpha1StorageVersion$Status$200[ResponseContentType]>;
    /**
     * create a StorageVersion
     * operationId: createInternalApiserverV1alpha1StorageVersion
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/storageversions
     */
    createInternalApiserverV1alpha1StorageVersion<ResponseContentType extends ResponseContentType$createInternalApiserverV1alpha1StorageVersion>(params: Params$createInternalApiserverV1alpha1StorageVersion<ResponseContentType>, option?: RequestOption): Promise<(Response$createInternalApiserverV1alpha1StorageVersion$Status$200 | Response$createInternalApiserverV1alpha1StorageVersion$Status$201 | Response$createInternalApiserverV1alpha1StorageVersion$Status$202)[ResponseContentType]>;
    /**
     * delete collection of StorageVersion
     * operationId: deleteInternalApiserverV1alpha1CollectionStorageVersion
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/storageversions
     */
    deleteInternalApiserverV1alpha1CollectionStorageVersion<ResponseContentType extends ResponseContentType$deleteInternalApiserverV1alpha1CollectionStorageVersion>(params: Params$deleteInternalApiserverV1alpha1CollectionStorageVersion<ResponseContentType>, option?: RequestOption): Promise<Response$deleteInternalApiserverV1alpha1CollectionStorageVersion$Status$200[ResponseContentType]>;
    /**
     * read the specified StorageVersion
     * operationId: readInternalApiserverV1alpha1StorageVersion
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/storageversions/{name}
     */
    readInternalApiserverV1alpha1StorageVersion<ResponseContentType extends ResponseContentType$readInternalApiserverV1alpha1StorageVersion>(params: Params$readInternalApiserverV1alpha1StorageVersion<ResponseContentType>, option?: RequestOption): Promise<Response$readInternalApiserverV1alpha1StorageVersion$Status$200[ResponseContentType]>;
    /**
     * replace the specified StorageVersion
     * operationId: replaceInternalApiserverV1alpha1StorageVersion
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/storageversions/{name}
     */
    replaceInternalApiserverV1alpha1StorageVersion<ResponseContentType extends ResponseContentType$replaceInternalApiserverV1alpha1StorageVersion>(params: Params$replaceInternalApiserverV1alpha1StorageVersion<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceInternalApiserverV1alpha1StorageVersion$Status$200 | Response$replaceInternalApiserverV1alpha1StorageVersion$Status$201)[ResponseContentType]>;
    /**
     * delete a StorageVersion
     * operationId: deleteInternalApiserverV1alpha1StorageVersion
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/storageversions/{name}
     */
    deleteInternalApiserverV1alpha1StorageVersion<ResponseContentType extends ResponseContentType$deleteInternalApiserverV1alpha1StorageVersion>(params: Params$deleteInternalApiserverV1alpha1StorageVersion<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteInternalApiserverV1alpha1StorageVersion$Status$200 | Response$deleteInternalApiserverV1alpha1StorageVersion$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified StorageVersion
     * operationId: patchInternalApiserverV1alpha1StorageVersion
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/storageversions/{name}
     */
    patchInternalApiserverV1alpha1StorageVersion<RequestContentType extends RequestContentType$patchInternalApiserverV1alpha1StorageVersion, ResponseContentType extends ResponseContentType$patchInternalApiserverV1alpha1StorageVersion>(params: Params$patchInternalApiserverV1alpha1StorageVersion<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchInternalApiserverV1alpha1StorageVersion$Status$200 | Response$patchInternalApiserverV1alpha1StorageVersion$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified StorageVersion
     * operationId: readInternalApiserverV1alpha1StorageVersionStatus
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/storageversions/{name}/status
     */
    readInternalApiserverV1alpha1StorageVersionStatus<ResponseContentType extends ResponseContentType$readInternalApiserverV1alpha1StorageVersionStatus>(params: Params$readInternalApiserverV1alpha1StorageVersionStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readInternalApiserverV1alpha1StorageVersionStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified StorageVersion
     * operationId: replaceInternalApiserverV1alpha1StorageVersionStatus
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/storageversions/{name}/status
     */
    replaceInternalApiserverV1alpha1StorageVersionStatus<ResponseContentType extends ResponseContentType$replaceInternalApiserverV1alpha1StorageVersionStatus>(params: Params$replaceInternalApiserverV1alpha1StorageVersionStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceInternalApiserverV1alpha1StorageVersionStatus$Status$200 | Response$replaceInternalApiserverV1alpha1StorageVersionStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified StorageVersion
     * operationId: patchInternalApiserverV1alpha1StorageVersionStatus
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/storageversions/{name}/status
     */
    patchInternalApiserverV1alpha1StorageVersionStatus<RequestContentType extends RequestContentType$patchInternalApiserverV1alpha1StorageVersionStatus, ResponseContentType extends ResponseContentType$patchInternalApiserverV1alpha1StorageVersionStatus>(params: Params$patchInternalApiserverV1alpha1StorageVersionStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchInternalApiserverV1alpha1StorageVersionStatus$Status$200 | Response$patchInternalApiserverV1alpha1StorageVersionStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of StorageVersion. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchInternalApiserverV1alpha1StorageVersionList
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/watch/storageversions
     */
    watchInternalApiserverV1alpha1StorageVersionList<ResponseContentType extends ResponseContentType$watchInternalApiserverV1alpha1StorageVersionList>(params: Params$watchInternalApiserverV1alpha1StorageVersionList<ResponseContentType>, option?: RequestOption): Promise<Response$watchInternalApiserverV1alpha1StorageVersionList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind StorageVersion. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchInternalApiserverV1alpha1StorageVersion
     * Request URI: /apis/internal.apiserver.k8s.io/v1alpha1/watch/storageversions/{name}
     */
    watchInternalApiserverV1alpha1StorageVersion<ResponseContentType extends ResponseContentType$watchInternalApiserverV1alpha1StorageVersion>(params: Params$watchInternalApiserverV1alpha1StorageVersion<ResponseContentType>, option?: RequestOption): Promise<Response$watchInternalApiserverV1alpha1StorageVersion$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getNetworkingAPIGroup
     * Request URI: /apis/networking.k8s.io/
     */
    getNetworkingAPIGroup<ResponseContentType extends ResponseContentType$getNetworkingAPIGroup>(params: Params$getNetworkingAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getNetworkingAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getNetworkingV1APIResources
     * Request URI: /apis/networking.k8s.io/v1/
     */
    getNetworkingV1APIResources<ResponseContentType extends ResponseContentType$getNetworkingV1APIResources>(params: Params$getNetworkingV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getNetworkingV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind IngressClass
     * operationId: listNetworkingV1IngressClass
     * Request URI: /apis/networking.k8s.io/v1/ingressclasses
     */
    listNetworkingV1IngressClass<ResponseContentType extends ResponseContentType$listNetworkingV1IngressClass>(params: Params$listNetworkingV1IngressClass<ResponseContentType>, option?: RequestOption): Promise<Response$listNetworkingV1IngressClass$Status$200[ResponseContentType]>;
    /**
     * create an IngressClass
     * operationId: createNetworkingV1IngressClass
     * Request URI: /apis/networking.k8s.io/v1/ingressclasses
     */
    createNetworkingV1IngressClass<ResponseContentType extends ResponseContentType$createNetworkingV1IngressClass>(params: Params$createNetworkingV1IngressClass<ResponseContentType>, option?: RequestOption): Promise<(Response$createNetworkingV1IngressClass$Status$200 | Response$createNetworkingV1IngressClass$Status$201 | Response$createNetworkingV1IngressClass$Status$202)[ResponseContentType]>;
    /**
     * delete collection of IngressClass
     * operationId: deleteNetworkingV1CollectionIngressClass
     * Request URI: /apis/networking.k8s.io/v1/ingressclasses
     */
    deleteNetworkingV1CollectionIngressClass<ResponseContentType extends ResponseContentType$deleteNetworkingV1CollectionIngressClass>(params: Params$deleteNetworkingV1CollectionIngressClass<ResponseContentType>, option?: RequestOption): Promise<Response$deleteNetworkingV1CollectionIngressClass$Status$200[ResponseContentType]>;
    /**
     * read the specified IngressClass
     * operationId: readNetworkingV1IngressClass
     * Request URI: /apis/networking.k8s.io/v1/ingressclasses/{name}
     */
    readNetworkingV1IngressClass<ResponseContentType extends ResponseContentType$readNetworkingV1IngressClass>(params: Params$readNetworkingV1IngressClass<ResponseContentType>, option?: RequestOption): Promise<Response$readNetworkingV1IngressClass$Status$200[ResponseContentType]>;
    /**
     * replace the specified IngressClass
     * operationId: replaceNetworkingV1IngressClass
     * Request URI: /apis/networking.k8s.io/v1/ingressclasses/{name}
     */
    replaceNetworkingV1IngressClass<ResponseContentType extends ResponseContentType$replaceNetworkingV1IngressClass>(params: Params$replaceNetworkingV1IngressClass<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceNetworkingV1IngressClass$Status$200 | Response$replaceNetworkingV1IngressClass$Status$201)[ResponseContentType]>;
    /**
     * delete an IngressClass
     * operationId: deleteNetworkingV1IngressClass
     * Request URI: /apis/networking.k8s.io/v1/ingressclasses/{name}
     */
    deleteNetworkingV1IngressClass<ResponseContentType extends ResponseContentType$deleteNetworkingV1IngressClass>(params: Params$deleteNetworkingV1IngressClass<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteNetworkingV1IngressClass$Status$200 | Response$deleteNetworkingV1IngressClass$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified IngressClass
     * operationId: patchNetworkingV1IngressClass
     * Request URI: /apis/networking.k8s.io/v1/ingressclasses/{name}
     */
    patchNetworkingV1IngressClass<RequestContentType extends RequestContentType$patchNetworkingV1IngressClass, ResponseContentType extends ResponseContentType$patchNetworkingV1IngressClass>(params: Params$patchNetworkingV1IngressClass<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchNetworkingV1IngressClass$Status$200 | Response$patchNetworkingV1IngressClass$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind Ingress
     * operationId: listNetworkingV1IngressForAllNamespaces
     * Request URI: /apis/networking.k8s.io/v1/ingresses
     */
    listNetworkingV1IngressForAllNamespaces<ResponseContentType extends ResponseContentType$listNetworkingV1IngressForAllNamespaces>(params: Params$listNetworkingV1IngressForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listNetworkingV1IngressForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Ingress
     * operationId: listNetworkingV1NamespacedIngress
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/ingresses
     */
    listNetworkingV1NamespacedIngress<ResponseContentType extends ResponseContentType$listNetworkingV1NamespacedIngress>(params: Params$listNetworkingV1NamespacedIngress<ResponseContentType>, option?: RequestOption): Promise<Response$listNetworkingV1NamespacedIngress$Status$200[ResponseContentType]>;
    /**
     * create an Ingress
     * operationId: createNetworkingV1NamespacedIngress
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/ingresses
     */
    createNetworkingV1NamespacedIngress<ResponseContentType extends ResponseContentType$createNetworkingV1NamespacedIngress>(params: Params$createNetworkingV1NamespacedIngress<ResponseContentType>, option?: RequestOption): Promise<(Response$createNetworkingV1NamespacedIngress$Status$200 | Response$createNetworkingV1NamespacedIngress$Status$201 | Response$createNetworkingV1NamespacedIngress$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Ingress
     * operationId: deleteNetworkingV1CollectionNamespacedIngress
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/ingresses
     */
    deleteNetworkingV1CollectionNamespacedIngress<ResponseContentType extends ResponseContentType$deleteNetworkingV1CollectionNamespacedIngress>(params: Params$deleteNetworkingV1CollectionNamespacedIngress<ResponseContentType>, option?: RequestOption): Promise<Response$deleteNetworkingV1CollectionNamespacedIngress$Status$200[ResponseContentType]>;
    /**
     * read the specified Ingress
     * operationId: readNetworkingV1NamespacedIngress
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/ingresses/{name}
     */
    readNetworkingV1NamespacedIngress<ResponseContentType extends ResponseContentType$readNetworkingV1NamespacedIngress>(params: Params$readNetworkingV1NamespacedIngress<ResponseContentType>, option?: RequestOption): Promise<Response$readNetworkingV1NamespacedIngress$Status$200[ResponseContentType]>;
    /**
     * replace the specified Ingress
     * operationId: replaceNetworkingV1NamespacedIngress
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/ingresses/{name}
     */
    replaceNetworkingV1NamespacedIngress<ResponseContentType extends ResponseContentType$replaceNetworkingV1NamespacedIngress>(params: Params$replaceNetworkingV1NamespacedIngress<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceNetworkingV1NamespacedIngress$Status$200 | Response$replaceNetworkingV1NamespacedIngress$Status$201)[ResponseContentType]>;
    /**
     * delete an Ingress
     * operationId: deleteNetworkingV1NamespacedIngress
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/ingresses/{name}
     */
    deleteNetworkingV1NamespacedIngress<ResponseContentType extends ResponseContentType$deleteNetworkingV1NamespacedIngress>(params: Params$deleteNetworkingV1NamespacedIngress<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteNetworkingV1NamespacedIngress$Status$200 | Response$deleteNetworkingV1NamespacedIngress$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Ingress
     * operationId: patchNetworkingV1NamespacedIngress
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/ingresses/{name}
     */
    patchNetworkingV1NamespacedIngress<RequestContentType extends RequestContentType$patchNetworkingV1NamespacedIngress, ResponseContentType extends ResponseContentType$patchNetworkingV1NamespacedIngress>(params: Params$patchNetworkingV1NamespacedIngress<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchNetworkingV1NamespacedIngress$Status$200 | Response$patchNetworkingV1NamespacedIngress$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified Ingress
     * operationId: readNetworkingV1NamespacedIngressStatus
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/ingresses/{name}/status
     */
    readNetworkingV1NamespacedIngressStatus<ResponseContentType extends ResponseContentType$readNetworkingV1NamespacedIngressStatus>(params: Params$readNetworkingV1NamespacedIngressStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readNetworkingV1NamespacedIngressStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified Ingress
     * operationId: replaceNetworkingV1NamespacedIngressStatus
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/ingresses/{name}/status
     */
    replaceNetworkingV1NamespacedIngressStatus<ResponseContentType extends ResponseContentType$replaceNetworkingV1NamespacedIngressStatus>(params: Params$replaceNetworkingV1NamespacedIngressStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceNetworkingV1NamespacedIngressStatus$Status$200 | Response$replaceNetworkingV1NamespacedIngressStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified Ingress
     * operationId: patchNetworkingV1NamespacedIngressStatus
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/ingresses/{name}/status
     */
    patchNetworkingV1NamespacedIngressStatus<RequestContentType extends RequestContentType$patchNetworkingV1NamespacedIngressStatus, ResponseContentType extends ResponseContentType$patchNetworkingV1NamespacedIngressStatus>(params: Params$patchNetworkingV1NamespacedIngressStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchNetworkingV1NamespacedIngressStatus$Status$200 | Response$patchNetworkingV1NamespacedIngressStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind NetworkPolicy
     * operationId: listNetworkingV1NamespacedNetworkPolicy
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies
     */
    listNetworkingV1NamespacedNetworkPolicy<ResponseContentType extends ResponseContentType$listNetworkingV1NamespacedNetworkPolicy>(params: Params$listNetworkingV1NamespacedNetworkPolicy<ResponseContentType>, option?: RequestOption): Promise<Response$listNetworkingV1NamespacedNetworkPolicy$Status$200[ResponseContentType]>;
    /**
     * create a NetworkPolicy
     * operationId: createNetworkingV1NamespacedNetworkPolicy
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies
     */
    createNetworkingV1NamespacedNetworkPolicy<ResponseContentType extends ResponseContentType$createNetworkingV1NamespacedNetworkPolicy>(params: Params$createNetworkingV1NamespacedNetworkPolicy<ResponseContentType>, option?: RequestOption): Promise<(Response$createNetworkingV1NamespacedNetworkPolicy$Status$200 | Response$createNetworkingV1NamespacedNetworkPolicy$Status$201 | Response$createNetworkingV1NamespacedNetworkPolicy$Status$202)[ResponseContentType]>;
    /**
     * delete collection of NetworkPolicy
     * operationId: deleteNetworkingV1CollectionNamespacedNetworkPolicy
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies
     */
    deleteNetworkingV1CollectionNamespacedNetworkPolicy<ResponseContentType extends ResponseContentType$deleteNetworkingV1CollectionNamespacedNetworkPolicy>(params: Params$deleteNetworkingV1CollectionNamespacedNetworkPolicy<ResponseContentType>, option?: RequestOption): Promise<Response$deleteNetworkingV1CollectionNamespacedNetworkPolicy$Status$200[ResponseContentType]>;
    /**
     * read the specified NetworkPolicy
     * operationId: readNetworkingV1NamespacedNetworkPolicy
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies/{name}
     */
    readNetworkingV1NamespacedNetworkPolicy<ResponseContentType extends ResponseContentType$readNetworkingV1NamespacedNetworkPolicy>(params: Params$readNetworkingV1NamespacedNetworkPolicy<ResponseContentType>, option?: RequestOption): Promise<Response$readNetworkingV1NamespacedNetworkPolicy$Status$200[ResponseContentType]>;
    /**
     * replace the specified NetworkPolicy
     * operationId: replaceNetworkingV1NamespacedNetworkPolicy
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies/{name}
     */
    replaceNetworkingV1NamespacedNetworkPolicy<ResponseContentType extends ResponseContentType$replaceNetworkingV1NamespacedNetworkPolicy>(params: Params$replaceNetworkingV1NamespacedNetworkPolicy<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceNetworkingV1NamespacedNetworkPolicy$Status$200 | Response$replaceNetworkingV1NamespacedNetworkPolicy$Status$201)[ResponseContentType]>;
    /**
     * delete a NetworkPolicy
     * operationId: deleteNetworkingV1NamespacedNetworkPolicy
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies/{name}
     */
    deleteNetworkingV1NamespacedNetworkPolicy<ResponseContentType extends ResponseContentType$deleteNetworkingV1NamespacedNetworkPolicy>(params: Params$deleteNetworkingV1NamespacedNetworkPolicy<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteNetworkingV1NamespacedNetworkPolicy$Status$200 | Response$deleteNetworkingV1NamespacedNetworkPolicy$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified NetworkPolicy
     * operationId: patchNetworkingV1NamespacedNetworkPolicy
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies/{name}
     */
    patchNetworkingV1NamespacedNetworkPolicy<RequestContentType extends RequestContentType$patchNetworkingV1NamespacedNetworkPolicy, ResponseContentType extends ResponseContentType$patchNetworkingV1NamespacedNetworkPolicy>(params: Params$patchNetworkingV1NamespacedNetworkPolicy<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchNetworkingV1NamespacedNetworkPolicy$Status$200 | Response$patchNetworkingV1NamespacedNetworkPolicy$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified NetworkPolicy
     * operationId: readNetworkingV1NamespacedNetworkPolicyStatus
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies/{name}/status
     */
    readNetworkingV1NamespacedNetworkPolicyStatus<ResponseContentType extends ResponseContentType$readNetworkingV1NamespacedNetworkPolicyStatus>(params: Params$readNetworkingV1NamespacedNetworkPolicyStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readNetworkingV1NamespacedNetworkPolicyStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified NetworkPolicy
     * operationId: replaceNetworkingV1NamespacedNetworkPolicyStatus
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies/{name}/status
     */
    replaceNetworkingV1NamespacedNetworkPolicyStatus<ResponseContentType extends ResponseContentType$replaceNetworkingV1NamespacedNetworkPolicyStatus>(params: Params$replaceNetworkingV1NamespacedNetworkPolicyStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceNetworkingV1NamespacedNetworkPolicyStatus$Status$200 | Response$replaceNetworkingV1NamespacedNetworkPolicyStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified NetworkPolicy
     * operationId: patchNetworkingV1NamespacedNetworkPolicyStatus
     * Request URI: /apis/networking.k8s.io/v1/namespaces/{namespace}/networkpolicies/{name}/status
     */
    patchNetworkingV1NamespacedNetworkPolicyStatus<RequestContentType extends RequestContentType$patchNetworkingV1NamespacedNetworkPolicyStatus, ResponseContentType extends ResponseContentType$patchNetworkingV1NamespacedNetworkPolicyStatus>(params: Params$patchNetworkingV1NamespacedNetworkPolicyStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchNetworkingV1NamespacedNetworkPolicyStatus$Status$200 | Response$patchNetworkingV1NamespacedNetworkPolicyStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind NetworkPolicy
     * operationId: listNetworkingV1NetworkPolicyForAllNamespaces
     * Request URI: /apis/networking.k8s.io/v1/networkpolicies
     */
    listNetworkingV1NetworkPolicyForAllNamespaces<ResponseContentType extends ResponseContentType$listNetworkingV1NetworkPolicyForAllNamespaces>(params: Params$listNetworkingV1NetworkPolicyForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listNetworkingV1NetworkPolicyForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of IngressClass. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchNetworkingV1IngressClassList
     * Request URI: /apis/networking.k8s.io/v1/watch/ingressclasses
     */
    watchNetworkingV1IngressClassList<ResponseContentType extends ResponseContentType$watchNetworkingV1IngressClassList>(params: Params$watchNetworkingV1IngressClassList<ResponseContentType>, option?: RequestOption): Promise<Response$watchNetworkingV1IngressClassList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind IngressClass. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchNetworkingV1IngressClass
     * Request URI: /apis/networking.k8s.io/v1/watch/ingressclasses/{name}
     */
    watchNetworkingV1IngressClass<ResponseContentType extends ResponseContentType$watchNetworkingV1IngressClass>(params: Params$watchNetworkingV1IngressClass<ResponseContentType>, option?: RequestOption): Promise<Response$watchNetworkingV1IngressClass$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Ingress. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchNetworkingV1IngressListForAllNamespaces
     * Request URI: /apis/networking.k8s.io/v1/watch/ingresses
     */
    watchNetworkingV1IngressListForAllNamespaces<ResponseContentType extends ResponseContentType$watchNetworkingV1IngressListForAllNamespaces>(params: Params$watchNetworkingV1IngressListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchNetworkingV1IngressListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Ingress. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchNetworkingV1NamespacedIngressList
     * Request URI: /apis/networking.k8s.io/v1/watch/namespaces/{namespace}/ingresses
     */
    watchNetworkingV1NamespacedIngressList<ResponseContentType extends ResponseContentType$watchNetworkingV1NamespacedIngressList>(params: Params$watchNetworkingV1NamespacedIngressList<ResponseContentType>, option?: RequestOption): Promise<Response$watchNetworkingV1NamespacedIngressList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Ingress. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchNetworkingV1NamespacedIngress
     * Request URI: /apis/networking.k8s.io/v1/watch/namespaces/{namespace}/ingresses/{name}
     */
    watchNetworkingV1NamespacedIngress<ResponseContentType extends ResponseContentType$watchNetworkingV1NamespacedIngress>(params: Params$watchNetworkingV1NamespacedIngress<ResponseContentType>, option?: RequestOption): Promise<Response$watchNetworkingV1NamespacedIngress$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of NetworkPolicy. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchNetworkingV1NamespacedNetworkPolicyList
     * Request URI: /apis/networking.k8s.io/v1/watch/namespaces/{namespace}/networkpolicies
     */
    watchNetworkingV1NamespacedNetworkPolicyList<ResponseContentType extends ResponseContentType$watchNetworkingV1NamespacedNetworkPolicyList>(params: Params$watchNetworkingV1NamespacedNetworkPolicyList<ResponseContentType>, option?: RequestOption): Promise<Response$watchNetworkingV1NamespacedNetworkPolicyList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind NetworkPolicy. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchNetworkingV1NamespacedNetworkPolicy
     * Request URI: /apis/networking.k8s.io/v1/watch/namespaces/{namespace}/networkpolicies/{name}
     */
    watchNetworkingV1NamespacedNetworkPolicy<ResponseContentType extends ResponseContentType$watchNetworkingV1NamespacedNetworkPolicy>(params: Params$watchNetworkingV1NamespacedNetworkPolicy<ResponseContentType>, option?: RequestOption): Promise<Response$watchNetworkingV1NamespacedNetworkPolicy$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of NetworkPolicy. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchNetworkingV1NetworkPolicyListForAllNamespaces
     * Request URI: /apis/networking.k8s.io/v1/watch/networkpolicies
     */
    watchNetworkingV1NetworkPolicyListForAllNamespaces<ResponseContentType extends ResponseContentType$watchNetworkingV1NetworkPolicyListForAllNamespaces>(params: Params$watchNetworkingV1NetworkPolicyListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchNetworkingV1NetworkPolicyListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getNetworkingV1alpha1APIResources
     * Request URI: /apis/networking.k8s.io/v1alpha1/
     */
    getNetworkingV1alpha1APIResources<ResponseContentType extends ResponseContentType$getNetworkingV1alpha1APIResources>(params: Params$getNetworkingV1alpha1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getNetworkingV1alpha1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind ClusterCIDR
     * operationId: listNetworkingV1alpha1ClusterCIDR
     * Request URI: /apis/networking.k8s.io/v1alpha1/clustercidrs
     */
    listNetworkingV1alpha1ClusterCIDR<ResponseContentType extends ResponseContentType$listNetworkingV1alpha1ClusterCIDR>(params: Params$listNetworkingV1alpha1ClusterCIDR<ResponseContentType>, option?: RequestOption): Promise<Response$listNetworkingV1alpha1ClusterCIDR$Status$200[ResponseContentType]>;
    /**
     * create a ClusterCIDR
     * operationId: createNetworkingV1alpha1ClusterCIDR
     * Request URI: /apis/networking.k8s.io/v1alpha1/clustercidrs
     */
    createNetworkingV1alpha1ClusterCIDR<ResponseContentType extends ResponseContentType$createNetworkingV1alpha1ClusterCIDR>(params: Params$createNetworkingV1alpha1ClusterCIDR<ResponseContentType>, option?: RequestOption): Promise<(Response$createNetworkingV1alpha1ClusterCIDR$Status$200 | Response$createNetworkingV1alpha1ClusterCIDR$Status$201 | Response$createNetworkingV1alpha1ClusterCIDR$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ClusterCIDR
     * operationId: deleteNetworkingV1alpha1CollectionClusterCIDR
     * Request URI: /apis/networking.k8s.io/v1alpha1/clustercidrs
     */
    deleteNetworkingV1alpha1CollectionClusterCIDR<ResponseContentType extends ResponseContentType$deleteNetworkingV1alpha1CollectionClusterCIDR>(params: Params$deleteNetworkingV1alpha1CollectionClusterCIDR<ResponseContentType>, option?: RequestOption): Promise<Response$deleteNetworkingV1alpha1CollectionClusterCIDR$Status$200[ResponseContentType]>;
    /**
     * read the specified ClusterCIDR
     * operationId: readNetworkingV1alpha1ClusterCIDR
     * Request URI: /apis/networking.k8s.io/v1alpha1/clustercidrs/{name}
     */
    readNetworkingV1alpha1ClusterCIDR<ResponseContentType extends ResponseContentType$readNetworkingV1alpha1ClusterCIDR>(params: Params$readNetworkingV1alpha1ClusterCIDR<ResponseContentType>, option?: RequestOption): Promise<Response$readNetworkingV1alpha1ClusterCIDR$Status$200[ResponseContentType]>;
    /**
     * replace the specified ClusterCIDR
     * operationId: replaceNetworkingV1alpha1ClusterCIDR
     * Request URI: /apis/networking.k8s.io/v1alpha1/clustercidrs/{name}
     */
    replaceNetworkingV1alpha1ClusterCIDR<ResponseContentType extends ResponseContentType$replaceNetworkingV1alpha1ClusterCIDR>(params: Params$replaceNetworkingV1alpha1ClusterCIDR<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceNetworkingV1alpha1ClusterCIDR$Status$200 | Response$replaceNetworkingV1alpha1ClusterCIDR$Status$201)[ResponseContentType]>;
    /**
     * delete a ClusterCIDR
     * operationId: deleteNetworkingV1alpha1ClusterCIDR
     * Request URI: /apis/networking.k8s.io/v1alpha1/clustercidrs/{name}
     */
    deleteNetworkingV1alpha1ClusterCIDR<ResponseContentType extends ResponseContentType$deleteNetworkingV1alpha1ClusterCIDR>(params: Params$deleteNetworkingV1alpha1ClusterCIDR<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteNetworkingV1alpha1ClusterCIDR$Status$200 | Response$deleteNetworkingV1alpha1ClusterCIDR$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ClusterCIDR
     * operationId: patchNetworkingV1alpha1ClusterCIDR
     * Request URI: /apis/networking.k8s.io/v1alpha1/clustercidrs/{name}
     */
    patchNetworkingV1alpha1ClusterCIDR<RequestContentType extends RequestContentType$patchNetworkingV1alpha1ClusterCIDR, ResponseContentType extends ResponseContentType$patchNetworkingV1alpha1ClusterCIDR>(params: Params$patchNetworkingV1alpha1ClusterCIDR<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchNetworkingV1alpha1ClusterCIDR$Status$200 | Response$patchNetworkingV1alpha1ClusterCIDR$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind IPAddress
     * operationId: listNetworkingV1alpha1IPAddress
     * Request URI: /apis/networking.k8s.io/v1alpha1/ipaddresses
     */
    listNetworkingV1alpha1IPAddress<ResponseContentType extends ResponseContentType$listNetworkingV1alpha1IPAddress>(params: Params$listNetworkingV1alpha1IPAddress<ResponseContentType>, option?: RequestOption): Promise<Response$listNetworkingV1alpha1IPAddress$Status$200[ResponseContentType]>;
    /**
     * create an IPAddress
     * operationId: createNetworkingV1alpha1IPAddress
     * Request URI: /apis/networking.k8s.io/v1alpha1/ipaddresses
     */
    createNetworkingV1alpha1IPAddress<ResponseContentType extends ResponseContentType$createNetworkingV1alpha1IPAddress>(params: Params$createNetworkingV1alpha1IPAddress<ResponseContentType>, option?: RequestOption): Promise<(Response$createNetworkingV1alpha1IPAddress$Status$200 | Response$createNetworkingV1alpha1IPAddress$Status$201 | Response$createNetworkingV1alpha1IPAddress$Status$202)[ResponseContentType]>;
    /**
     * delete collection of IPAddress
     * operationId: deleteNetworkingV1alpha1CollectionIPAddress
     * Request URI: /apis/networking.k8s.io/v1alpha1/ipaddresses
     */
    deleteNetworkingV1alpha1CollectionIPAddress<ResponseContentType extends ResponseContentType$deleteNetworkingV1alpha1CollectionIPAddress>(params: Params$deleteNetworkingV1alpha1CollectionIPAddress<ResponseContentType>, option?: RequestOption): Promise<Response$deleteNetworkingV1alpha1CollectionIPAddress$Status$200[ResponseContentType]>;
    /**
     * read the specified IPAddress
     * operationId: readNetworkingV1alpha1IPAddress
     * Request URI: /apis/networking.k8s.io/v1alpha1/ipaddresses/{name}
     */
    readNetworkingV1alpha1IPAddress<ResponseContentType extends ResponseContentType$readNetworkingV1alpha1IPAddress>(params: Params$readNetworkingV1alpha1IPAddress<ResponseContentType>, option?: RequestOption): Promise<Response$readNetworkingV1alpha1IPAddress$Status$200[ResponseContentType]>;
    /**
     * replace the specified IPAddress
     * operationId: replaceNetworkingV1alpha1IPAddress
     * Request URI: /apis/networking.k8s.io/v1alpha1/ipaddresses/{name}
     */
    replaceNetworkingV1alpha1IPAddress<ResponseContentType extends ResponseContentType$replaceNetworkingV1alpha1IPAddress>(params: Params$replaceNetworkingV1alpha1IPAddress<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceNetworkingV1alpha1IPAddress$Status$200 | Response$replaceNetworkingV1alpha1IPAddress$Status$201)[ResponseContentType]>;
    /**
     * delete an IPAddress
     * operationId: deleteNetworkingV1alpha1IPAddress
     * Request URI: /apis/networking.k8s.io/v1alpha1/ipaddresses/{name}
     */
    deleteNetworkingV1alpha1IPAddress<ResponseContentType extends ResponseContentType$deleteNetworkingV1alpha1IPAddress>(params: Params$deleteNetworkingV1alpha1IPAddress<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteNetworkingV1alpha1IPAddress$Status$200 | Response$deleteNetworkingV1alpha1IPAddress$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified IPAddress
     * operationId: patchNetworkingV1alpha1IPAddress
     * Request URI: /apis/networking.k8s.io/v1alpha1/ipaddresses/{name}
     */
    patchNetworkingV1alpha1IPAddress<RequestContentType extends RequestContentType$patchNetworkingV1alpha1IPAddress, ResponseContentType extends ResponseContentType$patchNetworkingV1alpha1IPAddress>(params: Params$patchNetworkingV1alpha1IPAddress<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchNetworkingV1alpha1IPAddress$Status$200 | Response$patchNetworkingV1alpha1IPAddress$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of ClusterCIDR. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchNetworkingV1alpha1ClusterCIDRList
     * Request URI: /apis/networking.k8s.io/v1alpha1/watch/clustercidrs
     */
    watchNetworkingV1alpha1ClusterCIDRList<ResponseContentType extends ResponseContentType$watchNetworkingV1alpha1ClusterCIDRList>(params: Params$watchNetworkingV1alpha1ClusterCIDRList<ResponseContentType>, option?: RequestOption): Promise<Response$watchNetworkingV1alpha1ClusterCIDRList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ClusterCIDR. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchNetworkingV1alpha1ClusterCIDR
     * Request URI: /apis/networking.k8s.io/v1alpha1/watch/clustercidrs/{name}
     */
    watchNetworkingV1alpha1ClusterCIDR<ResponseContentType extends ResponseContentType$watchNetworkingV1alpha1ClusterCIDR>(params: Params$watchNetworkingV1alpha1ClusterCIDR<ResponseContentType>, option?: RequestOption): Promise<Response$watchNetworkingV1alpha1ClusterCIDR$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of IPAddress. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchNetworkingV1alpha1IPAddressList
     * Request URI: /apis/networking.k8s.io/v1alpha1/watch/ipaddresses
     */
    watchNetworkingV1alpha1IPAddressList<ResponseContentType extends ResponseContentType$watchNetworkingV1alpha1IPAddressList>(params: Params$watchNetworkingV1alpha1IPAddressList<ResponseContentType>, option?: RequestOption): Promise<Response$watchNetworkingV1alpha1IPAddressList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind IPAddress. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchNetworkingV1alpha1IPAddress
     * Request URI: /apis/networking.k8s.io/v1alpha1/watch/ipaddresses/{name}
     */
    watchNetworkingV1alpha1IPAddress<ResponseContentType extends ResponseContentType$watchNetworkingV1alpha1IPAddress>(params: Params$watchNetworkingV1alpha1IPAddress<ResponseContentType>, option?: RequestOption): Promise<Response$watchNetworkingV1alpha1IPAddress$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getNodeAPIGroup
     * Request URI: /apis/node.k8s.io/
     */
    getNodeAPIGroup<ResponseContentType extends ResponseContentType$getNodeAPIGroup>(params: Params$getNodeAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getNodeAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getNodeV1APIResources
     * Request URI: /apis/node.k8s.io/v1/
     */
    getNodeV1APIResources<ResponseContentType extends ResponseContentType$getNodeV1APIResources>(params: Params$getNodeV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getNodeV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind RuntimeClass
     * operationId: listNodeV1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1/runtimeclasses
     */
    listNodeV1RuntimeClass<ResponseContentType extends ResponseContentType$listNodeV1RuntimeClass>(params: Params$listNodeV1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<Response$listNodeV1RuntimeClass$Status$200[ResponseContentType]>;
    /**
     * create a RuntimeClass
     * operationId: createNodeV1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1/runtimeclasses
     */
    createNodeV1RuntimeClass<ResponseContentType extends ResponseContentType$createNodeV1RuntimeClass>(params: Params$createNodeV1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<(Response$createNodeV1RuntimeClass$Status$200 | Response$createNodeV1RuntimeClass$Status$201 | Response$createNodeV1RuntimeClass$Status$202)[ResponseContentType]>;
    /**
     * delete collection of RuntimeClass
     * operationId: deleteNodeV1CollectionRuntimeClass
     * Request URI: /apis/node.k8s.io/v1/runtimeclasses
     */
    deleteNodeV1CollectionRuntimeClass<ResponseContentType extends ResponseContentType$deleteNodeV1CollectionRuntimeClass>(params: Params$deleteNodeV1CollectionRuntimeClass<ResponseContentType>, option?: RequestOption): Promise<Response$deleteNodeV1CollectionRuntimeClass$Status$200[ResponseContentType]>;
    /**
     * read the specified RuntimeClass
     * operationId: readNodeV1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1/runtimeclasses/{name}
     */
    readNodeV1RuntimeClass<ResponseContentType extends ResponseContentType$readNodeV1RuntimeClass>(params: Params$readNodeV1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<Response$readNodeV1RuntimeClass$Status$200[ResponseContentType]>;
    /**
     * replace the specified RuntimeClass
     * operationId: replaceNodeV1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1/runtimeclasses/{name}
     */
    replaceNodeV1RuntimeClass<ResponseContentType extends ResponseContentType$replaceNodeV1RuntimeClass>(params: Params$replaceNodeV1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceNodeV1RuntimeClass$Status$200 | Response$replaceNodeV1RuntimeClass$Status$201)[ResponseContentType]>;
    /**
     * delete a RuntimeClass
     * operationId: deleteNodeV1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1/runtimeclasses/{name}
     */
    deleteNodeV1RuntimeClass<ResponseContentType extends ResponseContentType$deleteNodeV1RuntimeClass>(params: Params$deleteNodeV1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteNodeV1RuntimeClass$Status$200 | Response$deleteNodeV1RuntimeClass$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified RuntimeClass
     * operationId: patchNodeV1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1/runtimeclasses/{name}
     */
    patchNodeV1RuntimeClass<RequestContentType extends RequestContentType$patchNodeV1RuntimeClass, ResponseContentType extends ResponseContentType$patchNodeV1RuntimeClass>(params: Params$patchNodeV1RuntimeClass<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchNodeV1RuntimeClass$Status$200 | Response$patchNodeV1RuntimeClass$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of RuntimeClass. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchNodeV1RuntimeClassList
     * Request URI: /apis/node.k8s.io/v1/watch/runtimeclasses
     */
    watchNodeV1RuntimeClassList<ResponseContentType extends ResponseContentType$watchNodeV1RuntimeClassList>(params: Params$watchNodeV1RuntimeClassList<ResponseContentType>, option?: RequestOption): Promise<Response$watchNodeV1RuntimeClassList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind RuntimeClass. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchNodeV1RuntimeClass
     * Request URI: /apis/node.k8s.io/v1/watch/runtimeclasses/{name}
     */
    watchNodeV1RuntimeClass<ResponseContentType extends ResponseContentType$watchNodeV1RuntimeClass>(params: Params$watchNodeV1RuntimeClass<ResponseContentType>, option?: RequestOption): Promise<Response$watchNodeV1RuntimeClass$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getPolicyAPIGroup
     * Request URI: /apis/policy/
     */
    getPolicyAPIGroup<ResponseContentType extends ResponseContentType$getPolicyAPIGroup>(params: Params$getPolicyAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getPolicyAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getPolicyV1APIResources
     * Request URI: /apis/policy/v1/
     */
    getPolicyV1APIResources<ResponseContentType extends ResponseContentType$getPolicyV1APIResources>(params: Params$getPolicyV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getPolicyV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind PodDisruptionBudget
     * operationId: listPolicyV1NamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1/namespaces/{namespace}/poddisruptionbudgets
     */
    listPolicyV1NamespacedPodDisruptionBudget<ResponseContentType extends ResponseContentType$listPolicyV1NamespacedPodDisruptionBudget>(params: Params$listPolicyV1NamespacedPodDisruptionBudget<ResponseContentType>, option?: RequestOption): Promise<Response$listPolicyV1NamespacedPodDisruptionBudget$Status$200[ResponseContentType]>;
    /**
     * create a PodDisruptionBudget
     * operationId: createPolicyV1NamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1/namespaces/{namespace}/poddisruptionbudgets
     */
    createPolicyV1NamespacedPodDisruptionBudget<ResponseContentType extends ResponseContentType$createPolicyV1NamespacedPodDisruptionBudget>(params: Params$createPolicyV1NamespacedPodDisruptionBudget<ResponseContentType>, option?: RequestOption): Promise<(Response$createPolicyV1NamespacedPodDisruptionBudget$Status$200 | Response$createPolicyV1NamespacedPodDisruptionBudget$Status$201 | Response$createPolicyV1NamespacedPodDisruptionBudget$Status$202)[ResponseContentType]>;
    /**
     * delete collection of PodDisruptionBudget
     * operationId: deletePolicyV1CollectionNamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1/namespaces/{namespace}/poddisruptionbudgets
     */
    deletePolicyV1CollectionNamespacedPodDisruptionBudget<ResponseContentType extends ResponseContentType$deletePolicyV1CollectionNamespacedPodDisruptionBudget>(params: Params$deletePolicyV1CollectionNamespacedPodDisruptionBudget<ResponseContentType>, option?: RequestOption): Promise<Response$deletePolicyV1CollectionNamespacedPodDisruptionBudget$Status$200[ResponseContentType]>;
    /**
     * read the specified PodDisruptionBudget
     * operationId: readPolicyV1NamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1/namespaces/{namespace}/poddisruptionbudgets/{name}
     */
    readPolicyV1NamespacedPodDisruptionBudget<ResponseContentType extends ResponseContentType$readPolicyV1NamespacedPodDisruptionBudget>(params: Params$readPolicyV1NamespacedPodDisruptionBudget<ResponseContentType>, option?: RequestOption): Promise<Response$readPolicyV1NamespacedPodDisruptionBudget$Status$200[ResponseContentType]>;
    /**
     * replace the specified PodDisruptionBudget
     * operationId: replacePolicyV1NamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1/namespaces/{namespace}/poddisruptionbudgets/{name}
     */
    replacePolicyV1NamespacedPodDisruptionBudget<ResponseContentType extends ResponseContentType$replacePolicyV1NamespacedPodDisruptionBudget>(params: Params$replacePolicyV1NamespacedPodDisruptionBudget<ResponseContentType>, option?: RequestOption): Promise<(Response$replacePolicyV1NamespacedPodDisruptionBudget$Status$200 | Response$replacePolicyV1NamespacedPodDisruptionBudget$Status$201)[ResponseContentType]>;
    /**
     * delete a PodDisruptionBudget
     * operationId: deletePolicyV1NamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1/namespaces/{namespace}/poddisruptionbudgets/{name}
     */
    deletePolicyV1NamespacedPodDisruptionBudget<ResponseContentType extends ResponseContentType$deletePolicyV1NamespacedPodDisruptionBudget>(params: Params$deletePolicyV1NamespacedPodDisruptionBudget<ResponseContentType>, option?: RequestOption): Promise<(Response$deletePolicyV1NamespacedPodDisruptionBudget$Status$200 | Response$deletePolicyV1NamespacedPodDisruptionBudget$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified PodDisruptionBudget
     * operationId: patchPolicyV1NamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1/namespaces/{namespace}/poddisruptionbudgets/{name}
     */
    patchPolicyV1NamespacedPodDisruptionBudget<RequestContentType extends RequestContentType$patchPolicyV1NamespacedPodDisruptionBudget, ResponseContentType extends ResponseContentType$patchPolicyV1NamespacedPodDisruptionBudget>(params: Params$patchPolicyV1NamespacedPodDisruptionBudget<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchPolicyV1NamespacedPodDisruptionBudget$Status$200 | Response$patchPolicyV1NamespacedPodDisruptionBudget$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified PodDisruptionBudget
     * operationId: readPolicyV1NamespacedPodDisruptionBudgetStatus
     * Request URI: /apis/policy/v1/namespaces/{namespace}/poddisruptionbudgets/{name}/status
     */
    readPolicyV1NamespacedPodDisruptionBudgetStatus<ResponseContentType extends ResponseContentType$readPolicyV1NamespacedPodDisruptionBudgetStatus>(params: Params$readPolicyV1NamespacedPodDisruptionBudgetStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readPolicyV1NamespacedPodDisruptionBudgetStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified PodDisruptionBudget
     * operationId: replacePolicyV1NamespacedPodDisruptionBudgetStatus
     * Request URI: /apis/policy/v1/namespaces/{namespace}/poddisruptionbudgets/{name}/status
     */
    replacePolicyV1NamespacedPodDisruptionBudgetStatus<ResponseContentType extends ResponseContentType$replacePolicyV1NamespacedPodDisruptionBudgetStatus>(params: Params$replacePolicyV1NamespacedPodDisruptionBudgetStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replacePolicyV1NamespacedPodDisruptionBudgetStatus$Status$200 | Response$replacePolicyV1NamespacedPodDisruptionBudgetStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified PodDisruptionBudget
     * operationId: patchPolicyV1NamespacedPodDisruptionBudgetStatus
     * Request URI: /apis/policy/v1/namespaces/{namespace}/poddisruptionbudgets/{name}/status
     */
    patchPolicyV1NamespacedPodDisruptionBudgetStatus<RequestContentType extends RequestContentType$patchPolicyV1NamespacedPodDisruptionBudgetStatus, ResponseContentType extends ResponseContentType$patchPolicyV1NamespacedPodDisruptionBudgetStatus>(params: Params$patchPolicyV1NamespacedPodDisruptionBudgetStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchPolicyV1NamespacedPodDisruptionBudgetStatus$Status$200 | Response$patchPolicyV1NamespacedPodDisruptionBudgetStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind PodDisruptionBudget
     * operationId: listPolicyV1PodDisruptionBudgetForAllNamespaces
     * Request URI: /apis/policy/v1/poddisruptionbudgets
     */
    listPolicyV1PodDisruptionBudgetForAllNamespaces<ResponseContentType extends ResponseContentType$listPolicyV1PodDisruptionBudgetForAllNamespaces>(params: Params$listPolicyV1PodDisruptionBudgetForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listPolicyV1PodDisruptionBudgetForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of PodDisruptionBudget. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchPolicyV1NamespacedPodDisruptionBudgetList
     * Request URI: /apis/policy/v1/watch/namespaces/{namespace}/poddisruptionbudgets
     */
    watchPolicyV1NamespacedPodDisruptionBudgetList<ResponseContentType extends ResponseContentType$watchPolicyV1NamespacedPodDisruptionBudgetList>(params: Params$watchPolicyV1NamespacedPodDisruptionBudgetList<ResponseContentType>, option?: RequestOption): Promise<Response$watchPolicyV1NamespacedPodDisruptionBudgetList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind PodDisruptionBudget. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchPolicyV1NamespacedPodDisruptionBudget
     * Request URI: /apis/policy/v1/watch/namespaces/{namespace}/poddisruptionbudgets/{name}
     */
    watchPolicyV1NamespacedPodDisruptionBudget<ResponseContentType extends ResponseContentType$watchPolicyV1NamespacedPodDisruptionBudget>(params: Params$watchPolicyV1NamespacedPodDisruptionBudget<ResponseContentType>, option?: RequestOption): Promise<Response$watchPolicyV1NamespacedPodDisruptionBudget$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of PodDisruptionBudget. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchPolicyV1PodDisruptionBudgetListForAllNamespaces
     * Request URI: /apis/policy/v1/watch/poddisruptionbudgets
     */
    watchPolicyV1PodDisruptionBudgetListForAllNamespaces<ResponseContentType extends ResponseContentType$watchPolicyV1PodDisruptionBudgetListForAllNamespaces>(params: Params$watchPolicyV1PodDisruptionBudgetListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchPolicyV1PodDisruptionBudgetListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getRbacAuthorizationAPIGroup
     * Request URI: /apis/rbac.authorization.k8s.io/
     */
    getRbacAuthorizationAPIGroup<ResponseContentType extends ResponseContentType$getRbacAuthorizationAPIGroup>(params: Params$getRbacAuthorizationAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getRbacAuthorizationAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getRbacAuthorizationV1APIResources
     * Request URI: /apis/rbac.authorization.k8s.io/v1/
     */
    getRbacAuthorizationV1APIResources<ResponseContentType extends ResponseContentType$getRbacAuthorizationV1APIResources>(params: Params$getRbacAuthorizationV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getRbacAuthorizationV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind ClusterRoleBinding
     * operationId: listRbacAuthorizationV1ClusterRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterrolebindings
     */
    listRbacAuthorizationV1ClusterRoleBinding<ResponseContentType extends ResponseContentType$listRbacAuthorizationV1ClusterRoleBinding>(params: Params$listRbacAuthorizationV1ClusterRoleBinding<ResponseContentType>, option?: RequestOption): Promise<Response$listRbacAuthorizationV1ClusterRoleBinding$Status$200[ResponseContentType]>;
    /**
     * create a ClusterRoleBinding
     * operationId: createRbacAuthorizationV1ClusterRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterrolebindings
     */
    createRbacAuthorizationV1ClusterRoleBinding<ResponseContentType extends ResponseContentType$createRbacAuthorizationV1ClusterRoleBinding>(params: Params$createRbacAuthorizationV1ClusterRoleBinding<ResponseContentType>, option?: RequestOption): Promise<(Response$createRbacAuthorizationV1ClusterRoleBinding$Status$200 | Response$createRbacAuthorizationV1ClusterRoleBinding$Status$201 | Response$createRbacAuthorizationV1ClusterRoleBinding$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ClusterRoleBinding
     * operationId: deleteRbacAuthorizationV1CollectionClusterRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterrolebindings
     */
    deleteRbacAuthorizationV1CollectionClusterRoleBinding<ResponseContentType extends ResponseContentType$deleteRbacAuthorizationV1CollectionClusterRoleBinding>(params: Params$deleteRbacAuthorizationV1CollectionClusterRoleBinding<ResponseContentType>, option?: RequestOption): Promise<Response$deleteRbacAuthorizationV1CollectionClusterRoleBinding$Status$200[ResponseContentType]>;
    /**
     * read the specified ClusterRoleBinding
     * operationId: readRbacAuthorizationV1ClusterRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterrolebindings/{name}
     */
    readRbacAuthorizationV1ClusterRoleBinding<ResponseContentType extends ResponseContentType$readRbacAuthorizationV1ClusterRoleBinding>(params: Params$readRbacAuthorizationV1ClusterRoleBinding<ResponseContentType>, option?: RequestOption): Promise<Response$readRbacAuthorizationV1ClusterRoleBinding$Status$200[ResponseContentType]>;
    /**
     * replace the specified ClusterRoleBinding
     * operationId: replaceRbacAuthorizationV1ClusterRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterrolebindings/{name}
     */
    replaceRbacAuthorizationV1ClusterRoleBinding<ResponseContentType extends ResponseContentType$replaceRbacAuthorizationV1ClusterRoleBinding>(params: Params$replaceRbacAuthorizationV1ClusterRoleBinding<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceRbacAuthorizationV1ClusterRoleBinding$Status$200 | Response$replaceRbacAuthorizationV1ClusterRoleBinding$Status$201)[ResponseContentType]>;
    /**
     * delete a ClusterRoleBinding
     * operationId: deleteRbacAuthorizationV1ClusterRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterrolebindings/{name}
     */
    deleteRbacAuthorizationV1ClusterRoleBinding<ResponseContentType extends ResponseContentType$deleteRbacAuthorizationV1ClusterRoleBinding>(params: Params$deleteRbacAuthorizationV1ClusterRoleBinding<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteRbacAuthorizationV1ClusterRoleBinding$Status$200 | Response$deleteRbacAuthorizationV1ClusterRoleBinding$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ClusterRoleBinding
     * operationId: patchRbacAuthorizationV1ClusterRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterrolebindings/{name}
     */
    patchRbacAuthorizationV1ClusterRoleBinding<RequestContentType extends RequestContentType$patchRbacAuthorizationV1ClusterRoleBinding, ResponseContentType extends ResponseContentType$patchRbacAuthorizationV1ClusterRoleBinding>(params: Params$patchRbacAuthorizationV1ClusterRoleBinding<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchRbacAuthorizationV1ClusterRoleBinding$Status$200 | Response$patchRbacAuthorizationV1ClusterRoleBinding$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind ClusterRole
     * operationId: listRbacAuthorizationV1ClusterRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterroles
     */
    listRbacAuthorizationV1ClusterRole<ResponseContentType extends ResponseContentType$listRbacAuthorizationV1ClusterRole>(params: Params$listRbacAuthorizationV1ClusterRole<ResponseContentType>, option?: RequestOption): Promise<Response$listRbacAuthorizationV1ClusterRole$Status$200[ResponseContentType]>;
    /**
     * create a ClusterRole
     * operationId: createRbacAuthorizationV1ClusterRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterroles
     */
    createRbacAuthorizationV1ClusterRole<ResponseContentType extends ResponseContentType$createRbacAuthorizationV1ClusterRole>(params: Params$createRbacAuthorizationV1ClusterRole<ResponseContentType>, option?: RequestOption): Promise<(Response$createRbacAuthorizationV1ClusterRole$Status$200 | Response$createRbacAuthorizationV1ClusterRole$Status$201 | Response$createRbacAuthorizationV1ClusterRole$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ClusterRole
     * operationId: deleteRbacAuthorizationV1CollectionClusterRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterroles
     */
    deleteRbacAuthorizationV1CollectionClusterRole<ResponseContentType extends ResponseContentType$deleteRbacAuthorizationV1CollectionClusterRole>(params: Params$deleteRbacAuthorizationV1CollectionClusterRole<ResponseContentType>, option?: RequestOption): Promise<Response$deleteRbacAuthorizationV1CollectionClusterRole$Status$200[ResponseContentType]>;
    /**
     * read the specified ClusterRole
     * operationId: readRbacAuthorizationV1ClusterRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterroles/{name}
     */
    readRbacAuthorizationV1ClusterRole<ResponseContentType extends ResponseContentType$readRbacAuthorizationV1ClusterRole>(params: Params$readRbacAuthorizationV1ClusterRole<ResponseContentType>, option?: RequestOption): Promise<Response$readRbacAuthorizationV1ClusterRole$Status$200[ResponseContentType]>;
    /**
     * replace the specified ClusterRole
     * operationId: replaceRbacAuthorizationV1ClusterRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterroles/{name}
     */
    replaceRbacAuthorizationV1ClusterRole<ResponseContentType extends ResponseContentType$replaceRbacAuthorizationV1ClusterRole>(params: Params$replaceRbacAuthorizationV1ClusterRole<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceRbacAuthorizationV1ClusterRole$Status$200 | Response$replaceRbacAuthorizationV1ClusterRole$Status$201)[ResponseContentType]>;
    /**
     * delete a ClusterRole
     * operationId: deleteRbacAuthorizationV1ClusterRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterroles/{name}
     */
    deleteRbacAuthorizationV1ClusterRole<ResponseContentType extends ResponseContentType$deleteRbacAuthorizationV1ClusterRole>(params: Params$deleteRbacAuthorizationV1ClusterRole<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteRbacAuthorizationV1ClusterRole$Status$200 | Response$deleteRbacAuthorizationV1ClusterRole$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ClusterRole
     * operationId: patchRbacAuthorizationV1ClusterRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/clusterroles/{name}
     */
    patchRbacAuthorizationV1ClusterRole<RequestContentType extends RequestContentType$patchRbacAuthorizationV1ClusterRole, ResponseContentType extends ResponseContentType$patchRbacAuthorizationV1ClusterRole>(params: Params$patchRbacAuthorizationV1ClusterRole<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchRbacAuthorizationV1ClusterRole$Status$200 | Response$patchRbacAuthorizationV1ClusterRole$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind RoleBinding
     * operationId: listRbacAuthorizationV1NamespacedRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/rolebindings
     */
    listRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType extends ResponseContentType$listRbacAuthorizationV1NamespacedRoleBinding>(params: Params$listRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType>, option?: RequestOption): Promise<Response$listRbacAuthorizationV1NamespacedRoleBinding$Status$200[ResponseContentType]>;
    /**
     * create a RoleBinding
     * operationId: createRbacAuthorizationV1NamespacedRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/rolebindings
     */
    createRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType extends ResponseContentType$createRbacAuthorizationV1NamespacedRoleBinding>(params: Params$createRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType>, option?: RequestOption): Promise<(Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$200 | Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$201 | Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$202)[ResponseContentType]>;
    /**
     * delete collection of RoleBinding
     * operationId: deleteRbacAuthorizationV1CollectionNamespacedRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/rolebindings
     */
    deleteRbacAuthorizationV1CollectionNamespacedRoleBinding<ResponseContentType extends ResponseContentType$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding>(params: Params$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding<ResponseContentType>, option?: RequestOption): Promise<Response$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding$Status$200[ResponseContentType]>;
    /**
     * read the specified RoleBinding
     * operationId: readRbacAuthorizationV1NamespacedRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/rolebindings/{name}
     */
    readRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType extends ResponseContentType$readRbacAuthorizationV1NamespacedRoleBinding>(params: Params$readRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType>, option?: RequestOption): Promise<Response$readRbacAuthorizationV1NamespacedRoleBinding$Status$200[ResponseContentType]>;
    /**
     * replace the specified RoleBinding
     * operationId: replaceRbacAuthorizationV1NamespacedRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/rolebindings/{name}
     */
    replaceRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType extends ResponseContentType$replaceRbacAuthorizationV1NamespacedRoleBinding>(params: Params$replaceRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceRbacAuthorizationV1NamespacedRoleBinding$Status$200 | Response$replaceRbacAuthorizationV1NamespacedRoleBinding$Status$201)[ResponseContentType]>;
    /**
     * delete a RoleBinding
     * operationId: deleteRbacAuthorizationV1NamespacedRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/rolebindings/{name}
     */
    deleteRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType extends ResponseContentType$deleteRbacAuthorizationV1NamespacedRoleBinding>(params: Params$deleteRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteRbacAuthorizationV1NamespacedRoleBinding$Status$200 | Response$deleteRbacAuthorizationV1NamespacedRoleBinding$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified RoleBinding
     * operationId: patchRbacAuthorizationV1NamespacedRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/rolebindings/{name}
     */
    patchRbacAuthorizationV1NamespacedRoleBinding<RequestContentType extends RequestContentType$patchRbacAuthorizationV1NamespacedRoleBinding, ResponseContentType extends ResponseContentType$patchRbacAuthorizationV1NamespacedRoleBinding>(params: Params$patchRbacAuthorizationV1NamespacedRoleBinding<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchRbacAuthorizationV1NamespacedRoleBinding$Status$200 | Response$patchRbacAuthorizationV1NamespacedRoleBinding$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind Role
     * operationId: listRbacAuthorizationV1NamespacedRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/roles
     */
    listRbacAuthorizationV1NamespacedRole<ResponseContentType extends ResponseContentType$listRbacAuthorizationV1NamespacedRole>(params: Params$listRbacAuthorizationV1NamespacedRole<ResponseContentType>, option?: RequestOption): Promise<Response$listRbacAuthorizationV1NamespacedRole$Status$200[ResponseContentType]>;
    /**
     * create a Role
     * operationId: createRbacAuthorizationV1NamespacedRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/roles
     */
    createRbacAuthorizationV1NamespacedRole<ResponseContentType extends ResponseContentType$createRbacAuthorizationV1NamespacedRole>(params: Params$createRbacAuthorizationV1NamespacedRole<ResponseContentType>, option?: RequestOption): Promise<(Response$createRbacAuthorizationV1NamespacedRole$Status$200 | Response$createRbacAuthorizationV1NamespacedRole$Status$201 | Response$createRbacAuthorizationV1NamespacedRole$Status$202)[ResponseContentType]>;
    /**
     * delete collection of Role
     * operationId: deleteRbacAuthorizationV1CollectionNamespacedRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/roles
     */
    deleteRbacAuthorizationV1CollectionNamespacedRole<ResponseContentType extends ResponseContentType$deleteRbacAuthorizationV1CollectionNamespacedRole>(params: Params$deleteRbacAuthorizationV1CollectionNamespacedRole<ResponseContentType>, option?: RequestOption): Promise<Response$deleteRbacAuthorizationV1CollectionNamespacedRole$Status$200[ResponseContentType]>;
    /**
     * read the specified Role
     * operationId: readRbacAuthorizationV1NamespacedRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/roles/{name}
     */
    readRbacAuthorizationV1NamespacedRole<ResponseContentType extends ResponseContentType$readRbacAuthorizationV1NamespacedRole>(params: Params$readRbacAuthorizationV1NamespacedRole<ResponseContentType>, option?: RequestOption): Promise<Response$readRbacAuthorizationV1NamespacedRole$Status$200[ResponseContentType]>;
    /**
     * replace the specified Role
     * operationId: replaceRbacAuthorizationV1NamespacedRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/roles/{name}
     */
    replaceRbacAuthorizationV1NamespacedRole<ResponseContentType extends ResponseContentType$replaceRbacAuthorizationV1NamespacedRole>(params: Params$replaceRbacAuthorizationV1NamespacedRole<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceRbacAuthorizationV1NamespacedRole$Status$200 | Response$replaceRbacAuthorizationV1NamespacedRole$Status$201)[ResponseContentType]>;
    /**
     * delete a Role
     * operationId: deleteRbacAuthorizationV1NamespacedRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/roles/{name}
     */
    deleteRbacAuthorizationV1NamespacedRole<ResponseContentType extends ResponseContentType$deleteRbacAuthorizationV1NamespacedRole>(params: Params$deleteRbacAuthorizationV1NamespacedRole<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteRbacAuthorizationV1NamespacedRole$Status$200 | Response$deleteRbacAuthorizationV1NamespacedRole$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified Role
     * operationId: patchRbacAuthorizationV1NamespacedRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/namespaces/{namespace}/roles/{name}
     */
    patchRbacAuthorizationV1NamespacedRole<RequestContentType extends RequestContentType$patchRbacAuthorizationV1NamespacedRole, ResponseContentType extends ResponseContentType$patchRbacAuthorizationV1NamespacedRole>(params: Params$patchRbacAuthorizationV1NamespacedRole<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchRbacAuthorizationV1NamespacedRole$Status$200 | Response$patchRbacAuthorizationV1NamespacedRole$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind RoleBinding
     * operationId: listRbacAuthorizationV1RoleBindingForAllNamespaces
     * Request URI: /apis/rbac.authorization.k8s.io/v1/rolebindings
     */
    listRbacAuthorizationV1RoleBindingForAllNamespaces<ResponseContentType extends ResponseContentType$listRbacAuthorizationV1RoleBindingForAllNamespaces>(params: Params$listRbacAuthorizationV1RoleBindingForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listRbacAuthorizationV1RoleBindingForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind Role
     * operationId: listRbacAuthorizationV1RoleForAllNamespaces
     * Request URI: /apis/rbac.authorization.k8s.io/v1/roles
     */
    listRbacAuthorizationV1RoleForAllNamespaces<ResponseContentType extends ResponseContentType$listRbacAuthorizationV1RoleForAllNamespaces>(params: Params$listRbacAuthorizationV1RoleForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listRbacAuthorizationV1RoleForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ClusterRoleBinding. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchRbacAuthorizationV1ClusterRoleBindingList
     * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/clusterrolebindings
     */
    watchRbacAuthorizationV1ClusterRoleBindingList<ResponseContentType extends ResponseContentType$watchRbacAuthorizationV1ClusterRoleBindingList>(params: Params$watchRbacAuthorizationV1ClusterRoleBindingList<ResponseContentType>, option?: RequestOption): Promise<Response$watchRbacAuthorizationV1ClusterRoleBindingList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ClusterRoleBinding. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchRbacAuthorizationV1ClusterRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/clusterrolebindings/{name}
     */
    watchRbacAuthorizationV1ClusterRoleBinding<ResponseContentType extends ResponseContentType$watchRbacAuthorizationV1ClusterRoleBinding>(params: Params$watchRbacAuthorizationV1ClusterRoleBinding<ResponseContentType>, option?: RequestOption): Promise<Response$watchRbacAuthorizationV1ClusterRoleBinding$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ClusterRole. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchRbacAuthorizationV1ClusterRoleList
     * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/clusterroles
     */
    watchRbacAuthorizationV1ClusterRoleList<ResponseContentType extends ResponseContentType$watchRbacAuthorizationV1ClusterRoleList>(params: Params$watchRbacAuthorizationV1ClusterRoleList<ResponseContentType>, option?: RequestOption): Promise<Response$watchRbacAuthorizationV1ClusterRoleList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ClusterRole. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchRbacAuthorizationV1ClusterRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/clusterroles/{name}
     */
    watchRbacAuthorizationV1ClusterRole<ResponseContentType extends ResponseContentType$watchRbacAuthorizationV1ClusterRole>(params: Params$watchRbacAuthorizationV1ClusterRole<ResponseContentType>, option?: RequestOption): Promise<Response$watchRbacAuthorizationV1ClusterRole$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of RoleBinding. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchRbacAuthorizationV1NamespacedRoleBindingList
     * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/namespaces/{namespace}/rolebindings
     */
    watchRbacAuthorizationV1NamespacedRoleBindingList<ResponseContentType extends ResponseContentType$watchRbacAuthorizationV1NamespacedRoleBindingList>(params: Params$watchRbacAuthorizationV1NamespacedRoleBindingList<ResponseContentType>, option?: RequestOption): Promise<Response$watchRbacAuthorizationV1NamespacedRoleBindingList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind RoleBinding. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchRbacAuthorizationV1NamespacedRoleBinding
     * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/namespaces/{namespace}/rolebindings/{name}
     */
    watchRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType extends ResponseContentType$watchRbacAuthorizationV1NamespacedRoleBinding>(params: Params$watchRbacAuthorizationV1NamespacedRoleBinding<ResponseContentType>, option?: RequestOption): Promise<Response$watchRbacAuthorizationV1NamespacedRoleBinding$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Role. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchRbacAuthorizationV1NamespacedRoleList
     * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/namespaces/{namespace}/roles
     */
    watchRbacAuthorizationV1NamespacedRoleList<ResponseContentType extends ResponseContentType$watchRbacAuthorizationV1NamespacedRoleList>(params: Params$watchRbacAuthorizationV1NamespacedRoleList<ResponseContentType>, option?: RequestOption): Promise<Response$watchRbacAuthorizationV1NamespacedRoleList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind Role. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchRbacAuthorizationV1NamespacedRole
     * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/namespaces/{namespace}/roles/{name}
     */
    watchRbacAuthorizationV1NamespacedRole<ResponseContentType extends ResponseContentType$watchRbacAuthorizationV1NamespacedRole>(params: Params$watchRbacAuthorizationV1NamespacedRole<ResponseContentType>, option?: RequestOption): Promise<Response$watchRbacAuthorizationV1NamespacedRole$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of RoleBinding. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchRbacAuthorizationV1RoleBindingListForAllNamespaces
     * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/rolebindings
     */
    watchRbacAuthorizationV1RoleBindingListForAllNamespaces<ResponseContentType extends ResponseContentType$watchRbacAuthorizationV1RoleBindingListForAllNamespaces>(params: Params$watchRbacAuthorizationV1RoleBindingListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchRbacAuthorizationV1RoleBindingListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of Role. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchRbacAuthorizationV1RoleListForAllNamespaces
     * Request URI: /apis/rbac.authorization.k8s.io/v1/watch/roles
     */
    watchRbacAuthorizationV1RoleListForAllNamespaces<ResponseContentType extends ResponseContentType$watchRbacAuthorizationV1RoleListForAllNamespaces>(params: Params$watchRbacAuthorizationV1RoleListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchRbacAuthorizationV1RoleListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getResourceAPIGroup
     * Request URI: /apis/resource.k8s.io/
     */
    getResourceAPIGroup<ResponseContentType extends ResponseContentType$getResourceAPIGroup>(params: Params$getResourceAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getResourceAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getResourceV1alpha2APIResources
     * Request URI: /apis/resource.k8s.io/v1alpha2/
     */
    getResourceV1alpha2APIResources<ResponseContentType extends ResponseContentType$getResourceV1alpha2APIResources>(params: Params$getResourceV1alpha2APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getResourceV1alpha2APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind PodSchedulingContext
     * operationId: listResourceV1alpha2NamespacedPodSchedulingContext
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/podschedulingcontexts
     */
    listResourceV1alpha2NamespacedPodSchedulingContext<ResponseContentType extends ResponseContentType$listResourceV1alpha2NamespacedPodSchedulingContext>(params: Params$listResourceV1alpha2NamespacedPodSchedulingContext<ResponseContentType>, option?: RequestOption): Promise<Response$listResourceV1alpha2NamespacedPodSchedulingContext$Status$200[ResponseContentType]>;
    /**
     * create a PodSchedulingContext
     * operationId: createResourceV1alpha2NamespacedPodSchedulingContext
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/podschedulingcontexts
     */
    createResourceV1alpha2NamespacedPodSchedulingContext<ResponseContentType extends ResponseContentType$createResourceV1alpha2NamespacedPodSchedulingContext>(params: Params$createResourceV1alpha2NamespacedPodSchedulingContext<ResponseContentType>, option?: RequestOption): Promise<(Response$createResourceV1alpha2NamespacedPodSchedulingContext$Status$200 | Response$createResourceV1alpha2NamespacedPodSchedulingContext$Status$201 | Response$createResourceV1alpha2NamespacedPodSchedulingContext$Status$202)[ResponseContentType]>;
    /**
     * delete collection of PodSchedulingContext
     * operationId: deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/podschedulingcontexts
     */
    deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext<ResponseContentType extends ResponseContentType$deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext>(params: Params$deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext<ResponseContentType>, option?: RequestOption): Promise<Response$deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext$Status$200[ResponseContentType]>;
    /**
     * read the specified PodSchedulingContext
     * operationId: readResourceV1alpha2NamespacedPodSchedulingContext
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/podschedulingcontexts/{name}
     */
    readResourceV1alpha2NamespacedPodSchedulingContext<ResponseContentType extends ResponseContentType$readResourceV1alpha2NamespacedPodSchedulingContext>(params: Params$readResourceV1alpha2NamespacedPodSchedulingContext<ResponseContentType>, option?: RequestOption): Promise<Response$readResourceV1alpha2NamespacedPodSchedulingContext$Status$200[ResponseContentType]>;
    /**
     * replace the specified PodSchedulingContext
     * operationId: replaceResourceV1alpha2NamespacedPodSchedulingContext
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/podschedulingcontexts/{name}
     */
    replaceResourceV1alpha2NamespacedPodSchedulingContext<ResponseContentType extends ResponseContentType$replaceResourceV1alpha2NamespacedPodSchedulingContext>(params: Params$replaceResourceV1alpha2NamespacedPodSchedulingContext<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceResourceV1alpha2NamespacedPodSchedulingContext$Status$200 | Response$replaceResourceV1alpha2NamespacedPodSchedulingContext$Status$201)[ResponseContentType]>;
    /**
     * delete a PodSchedulingContext
     * operationId: deleteResourceV1alpha2NamespacedPodSchedulingContext
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/podschedulingcontexts/{name}
     */
    deleteResourceV1alpha2NamespacedPodSchedulingContext<ResponseContentType extends ResponseContentType$deleteResourceV1alpha2NamespacedPodSchedulingContext>(params: Params$deleteResourceV1alpha2NamespacedPodSchedulingContext<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteResourceV1alpha2NamespacedPodSchedulingContext$Status$200 | Response$deleteResourceV1alpha2NamespacedPodSchedulingContext$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified PodSchedulingContext
     * operationId: patchResourceV1alpha2NamespacedPodSchedulingContext
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/podschedulingcontexts/{name}
     */
    patchResourceV1alpha2NamespacedPodSchedulingContext<RequestContentType extends RequestContentType$patchResourceV1alpha2NamespacedPodSchedulingContext, ResponseContentType extends ResponseContentType$patchResourceV1alpha2NamespacedPodSchedulingContext>(params: Params$patchResourceV1alpha2NamespacedPodSchedulingContext<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchResourceV1alpha2NamespacedPodSchedulingContext$Status$200 | Response$patchResourceV1alpha2NamespacedPodSchedulingContext$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified PodSchedulingContext
     * operationId: readResourceV1alpha2NamespacedPodSchedulingContextStatus
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/podschedulingcontexts/{name}/status
     */
    readResourceV1alpha2NamespacedPodSchedulingContextStatus<ResponseContentType extends ResponseContentType$readResourceV1alpha2NamespacedPodSchedulingContextStatus>(params: Params$readResourceV1alpha2NamespacedPodSchedulingContextStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified PodSchedulingContext
     * operationId: replaceResourceV1alpha2NamespacedPodSchedulingContextStatus
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/podschedulingcontexts/{name}/status
     */
    replaceResourceV1alpha2NamespacedPodSchedulingContextStatus<ResponseContentType extends ResponseContentType$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus>(params: Params$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$200 | Response$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified PodSchedulingContext
     * operationId: patchResourceV1alpha2NamespacedPodSchedulingContextStatus
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/podschedulingcontexts/{name}/status
     */
    patchResourceV1alpha2NamespacedPodSchedulingContextStatus<RequestContentType extends RequestContentType$patchResourceV1alpha2NamespacedPodSchedulingContextStatus, ResponseContentType extends ResponseContentType$patchResourceV1alpha2NamespacedPodSchedulingContextStatus>(params: Params$patchResourceV1alpha2NamespacedPodSchedulingContextStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$200 | Response$patchResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind ResourceClaim
     * operationId: listResourceV1alpha2NamespacedResourceClaim
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/resourceclaims
     */
    listResourceV1alpha2NamespacedResourceClaim<ResponseContentType extends ResponseContentType$listResourceV1alpha2NamespacedResourceClaim>(params: Params$listResourceV1alpha2NamespacedResourceClaim<ResponseContentType>, option?: RequestOption): Promise<Response$listResourceV1alpha2NamespacedResourceClaim$Status$200[ResponseContentType]>;
    /**
     * create a ResourceClaim
     * operationId: createResourceV1alpha2NamespacedResourceClaim
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/resourceclaims
     */
    createResourceV1alpha2NamespacedResourceClaim<ResponseContentType extends ResponseContentType$createResourceV1alpha2NamespacedResourceClaim>(params: Params$createResourceV1alpha2NamespacedResourceClaim<ResponseContentType>, option?: RequestOption): Promise<(Response$createResourceV1alpha2NamespacedResourceClaim$Status$200 | Response$createResourceV1alpha2NamespacedResourceClaim$Status$201 | Response$createResourceV1alpha2NamespacedResourceClaim$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ResourceClaim
     * operationId: deleteResourceV1alpha2CollectionNamespacedResourceClaim
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/resourceclaims
     */
    deleteResourceV1alpha2CollectionNamespacedResourceClaim<ResponseContentType extends ResponseContentType$deleteResourceV1alpha2CollectionNamespacedResourceClaim>(params: Params$deleteResourceV1alpha2CollectionNamespacedResourceClaim<ResponseContentType>, option?: RequestOption): Promise<Response$deleteResourceV1alpha2CollectionNamespacedResourceClaim$Status$200[ResponseContentType]>;
    /**
     * read the specified ResourceClaim
     * operationId: readResourceV1alpha2NamespacedResourceClaim
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/resourceclaims/{name}
     */
    readResourceV1alpha2NamespacedResourceClaim<ResponseContentType extends ResponseContentType$readResourceV1alpha2NamespacedResourceClaim>(params: Params$readResourceV1alpha2NamespacedResourceClaim<ResponseContentType>, option?: RequestOption): Promise<Response$readResourceV1alpha2NamespacedResourceClaim$Status$200[ResponseContentType]>;
    /**
     * replace the specified ResourceClaim
     * operationId: replaceResourceV1alpha2NamespacedResourceClaim
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/resourceclaims/{name}
     */
    replaceResourceV1alpha2NamespacedResourceClaim<ResponseContentType extends ResponseContentType$replaceResourceV1alpha2NamespacedResourceClaim>(params: Params$replaceResourceV1alpha2NamespacedResourceClaim<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceResourceV1alpha2NamespacedResourceClaim$Status$200 | Response$replaceResourceV1alpha2NamespacedResourceClaim$Status$201)[ResponseContentType]>;
    /**
     * delete a ResourceClaim
     * operationId: deleteResourceV1alpha2NamespacedResourceClaim
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/resourceclaims/{name}
     */
    deleteResourceV1alpha2NamespacedResourceClaim<ResponseContentType extends ResponseContentType$deleteResourceV1alpha2NamespacedResourceClaim>(params: Params$deleteResourceV1alpha2NamespacedResourceClaim<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteResourceV1alpha2NamespacedResourceClaim$Status$200 | Response$deleteResourceV1alpha2NamespacedResourceClaim$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ResourceClaim
     * operationId: patchResourceV1alpha2NamespacedResourceClaim
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/resourceclaims/{name}
     */
    patchResourceV1alpha2NamespacedResourceClaim<RequestContentType extends RequestContentType$patchResourceV1alpha2NamespacedResourceClaim, ResponseContentType extends ResponseContentType$patchResourceV1alpha2NamespacedResourceClaim>(params: Params$patchResourceV1alpha2NamespacedResourceClaim<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchResourceV1alpha2NamespacedResourceClaim$Status$200 | Response$patchResourceV1alpha2NamespacedResourceClaim$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified ResourceClaim
     * operationId: readResourceV1alpha2NamespacedResourceClaimStatus
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/resourceclaims/{name}/status
     */
    readResourceV1alpha2NamespacedResourceClaimStatus<ResponseContentType extends ResponseContentType$readResourceV1alpha2NamespacedResourceClaimStatus>(params: Params$readResourceV1alpha2NamespacedResourceClaimStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readResourceV1alpha2NamespacedResourceClaimStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified ResourceClaim
     * operationId: replaceResourceV1alpha2NamespacedResourceClaimStatus
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/resourceclaims/{name}/status
     */
    replaceResourceV1alpha2NamespacedResourceClaimStatus<ResponseContentType extends ResponseContentType$replaceResourceV1alpha2NamespacedResourceClaimStatus>(params: Params$replaceResourceV1alpha2NamespacedResourceClaimStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceResourceV1alpha2NamespacedResourceClaimStatus$Status$200 | Response$replaceResourceV1alpha2NamespacedResourceClaimStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified ResourceClaim
     * operationId: patchResourceV1alpha2NamespacedResourceClaimStatus
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/resourceclaims/{name}/status
     */
    patchResourceV1alpha2NamespacedResourceClaimStatus<RequestContentType extends RequestContentType$patchResourceV1alpha2NamespacedResourceClaimStatus, ResponseContentType extends ResponseContentType$patchResourceV1alpha2NamespacedResourceClaimStatus>(params: Params$patchResourceV1alpha2NamespacedResourceClaimStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchResourceV1alpha2NamespacedResourceClaimStatus$Status$200 | Response$patchResourceV1alpha2NamespacedResourceClaimStatus$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind ResourceClaimTemplate
     * operationId: listResourceV1alpha2NamespacedResourceClaimTemplate
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/resourceclaimtemplates
     */
    listResourceV1alpha2NamespacedResourceClaimTemplate<ResponseContentType extends ResponseContentType$listResourceV1alpha2NamespacedResourceClaimTemplate>(params: Params$listResourceV1alpha2NamespacedResourceClaimTemplate<ResponseContentType>, option?: RequestOption): Promise<Response$listResourceV1alpha2NamespacedResourceClaimTemplate$Status$200[ResponseContentType]>;
    /**
     * create a ResourceClaimTemplate
     * operationId: createResourceV1alpha2NamespacedResourceClaimTemplate
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/resourceclaimtemplates
     */
    createResourceV1alpha2NamespacedResourceClaimTemplate<ResponseContentType extends ResponseContentType$createResourceV1alpha2NamespacedResourceClaimTemplate>(params: Params$createResourceV1alpha2NamespacedResourceClaimTemplate<ResponseContentType>, option?: RequestOption): Promise<(Response$createResourceV1alpha2NamespacedResourceClaimTemplate$Status$200 | Response$createResourceV1alpha2NamespacedResourceClaimTemplate$Status$201 | Response$createResourceV1alpha2NamespacedResourceClaimTemplate$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ResourceClaimTemplate
     * operationId: deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/resourceclaimtemplates
     */
    deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate<ResponseContentType extends ResponseContentType$deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate>(params: Params$deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate<ResponseContentType>, option?: RequestOption): Promise<Response$deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate$Status$200[ResponseContentType]>;
    /**
     * read the specified ResourceClaimTemplate
     * operationId: readResourceV1alpha2NamespacedResourceClaimTemplate
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/resourceclaimtemplates/{name}
     */
    readResourceV1alpha2NamespacedResourceClaimTemplate<ResponseContentType extends ResponseContentType$readResourceV1alpha2NamespacedResourceClaimTemplate>(params: Params$readResourceV1alpha2NamespacedResourceClaimTemplate<ResponseContentType>, option?: RequestOption): Promise<Response$readResourceV1alpha2NamespacedResourceClaimTemplate$Status$200[ResponseContentType]>;
    /**
     * replace the specified ResourceClaimTemplate
     * operationId: replaceResourceV1alpha2NamespacedResourceClaimTemplate
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/resourceclaimtemplates/{name}
     */
    replaceResourceV1alpha2NamespacedResourceClaimTemplate<ResponseContentType extends ResponseContentType$replaceResourceV1alpha2NamespacedResourceClaimTemplate>(params: Params$replaceResourceV1alpha2NamespacedResourceClaimTemplate<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceResourceV1alpha2NamespacedResourceClaimTemplate$Status$200 | Response$replaceResourceV1alpha2NamespacedResourceClaimTemplate$Status$201)[ResponseContentType]>;
    /**
     * delete a ResourceClaimTemplate
     * operationId: deleteResourceV1alpha2NamespacedResourceClaimTemplate
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/resourceclaimtemplates/{name}
     */
    deleteResourceV1alpha2NamespacedResourceClaimTemplate<ResponseContentType extends ResponseContentType$deleteResourceV1alpha2NamespacedResourceClaimTemplate>(params: Params$deleteResourceV1alpha2NamespacedResourceClaimTemplate<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteResourceV1alpha2NamespacedResourceClaimTemplate$Status$200 | Response$deleteResourceV1alpha2NamespacedResourceClaimTemplate$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ResourceClaimTemplate
     * operationId: patchResourceV1alpha2NamespacedResourceClaimTemplate
     * Request URI: /apis/resource.k8s.io/v1alpha2/namespaces/{namespace}/resourceclaimtemplates/{name}
     */
    patchResourceV1alpha2NamespacedResourceClaimTemplate<RequestContentType extends RequestContentType$patchResourceV1alpha2NamespacedResourceClaimTemplate, ResponseContentType extends ResponseContentType$patchResourceV1alpha2NamespacedResourceClaimTemplate>(params: Params$patchResourceV1alpha2NamespacedResourceClaimTemplate<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchResourceV1alpha2NamespacedResourceClaimTemplate$Status$200 | Response$patchResourceV1alpha2NamespacedResourceClaimTemplate$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind PodSchedulingContext
     * operationId: listResourceV1alpha2PodSchedulingContextForAllNamespaces
     * Request URI: /apis/resource.k8s.io/v1alpha2/podschedulingcontexts
     */
    listResourceV1alpha2PodSchedulingContextForAllNamespaces<ResponseContentType extends ResponseContentType$listResourceV1alpha2PodSchedulingContextForAllNamespaces>(params: Params$listResourceV1alpha2PodSchedulingContextForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listResourceV1alpha2PodSchedulingContextForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind ResourceClaim
     * operationId: listResourceV1alpha2ResourceClaimForAllNamespaces
     * Request URI: /apis/resource.k8s.io/v1alpha2/resourceclaims
     */
    listResourceV1alpha2ResourceClaimForAllNamespaces<ResponseContentType extends ResponseContentType$listResourceV1alpha2ResourceClaimForAllNamespaces>(params: Params$listResourceV1alpha2ResourceClaimForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listResourceV1alpha2ResourceClaimForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind ResourceClaimTemplate
     * operationId: listResourceV1alpha2ResourceClaimTemplateForAllNamespaces
     * Request URI: /apis/resource.k8s.io/v1alpha2/resourceclaimtemplates
     */
    listResourceV1alpha2ResourceClaimTemplateForAllNamespaces<ResponseContentType extends ResponseContentType$listResourceV1alpha2ResourceClaimTemplateForAllNamespaces>(params: Params$listResourceV1alpha2ResourceClaimTemplateForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listResourceV1alpha2ResourceClaimTemplateForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind ResourceClass
     * operationId: listResourceV1alpha2ResourceClass
     * Request URI: /apis/resource.k8s.io/v1alpha2/resourceclasses
     */
    listResourceV1alpha2ResourceClass<ResponseContentType extends ResponseContentType$listResourceV1alpha2ResourceClass>(params: Params$listResourceV1alpha2ResourceClass<ResponseContentType>, option?: RequestOption): Promise<Response$listResourceV1alpha2ResourceClass$Status$200[ResponseContentType]>;
    /**
     * create a ResourceClass
     * operationId: createResourceV1alpha2ResourceClass
     * Request URI: /apis/resource.k8s.io/v1alpha2/resourceclasses
     */
    createResourceV1alpha2ResourceClass<ResponseContentType extends ResponseContentType$createResourceV1alpha2ResourceClass>(params: Params$createResourceV1alpha2ResourceClass<ResponseContentType>, option?: RequestOption): Promise<(Response$createResourceV1alpha2ResourceClass$Status$200 | Response$createResourceV1alpha2ResourceClass$Status$201 | Response$createResourceV1alpha2ResourceClass$Status$202)[ResponseContentType]>;
    /**
     * delete collection of ResourceClass
     * operationId: deleteResourceV1alpha2CollectionResourceClass
     * Request URI: /apis/resource.k8s.io/v1alpha2/resourceclasses
     */
    deleteResourceV1alpha2CollectionResourceClass<ResponseContentType extends ResponseContentType$deleteResourceV1alpha2CollectionResourceClass>(params: Params$deleteResourceV1alpha2CollectionResourceClass<ResponseContentType>, option?: RequestOption): Promise<Response$deleteResourceV1alpha2CollectionResourceClass$Status$200[ResponseContentType]>;
    /**
     * read the specified ResourceClass
     * operationId: readResourceV1alpha2ResourceClass
     * Request URI: /apis/resource.k8s.io/v1alpha2/resourceclasses/{name}
     */
    readResourceV1alpha2ResourceClass<ResponseContentType extends ResponseContentType$readResourceV1alpha2ResourceClass>(params: Params$readResourceV1alpha2ResourceClass<ResponseContentType>, option?: RequestOption): Promise<Response$readResourceV1alpha2ResourceClass$Status$200[ResponseContentType]>;
    /**
     * replace the specified ResourceClass
     * operationId: replaceResourceV1alpha2ResourceClass
     * Request URI: /apis/resource.k8s.io/v1alpha2/resourceclasses/{name}
     */
    replaceResourceV1alpha2ResourceClass<ResponseContentType extends ResponseContentType$replaceResourceV1alpha2ResourceClass>(params: Params$replaceResourceV1alpha2ResourceClass<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceResourceV1alpha2ResourceClass$Status$200 | Response$replaceResourceV1alpha2ResourceClass$Status$201)[ResponseContentType]>;
    /**
     * delete a ResourceClass
     * operationId: deleteResourceV1alpha2ResourceClass
     * Request URI: /apis/resource.k8s.io/v1alpha2/resourceclasses/{name}
     */
    deleteResourceV1alpha2ResourceClass<ResponseContentType extends ResponseContentType$deleteResourceV1alpha2ResourceClass>(params: Params$deleteResourceV1alpha2ResourceClass<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteResourceV1alpha2ResourceClass$Status$200 | Response$deleteResourceV1alpha2ResourceClass$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified ResourceClass
     * operationId: patchResourceV1alpha2ResourceClass
     * Request URI: /apis/resource.k8s.io/v1alpha2/resourceclasses/{name}
     */
    patchResourceV1alpha2ResourceClass<RequestContentType extends RequestContentType$patchResourceV1alpha2ResourceClass, ResponseContentType extends ResponseContentType$patchResourceV1alpha2ResourceClass>(params: Params$patchResourceV1alpha2ResourceClass<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchResourceV1alpha2ResourceClass$Status$200 | Response$patchResourceV1alpha2ResourceClass$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of PodSchedulingContext. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchResourceV1alpha2NamespacedPodSchedulingContextList
     * Request URI: /apis/resource.k8s.io/v1alpha2/watch/namespaces/{namespace}/podschedulingcontexts
     */
    watchResourceV1alpha2NamespacedPodSchedulingContextList<ResponseContentType extends ResponseContentType$watchResourceV1alpha2NamespacedPodSchedulingContextList>(params: Params$watchResourceV1alpha2NamespacedPodSchedulingContextList<ResponseContentType>, option?: RequestOption): Promise<Response$watchResourceV1alpha2NamespacedPodSchedulingContextList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind PodSchedulingContext. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchResourceV1alpha2NamespacedPodSchedulingContext
     * Request URI: /apis/resource.k8s.io/v1alpha2/watch/namespaces/{namespace}/podschedulingcontexts/{name}
     */
    watchResourceV1alpha2NamespacedPodSchedulingContext<ResponseContentType extends ResponseContentType$watchResourceV1alpha2NamespacedPodSchedulingContext>(params: Params$watchResourceV1alpha2NamespacedPodSchedulingContext<ResponseContentType>, option?: RequestOption): Promise<Response$watchResourceV1alpha2NamespacedPodSchedulingContext$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ResourceClaim. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchResourceV1alpha2NamespacedResourceClaimList
     * Request URI: /apis/resource.k8s.io/v1alpha2/watch/namespaces/{namespace}/resourceclaims
     */
    watchResourceV1alpha2NamespacedResourceClaimList<ResponseContentType extends ResponseContentType$watchResourceV1alpha2NamespacedResourceClaimList>(params: Params$watchResourceV1alpha2NamespacedResourceClaimList<ResponseContentType>, option?: RequestOption): Promise<Response$watchResourceV1alpha2NamespacedResourceClaimList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ResourceClaim. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchResourceV1alpha2NamespacedResourceClaim
     * Request URI: /apis/resource.k8s.io/v1alpha2/watch/namespaces/{namespace}/resourceclaims/{name}
     */
    watchResourceV1alpha2NamespacedResourceClaim<ResponseContentType extends ResponseContentType$watchResourceV1alpha2NamespacedResourceClaim>(params: Params$watchResourceV1alpha2NamespacedResourceClaim<ResponseContentType>, option?: RequestOption): Promise<Response$watchResourceV1alpha2NamespacedResourceClaim$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ResourceClaimTemplate. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchResourceV1alpha2NamespacedResourceClaimTemplateList
     * Request URI: /apis/resource.k8s.io/v1alpha2/watch/namespaces/{namespace}/resourceclaimtemplates
     */
    watchResourceV1alpha2NamespacedResourceClaimTemplateList<ResponseContentType extends ResponseContentType$watchResourceV1alpha2NamespacedResourceClaimTemplateList>(params: Params$watchResourceV1alpha2NamespacedResourceClaimTemplateList<ResponseContentType>, option?: RequestOption): Promise<Response$watchResourceV1alpha2NamespacedResourceClaimTemplateList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ResourceClaimTemplate. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchResourceV1alpha2NamespacedResourceClaimTemplate
     * Request URI: /apis/resource.k8s.io/v1alpha2/watch/namespaces/{namespace}/resourceclaimtemplates/{name}
     */
    watchResourceV1alpha2NamespacedResourceClaimTemplate<ResponseContentType extends ResponseContentType$watchResourceV1alpha2NamespacedResourceClaimTemplate>(params: Params$watchResourceV1alpha2NamespacedResourceClaimTemplate<ResponseContentType>, option?: RequestOption): Promise<Response$watchResourceV1alpha2NamespacedResourceClaimTemplate$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of PodSchedulingContext. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchResourceV1alpha2PodSchedulingContextListForAllNamespaces
     * Request URI: /apis/resource.k8s.io/v1alpha2/watch/podschedulingcontexts
     */
    watchResourceV1alpha2PodSchedulingContextListForAllNamespaces<ResponseContentType extends ResponseContentType$watchResourceV1alpha2PodSchedulingContextListForAllNamespaces>(params: Params$watchResourceV1alpha2PodSchedulingContextListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchResourceV1alpha2PodSchedulingContextListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ResourceClaim. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchResourceV1alpha2ResourceClaimListForAllNamespaces
     * Request URI: /apis/resource.k8s.io/v1alpha2/watch/resourceclaims
     */
    watchResourceV1alpha2ResourceClaimListForAllNamespaces<ResponseContentType extends ResponseContentType$watchResourceV1alpha2ResourceClaimListForAllNamespaces>(params: Params$watchResourceV1alpha2ResourceClaimListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchResourceV1alpha2ResourceClaimListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ResourceClaimTemplate. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchResourceV1alpha2ResourceClaimTemplateListForAllNamespaces
     * Request URI: /apis/resource.k8s.io/v1alpha2/watch/resourceclaimtemplates
     */
    watchResourceV1alpha2ResourceClaimTemplateListForAllNamespaces<ResponseContentType extends ResponseContentType$watchResourceV1alpha2ResourceClaimTemplateListForAllNamespaces>(params: Params$watchResourceV1alpha2ResourceClaimTemplateListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchResourceV1alpha2ResourceClaimTemplateListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of ResourceClass. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchResourceV1alpha2ResourceClassList
     * Request URI: /apis/resource.k8s.io/v1alpha2/watch/resourceclasses
     */
    watchResourceV1alpha2ResourceClassList<ResponseContentType extends ResponseContentType$watchResourceV1alpha2ResourceClassList>(params: Params$watchResourceV1alpha2ResourceClassList<ResponseContentType>, option?: RequestOption): Promise<Response$watchResourceV1alpha2ResourceClassList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind ResourceClass. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchResourceV1alpha2ResourceClass
     * Request URI: /apis/resource.k8s.io/v1alpha2/watch/resourceclasses/{name}
     */
    watchResourceV1alpha2ResourceClass<ResponseContentType extends ResponseContentType$watchResourceV1alpha2ResourceClass>(params: Params$watchResourceV1alpha2ResourceClass<ResponseContentType>, option?: RequestOption): Promise<Response$watchResourceV1alpha2ResourceClass$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getSchedulingAPIGroup
     * Request URI: /apis/scheduling.k8s.io/
     */
    getSchedulingAPIGroup<ResponseContentType extends ResponseContentType$getSchedulingAPIGroup>(params: Params$getSchedulingAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getSchedulingAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getSchedulingV1APIResources
     * Request URI: /apis/scheduling.k8s.io/v1/
     */
    getSchedulingV1APIResources<ResponseContentType extends ResponseContentType$getSchedulingV1APIResources>(params: Params$getSchedulingV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getSchedulingV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind PriorityClass
     * operationId: listSchedulingV1PriorityClass
     * Request URI: /apis/scheduling.k8s.io/v1/priorityclasses
     */
    listSchedulingV1PriorityClass<ResponseContentType extends ResponseContentType$listSchedulingV1PriorityClass>(params: Params$listSchedulingV1PriorityClass<ResponseContentType>, option?: RequestOption): Promise<Response$listSchedulingV1PriorityClass$Status$200[ResponseContentType]>;
    /**
     * create a PriorityClass
     * operationId: createSchedulingV1PriorityClass
     * Request URI: /apis/scheduling.k8s.io/v1/priorityclasses
     */
    createSchedulingV1PriorityClass<ResponseContentType extends ResponseContentType$createSchedulingV1PriorityClass>(params: Params$createSchedulingV1PriorityClass<ResponseContentType>, option?: RequestOption): Promise<(Response$createSchedulingV1PriorityClass$Status$200 | Response$createSchedulingV1PriorityClass$Status$201 | Response$createSchedulingV1PriorityClass$Status$202)[ResponseContentType]>;
    /**
     * delete collection of PriorityClass
     * operationId: deleteSchedulingV1CollectionPriorityClass
     * Request URI: /apis/scheduling.k8s.io/v1/priorityclasses
     */
    deleteSchedulingV1CollectionPriorityClass<ResponseContentType extends ResponseContentType$deleteSchedulingV1CollectionPriorityClass>(params: Params$deleteSchedulingV1CollectionPriorityClass<ResponseContentType>, option?: RequestOption): Promise<Response$deleteSchedulingV1CollectionPriorityClass$Status$200[ResponseContentType]>;
    /**
     * read the specified PriorityClass
     * operationId: readSchedulingV1PriorityClass
     * Request URI: /apis/scheduling.k8s.io/v1/priorityclasses/{name}
     */
    readSchedulingV1PriorityClass<ResponseContentType extends ResponseContentType$readSchedulingV1PriorityClass>(params: Params$readSchedulingV1PriorityClass<ResponseContentType>, option?: RequestOption): Promise<Response$readSchedulingV1PriorityClass$Status$200[ResponseContentType]>;
    /**
     * replace the specified PriorityClass
     * operationId: replaceSchedulingV1PriorityClass
     * Request URI: /apis/scheduling.k8s.io/v1/priorityclasses/{name}
     */
    replaceSchedulingV1PriorityClass<ResponseContentType extends ResponseContentType$replaceSchedulingV1PriorityClass>(params: Params$replaceSchedulingV1PriorityClass<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceSchedulingV1PriorityClass$Status$200 | Response$replaceSchedulingV1PriorityClass$Status$201)[ResponseContentType]>;
    /**
     * delete a PriorityClass
     * operationId: deleteSchedulingV1PriorityClass
     * Request URI: /apis/scheduling.k8s.io/v1/priorityclasses/{name}
     */
    deleteSchedulingV1PriorityClass<ResponseContentType extends ResponseContentType$deleteSchedulingV1PriorityClass>(params: Params$deleteSchedulingV1PriorityClass<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteSchedulingV1PriorityClass$Status$200 | Response$deleteSchedulingV1PriorityClass$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified PriorityClass
     * operationId: patchSchedulingV1PriorityClass
     * Request URI: /apis/scheduling.k8s.io/v1/priorityclasses/{name}
     */
    patchSchedulingV1PriorityClass<RequestContentType extends RequestContentType$patchSchedulingV1PriorityClass, ResponseContentType extends ResponseContentType$patchSchedulingV1PriorityClass>(params: Params$patchSchedulingV1PriorityClass<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchSchedulingV1PriorityClass$Status$200 | Response$patchSchedulingV1PriorityClass$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of PriorityClass. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchSchedulingV1PriorityClassList
     * Request URI: /apis/scheduling.k8s.io/v1/watch/priorityclasses
     */
    watchSchedulingV1PriorityClassList<ResponseContentType extends ResponseContentType$watchSchedulingV1PriorityClassList>(params: Params$watchSchedulingV1PriorityClassList<ResponseContentType>, option?: RequestOption): Promise<Response$watchSchedulingV1PriorityClassList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind PriorityClass. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchSchedulingV1PriorityClass
     * Request URI: /apis/scheduling.k8s.io/v1/watch/priorityclasses/{name}
     */
    watchSchedulingV1PriorityClass<ResponseContentType extends ResponseContentType$watchSchedulingV1PriorityClass>(params: Params$watchSchedulingV1PriorityClass<ResponseContentType>, option?: RequestOption): Promise<Response$watchSchedulingV1PriorityClass$Status$200[ResponseContentType]>;
    /**
     * get information of a group
     * operationId: getStorageAPIGroup
     * Request URI: /apis/storage.k8s.io/
     */
    getStorageAPIGroup<ResponseContentType extends ResponseContentType$getStorageAPIGroup>(params: Params$getStorageAPIGroup<ResponseContentType>, option?: RequestOption): Promise<Response$getStorageAPIGroup$Status$200[ResponseContentType]>;
    /**
     * get available resources
     * operationId: getStorageV1APIResources
     * Request URI: /apis/storage.k8s.io/v1/
     */
    getStorageV1APIResources<ResponseContentType extends ResponseContentType$getStorageV1APIResources>(params: Params$getStorageV1APIResources<ResponseContentType>, option?: RequestOption): Promise<Response$getStorageV1APIResources$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind CSIDriver
     * operationId: listStorageV1CSIDriver
     * Request URI: /apis/storage.k8s.io/v1/csidrivers
     */
    listStorageV1CSIDriver<ResponseContentType extends ResponseContentType$listStorageV1CSIDriver>(params: Params$listStorageV1CSIDriver<ResponseContentType>, option?: RequestOption): Promise<Response$listStorageV1CSIDriver$Status$200[ResponseContentType]>;
    /**
     * create a CSIDriver
     * operationId: createStorageV1CSIDriver
     * Request URI: /apis/storage.k8s.io/v1/csidrivers
     */
    createStorageV1CSIDriver<ResponseContentType extends ResponseContentType$createStorageV1CSIDriver>(params: Params$createStorageV1CSIDriver<ResponseContentType>, option?: RequestOption): Promise<(Response$createStorageV1CSIDriver$Status$200 | Response$createStorageV1CSIDriver$Status$201 | Response$createStorageV1CSIDriver$Status$202)[ResponseContentType]>;
    /**
     * delete collection of CSIDriver
     * operationId: deleteStorageV1CollectionCSIDriver
     * Request URI: /apis/storage.k8s.io/v1/csidrivers
     */
    deleteStorageV1CollectionCSIDriver<ResponseContentType extends ResponseContentType$deleteStorageV1CollectionCSIDriver>(params: Params$deleteStorageV1CollectionCSIDriver<ResponseContentType>, option?: RequestOption): Promise<Response$deleteStorageV1CollectionCSIDriver$Status$200[ResponseContentType]>;
    /**
     * read the specified CSIDriver
     * operationId: readStorageV1CSIDriver
     * Request URI: /apis/storage.k8s.io/v1/csidrivers/{name}
     */
    readStorageV1CSIDriver<ResponseContentType extends ResponseContentType$readStorageV1CSIDriver>(params: Params$readStorageV1CSIDriver<ResponseContentType>, option?: RequestOption): Promise<Response$readStorageV1CSIDriver$Status$200[ResponseContentType]>;
    /**
     * replace the specified CSIDriver
     * operationId: replaceStorageV1CSIDriver
     * Request URI: /apis/storage.k8s.io/v1/csidrivers/{name}
     */
    replaceStorageV1CSIDriver<ResponseContentType extends ResponseContentType$replaceStorageV1CSIDriver>(params: Params$replaceStorageV1CSIDriver<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceStorageV1CSIDriver$Status$200 | Response$replaceStorageV1CSIDriver$Status$201)[ResponseContentType]>;
    /**
     * delete a CSIDriver
     * operationId: deleteStorageV1CSIDriver
     * Request URI: /apis/storage.k8s.io/v1/csidrivers/{name}
     */
    deleteStorageV1CSIDriver<ResponseContentType extends ResponseContentType$deleteStorageV1CSIDriver>(params: Params$deleteStorageV1CSIDriver<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteStorageV1CSIDriver$Status$200 | Response$deleteStorageV1CSIDriver$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified CSIDriver
     * operationId: patchStorageV1CSIDriver
     * Request URI: /apis/storage.k8s.io/v1/csidrivers/{name}
     */
    patchStorageV1CSIDriver<RequestContentType extends RequestContentType$patchStorageV1CSIDriver, ResponseContentType extends ResponseContentType$patchStorageV1CSIDriver>(params: Params$patchStorageV1CSIDriver<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchStorageV1CSIDriver$Status$200 | Response$patchStorageV1CSIDriver$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind CSINode
     * operationId: listStorageV1CSINode
     * Request URI: /apis/storage.k8s.io/v1/csinodes
     */
    listStorageV1CSINode<ResponseContentType extends ResponseContentType$listStorageV1CSINode>(params: Params$listStorageV1CSINode<ResponseContentType>, option?: RequestOption): Promise<Response$listStorageV1CSINode$Status$200[ResponseContentType]>;
    /**
     * create a CSINode
     * operationId: createStorageV1CSINode
     * Request URI: /apis/storage.k8s.io/v1/csinodes
     */
    createStorageV1CSINode<ResponseContentType extends ResponseContentType$createStorageV1CSINode>(params: Params$createStorageV1CSINode<ResponseContentType>, option?: RequestOption): Promise<(Response$createStorageV1CSINode$Status$200 | Response$createStorageV1CSINode$Status$201 | Response$createStorageV1CSINode$Status$202)[ResponseContentType]>;
    /**
     * delete collection of CSINode
     * operationId: deleteStorageV1CollectionCSINode
     * Request URI: /apis/storage.k8s.io/v1/csinodes
     */
    deleteStorageV1CollectionCSINode<ResponseContentType extends ResponseContentType$deleteStorageV1CollectionCSINode>(params: Params$deleteStorageV1CollectionCSINode<ResponseContentType>, option?: RequestOption): Promise<Response$deleteStorageV1CollectionCSINode$Status$200[ResponseContentType]>;
    /**
     * read the specified CSINode
     * operationId: readStorageV1CSINode
     * Request URI: /apis/storage.k8s.io/v1/csinodes/{name}
     */
    readStorageV1CSINode<ResponseContentType extends ResponseContentType$readStorageV1CSINode>(params: Params$readStorageV1CSINode<ResponseContentType>, option?: RequestOption): Promise<Response$readStorageV1CSINode$Status$200[ResponseContentType]>;
    /**
     * replace the specified CSINode
     * operationId: replaceStorageV1CSINode
     * Request URI: /apis/storage.k8s.io/v1/csinodes/{name}
     */
    replaceStorageV1CSINode<ResponseContentType extends ResponseContentType$replaceStorageV1CSINode>(params: Params$replaceStorageV1CSINode<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceStorageV1CSINode$Status$200 | Response$replaceStorageV1CSINode$Status$201)[ResponseContentType]>;
    /**
     * delete a CSINode
     * operationId: deleteStorageV1CSINode
     * Request URI: /apis/storage.k8s.io/v1/csinodes/{name}
     */
    deleteStorageV1CSINode<ResponseContentType extends ResponseContentType$deleteStorageV1CSINode>(params: Params$deleteStorageV1CSINode<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteStorageV1CSINode$Status$200 | Response$deleteStorageV1CSINode$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified CSINode
     * operationId: patchStorageV1CSINode
     * Request URI: /apis/storage.k8s.io/v1/csinodes/{name}
     */
    patchStorageV1CSINode<RequestContentType extends RequestContentType$patchStorageV1CSINode, ResponseContentType extends ResponseContentType$patchStorageV1CSINode>(params: Params$patchStorageV1CSINode<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchStorageV1CSINode$Status$200 | Response$patchStorageV1CSINode$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind CSIStorageCapacity
     * operationId: listStorageV1CSIStorageCapacityForAllNamespaces
     * Request URI: /apis/storage.k8s.io/v1/csistoragecapacities
     */
    listStorageV1CSIStorageCapacityForAllNamespaces<ResponseContentType extends ResponseContentType$listStorageV1CSIStorageCapacityForAllNamespaces>(params: Params$listStorageV1CSIStorageCapacityForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$listStorageV1CSIStorageCapacityForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * list or watch objects of kind CSIStorageCapacity
     * operationId: listStorageV1NamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1/namespaces/{namespace}/csistoragecapacities
     */
    listStorageV1NamespacedCSIStorageCapacity<ResponseContentType extends ResponseContentType$listStorageV1NamespacedCSIStorageCapacity>(params: Params$listStorageV1NamespacedCSIStorageCapacity<ResponseContentType>, option?: RequestOption): Promise<Response$listStorageV1NamespacedCSIStorageCapacity$Status$200[ResponseContentType]>;
    /**
     * create a CSIStorageCapacity
     * operationId: createStorageV1NamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1/namespaces/{namespace}/csistoragecapacities
     */
    createStorageV1NamespacedCSIStorageCapacity<ResponseContentType extends ResponseContentType$createStorageV1NamespacedCSIStorageCapacity>(params: Params$createStorageV1NamespacedCSIStorageCapacity<ResponseContentType>, option?: RequestOption): Promise<(Response$createStorageV1NamespacedCSIStorageCapacity$Status$200 | Response$createStorageV1NamespacedCSIStorageCapacity$Status$201 | Response$createStorageV1NamespacedCSIStorageCapacity$Status$202)[ResponseContentType]>;
    /**
     * delete collection of CSIStorageCapacity
     * operationId: deleteStorageV1CollectionNamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1/namespaces/{namespace}/csistoragecapacities
     */
    deleteStorageV1CollectionNamespacedCSIStorageCapacity<ResponseContentType extends ResponseContentType$deleteStorageV1CollectionNamespacedCSIStorageCapacity>(params: Params$deleteStorageV1CollectionNamespacedCSIStorageCapacity<ResponseContentType>, option?: RequestOption): Promise<Response$deleteStorageV1CollectionNamespacedCSIStorageCapacity$Status$200[ResponseContentType]>;
    /**
     * read the specified CSIStorageCapacity
     * operationId: readStorageV1NamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1/namespaces/{namespace}/csistoragecapacities/{name}
     */
    readStorageV1NamespacedCSIStorageCapacity<ResponseContentType extends ResponseContentType$readStorageV1NamespacedCSIStorageCapacity>(params: Params$readStorageV1NamespacedCSIStorageCapacity<ResponseContentType>, option?: RequestOption): Promise<Response$readStorageV1NamespacedCSIStorageCapacity$Status$200[ResponseContentType]>;
    /**
     * replace the specified CSIStorageCapacity
     * operationId: replaceStorageV1NamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1/namespaces/{namespace}/csistoragecapacities/{name}
     */
    replaceStorageV1NamespacedCSIStorageCapacity<ResponseContentType extends ResponseContentType$replaceStorageV1NamespacedCSIStorageCapacity>(params: Params$replaceStorageV1NamespacedCSIStorageCapacity<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceStorageV1NamespacedCSIStorageCapacity$Status$200 | Response$replaceStorageV1NamespacedCSIStorageCapacity$Status$201)[ResponseContentType]>;
    /**
     * delete a CSIStorageCapacity
     * operationId: deleteStorageV1NamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1/namespaces/{namespace}/csistoragecapacities/{name}
     */
    deleteStorageV1NamespacedCSIStorageCapacity<ResponseContentType extends ResponseContentType$deleteStorageV1NamespacedCSIStorageCapacity>(params: Params$deleteStorageV1NamespacedCSIStorageCapacity<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteStorageV1NamespacedCSIStorageCapacity$Status$200 | Response$deleteStorageV1NamespacedCSIStorageCapacity$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified CSIStorageCapacity
     * operationId: patchStorageV1NamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1/namespaces/{namespace}/csistoragecapacities/{name}
     */
    patchStorageV1NamespacedCSIStorageCapacity<RequestContentType extends RequestContentType$patchStorageV1NamespacedCSIStorageCapacity, ResponseContentType extends ResponseContentType$patchStorageV1NamespacedCSIStorageCapacity>(params: Params$patchStorageV1NamespacedCSIStorageCapacity<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchStorageV1NamespacedCSIStorageCapacity$Status$200 | Response$patchStorageV1NamespacedCSIStorageCapacity$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind StorageClass
     * operationId: listStorageV1StorageClass
     * Request URI: /apis/storage.k8s.io/v1/storageclasses
     */
    listStorageV1StorageClass<ResponseContentType extends ResponseContentType$listStorageV1StorageClass>(params: Params$listStorageV1StorageClass<ResponseContentType>, option?: RequestOption): Promise<Response$listStorageV1StorageClass$Status$200[ResponseContentType]>;
    /**
     * create a StorageClass
     * operationId: createStorageV1StorageClass
     * Request URI: /apis/storage.k8s.io/v1/storageclasses
     */
    createStorageV1StorageClass<ResponseContentType extends ResponseContentType$createStorageV1StorageClass>(params: Params$createStorageV1StorageClass<ResponseContentType>, option?: RequestOption): Promise<(Response$createStorageV1StorageClass$Status$200 | Response$createStorageV1StorageClass$Status$201 | Response$createStorageV1StorageClass$Status$202)[ResponseContentType]>;
    /**
     * delete collection of StorageClass
     * operationId: deleteStorageV1CollectionStorageClass
     * Request URI: /apis/storage.k8s.io/v1/storageclasses
     */
    deleteStorageV1CollectionStorageClass<ResponseContentType extends ResponseContentType$deleteStorageV1CollectionStorageClass>(params: Params$deleteStorageV1CollectionStorageClass<ResponseContentType>, option?: RequestOption): Promise<Response$deleteStorageV1CollectionStorageClass$Status$200[ResponseContentType]>;
    /**
     * read the specified StorageClass
     * operationId: readStorageV1StorageClass
     * Request URI: /apis/storage.k8s.io/v1/storageclasses/{name}
     */
    readStorageV1StorageClass<ResponseContentType extends ResponseContentType$readStorageV1StorageClass>(params: Params$readStorageV1StorageClass<ResponseContentType>, option?: RequestOption): Promise<Response$readStorageV1StorageClass$Status$200[ResponseContentType]>;
    /**
     * replace the specified StorageClass
     * operationId: replaceStorageV1StorageClass
     * Request URI: /apis/storage.k8s.io/v1/storageclasses/{name}
     */
    replaceStorageV1StorageClass<ResponseContentType extends ResponseContentType$replaceStorageV1StorageClass>(params: Params$replaceStorageV1StorageClass<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceStorageV1StorageClass$Status$200 | Response$replaceStorageV1StorageClass$Status$201)[ResponseContentType]>;
    /**
     * delete a StorageClass
     * operationId: deleteStorageV1StorageClass
     * Request URI: /apis/storage.k8s.io/v1/storageclasses/{name}
     */
    deleteStorageV1StorageClass<ResponseContentType extends ResponseContentType$deleteStorageV1StorageClass>(params: Params$deleteStorageV1StorageClass<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteStorageV1StorageClass$Status$200 | Response$deleteStorageV1StorageClass$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified StorageClass
     * operationId: patchStorageV1StorageClass
     * Request URI: /apis/storage.k8s.io/v1/storageclasses/{name}
     */
    patchStorageV1StorageClass<RequestContentType extends RequestContentType$patchStorageV1StorageClass, ResponseContentType extends ResponseContentType$patchStorageV1StorageClass>(params: Params$patchStorageV1StorageClass<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchStorageV1StorageClass$Status$200 | Response$patchStorageV1StorageClass$Status$201)[ResponseContentType]>;
    /**
     * list or watch objects of kind VolumeAttachment
     * operationId: listStorageV1VolumeAttachment
     * Request URI: /apis/storage.k8s.io/v1/volumeattachments
     */
    listStorageV1VolumeAttachment<ResponseContentType extends ResponseContentType$listStorageV1VolumeAttachment>(params: Params$listStorageV1VolumeAttachment<ResponseContentType>, option?: RequestOption): Promise<Response$listStorageV1VolumeAttachment$Status$200[ResponseContentType]>;
    /**
     * create a VolumeAttachment
     * operationId: createStorageV1VolumeAttachment
     * Request URI: /apis/storage.k8s.io/v1/volumeattachments
     */
    createStorageV1VolumeAttachment<ResponseContentType extends ResponseContentType$createStorageV1VolumeAttachment>(params: Params$createStorageV1VolumeAttachment<ResponseContentType>, option?: RequestOption): Promise<(Response$createStorageV1VolumeAttachment$Status$200 | Response$createStorageV1VolumeAttachment$Status$201 | Response$createStorageV1VolumeAttachment$Status$202)[ResponseContentType]>;
    /**
     * delete collection of VolumeAttachment
     * operationId: deleteStorageV1CollectionVolumeAttachment
     * Request URI: /apis/storage.k8s.io/v1/volumeattachments
     */
    deleteStorageV1CollectionVolumeAttachment<ResponseContentType extends ResponseContentType$deleteStorageV1CollectionVolumeAttachment>(params: Params$deleteStorageV1CollectionVolumeAttachment<ResponseContentType>, option?: RequestOption): Promise<Response$deleteStorageV1CollectionVolumeAttachment$Status$200[ResponseContentType]>;
    /**
     * read the specified VolumeAttachment
     * operationId: readStorageV1VolumeAttachment
     * Request URI: /apis/storage.k8s.io/v1/volumeattachments/{name}
     */
    readStorageV1VolumeAttachment<ResponseContentType extends ResponseContentType$readStorageV1VolumeAttachment>(params: Params$readStorageV1VolumeAttachment<ResponseContentType>, option?: RequestOption): Promise<Response$readStorageV1VolumeAttachment$Status$200[ResponseContentType]>;
    /**
     * replace the specified VolumeAttachment
     * operationId: replaceStorageV1VolumeAttachment
     * Request URI: /apis/storage.k8s.io/v1/volumeattachments/{name}
     */
    replaceStorageV1VolumeAttachment<ResponseContentType extends ResponseContentType$replaceStorageV1VolumeAttachment>(params: Params$replaceStorageV1VolumeAttachment<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceStorageV1VolumeAttachment$Status$200 | Response$replaceStorageV1VolumeAttachment$Status$201)[ResponseContentType]>;
    /**
     * delete a VolumeAttachment
     * operationId: deleteStorageV1VolumeAttachment
     * Request URI: /apis/storage.k8s.io/v1/volumeattachments/{name}
     */
    deleteStorageV1VolumeAttachment<ResponseContentType extends ResponseContentType$deleteStorageV1VolumeAttachment>(params: Params$deleteStorageV1VolumeAttachment<ResponseContentType>, option?: RequestOption): Promise<(Response$deleteStorageV1VolumeAttachment$Status$200 | Response$deleteStorageV1VolumeAttachment$Status$202)[ResponseContentType]>;
    /**
     * partially update the specified VolumeAttachment
     * operationId: patchStorageV1VolumeAttachment
     * Request URI: /apis/storage.k8s.io/v1/volumeattachments/{name}
     */
    patchStorageV1VolumeAttachment<RequestContentType extends RequestContentType$patchStorageV1VolumeAttachment, ResponseContentType extends ResponseContentType$patchStorageV1VolumeAttachment>(params: Params$patchStorageV1VolumeAttachment<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchStorageV1VolumeAttachment$Status$200 | Response$patchStorageV1VolumeAttachment$Status$201)[ResponseContentType]>;
    /**
     * read status of the specified VolumeAttachment
     * operationId: readStorageV1VolumeAttachmentStatus
     * Request URI: /apis/storage.k8s.io/v1/volumeattachments/{name}/status
     */
    readStorageV1VolumeAttachmentStatus<ResponseContentType extends ResponseContentType$readStorageV1VolumeAttachmentStatus>(params: Params$readStorageV1VolumeAttachmentStatus<ResponseContentType>, option?: RequestOption): Promise<Response$readStorageV1VolumeAttachmentStatus$Status$200[ResponseContentType]>;
    /**
     * replace status of the specified VolumeAttachment
     * operationId: replaceStorageV1VolumeAttachmentStatus
     * Request URI: /apis/storage.k8s.io/v1/volumeattachments/{name}/status
     */
    replaceStorageV1VolumeAttachmentStatus<ResponseContentType extends ResponseContentType$replaceStorageV1VolumeAttachmentStatus>(params: Params$replaceStorageV1VolumeAttachmentStatus<ResponseContentType>, option?: RequestOption): Promise<(Response$replaceStorageV1VolumeAttachmentStatus$Status$200 | Response$replaceStorageV1VolumeAttachmentStatus$Status$201)[ResponseContentType]>;
    /**
     * partially update status of the specified VolumeAttachment
     * operationId: patchStorageV1VolumeAttachmentStatus
     * Request URI: /apis/storage.k8s.io/v1/volumeattachments/{name}/status
     */
    patchStorageV1VolumeAttachmentStatus<RequestContentType extends RequestContentType$patchStorageV1VolumeAttachmentStatus, ResponseContentType extends ResponseContentType$patchStorageV1VolumeAttachmentStatus>(params: Params$patchStorageV1VolumeAttachmentStatus<RequestContentType, ResponseContentType>, option?: RequestOption): Promise<(Response$patchStorageV1VolumeAttachmentStatus$Status$200 | Response$patchStorageV1VolumeAttachmentStatus$Status$201)[ResponseContentType]>;
    /**
     * watch individual changes to a list of CSIDriver. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchStorageV1CSIDriverList
     * Request URI: /apis/storage.k8s.io/v1/watch/csidrivers
     */
    watchStorageV1CSIDriverList<ResponseContentType extends ResponseContentType$watchStorageV1CSIDriverList>(params: Params$watchStorageV1CSIDriverList<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1CSIDriverList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind CSIDriver. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchStorageV1CSIDriver
     * Request URI: /apis/storage.k8s.io/v1/watch/csidrivers/{name}
     */
    watchStorageV1CSIDriver<ResponseContentType extends ResponseContentType$watchStorageV1CSIDriver>(params: Params$watchStorageV1CSIDriver<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1CSIDriver$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of CSINode. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchStorageV1CSINodeList
     * Request URI: /apis/storage.k8s.io/v1/watch/csinodes
     */
    watchStorageV1CSINodeList<ResponseContentType extends ResponseContentType$watchStorageV1CSINodeList>(params: Params$watchStorageV1CSINodeList<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1CSINodeList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind CSINode. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchStorageV1CSINode
     * Request URI: /apis/storage.k8s.io/v1/watch/csinodes/{name}
     */
    watchStorageV1CSINode<ResponseContentType extends ResponseContentType$watchStorageV1CSINode>(params: Params$watchStorageV1CSINode<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1CSINode$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of CSIStorageCapacity. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchStorageV1CSIStorageCapacityListForAllNamespaces
     * Request URI: /apis/storage.k8s.io/v1/watch/csistoragecapacities
     */
    watchStorageV1CSIStorageCapacityListForAllNamespaces<ResponseContentType extends ResponseContentType$watchStorageV1CSIStorageCapacityListForAllNamespaces>(params: Params$watchStorageV1CSIStorageCapacityListForAllNamespaces<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1CSIStorageCapacityListForAllNamespaces$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of CSIStorageCapacity. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchStorageV1NamespacedCSIStorageCapacityList
     * Request URI: /apis/storage.k8s.io/v1/watch/namespaces/{namespace}/csistoragecapacities
     */
    watchStorageV1NamespacedCSIStorageCapacityList<ResponseContentType extends ResponseContentType$watchStorageV1NamespacedCSIStorageCapacityList>(params: Params$watchStorageV1NamespacedCSIStorageCapacityList<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1NamespacedCSIStorageCapacityList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind CSIStorageCapacity. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchStorageV1NamespacedCSIStorageCapacity
     * Request URI: /apis/storage.k8s.io/v1/watch/namespaces/{namespace}/csistoragecapacities/{name}
     */
    watchStorageV1NamespacedCSIStorageCapacity<ResponseContentType extends ResponseContentType$watchStorageV1NamespacedCSIStorageCapacity>(params: Params$watchStorageV1NamespacedCSIStorageCapacity<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1NamespacedCSIStorageCapacity$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of StorageClass. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchStorageV1StorageClassList
     * Request URI: /apis/storage.k8s.io/v1/watch/storageclasses
     */
    watchStorageV1StorageClassList<ResponseContentType extends ResponseContentType$watchStorageV1StorageClassList>(params: Params$watchStorageV1StorageClassList<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1StorageClassList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind StorageClass. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchStorageV1StorageClass
     * Request URI: /apis/storage.k8s.io/v1/watch/storageclasses/{name}
     */
    watchStorageV1StorageClass<ResponseContentType extends ResponseContentType$watchStorageV1StorageClass>(params: Params$watchStorageV1StorageClass<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1StorageClass$Status$200[ResponseContentType]>;
    /**
     * watch individual changes to a list of VolumeAttachment. deprecated: use the 'watch' parameter with a list operation instead.
     * operationId: watchStorageV1VolumeAttachmentList
     * Request URI: /apis/storage.k8s.io/v1/watch/volumeattachments
     */
    watchStorageV1VolumeAttachmentList<ResponseContentType extends ResponseContentType$watchStorageV1VolumeAttachmentList>(params: Params$watchStorageV1VolumeAttachmentList<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1VolumeAttachmentList$Status$200[ResponseContentType]>;
    /**
     * watch changes to an object of kind VolumeAttachment. deprecated: use the 'watch' parameter with a list operation instead, filtered to a single item with the 'fieldSelector' parameter.
     * operationId: watchStorageV1VolumeAttachment
     * Request URI: /apis/storage.k8s.io/v1/watch/volumeattachments/{name}
     */
    watchStorageV1VolumeAttachment<ResponseContentType extends ResponseContentType$watchStorageV1VolumeAttachment>(params: Params$watchStorageV1VolumeAttachment<ResponseContentType>, option?: RequestOption): Promise<Response$watchStorageV1VolumeAttachment$Status$200[ResponseContentType]>;
    /**
     * operationId: logFileListHandler
     * Request URI: /logs/
     */
    logFileListHandler(option?: RequestOption): Promise<void>;
    /**
     * operationId: logFileHandler
     * Request URI: /logs/{logpath}
     */
    logFileHandler(params: Params$logFileHandler, option?: RequestOption): Promise<void>;
    /**
     * get service account issuer OpenID JSON Web Key Set (contains public token verification keys)
     * operationId: getServiceAccountIssuerOpenIDKeyset
     * Request URI: /openid/v1/jwks/
     */
    getServiceAccountIssuerOpenIDKeyset(option?: RequestOption): Promise<Response$getServiceAccountIssuerOpenIDKeyset$Status$200["application/jwk-set+json"]>;
    /**
     * get the code version
     * operationId: getCodeVersion
     * Request URI: /version/
     */
    getCodeVersion(option?: RequestOption): Promise<Response$getCodeVersion$Status$200["application/json"]>;
}

export { type ApiClient, Client, type Encoding, ErrorResponse, type HttpMethod, type ObjectLike, type Parameter$connectCoreV1DeleteNamespacedPodProxy, type Parameter$connectCoreV1DeleteNamespacedPodProxyWithPath, type Parameter$connectCoreV1DeleteNamespacedServiceProxy, type Parameter$connectCoreV1DeleteNamespacedServiceProxyWithPath, type Parameter$connectCoreV1DeleteNodeProxy, type Parameter$connectCoreV1DeleteNodeProxyWithPath, type Parameter$connectCoreV1GetNamespacedPodAttach, type Parameter$connectCoreV1GetNamespacedPodExec, type Parameter$connectCoreV1GetNamespacedPodPortforward, type Parameter$connectCoreV1GetNamespacedPodProxy, type Parameter$connectCoreV1GetNamespacedPodProxyWithPath, type Parameter$connectCoreV1GetNamespacedServiceProxy, type Parameter$connectCoreV1GetNamespacedServiceProxyWithPath, type Parameter$connectCoreV1GetNodeProxy, type Parameter$connectCoreV1GetNodeProxyWithPath, type Parameter$connectCoreV1HeadNamespacedPodProxy, type Parameter$connectCoreV1HeadNamespacedPodProxyWithPath, type Parameter$connectCoreV1HeadNamespacedServiceProxy, type Parameter$connectCoreV1HeadNamespacedServiceProxyWithPath, type Parameter$connectCoreV1HeadNodeProxy, type Parameter$connectCoreV1HeadNodeProxyWithPath, type Parameter$connectCoreV1OptionsNamespacedPodProxy, type Parameter$connectCoreV1OptionsNamespacedPodProxyWithPath, type Parameter$connectCoreV1OptionsNamespacedServiceProxy, type Parameter$connectCoreV1OptionsNamespacedServiceProxyWithPath, type Parameter$connectCoreV1OptionsNodeProxy, type Parameter$connectCoreV1OptionsNodeProxyWithPath, type Parameter$connectCoreV1PatchNamespacedPodProxy, type Parameter$connectCoreV1PatchNamespacedPodProxyWithPath, type Parameter$connectCoreV1PatchNamespacedServiceProxy, type Parameter$connectCoreV1PatchNamespacedServiceProxyWithPath, type Parameter$connectCoreV1PatchNodeProxy, type Parameter$connectCoreV1PatchNodeProxyWithPath, type Parameter$connectCoreV1PostNamespacedPodAttach, type Parameter$connectCoreV1PostNamespacedPodExec, type Parameter$connectCoreV1PostNamespacedPodPortforward, type Parameter$connectCoreV1PostNamespacedPodProxy, type Parameter$connectCoreV1PostNamespacedPodProxyWithPath, type Parameter$connectCoreV1PostNamespacedServiceProxy, type Parameter$connectCoreV1PostNamespacedServiceProxyWithPath, type Parameter$connectCoreV1PostNodeProxy, type Parameter$connectCoreV1PostNodeProxyWithPath, type Parameter$connectCoreV1PutNamespacedPodProxy, type Parameter$connectCoreV1PutNamespacedPodProxyWithPath, type Parameter$connectCoreV1PutNamespacedServiceProxy, type Parameter$connectCoreV1PutNamespacedServiceProxyWithPath, type Parameter$connectCoreV1PutNodeProxy, type Parameter$connectCoreV1PutNodeProxyWithPath, type Parameter$createAdmissionregistrationV1MutatingWebhookConfiguration, type Parameter$createAdmissionregistrationV1ValidatingWebhookConfiguration, type Parameter$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type Parameter$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type Parameter$createApiextensionsV1CustomResourceDefinition, type Parameter$createApiregistrationV1APIService, type Parameter$createAppsV1NamespacedControllerRevision, type Parameter$createAppsV1NamespacedDaemonSet, type Parameter$createAppsV1NamespacedDeployment, type Parameter$createAppsV1NamespacedReplicaSet, type Parameter$createAppsV1NamespacedStatefulSet, type Parameter$createAuthenticationV1TokenReview, type Parameter$createAuthenticationV1alpha1SelfSubjectReview, type Parameter$createAuthenticationV1beta1SelfSubjectReview, type Parameter$createAuthorizationV1NamespacedLocalSubjectAccessReview, type Parameter$createAuthorizationV1SelfSubjectAccessReview, type Parameter$createAuthorizationV1SelfSubjectRulesReview, type Parameter$createAuthorizationV1SubjectAccessReview, type Parameter$createAutoscalingV1NamespacedHorizontalPodAutoscaler, type Parameter$createAutoscalingV2NamespacedHorizontalPodAutoscaler, type Parameter$createBatchV1NamespacedCronJob, type Parameter$createBatchV1NamespacedJob, type Parameter$createCertificatesV1CertificateSigningRequest, type Parameter$createCertificatesV1alpha1ClusterTrustBundle, type Parameter$createCoordinationV1NamespacedLease, type Parameter$createCoreV1Namespace, type Parameter$createCoreV1NamespacedBinding, type Parameter$createCoreV1NamespacedConfigMap, type Parameter$createCoreV1NamespacedEndpoints, type Parameter$createCoreV1NamespacedEvent, type Parameter$createCoreV1NamespacedLimitRange, type Parameter$createCoreV1NamespacedPersistentVolumeClaim, type Parameter$createCoreV1NamespacedPod, type Parameter$createCoreV1NamespacedPodBinding, type Parameter$createCoreV1NamespacedPodEviction, type Parameter$createCoreV1NamespacedPodTemplate, type Parameter$createCoreV1NamespacedReplicationController, type Parameter$createCoreV1NamespacedResourceQuota, type Parameter$createCoreV1NamespacedSecret, type Parameter$createCoreV1NamespacedService, type Parameter$createCoreV1NamespacedServiceAccount, type Parameter$createCoreV1NamespacedServiceAccountToken, type Parameter$createCoreV1Node, type Parameter$createCoreV1PersistentVolume, type Parameter$createDiscoveryV1NamespacedEndpointSlice, type Parameter$createEventsV1NamespacedEvent, type Parameter$createFlowcontrolApiserverV1beta2FlowSchema, type Parameter$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type Parameter$createFlowcontrolApiserverV1beta3FlowSchema, type Parameter$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type Parameter$createInternalApiserverV1alpha1StorageVersion, type Parameter$createNetworkingV1IngressClass, type Parameter$createNetworkingV1NamespacedIngress, type Parameter$createNetworkingV1NamespacedNetworkPolicy, type Parameter$createNetworkingV1alpha1ClusterCIDR, type Parameter$createNetworkingV1alpha1IPAddress, type Parameter$createNodeV1RuntimeClass, type Parameter$createPolicyV1NamespacedPodDisruptionBudget, type Parameter$createRbacAuthorizationV1ClusterRole, type Parameter$createRbacAuthorizationV1ClusterRoleBinding, type Parameter$createRbacAuthorizationV1NamespacedRole, type Parameter$createRbacAuthorizationV1NamespacedRoleBinding, type Parameter$createResourceV1alpha2NamespacedPodSchedulingContext, type Parameter$createResourceV1alpha2NamespacedResourceClaim, type Parameter$createResourceV1alpha2NamespacedResourceClaimTemplate, type Parameter$createResourceV1alpha2ResourceClass, type Parameter$createSchedulingV1PriorityClass, type Parameter$createStorageV1CSIDriver, type Parameter$createStorageV1CSINode, type Parameter$createStorageV1NamespacedCSIStorageCapacity, type Parameter$createStorageV1StorageClass, type Parameter$createStorageV1VolumeAttachment, type Parameter$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration, type Parameter$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration, type Parameter$deleteAdmissionregistrationV1MutatingWebhookConfiguration, type Parameter$deleteAdmissionregistrationV1ValidatingWebhookConfiguration, type Parameter$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy, type Parameter$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding, type Parameter$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type Parameter$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type Parameter$deleteApiextensionsV1CollectionCustomResourceDefinition, type Parameter$deleteApiextensionsV1CustomResourceDefinition, type Parameter$deleteApiregistrationV1APIService, type Parameter$deleteApiregistrationV1CollectionAPIService, type Parameter$deleteAppsV1CollectionNamespacedControllerRevision, type Parameter$deleteAppsV1CollectionNamespacedDaemonSet, type Parameter$deleteAppsV1CollectionNamespacedDeployment, type Parameter$deleteAppsV1CollectionNamespacedReplicaSet, type Parameter$deleteAppsV1CollectionNamespacedStatefulSet, type Parameter$deleteAppsV1NamespacedControllerRevision, type Parameter$deleteAppsV1NamespacedDaemonSet, type Parameter$deleteAppsV1NamespacedDeployment, type Parameter$deleteAppsV1NamespacedReplicaSet, type Parameter$deleteAppsV1NamespacedStatefulSet, type Parameter$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler, type Parameter$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler, type Parameter$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler, type Parameter$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler, type Parameter$deleteBatchV1CollectionNamespacedCronJob, type Parameter$deleteBatchV1CollectionNamespacedJob, type Parameter$deleteBatchV1NamespacedCronJob, type Parameter$deleteBatchV1NamespacedJob, type Parameter$deleteCertificatesV1CertificateSigningRequest, type Parameter$deleteCertificatesV1CollectionCertificateSigningRequest, type Parameter$deleteCertificatesV1alpha1ClusterTrustBundle, type Parameter$deleteCertificatesV1alpha1CollectionClusterTrustBundle, type Parameter$deleteCoordinationV1CollectionNamespacedLease, type Parameter$deleteCoordinationV1NamespacedLease, type Parameter$deleteCoreV1CollectionNamespacedConfigMap, type Parameter$deleteCoreV1CollectionNamespacedEndpoints, type Parameter$deleteCoreV1CollectionNamespacedEvent, type Parameter$deleteCoreV1CollectionNamespacedLimitRange, type Parameter$deleteCoreV1CollectionNamespacedPersistentVolumeClaim, type Parameter$deleteCoreV1CollectionNamespacedPod, type Parameter$deleteCoreV1CollectionNamespacedPodTemplate, type Parameter$deleteCoreV1CollectionNamespacedReplicationController, type Parameter$deleteCoreV1CollectionNamespacedResourceQuota, type Parameter$deleteCoreV1CollectionNamespacedSecret, type Parameter$deleteCoreV1CollectionNamespacedService, type Parameter$deleteCoreV1CollectionNamespacedServiceAccount, type Parameter$deleteCoreV1CollectionNode, type Parameter$deleteCoreV1CollectionPersistentVolume, type Parameter$deleteCoreV1Namespace, type Parameter$deleteCoreV1NamespacedConfigMap, type Parameter$deleteCoreV1NamespacedEndpoints, type Parameter$deleteCoreV1NamespacedEvent, type Parameter$deleteCoreV1NamespacedLimitRange, type Parameter$deleteCoreV1NamespacedPersistentVolumeClaim, type Parameter$deleteCoreV1NamespacedPod, type Parameter$deleteCoreV1NamespacedPodTemplate, type Parameter$deleteCoreV1NamespacedReplicationController, type Parameter$deleteCoreV1NamespacedResourceQuota, type Parameter$deleteCoreV1NamespacedSecret, type Parameter$deleteCoreV1NamespacedService, type Parameter$deleteCoreV1NamespacedServiceAccount, type Parameter$deleteCoreV1Node, type Parameter$deleteCoreV1PersistentVolume, type Parameter$deleteDiscoveryV1CollectionNamespacedEndpointSlice, type Parameter$deleteDiscoveryV1NamespacedEndpointSlice, type Parameter$deleteEventsV1CollectionNamespacedEvent, type Parameter$deleteEventsV1NamespacedEvent, type Parameter$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema, type Parameter$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration, type Parameter$deleteFlowcontrolApiserverV1beta2FlowSchema, type Parameter$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type Parameter$deleteFlowcontrolApiserverV1beta3CollectionFlowSchema, type Parameter$deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration, type Parameter$deleteFlowcontrolApiserverV1beta3FlowSchema, type Parameter$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type Parameter$deleteInternalApiserverV1alpha1CollectionStorageVersion, type Parameter$deleteInternalApiserverV1alpha1StorageVersion, type Parameter$deleteNetworkingV1CollectionIngressClass, type Parameter$deleteNetworkingV1CollectionNamespacedIngress, type Parameter$deleteNetworkingV1CollectionNamespacedNetworkPolicy, type Parameter$deleteNetworkingV1IngressClass, type Parameter$deleteNetworkingV1NamespacedIngress, type Parameter$deleteNetworkingV1NamespacedNetworkPolicy, type Parameter$deleteNetworkingV1alpha1ClusterCIDR, type Parameter$deleteNetworkingV1alpha1CollectionClusterCIDR, type Parameter$deleteNetworkingV1alpha1CollectionIPAddress, type Parameter$deleteNetworkingV1alpha1IPAddress, type Parameter$deleteNodeV1CollectionRuntimeClass, type Parameter$deleteNodeV1RuntimeClass, type Parameter$deletePolicyV1CollectionNamespacedPodDisruptionBudget, type Parameter$deletePolicyV1NamespacedPodDisruptionBudget, type Parameter$deleteRbacAuthorizationV1ClusterRole, type Parameter$deleteRbacAuthorizationV1ClusterRoleBinding, type Parameter$deleteRbacAuthorizationV1CollectionClusterRole, type Parameter$deleteRbacAuthorizationV1CollectionClusterRoleBinding, type Parameter$deleteRbacAuthorizationV1CollectionNamespacedRole, type Parameter$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding, type Parameter$deleteRbacAuthorizationV1NamespacedRole, type Parameter$deleteRbacAuthorizationV1NamespacedRoleBinding, type Parameter$deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext, type Parameter$deleteResourceV1alpha2CollectionNamespacedResourceClaim, type Parameter$deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate, type Parameter$deleteResourceV1alpha2CollectionResourceClass, type Parameter$deleteResourceV1alpha2NamespacedPodSchedulingContext, type Parameter$deleteResourceV1alpha2NamespacedResourceClaim, type Parameter$deleteResourceV1alpha2NamespacedResourceClaimTemplate, type Parameter$deleteResourceV1alpha2ResourceClass, type Parameter$deleteSchedulingV1CollectionPriorityClass, type Parameter$deleteSchedulingV1PriorityClass, type Parameter$deleteStorageV1CSIDriver, type Parameter$deleteStorageV1CSINode, type Parameter$deleteStorageV1CollectionCSIDriver, type Parameter$deleteStorageV1CollectionCSINode, type Parameter$deleteStorageV1CollectionNamespacedCSIStorageCapacity, type Parameter$deleteStorageV1CollectionStorageClass, type Parameter$deleteStorageV1CollectionVolumeAttachment, type Parameter$deleteStorageV1NamespacedCSIStorageCapacity, type Parameter$deleteStorageV1StorageClass, type Parameter$deleteStorageV1VolumeAttachment, type Parameter$listAdmissionregistrationV1MutatingWebhookConfiguration, type Parameter$listAdmissionregistrationV1ValidatingWebhookConfiguration, type Parameter$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type Parameter$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type Parameter$listApiextensionsV1CustomResourceDefinition, type Parameter$listApiregistrationV1APIService, type Parameter$listAppsV1ControllerRevisionForAllNamespaces, type Parameter$listAppsV1DaemonSetForAllNamespaces, type Parameter$listAppsV1DeploymentForAllNamespaces, type Parameter$listAppsV1NamespacedControllerRevision, type Parameter$listAppsV1NamespacedDaemonSet, type Parameter$listAppsV1NamespacedDeployment, type Parameter$listAppsV1NamespacedReplicaSet, type Parameter$listAppsV1NamespacedStatefulSet, type Parameter$listAppsV1ReplicaSetForAllNamespaces, type Parameter$listAppsV1StatefulSetForAllNamespaces, type Parameter$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces, type Parameter$listAutoscalingV1NamespacedHorizontalPodAutoscaler, type Parameter$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces, type Parameter$listAutoscalingV2NamespacedHorizontalPodAutoscaler, type Parameter$listBatchV1CronJobForAllNamespaces, type Parameter$listBatchV1JobForAllNamespaces, type Parameter$listBatchV1NamespacedCronJob, type Parameter$listBatchV1NamespacedJob, type Parameter$listCertificatesV1CertificateSigningRequest, type Parameter$listCertificatesV1alpha1ClusterTrustBundle, type Parameter$listCoordinationV1LeaseForAllNamespaces, type Parameter$listCoordinationV1NamespacedLease, type Parameter$listCoreV1ComponentStatus, type Parameter$listCoreV1ConfigMapForAllNamespaces, type Parameter$listCoreV1EndpointsForAllNamespaces, type Parameter$listCoreV1EventForAllNamespaces, type Parameter$listCoreV1LimitRangeForAllNamespaces, type Parameter$listCoreV1Namespace, type Parameter$listCoreV1NamespacedConfigMap, type Parameter$listCoreV1NamespacedEndpoints, type Parameter$listCoreV1NamespacedEvent, type Parameter$listCoreV1NamespacedLimitRange, type Parameter$listCoreV1NamespacedPersistentVolumeClaim, type Parameter$listCoreV1NamespacedPod, type Parameter$listCoreV1NamespacedPodTemplate, type Parameter$listCoreV1NamespacedReplicationController, type Parameter$listCoreV1NamespacedResourceQuota, type Parameter$listCoreV1NamespacedSecret, type Parameter$listCoreV1NamespacedService, type Parameter$listCoreV1NamespacedServiceAccount, type Parameter$listCoreV1Node, type Parameter$listCoreV1PersistentVolume, type Parameter$listCoreV1PersistentVolumeClaimForAllNamespaces, type Parameter$listCoreV1PodForAllNamespaces, type Parameter$listCoreV1PodTemplateForAllNamespaces, type Parameter$listCoreV1ReplicationControllerForAllNamespaces, type Parameter$listCoreV1ResourceQuotaForAllNamespaces, type Parameter$listCoreV1SecretForAllNamespaces, type Parameter$listCoreV1ServiceAccountForAllNamespaces, type Parameter$listCoreV1ServiceForAllNamespaces, type Parameter$listDiscoveryV1EndpointSliceForAllNamespaces, type Parameter$listDiscoveryV1NamespacedEndpointSlice, type Parameter$listEventsV1EventForAllNamespaces, type Parameter$listEventsV1NamespacedEvent, type Parameter$listFlowcontrolApiserverV1beta2FlowSchema, type Parameter$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type Parameter$listFlowcontrolApiserverV1beta3FlowSchema, type Parameter$listFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type Parameter$listInternalApiserverV1alpha1StorageVersion, type Parameter$listNetworkingV1IngressClass, type Parameter$listNetworkingV1IngressForAllNamespaces, type Parameter$listNetworkingV1NamespacedIngress, type Parameter$listNetworkingV1NamespacedNetworkPolicy, type Parameter$listNetworkingV1NetworkPolicyForAllNamespaces, type Parameter$listNetworkingV1alpha1ClusterCIDR, type Parameter$listNetworkingV1alpha1IPAddress, type Parameter$listNodeV1RuntimeClass, type Parameter$listPolicyV1NamespacedPodDisruptionBudget, type Parameter$listPolicyV1PodDisruptionBudgetForAllNamespaces, type Parameter$listRbacAuthorizationV1ClusterRole, type Parameter$listRbacAuthorizationV1ClusterRoleBinding, type Parameter$listRbacAuthorizationV1NamespacedRole, type Parameter$listRbacAuthorizationV1NamespacedRoleBinding, type Parameter$listRbacAuthorizationV1RoleBindingForAllNamespaces, type Parameter$listRbacAuthorizationV1RoleForAllNamespaces, type Parameter$listResourceV1alpha2NamespacedPodSchedulingContext, type Parameter$listResourceV1alpha2NamespacedResourceClaim, type Parameter$listResourceV1alpha2NamespacedResourceClaimTemplate, type Parameter$listResourceV1alpha2PodSchedulingContextForAllNamespaces, type Parameter$listResourceV1alpha2ResourceClaimForAllNamespaces, type Parameter$listResourceV1alpha2ResourceClaimTemplateForAllNamespaces, type Parameter$listResourceV1alpha2ResourceClass, type Parameter$listSchedulingV1PriorityClass, type Parameter$listStorageV1CSIDriver, type Parameter$listStorageV1CSINode, type Parameter$listStorageV1CSIStorageCapacityForAllNamespaces, type Parameter$listStorageV1NamespacedCSIStorageCapacity, type Parameter$listStorageV1StorageClass, type Parameter$listStorageV1VolumeAttachment, type Parameter$logFileHandler, type Parameter$patchAdmissionregistrationV1MutatingWebhookConfiguration, type Parameter$patchAdmissionregistrationV1ValidatingWebhookConfiguration, type Parameter$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type Parameter$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type Parameter$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus, type Parameter$patchApiextensionsV1CustomResourceDefinition, type Parameter$patchApiextensionsV1CustomResourceDefinitionStatus, type Parameter$patchApiregistrationV1APIService, type Parameter$patchApiregistrationV1APIServiceStatus, type Parameter$patchAppsV1NamespacedControllerRevision, type Parameter$patchAppsV1NamespacedDaemonSet, type Parameter$patchAppsV1NamespacedDaemonSetStatus, type Parameter$patchAppsV1NamespacedDeployment, type Parameter$patchAppsV1NamespacedDeploymentScale, type Parameter$patchAppsV1NamespacedDeploymentStatus, type Parameter$patchAppsV1NamespacedReplicaSet, type Parameter$patchAppsV1NamespacedReplicaSetScale, type Parameter$patchAppsV1NamespacedReplicaSetStatus, type Parameter$patchAppsV1NamespacedStatefulSet, type Parameter$patchAppsV1NamespacedStatefulSetScale, type Parameter$patchAppsV1NamespacedStatefulSetStatus, type Parameter$patchAutoscalingV1NamespacedHorizontalPodAutoscaler, type Parameter$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus, type Parameter$patchAutoscalingV2NamespacedHorizontalPodAutoscaler, type Parameter$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus, type Parameter$patchBatchV1NamespacedCronJob, type Parameter$patchBatchV1NamespacedCronJobStatus, type Parameter$patchBatchV1NamespacedJob, type Parameter$patchBatchV1NamespacedJobStatus, type Parameter$patchCertificatesV1CertificateSigningRequest, type Parameter$patchCertificatesV1CertificateSigningRequestApproval, type Parameter$patchCertificatesV1CertificateSigningRequestStatus, type Parameter$patchCertificatesV1alpha1ClusterTrustBundle, type Parameter$patchCoordinationV1NamespacedLease, type Parameter$patchCoreV1Namespace, type Parameter$patchCoreV1NamespaceStatus, type Parameter$patchCoreV1NamespacedConfigMap, type Parameter$patchCoreV1NamespacedEndpoints, type Parameter$patchCoreV1NamespacedEvent, type Parameter$patchCoreV1NamespacedLimitRange, type Parameter$patchCoreV1NamespacedPersistentVolumeClaim, type Parameter$patchCoreV1NamespacedPersistentVolumeClaimStatus, type Parameter$patchCoreV1NamespacedPod, type Parameter$patchCoreV1NamespacedPodEphemeralcontainers, type Parameter$patchCoreV1NamespacedPodStatus, type Parameter$patchCoreV1NamespacedPodTemplate, type Parameter$patchCoreV1NamespacedReplicationController, type Parameter$patchCoreV1NamespacedReplicationControllerScale, type Parameter$patchCoreV1NamespacedReplicationControllerStatus, type Parameter$patchCoreV1NamespacedResourceQuota, type Parameter$patchCoreV1NamespacedResourceQuotaStatus, type Parameter$patchCoreV1NamespacedSecret, type Parameter$patchCoreV1NamespacedService, type Parameter$patchCoreV1NamespacedServiceAccount, type Parameter$patchCoreV1NamespacedServiceStatus, type Parameter$patchCoreV1Node, type Parameter$patchCoreV1NodeStatus, type Parameter$patchCoreV1PersistentVolume, type Parameter$patchCoreV1PersistentVolumeStatus, type Parameter$patchDiscoveryV1NamespacedEndpointSlice, type Parameter$patchEventsV1NamespacedEvent, type Parameter$patchFlowcontrolApiserverV1beta2FlowSchema, type Parameter$patchFlowcontrolApiserverV1beta2FlowSchemaStatus, type Parameter$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type Parameter$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus, type Parameter$patchFlowcontrolApiserverV1beta3FlowSchema, type Parameter$patchFlowcontrolApiserverV1beta3FlowSchemaStatus, type Parameter$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type Parameter$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus, type Parameter$patchInternalApiserverV1alpha1StorageVersion, type Parameter$patchInternalApiserverV1alpha1StorageVersionStatus, type Parameter$patchNetworkingV1IngressClass, type Parameter$patchNetworkingV1NamespacedIngress, type Parameter$patchNetworkingV1NamespacedIngressStatus, type Parameter$patchNetworkingV1NamespacedNetworkPolicy, type Parameter$patchNetworkingV1NamespacedNetworkPolicyStatus, type Parameter$patchNetworkingV1alpha1ClusterCIDR, type Parameter$patchNetworkingV1alpha1IPAddress, type Parameter$patchNodeV1RuntimeClass, type Parameter$patchPolicyV1NamespacedPodDisruptionBudget, type Parameter$patchPolicyV1NamespacedPodDisruptionBudgetStatus, type Parameter$patchRbacAuthorizationV1ClusterRole, type Parameter$patchRbacAuthorizationV1ClusterRoleBinding, type Parameter$patchRbacAuthorizationV1NamespacedRole, type Parameter$patchRbacAuthorizationV1NamespacedRoleBinding, type Parameter$patchResourceV1alpha2NamespacedPodSchedulingContext, type Parameter$patchResourceV1alpha2NamespacedPodSchedulingContextStatus, type Parameter$patchResourceV1alpha2NamespacedResourceClaim, type Parameter$patchResourceV1alpha2NamespacedResourceClaimStatus, type Parameter$patchResourceV1alpha2NamespacedResourceClaimTemplate, type Parameter$patchResourceV1alpha2ResourceClass, type Parameter$patchSchedulingV1PriorityClass, type Parameter$patchStorageV1CSIDriver, type Parameter$patchStorageV1CSINode, type Parameter$patchStorageV1NamespacedCSIStorageCapacity, type Parameter$patchStorageV1StorageClass, type Parameter$patchStorageV1VolumeAttachment, type Parameter$patchStorageV1VolumeAttachmentStatus, type Parameter$readAdmissionregistrationV1MutatingWebhookConfiguration, type Parameter$readAdmissionregistrationV1ValidatingWebhookConfiguration, type Parameter$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type Parameter$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type Parameter$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus, type Parameter$readApiextensionsV1CustomResourceDefinition, type Parameter$readApiextensionsV1CustomResourceDefinitionStatus, type Parameter$readApiregistrationV1APIService, type Parameter$readApiregistrationV1APIServiceStatus, type Parameter$readAppsV1NamespacedControllerRevision, type Parameter$readAppsV1NamespacedDaemonSet, type Parameter$readAppsV1NamespacedDaemonSetStatus, type Parameter$readAppsV1NamespacedDeployment, type Parameter$readAppsV1NamespacedDeploymentScale, type Parameter$readAppsV1NamespacedDeploymentStatus, type Parameter$readAppsV1NamespacedReplicaSet, type Parameter$readAppsV1NamespacedReplicaSetScale, type Parameter$readAppsV1NamespacedReplicaSetStatus, type Parameter$readAppsV1NamespacedStatefulSet, type Parameter$readAppsV1NamespacedStatefulSetScale, type Parameter$readAppsV1NamespacedStatefulSetStatus, type Parameter$readAutoscalingV1NamespacedHorizontalPodAutoscaler, type Parameter$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus, type Parameter$readAutoscalingV2NamespacedHorizontalPodAutoscaler, type Parameter$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus, type Parameter$readBatchV1NamespacedCronJob, type Parameter$readBatchV1NamespacedCronJobStatus, type Parameter$readBatchV1NamespacedJob, type Parameter$readBatchV1NamespacedJobStatus, type Parameter$readCertificatesV1CertificateSigningRequest, type Parameter$readCertificatesV1CertificateSigningRequestApproval, type Parameter$readCertificatesV1CertificateSigningRequestStatus, type Parameter$readCertificatesV1alpha1ClusterTrustBundle, type Parameter$readCoordinationV1NamespacedLease, type Parameter$readCoreV1ComponentStatus, type Parameter$readCoreV1Namespace, type Parameter$readCoreV1NamespaceStatus, type Parameter$readCoreV1NamespacedConfigMap, type Parameter$readCoreV1NamespacedEndpoints, type Parameter$readCoreV1NamespacedEvent, type Parameter$readCoreV1NamespacedLimitRange, type Parameter$readCoreV1NamespacedPersistentVolumeClaim, type Parameter$readCoreV1NamespacedPersistentVolumeClaimStatus, type Parameter$readCoreV1NamespacedPod, type Parameter$readCoreV1NamespacedPodEphemeralcontainers, type Parameter$readCoreV1NamespacedPodLog, type Parameter$readCoreV1NamespacedPodStatus, type Parameter$readCoreV1NamespacedPodTemplate, type Parameter$readCoreV1NamespacedReplicationController, type Parameter$readCoreV1NamespacedReplicationControllerScale, type Parameter$readCoreV1NamespacedReplicationControllerStatus, type Parameter$readCoreV1NamespacedResourceQuota, type Parameter$readCoreV1NamespacedResourceQuotaStatus, type Parameter$readCoreV1NamespacedSecret, type Parameter$readCoreV1NamespacedService, type Parameter$readCoreV1NamespacedServiceAccount, type Parameter$readCoreV1NamespacedServiceStatus, type Parameter$readCoreV1Node, type Parameter$readCoreV1NodeStatus, type Parameter$readCoreV1PersistentVolume, type Parameter$readCoreV1PersistentVolumeStatus, type Parameter$readDiscoveryV1NamespacedEndpointSlice, type Parameter$readEventsV1NamespacedEvent, type Parameter$readFlowcontrolApiserverV1beta2FlowSchema, type Parameter$readFlowcontrolApiserverV1beta2FlowSchemaStatus, type Parameter$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type Parameter$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus, type Parameter$readFlowcontrolApiserverV1beta3FlowSchema, type Parameter$readFlowcontrolApiserverV1beta3FlowSchemaStatus, type Parameter$readFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type Parameter$readFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus, type Parameter$readInternalApiserverV1alpha1StorageVersion, type Parameter$readInternalApiserverV1alpha1StorageVersionStatus, type Parameter$readNetworkingV1IngressClass, type Parameter$readNetworkingV1NamespacedIngress, type Parameter$readNetworkingV1NamespacedIngressStatus, type Parameter$readNetworkingV1NamespacedNetworkPolicy, type Parameter$readNetworkingV1NamespacedNetworkPolicyStatus, type Parameter$readNetworkingV1alpha1ClusterCIDR, type Parameter$readNetworkingV1alpha1IPAddress, type Parameter$readNodeV1RuntimeClass, type Parameter$readPolicyV1NamespacedPodDisruptionBudget, type Parameter$readPolicyV1NamespacedPodDisruptionBudgetStatus, type Parameter$readRbacAuthorizationV1ClusterRole, type Parameter$readRbacAuthorizationV1ClusterRoleBinding, type Parameter$readRbacAuthorizationV1NamespacedRole, type Parameter$readRbacAuthorizationV1NamespacedRoleBinding, type Parameter$readResourceV1alpha2NamespacedPodSchedulingContext, type Parameter$readResourceV1alpha2NamespacedPodSchedulingContextStatus, type Parameter$readResourceV1alpha2NamespacedResourceClaim, type Parameter$readResourceV1alpha2NamespacedResourceClaimStatus, type Parameter$readResourceV1alpha2NamespacedResourceClaimTemplate, type Parameter$readResourceV1alpha2ResourceClass, type Parameter$readSchedulingV1PriorityClass, type Parameter$readStorageV1CSIDriver, type Parameter$readStorageV1CSINode, type Parameter$readStorageV1NamespacedCSIStorageCapacity, type Parameter$readStorageV1StorageClass, type Parameter$readStorageV1VolumeAttachment, type Parameter$readStorageV1VolumeAttachmentStatus, type Parameter$replaceAdmissionregistrationV1MutatingWebhookConfiguration, type Parameter$replaceAdmissionregistrationV1ValidatingWebhookConfiguration, type Parameter$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type Parameter$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type Parameter$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus, type Parameter$replaceApiextensionsV1CustomResourceDefinition, type Parameter$replaceApiextensionsV1CustomResourceDefinitionStatus, type Parameter$replaceApiregistrationV1APIService, type Parameter$replaceApiregistrationV1APIServiceStatus, type Parameter$replaceAppsV1NamespacedControllerRevision, type Parameter$replaceAppsV1NamespacedDaemonSet, type Parameter$replaceAppsV1NamespacedDaemonSetStatus, type Parameter$replaceAppsV1NamespacedDeployment, type Parameter$replaceAppsV1NamespacedDeploymentScale, type Parameter$replaceAppsV1NamespacedDeploymentStatus, type Parameter$replaceAppsV1NamespacedReplicaSet, type Parameter$replaceAppsV1NamespacedReplicaSetScale, type Parameter$replaceAppsV1NamespacedReplicaSetStatus, type Parameter$replaceAppsV1NamespacedStatefulSet, type Parameter$replaceAppsV1NamespacedStatefulSetScale, type Parameter$replaceAppsV1NamespacedStatefulSetStatus, type Parameter$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler, type Parameter$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus, type Parameter$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler, type Parameter$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus, type Parameter$replaceBatchV1NamespacedCronJob, type Parameter$replaceBatchV1NamespacedCronJobStatus, type Parameter$replaceBatchV1NamespacedJob, type Parameter$replaceBatchV1NamespacedJobStatus, type Parameter$replaceCertificatesV1CertificateSigningRequest, type Parameter$replaceCertificatesV1CertificateSigningRequestApproval, type Parameter$replaceCertificatesV1CertificateSigningRequestStatus, type Parameter$replaceCertificatesV1alpha1ClusterTrustBundle, type Parameter$replaceCoordinationV1NamespacedLease, type Parameter$replaceCoreV1Namespace, type Parameter$replaceCoreV1NamespaceFinalize, type Parameter$replaceCoreV1NamespaceStatus, type Parameter$replaceCoreV1NamespacedConfigMap, type Parameter$replaceCoreV1NamespacedEndpoints, type Parameter$replaceCoreV1NamespacedEvent, type Parameter$replaceCoreV1NamespacedLimitRange, type Parameter$replaceCoreV1NamespacedPersistentVolumeClaim, type Parameter$replaceCoreV1NamespacedPersistentVolumeClaimStatus, type Parameter$replaceCoreV1NamespacedPod, type Parameter$replaceCoreV1NamespacedPodEphemeralcontainers, type Parameter$replaceCoreV1NamespacedPodStatus, type Parameter$replaceCoreV1NamespacedPodTemplate, type Parameter$replaceCoreV1NamespacedReplicationController, type Parameter$replaceCoreV1NamespacedReplicationControllerScale, type Parameter$replaceCoreV1NamespacedReplicationControllerStatus, type Parameter$replaceCoreV1NamespacedResourceQuota, type Parameter$replaceCoreV1NamespacedResourceQuotaStatus, type Parameter$replaceCoreV1NamespacedSecret, type Parameter$replaceCoreV1NamespacedService, type Parameter$replaceCoreV1NamespacedServiceAccount, type Parameter$replaceCoreV1NamespacedServiceStatus, type Parameter$replaceCoreV1Node, type Parameter$replaceCoreV1NodeStatus, type Parameter$replaceCoreV1PersistentVolume, type Parameter$replaceCoreV1PersistentVolumeStatus, type Parameter$replaceDiscoveryV1NamespacedEndpointSlice, type Parameter$replaceEventsV1NamespacedEvent, type Parameter$replaceFlowcontrolApiserverV1beta2FlowSchema, type Parameter$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus, type Parameter$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type Parameter$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus, type Parameter$replaceFlowcontrolApiserverV1beta3FlowSchema, type Parameter$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus, type Parameter$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type Parameter$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus, type Parameter$replaceInternalApiserverV1alpha1StorageVersion, type Parameter$replaceInternalApiserverV1alpha1StorageVersionStatus, type Parameter$replaceNetworkingV1IngressClass, type Parameter$replaceNetworkingV1NamespacedIngress, type Parameter$replaceNetworkingV1NamespacedIngressStatus, type Parameter$replaceNetworkingV1NamespacedNetworkPolicy, type Parameter$replaceNetworkingV1NamespacedNetworkPolicyStatus, type Parameter$replaceNetworkingV1alpha1ClusterCIDR, type Parameter$replaceNetworkingV1alpha1IPAddress, type Parameter$replaceNodeV1RuntimeClass, type Parameter$replacePolicyV1NamespacedPodDisruptionBudget, type Parameter$replacePolicyV1NamespacedPodDisruptionBudgetStatus, type Parameter$replaceRbacAuthorizationV1ClusterRole, type Parameter$replaceRbacAuthorizationV1ClusterRoleBinding, type Parameter$replaceRbacAuthorizationV1NamespacedRole, type Parameter$replaceRbacAuthorizationV1NamespacedRoleBinding, type Parameter$replaceResourceV1alpha2NamespacedPodSchedulingContext, type Parameter$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus, type Parameter$replaceResourceV1alpha2NamespacedResourceClaim, type Parameter$replaceResourceV1alpha2NamespacedResourceClaimStatus, type Parameter$replaceResourceV1alpha2NamespacedResourceClaimTemplate, type Parameter$replaceResourceV1alpha2ResourceClass, type Parameter$replaceSchedulingV1PriorityClass, type Parameter$replaceStorageV1CSIDriver, type Parameter$replaceStorageV1CSINode, type Parameter$replaceStorageV1NamespacedCSIStorageCapacity, type Parameter$replaceStorageV1StorageClass, type Parameter$replaceStorageV1VolumeAttachment, type Parameter$replaceStorageV1VolumeAttachmentStatus, type Parameter$watchAdmissionregistrationV1MutatingWebhookConfiguration, type Parameter$watchAdmissionregistrationV1MutatingWebhookConfigurationList, type Parameter$watchAdmissionregistrationV1ValidatingWebhookConfiguration, type Parameter$watchAdmissionregistrationV1ValidatingWebhookConfigurationList, type Parameter$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type Parameter$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type Parameter$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBindingList, type Parameter$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyList, type Parameter$watchApiextensionsV1CustomResourceDefinition, type Parameter$watchApiextensionsV1CustomResourceDefinitionList, type Parameter$watchApiregistrationV1APIService, type Parameter$watchApiregistrationV1APIServiceList, type Parameter$watchAppsV1ControllerRevisionListForAllNamespaces, type Parameter$watchAppsV1DaemonSetListForAllNamespaces, type Parameter$watchAppsV1DeploymentListForAllNamespaces, type Parameter$watchAppsV1NamespacedControllerRevision, type Parameter$watchAppsV1NamespacedControllerRevisionList, type Parameter$watchAppsV1NamespacedDaemonSet, type Parameter$watchAppsV1NamespacedDaemonSetList, type Parameter$watchAppsV1NamespacedDeployment, type Parameter$watchAppsV1NamespacedDeploymentList, type Parameter$watchAppsV1NamespacedReplicaSet, type Parameter$watchAppsV1NamespacedReplicaSetList, type Parameter$watchAppsV1NamespacedStatefulSet, type Parameter$watchAppsV1NamespacedStatefulSetList, type Parameter$watchAppsV1ReplicaSetListForAllNamespaces, type Parameter$watchAppsV1StatefulSetListForAllNamespaces, type Parameter$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces, type Parameter$watchAutoscalingV1NamespacedHorizontalPodAutoscaler, type Parameter$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList, type Parameter$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces, type Parameter$watchAutoscalingV2NamespacedHorizontalPodAutoscaler, type Parameter$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList, type Parameter$watchBatchV1CronJobListForAllNamespaces, type Parameter$watchBatchV1JobListForAllNamespaces, type Parameter$watchBatchV1NamespacedCronJob, type Parameter$watchBatchV1NamespacedCronJobList, type Parameter$watchBatchV1NamespacedJob, type Parameter$watchBatchV1NamespacedJobList, type Parameter$watchCertificatesV1CertificateSigningRequest, type Parameter$watchCertificatesV1CertificateSigningRequestList, type Parameter$watchCertificatesV1alpha1ClusterTrustBundle, type Parameter$watchCertificatesV1alpha1ClusterTrustBundleList, type Parameter$watchCoordinationV1LeaseListForAllNamespaces, type Parameter$watchCoordinationV1NamespacedLease, type Parameter$watchCoordinationV1NamespacedLeaseList, type Parameter$watchCoreV1ConfigMapListForAllNamespaces, type Parameter$watchCoreV1EndpointsListForAllNamespaces, type Parameter$watchCoreV1EventListForAllNamespaces, type Parameter$watchCoreV1LimitRangeListForAllNamespaces, type Parameter$watchCoreV1Namespace, type Parameter$watchCoreV1NamespaceList, type Parameter$watchCoreV1NamespacedConfigMap, type Parameter$watchCoreV1NamespacedConfigMapList, type Parameter$watchCoreV1NamespacedEndpoints, type Parameter$watchCoreV1NamespacedEndpointsList, type Parameter$watchCoreV1NamespacedEvent, type Parameter$watchCoreV1NamespacedEventList, type Parameter$watchCoreV1NamespacedLimitRange, type Parameter$watchCoreV1NamespacedLimitRangeList, type Parameter$watchCoreV1NamespacedPersistentVolumeClaim, type Parameter$watchCoreV1NamespacedPersistentVolumeClaimList, type Parameter$watchCoreV1NamespacedPod, type Parameter$watchCoreV1NamespacedPodList, type Parameter$watchCoreV1NamespacedPodTemplate, type Parameter$watchCoreV1NamespacedPodTemplateList, type Parameter$watchCoreV1NamespacedReplicationController, type Parameter$watchCoreV1NamespacedReplicationControllerList, type Parameter$watchCoreV1NamespacedResourceQuota, type Parameter$watchCoreV1NamespacedResourceQuotaList, type Parameter$watchCoreV1NamespacedSecret, type Parameter$watchCoreV1NamespacedSecretList, type Parameter$watchCoreV1NamespacedService, type Parameter$watchCoreV1NamespacedServiceAccount, type Parameter$watchCoreV1NamespacedServiceAccountList, type Parameter$watchCoreV1NamespacedServiceList, type Parameter$watchCoreV1Node, type Parameter$watchCoreV1NodeList, type Parameter$watchCoreV1PersistentVolume, type Parameter$watchCoreV1PersistentVolumeClaimListForAllNamespaces, type Parameter$watchCoreV1PersistentVolumeList, type Parameter$watchCoreV1PodListForAllNamespaces, type Parameter$watchCoreV1PodTemplateListForAllNamespaces, type Parameter$watchCoreV1ReplicationControllerListForAllNamespaces, type Parameter$watchCoreV1ResourceQuotaListForAllNamespaces, type Parameter$watchCoreV1SecretListForAllNamespaces, type Parameter$watchCoreV1ServiceAccountListForAllNamespaces, type Parameter$watchCoreV1ServiceListForAllNamespaces, type Parameter$watchDiscoveryV1EndpointSliceListForAllNamespaces, type Parameter$watchDiscoveryV1NamespacedEndpointSlice, type Parameter$watchDiscoveryV1NamespacedEndpointSliceList, type Parameter$watchEventsV1EventListForAllNamespaces, type Parameter$watchEventsV1NamespacedEvent, type Parameter$watchEventsV1NamespacedEventList, type Parameter$watchFlowcontrolApiserverV1beta2FlowSchema, type Parameter$watchFlowcontrolApiserverV1beta2FlowSchemaList, type Parameter$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type Parameter$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList, type Parameter$watchFlowcontrolApiserverV1beta3FlowSchema, type Parameter$watchFlowcontrolApiserverV1beta3FlowSchemaList, type Parameter$watchFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type Parameter$watchFlowcontrolApiserverV1beta3PriorityLevelConfigurationList, type Parameter$watchInternalApiserverV1alpha1StorageVersion, type Parameter$watchInternalApiserverV1alpha1StorageVersionList, type Parameter$watchNetworkingV1IngressClass, type Parameter$watchNetworkingV1IngressClassList, type Parameter$watchNetworkingV1IngressListForAllNamespaces, type Parameter$watchNetworkingV1NamespacedIngress, type Parameter$watchNetworkingV1NamespacedIngressList, type Parameter$watchNetworkingV1NamespacedNetworkPolicy, type Parameter$watchNetworkingV1NamespacedNetworkPolicyList, type Parameter$watchNetworkingV1NetworkPolicyListForAllNamespaces, type Parameter$watchNetworkingV1alpha1ClusterCIDR, type Parameter$watchNetworkingV1alpha1ClusterCIDRList, type Parameter$watchNetworkingV1alpha1IPAddress, type Parameter$watchNetworkingV1alpha1IPAddressList, type Parameter$watchNodeV1RuntimeClass, type Parameter$watchNodeV1RuntimeClassList, type Parameter$watchPolicyV1NamespacedPodDisruptionBudget, type Parameter$watchPolicyV1NamespacedPodDisruptionBudgetList, type Parameter$watchPolicyV1PodDisruptionBudgetListForAllNamespaces, type Parameter$watchRbacAuthorizationV1ClusterRole, type Parameter$watchRbacAuthorizationV1ClusterRoleBinding, type Parameter$watchRbacAuthorizationV1ClusterRoleBindingList, type Parameter$watchRbacAuthorizationV1ClusterRoleList, type Parameter$watchRbacAuthorizationV1NamespacedRole, type Parameter$watchRbacAuthorizationV1NamespacedRoleBinding, type Parameter$watchRbacAuthorizationV1NamespacedRoleBindingList, type Parameter$watchRbacAuthorizationV1NamespacedRoleList, type Parameter$watchRbacAuthorizationV1RoleBindingListForAllNamespaces, type Parameter$watchRbacAuthorizationV1RoleListForAllNamespaces, type Parameter$watchResourceV1alpha2NamespacedPodSchedulingContext, type Parameter$watchResourceV1alpha2NamespacedPodSchedulingContextList, type Parameter$watchResourceV1alpha2NamespacedResourceClaim, type Parameter$watchResourceV1alpha2NamespacedResourceClaimList, type Parameter$watchResourceV1alpha2NamespacedResourceClaimTemplate, type Parameter$watchResourceV1alpha2NamespacedResourceClaimTemplateList, type Parameter$watchResourceV1alpha2PodSchedulingContextListForAllNamespaces, type Parameter$watchResourceV1alpha2ResourceClaimListForAllNamespaces, type Parameter$watchResourceV1alpha2ResourceClaimTemplateListForAllNamespaces, type Parameter$watchResourceV1alpha2ResourceClass, type Parameter$watchResourceV1alpha2ResourceClassList, type Parameter$watchSchedulingV1PriorityClass, type Parameter$watchSchedulingV1PriorityClassList, type Parameter$watchStorageV1CSIDriver, type Parameter$watchStorageV1CSIDriverList, type Parameter$watchStorageV1CSINode, type Parameter$watchStorageV1CSINodeList, type Parameter$watchStorageV1CSIStorageCapacityListForAllNamespaces, type Parameter$watchStorageV1NamespacedCSIStorageCapacity, type Parameter$watchStorageV1NamespacedCSIStorageCapacityList, type Parameter$watchStorageV1StorageClass, type Parameter$watchStorageV1StorageClassList, type Parameter$watchStorageV1VolumeAttachment, type Parameter$watchStorageV1VolumeAttachmentList, type Params$connectCoreV1DeleteNamespacedPodProxy, type Params$connectCoreV1DeleteNamespacedPodProxyWithPath, type Params$connectCoreV1DeleteNamespacedServiceProxy, type Params$connectCoreV1DeleteNamespacedServiceProxyWithPath, type Params$connectCoreV1DeleteNodeProxy, type Params$connectCoreV1DeleteNodeProxyWithPath, type Params$connectCoreV1GetNamespacedPodAttach, type Params$connectCoreV1GetNamespacedPodExec, type Params$connectCoreV1GetNamespacedPodPortforward, type Params$connectCoreV1GetNamespacedPodProxy, type Params$connectCoreV1GetNamespacedPodProxyWithPath, type Params$connectCoreV1GetNamespacedServiceProxy, type Params$connectCoreV1GetNamespacedServiceProxyWithPath, type Params$connectCoreV1GetNodeProxy, type Params$connectCoreV1GetNodeProxyWithPath, type Params$connectCoreV1HeadNamespacedPodProxy, type Params$connectCoreV1HeadNamespacedPodProxyWithPath, type Params$connectCoreV1HeadNamespacedServiceProxy, type Params$connectCoreV1HeadNamespacedServiceProxyWithPath, type Params$connectCoreV1HeadNodeProxy, type Params$connectCoreV1HeadNodeProxyWithPath, type Params$connectCoreV1OptionsNamespacedPodProxy, type Params$connectCoreV1OptionsNamespacedPodProxyWithPath, type Params$connectCoreV1OptionsNamespacedServiceProxy, type Params$connectCoreV1OptionsNamespacedServiceProxyWithPath, type Params$connectCoreV1OptionsNodeProxy, type Params$connectCoreV1OptionsNodeProxyWithPath, type Params$connectCoreV1PatchNamespacedPodProxy, type Params$connectCoreV1PatchNamespacedPodProxyWithPath, type Params$connectCoreV1PatchNamespacedServiceProxy, type Params$connectCoreV1PatchNamespacedServiceProxyWithPath, type Params$connectCoreV1PatchNodeProxy, type Params$connectCoreV1PatchNodeProxyWithPath, type Params$connectCoreV1PostNamespacedPodAttach, type Params$connectCoreV1PostNamespacedPodExec, type Params$connectCoreV1PostNamespacedPodPortforward, type Params$connectCoreV1PostNamespacedPodProxy, type Params$connectCoreV1PostNamespacedPodProxyWithPath, type Params$connectCoreV1PostNamespacedServiceProxy, type Params$connectCoreV1PostNamespacedServiceProxyWithPath, type Params$connectCoreV1PostNodeProxy, type Params$connectCoreV1PostNodeProxyWithPath, type Params$connectCoreV1PutNamespacedPodProxy, type Params$connectCoreV1PutNamespacedPodProxyWithPath, type Params$connectCoreV1PutNamespacedServiceProxy, type Params$connectCoreV1PutNamespacedServiceProxyWithPath, type Params$connectCoreV1PutNodeProxy, type Params$connectCoreV1PutNodeProxyWithPath, type Params$createAdmissionregistrationV1MutatingWebhookConfiguration, type Params$createAdmissionregistrationV1ValidatingWebhookConfiguration, type Params$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type Params$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type Params$createApiextensionsV1CustomResourceDefinition, type Params$createApiregistrationV1APIService, type Params$createAppsV1NamespacedControllerRevision, type Params$createAppsV1NamespacedDaemonSet, type Params$createAppsV1NamespacedDeployment, type Params$createAppsV1NamespacedReplicaSet, type Params$createAppsV1NamespacedStatefulSet, type Params$createAuthenticationV1TokenReview, type Params$createAuthenticationV1alpha1SelfSubjectReview, type Params$createAuthenticationV1beta1SelfSubjectReview, type Params$createAuthorizationV1NamespacedLocalSubjectAccessReview, type Params$createAuthorizationV1SelfSubjectAccessReview, type Params$createAuthorizationV1SelfSubjectRulesReview, type Params$createAuthorizationV1SubjectAccessReview, type Params$createAutoscalingV1NamespacedHorizontalPodAutoscaler, type Params$createAutoscalingV2NamespacedHorizontalPodAutoscaler, type Params$createBatchV1NamespacedCronJob, type Params$createBatchV1NamespacedJob, type Params$createCertificatesV1CertificateSigningRequest, type Params$createCertificatesV1alpha1ClusterTrustBundle, type Params$createCoordinationV1NamespacedLease, type Params$createCoreV1Namespace, type Params$createCoreV1NamespacedBinding, type Params$createCoreV1NamespacedConfigMap, type Params$createCoreV1NamespacedEndpoints, type Params$createCoreV1NamespacedEvent, type Params$createCoreV1NamespacedLimitRange, type Params$createCoreV1NamespacedPersistentVolumeClaim, type Params$createCoreV1NamespacedPod, type Params$createCoreV1NamespacedPodBinding, type Params$createCoreV1NamespacedPodEviction, type Params$createCoreV1NamespacedPodTemplate, type Params$createCoreV1NamespacedReplicationController, type Params$createCoreV1NamespacedResourceQuota, type Params$createCoreV1NamespacedSecret, type Params$createCoreV1NamespacedService, type Params$createCoreV1NamespacedServiceAccount, type Params$createCoreV1NamespacedServiceAccountToken, type Params$createCoreV1Node, type Params$createCoreV1PersistentVolume, type Params$createDiscoveryV1NamespacedEndpointSlice, type Params$createEventsV1NamespacedEvent, type Params$createFlowcontrolApiserverV1beta2FlowSchema, type Params$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type Params$createFlowcontrolApiserverV1beta3FlowSchema, type Params$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type Params$createInternalApiserverV1alpha1StorageVersion, type Params$createNetworkingV1IngressClass, type Params$createNetworkingV1NamespacedIngress, type Params$createNetworkingV1NamespacedNetworkPolicy, type Params$createNetworkingV1alpha1ClusterCIDR, type Params$createNetworkingV1alpha1IPAddress, type Params$createNodeV1RuntimeClass, type Params$createPolicyV1NamespacedPodDisruptionBudget, type Params$createRbacAuthorizationV1ClusterRole, type Params$createRbacAuthorizationV1ClusterRoleBinding, type Params$createRbacAuthorizationV1NamespacedRole, type Params$createRbacAuthorizationV1NamespacedRoleBinding, type Params$createResourceV1alpha2NamespacedPodSchedulingContext, type Params$createResourceV1alpha2NamespacedResourceClaim, type Params$createResourceV1alpha2NamespacedResourceClaimTemplate, type Params$createResourceV1alpha2ResourceClass, type Params$createSchedulingV1PriorityClass, type Params$createStorageV1CSIDriver, type Params$createStorageV1CSINode, type Params$createStorageV1NamespacedCSIStorageCapacity, type Params$createStorageV1StorageClass, type Params$createStorageV1VolumeAttachment, type Params$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration, type Params$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration, type Params$deleteAdmissionregistrationV1MutatingWebhookConfiguration, type Params$deleteAdmissionregistrationV1ValidatingWebhookConfiguration, type Params$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy, type Params$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding, type Params$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type Params$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type Params$deleteApiextensionsV1CollectionCustomResourceDefinition, type Params$deleteApiextensionsV1CustomResourceDefinition, type Params$deleteApiregistrationV1APIService, type Params$deleteApiregistrationV1CollectionAPIService, type Params$deleteAppsV1CollectionNamespacedControllerRevision, type Params$deleteAppsV1CollectionNamespacedDaemonSet, type Params$deleteAppsV1CollectionNamespacedDeployment, type Params$deleteAppsV1CollectionNamespacedReplicaSet, type Params$deleteAppsV1CollectionNamespacedStatefulSet, type Params$deleteAppsV1NamespacedControllerRevision, type Params$deleteAppsV1NamespacedDaemonSet, type Params$deleteAppsV1NamespacedDeployment, type Params$deleteAppsV1NamespacedReplicaSet, type Params$deleteAppsV1NamespacedStatefulSet, type Params$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler, type Params$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler, type Params$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler, type Params$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler, type Params$deleteBatchV1CollectionNamespacedCronJob, type Params$deleteBatchV1CollectionNamespacedJob, type Params$deleteBatchV1NamespacedCronJob, type Params$deleteBatchV1NamespacedJob, type Params$deleteCertificatesV1CertificateSigningRequest, type Params$deleteCertificatesV1CollectionCertificateSigningRequest, type Params$deleteCertificatesV1alpha1ClusterTrustBundle, type Params$deleteCertificatesV1alpha1CollectionClusterTrustBundle, type Params$deleteCoordinationV1CollectionNamespacedLease, type Params$deleteCoordinationV1NamespacedLease, type Params$deleteCoreV1CollectionNamespacedConfigMap, type Params$deleteCoreV1CollectionNamespacedEndpoints, type Params$deleteCoreV1CollectionNamespacedEvent, type Params$deleteCoreV1CollectionNamespacedLimitRange, type Params$deleteCoreV1CollectionNamespacedPersistentVolumeClaim, type Params$deleteCoreV1CollectionNamespacedPod, type Params$deleteCoreV1CollectionNamespacedPodTemplate, type Params$deleteCoreV1CollectionNamespacedReplicationController, type Params$deleteCoreV1CollectionNamespacedResourceQuota, type Params$deleteCoreV1CollectionNamespacedSecret, type Params$deleteCoreV1CollectionNamespacedService, type Params$deleteCoreV1CollectionNamespacedServiceAccount, type Params$deleteCoreV1CollectionNode, type Params$deleteCoreV1CollectionPersistentVolume, type Params$deleteCoreV1Namespace, type Params$deleteCoreV1NamespacedConfigMap, type Params$deleteCoreV1NamespacedEndpoints, type Params$deleteCoreV1NamespacedEvent, type Params$deleteCoreV1NamespacedLimitRange, type Params$deleteCoreV1NamespacedPersistentVolumeClaim, type Params$deleteCoreV1NamespacedPod, type Params$deleteCoreV1NamespacedPodTemplate, type Params$deleteCoreV1NamespacedReplicationController, type Params$deleteCoreV1NamespacedResourceQuota, type Params$deleteCoreV1NamespacedSecret, type Params$deleteCoreV1NamespacedService, type Params$deleteCoreV1NamespacedServiceAccount, type Params$deleteCoreV1Node, type Params$deleteCoreV1PersistentVolume, type Params$deleteDiscoveryV1CollectionNamespacedEndpointSlice, type Params$deleteDiscoveryV1NamespacedEndpointSlice, type Params$deleteEventsV1CollectionNamespacedEvent, type Params$deleteEventsV1NamespacedEvent, type Params$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema, type Params$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration, type Params$deleteFlowcontrolApiserverV1beta2FlowSchema, type Params$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type Params$deleteFlowcontrolApiserverV1beta3CollectionFlowSchema, type Params$deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration, type Params$deleteFlowcontrolApiserverV1beta3FlowSchema, type Params$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type Params$deleteInternalApiserverV1alpha1CollectionStorageVersion, type Params$deleteInternalApiserverV1alpha1StorageVersion, type Params$deleteNetworkingV1CollectionIngressClass, type Params$deleteNetworkingV1CollectionNamespacedIngress, type Params$deleteNetworkingV1CollectionNamespacedNetworkPolicy, type Params$deleteNetworkingV1IngressClass, type Params$deleteNetworkingV1NamespacedIngress, type Params$deleteNetworkingV1NamespacedNetworkPolicy, type Params$deleteNetworkingV1alpha1ClusterCIDR, type Params$deleteNetworkingV1alpha1CollectionClusterCIDR, type Params$deleteNetworkingV1alpha1CollectionIPAddress, type Params$deleteNetworkingV1alpha1IPAddress, type Params$deleteNodeV1CollectionRuntimeClass, type Params$deleteNodeV1RuntimeClass, type Params$deletePolicyV1CollectionNamespacedPodDisruptionBudget, type Params$deletePolicyV1NamespacedPodDisruptionBudget, type Params$deleteRbacAuthorizationV1ClusterRole, type Params$deleteRbacAuthorizationV1ClusterRoleBinding, type Params$deleteRbacAuthorizationV1CollectionClusterRole, type Params$deleteRbacAuthorizationV1CollectionClusterRoleBinding, type Params$deleteRbacAuthorizationV1CollectionNamespacedRole, type Params$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding, type Params$deleteRbacAuthorizationV1NamespacedRole, type Params$deleteRbacAuthorizationV1NamespacedRoleBinding, type Params$deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext, type Params$deleteResourceV1alpha2CollectionNamespacedResourceClaim, type Params$deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate, type Params$deleteResourceV1alpha2CollectionResourceClass, type Params$deleteResourceV1alpha2NamespacedPodSchedulingContext, type Params$deleteResourceV1alpha2NamespacedResourceClaim, type Params$deleteResourceV1alpha2NamespacedResourceClaimTemplate, type Params$deleteResourceV1alpha2ResourceClass, type Params$deleteSchedulingV1CollectionPriorityClass, type Params$deleteSchedulingV1PriorityClass, type Params$deleteStorageV1CSIDriver, type Params$deleteStorageV1CSINode, type Params$deleteStorageV1CollectionCSIDriver, type Params$deleteStorageV1CollectionCSINode, type Params$deleteStorageV1CollectionNamespacedCSIStorageCapacity, type Params$deleteStorageV1CollectionStorageClass, type Params$deleteStorageV1CollectionVolumeAttachment, type Params$deleteStorageV1NamespacedCSIStorageCapacity, type Params$deleteStorageV1StorageClass, type Params$deleteStorageV1VolumeAttachment, type Params$getAPIVersions, type Params$getAdmissionregistrationAPIGroup, type Params$getAdmissionregistrationV1APIResources, type Params$getAdmissionregistrationV1alpha1APIResources, type Params$getApiextensionsAPIGroup, type Params$getApiextensionsV1APIResources, type Params$getApiregistrationAPIGroup, type Params$getApiregistrationV1APIResources, type Params$getAppsAPIGroup, type Params$getAppsV1APIResources, type Params$getAuthenticationAPIGroup, type Params$getAuthenticationV1APIResources, type Params$getAuthenticationV1alpha1APIResources, type Params$getAuthenticationV1beta1APIResources, type Params$getAuthorizationAPIGroup, type Params$getAuthorizationV1APIResources, type Params$getAutoscalingAPIGroup, type Params$getAutoscalingV1APIResources, type Params$getAutoscalingV2APIResources, type Params$getBatchAPIGroup, type Params$getBatchV1APIResources, type Params$getCertificatesAPIGroup, type Params$getCertificatesV1APIResources, type Params$getCertificatesV1alpha1APIResources, type Params$getCoordinationAPIGroup, type Params$getCoordinationV1APIResources, type Params$getCoreAPIVersions, type Params$getCoreV1APIResources, type Params$getDiscoveryAPIGroup, type Params$getDiscoveryV1APIResources, type Params$getEventsAPIGroup, type Params$getEventsV1APIResources, type Params$getFlowcontrolApiserverAPIGroup, type Params$getFlowcontrolApiserverV1beta2APIResources, type Params$getFlowcontrolApiserverV1beta3APIResources, type Params$getInternalApiserverAPIGroup, type Params$getInternalApiserverV1alpha1APIResources, type Params$getNetworkingAPIGroup, type Params$getNetworkingV1APIResources, type Params$getNetworkingV1alpha1APIResources, type Params$getNodeAPIGroup, type Params$getNodeV1APIResources, type Params$getPolicyAPIGroup, type Params$getPolicyV1APIResources, type Params$getRbacAuthorizationAPIGroup, type Params$getRbacAuthorizationV1APIResources, type Params$getResourceAPIGroup, type Params$getResourceV1alpha2APIResources, type Params$getSchedulingAPIGroup, type Params$getSchedulingV1APIResources, type Params$getStorageAPIGroup, type Params$getStorageV1APIResources, type Params$listAdmissionregistrationV1MutatingWebhookConfiguration, type Params$listAdmissionregistrationV1ValidatingWebhookConfiguration, type Params$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type Params$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type Params$listApiextensionsV1CustomResourceDefinition, type Params$listApiregistrationV1APIService, type Params$listAppsV1ControllerRevisionForAllNamespaces, type Params$listAppsV1DaemonSetForAllNamespaces, type Params$listAppsV1DeploymentForAllNamespaces, type Params$listAppsV1NamespacedControllerRevision, type Params$listAppsV1NamespacedDaemonSet, type Params$listAppsV1NamespacedDeployment, type Params$listAppsV1NamespacedReplicaSet, type Params$listAppsV1NamespacedStatefulSet, type Params$listAppsV1ReplicaSetForAllNamespaces, type Params$listAppsV1StatefulSetForAllNamespaces, type Params$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces, type Params$listAutoscalingV1NamespacedHorizontalPodAutoscaler, type Params$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces, type Params$listAutoscalingV2NamespacedHorizontalPodAutoscaler, type Params$listBatchV1CronJobForAllNamespaces, type Params$listBatchV1JobForAllNamespaces, type Params$listBatchV1NamespacedCronJob, type Params$listBatchV1NamespacedJob, type Params$listCertificatesV1CertificateSigningRequest, type Params$listCertificatesV1alpha1ClusterTrustBundle, type Params$listCoordinationV1LeaseForAllNamespaces, type Params$listCoordinationV1NamespacedLease, type Params$listCoreV1ComponentStatus, type Params$listCoreV1ConfigMapForAllNamespaces, type Params$listCoreV1EndpointsForAllNamespaces, type Params$listCoreV1EventForAllNamespaces, type Params$listCoreV1LimitRangeForAllNamespaces, type Params$listCoreV1Namespace, type Params$listCoreV1NamespacedConfigMap, type Params$listCoreV1NamespacedEndpoints, type Params$listCoreV1NamespacedEvent, type Params$listCoreV1NamespacedLimitRange, type Params$listCoreV1NamespacedPersistentVolumeClaim, type Params$listCoreV1NamespacedPod, type Params$listCoreV1NamespacedPodTemplate, type Params$listCoreV1NamespacedReplicationController, type Params$listCoreV1NamespacedResourceQuota, type Params$listCoreV1NamespacedSecret, type Params$listCoreV1NamespacedService, type Params$listCoreV1NamespacedServiceAccount, type Params$listCoreV1Node, type Params$listCoreV1PersistentVolume, type Params$listCoreV1PersistentVolumeClaimForAllNamespaces, type Params$listCoreV1PodForAllNamespaces, type Params$listCoreV1PodTemplateForAllNamespaces, type Params$listCoreV1ReplicationControllerForAllNamespaces, type Params$listCoreV1ResourceQuotaForAllNamespaces, type Params$listCoreV1SecretForAllNamespaces, type Params$listCoreV1ServiceAccountForAllNamespaces, type Params$listCoreV1ServiceForAllNamespaces, type Params$listDiscoveryV1EndpointSliceForAllNamespaces, type Params$listDiscoveryV1NamespacedEndpointSlice, type Params$listEventsV1EventForAllNamespaces, type Params$listEventsV1NamespacedEvent, type Params$listFlowcontrolApiserverV1beta2FlowSchema, type Params$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type Params$listFlowcontrolApiserverV1beta3FlowSchema, type Params$listFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type Params$listInternalApiserverV1alpha1StorageVersion, type Params$listNetworkingV1IngressClass, type Params$listNetworkingV1IngressForAllNamespaces, type Params$listNetworkingV1NamespacedIngress, type Params$listNetworkingV1NamespacedNetworkPolicy, type Params$listNetworkingV1NetworkPolicyForAllNamespaces, type Params$listNetworkingV1alpha1ClusterCIDR, type Params$listNetworkingV1alpha1IPAddress, type Params$listNodeV1RuntimeClass, type Params$listPolicyV1NamespacedPodDisruptionBudget, type Params$listPolicyV1PodDisruptionBudgetForAllNamespaces, type Params$listRbacAuthorizationV1ClusterRole, type Params$listRbacAuthorizationV1ClusterRoleBinding, type Params$listRbacAuthorizationV1NamespacedRole, type Params$listRbacAuthorizationV1NamespacedRoleBinding, type Params$listRbacAuthorizationV1RoleBindingForAllNamespaces, type Params$listRbacAuthorizationV1RoleForAllNamespaces, type Params$listResourceV1alpha2NamespacedPodSchedulingContext, type Params$listResourceV1alpha2NamespacedResourceClaim, type Params$listResourceV1alpha2NamespacedResourceClaimTemplate, type Params$listResourceV1alpha2PodSchedulingContextForAllNamespaces, type Params$listResourceV1alpha2ResourceClaimForAllNamespaces, type Params$listResourceV1alpha2ResourceClaimTemplateForAllNamespaces, type Params$listResourceV1alpha2ResourceClass, type Params$listSchedulingV1PriorityClass, type Params$listStorageV1CSIDriver, type Params$listStorageV1CSINode, type Params$listStorageV1CSIStorageCapacityForAllNamespaces, type Params$listStorageV1NamespacedCSIStorageCapacity, type Params$listStorageV1StorageClass, type Params$listStorageV1VolumeAttachment, type Params$logFileHandler, type Params$patchAdmissionregistrationV1MutatingWebhookConfiguration, type Params$patchAdmissionregistrationV1ValidatingWebhookConfiguration, type Params$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type Params$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type Params$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus, type Params$patchApiextensionsV1CustomResourceDefinition, type Params$patchApiextensionsV1CustomResourceDefinitionStatus, type Params$patchApiregistrationV1APIService, type Params$patchApiregistrationV1APIServiceStatus, type Params$patchAppsV1NamespacedControllerRevision, type Params$patchAppsV1NamespacedDaemonSet, type Params$patchAppsV1NamespacedDaemonSetStatus, type Params$patchAppsV1NamespacedDeployment, type Params$patchAppsV1NamespacedDeploymentScale, type Params$patchAppsV1NamespacedDeploymentStatus, type Params$patchAppsV1NamespacedReplicaSet, type Params$patchAppsV1NamespacedReplicaSetScale, type Params$patchAppsV1NamespacedReplicaSetStatus, type Params$patchAppsV1NamespacedStatefulSet, type Params$patchAppsV1NamespacedStatefulSetScale, type Params$patchAppsV1NamespacedStatefulSetStatus, type Params$patchAutoscalingV1NamespacedHorizontalPodAutoscaler, type Params$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus, type Params$patchAutoscalingV2NamespacedHorizontalPodAutoscaler, type Params$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus, type Params$patchBatchV1NamespacedCronJob, type Params$patchBatchV1NamespacedCronJobStatus, type Params$patchBatchV1NamespacedJob, type Params$patchBatchV1NamespacedJobStatus, type Params$patchCertificatesV1CertificateSigningRequest, type Params$patchCertificatesV1CertificateSigningRequestApproval, type Params$patchCertificatesV1CertificateSigningRequestStatus, type Params$patchCertificatesV1alpha1ClusterTrustBundle, type Params$patchCoordinationV1NamespacedLease, type Params$patchCoreV1Namespace, type Params$patchCoreV1NamespaceStatus, type Params$patchCoreV1NamespacedConfigMap, type Params$patchCoreV1NamespacedEndpoints, type Params$patchCoreV1NamespacedEvent, type Params$patchCoreV1NamespacedLimitRange, type Params$patchCoreV1NamespacedPersistentVolumeClaim, type Params$patchCoreV1NamespacedPersistentVolumeClaimStatus, type Params$patchCoreV1NamespacedPod, type Params$patchCoreV1NamespacedPodEphemeralcontainers, type Params$patchCoreV1NamespacedPodStatus, type Params$patchCoreV1NamespacedPodTemplate, type Params$patchCoreV1NamespacedReplicationController, type Params$patchCoreV1NamespacedReplicationControllerScale, type Params$patchCoreV1NamespacedReplicationControllerStatus, type Params$patchCoreV1NamespacedResourceQuota, type Params$patchCoreV1NamespacedResourceQuotaStatus, type Params$patchCoreV1NamespacedSecret, type Params$patchCoreV1NamespacedService, type Params$patchCoreV1NamespacedServiceAccount, type Params$patchCoreV1NamespacedServiceStatus, type Params$patchCoreV1Node, type Params$patchCoreV1NodeStatus, type Params$patchCoreV1PersistentVolume, type Params$patchCoreV1PersistentVolumeStatus, type Params$patchDiscoveryV1NamespacedEndpointSlice, type Params$patchEventsV1NamespacedEvent, type Params$patchFlowcontrolApiserverV1beta2FlowSchema, type Params$patchFlowcontrolApiserverV1beta2FlowSchemaStatus, type Params$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type Params$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus, type Params$patchFlowcontrolApiserverV1beta3FlowSchema, type Params$patchFlowcontrolApiserverV1beta3FlowSchemaStatus, type Params$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type Params$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus, type Params$patchInternalApiserverV1alpha1StorageVersion, type Params$patchInternalApiserverV1alpha1StorageVersionStatus, type Params$patchNetworkingV1IngressClass, type Params$patchNetworkingV1NamespacedIngress, type Params$patchNetworkingV1NamespacedIngressStatus, type Params$patchNetworkingV1NamespacedNetworkPolicy, type Params$patchNetworkingV1NamespacedNetworkPolicyStatus, type Params$patchNetworkingV1alpha1ClusterCIDR, type Params$patchNetworkingV1alpha1IPAddress, type Params$patchNodeV1RuntimeClass, type Params$patchPolicyV1NamespacedPodDisruptionBudget, type Params$patchPolicyV1NamespacedPodDisruptionBudgetStatus, type Params$patchRbacAuthorizationV1ClusterRole, type Params$patchRbacAuthorizationV1ClusterRoleBinding, type Params$patchRbacAuthorizationV1NamespacedRole, type Params$patchRbacAuthorizationV1NamespacedRoleBinding, type Params$patchResourceV1alpha2NamespacedPodSchedulingContext, type Params$patchResourceV1alpha2NamespacedPodSchedulingContextStatus, type Params$patchResourceV1alpha2NamespacedResourceClaim, type Params$patchResourceV1alpha2NamespacedResourceClaimStatus, type Params$patchResourceV1alpha2NamespacedResourceClaimTemplate, type Params$patchResourceV1alpha2ResourceClass, type Params$patchSchedulingV1PriorityClass, type Params$patchStorageV1CSIDriver, type Params$patchStorageV1CSINode, type Params$patchStorageV1NamespacedCSIStorageCapacity, type Params$patchStorageV1StorageClass, type Params$patchStorageV1VolumeAttachment, type Params$patchStorageV1VolumeAttachmentStatus, type Params$readAdmissionregistrationV1MutatingWebhookConfiguration, type Params$readAdmissionregistrationV1ValidatingWebhookConfiguration, type Params$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type Params$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type Params$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus, type Params$readApiextensionsV1CustomResourceDefinition, type Params$readApiextensionsV1CustomResourceDefinitionStatus, type Params$readApiregistrationV1APIService, type Params$readApiregistrationV1APIServiceStatus, type Params$readAppsV1NamespacedControllerRevision, type Params$readAppsV1NamespacedDaemonSet, type Params$readAppsV1NamespacedDaemonSetStatus, type Params$readAppsV1NamespacedDeployment, type Params$readAppsV1NamespacedDeploymentScale, type Params$readAppsV1NamespacedDeploymentStatus, type Params$readAppsV1NamespacedReplicaSet, type Params$readAppsV1NamespacedReplicaSetScale, type Params$readAppsV1NamespacedReplicaSetStatus, type Params$readAppsV1NamespacedStatefulSet, type Params$readAppsV1NamespacedStatefulSetScale, type Params$readAppsV1NamespacedStatefulSetStatus, type Params$readAutoscalingV1NamespacedHorizontalPodAutoscaler, type Params$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus, type Params$readAutoscalingV2NamespacedHorizontalPodAutoscaler, type Params$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus, type Params$readBatchV1NamespacedCronJob, type Params$readBatchV1NamespacedCronJobStatus, type Params$readBatchV1NamespacedJob, type Params$readBatchV1NamespacedJobStatus, type Params$readCertificatesV1CertificateSigningRequest, type Params$readCertificatesV1CertificateSigningRequestApproval, type Params$readCertificatesV1CertificateSigningRequestStatus, type Params$readCertificatesV1alpha1ClusterTrustBundle, type Params$readCoordinationV1NamespacedLease, type Params$readCoreV1ComponentStatus, type Params$readCoreV1Namespace, type Params$readCoreV1NamespaceStatus, type Params$readCoreV1NamespacedConfigMap, type Params$readCoreV1NamespacedEndpoints, type Params$readCoreV1NamespacedEvent, type Params$readCoreV1NamespacedLimitRange, type Params$readCoreV1NamespacedPersistentVolumeClaim, type Params$readCoreV1NamespacedPersistentVolumeClaimStatus, type Params$readCoreV1NamespacedPod, type Params$readCoreV1NamespacedPodEphemeralcontainers, type Params$readCoreV1NamespacedPodLog, type Params$readCoreV1NamespacedPodStatus, type Params$readCoreV1NamespacedPodTemplate, type Params$readCoreV1NamespacedReplicationController, type Params$readCoreV1NamespacedReplicationControllerScale, type Params$readCoreV1NamespacedReplicationControllerStatus, type Params$readCoreV1NamespacedResourceQuota, type Params$readCoreV1NamespacedResourceQuotaStatus, type Params$readCoreV1NamespacedSecret, type Params$readCoreV1NamespacedService, type Params$readCoreV1NamespacedServiceAccount, type Params$readCoreV1NamespacedServiceStatus, type Params$readCoreV1Node, type Params$readCoreV1NodeStatus, type Params$readCoreV1PersistentVolume, type Params$readCoreV1PersistentVolumeStatus, type Params$readDiscoveryV1NamespacedEndpointSlice, type Params$readEventsV1NamespacedEvent, type Params$readFlowcontrolApiserverV1beta2FlowSchema, type Params$readFlowcontrolApiserverV1beta2FlowSchemaStatus, type Params$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type Params$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus, type Params$readFlowcontrolApiserverV1beta3FlowSchema, type Params$readFlowcontrolApiserverV1beta3FlowSchemaStatus, type Params$readFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type Params$readFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus, type Params$readInternalApiserverV1alpha1StorageVersion, type Params$readInternalApiserverV1alpha1StorageVersionStatus, type Params$readNetworkingV1IngressClass, type Params$readNetworkingV1NamespacedIngress, type Params$readNetworkingV1NamespacedIngressStatus, type Params$readNetworkingV1NamespacedNetworkPolicy, type Params$readNetworkingV1NamespacedNetworkPolicyStatus, type Params$readNetworkingV1alpha1ClusterCIDR, type Params$readNetworkingV1alpha1IPAddress, type Params$readNodeV1RuntimeClass, type Params$readPolicyV1NamespacedPodDisruptionBudget, type Params$readPolicyV1NamespacedPodDisruptionBudgetStatus, type Params$readRbacAuthorizationV1ClusterRole, type Params$readRbacAuthorizationV1ClusterRoleBinding, type Params$readRbacAuthorizationV1NamespacedRole, type Params$readRbacAuthorizationV1NamespacedRoleBinding, type Params$readResourceV1alpha2NamespacedPodSchedulingContext, type Params$readResourceV1alpha2NamespacedPodSchedulingContextStatus, type Params$readResourceV1alpha2NamespacedResourceClaim, type Params$readResourceV1alpha2NamespacedResourceClaimStatus, type Params$readResourceV1alpha2NamespacedResourceClaimTemplate, type Params$readResourceV1alpha2ResourceClass, type Params$readSchedulingV1PriorityClass, type Params$readStorageV1CSIDriver, type Params$readStorageV1CSINode, type Params$readStorageV1NamespacedCSIStorageCapacity, type Params$readStorageV1StorageClass, type Params$readStorageV1VolumeAttachment, type Params$readStorageV1VolumeAttachmentStatus, type Params$replaceAdmissionregistrationV1MutatingWebhookConfiguration, type Params$replaceAdmissionregistrationV1ValidatingWebhookConfiguration, type Params$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type Params$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type Params$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus, type Params$replaceApiextensionsV1CustomResourceDefinition, type Params$replaceApiextensionsV1CustomResourceDefinitionStatus, type Params$replaceApiregistrationV1APIService, type Params$replaceApiregistrationV1APIServiceStatus, type Params$replaceAppsV1NamespacedControllerRevision, type Params$replaceAppsV1NamespacedDaemonSet, type Params$replaceAppsV1NamespacedDaemonSetStatus, type Params$replaceAppsV1NamespacedDeployment, type Params$replaceAppsV1NamespacedDeploymentScale, type Params$replaceAppsV1NamespacedDeploymentStatus, type Params$replaceAppsV1NamespacedReplicaSet, type Params$replaceAppsV1NamespacedReplicaSetScale, type Params$replaceAppsV1NamespacedReplicaSetStatus, type Params$replaceAppsV1NamespacedStatefulSet, type Params$replaceAppsV1NamespacedStatefulSetScale, type Params$replaceAppsV1NamespacedStatefulSetStatus, type Params$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler, type Params$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus, type Params$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler, type Params$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus, type Params$replaceBatchV1NamespacedCronJob, type Params$replaceBatchV1NamespacedCronJobStatus, type Params$replaceBatchV1NamespacedJob, type Params$replaceBatchV1NamespacedJobStatus, type Params$replaceCertificatesV1CertificateSigningRequest, type Params$replaceCertificatesV1CertificateSigningRequestApproval, type Params$replaceCertificatesV1CertificateSigningRequestStatus, type Params$replaceCertificatesV1alpha1ClusterTrustBundle, type Params$replaceCoordinationV1NamespacedLease, type Params$replaceCoreV1Namespace, type Params$replaceCoreV1NamespaceFinalize, type Params$replaceCoreV1NamespaceStatus, type Params$replaceCoreV1NamespacedConfigMap, type Params$replaceCoreV1NamespacedEndpoints, type Params$replaceCoreV1NamespacedEvent, type Params$replaceCoreV1NamespacedLimitRange, type Params$replaceCoreV1NamespacedPersistentVolumeClaim, type Params$replaceCoreV1NamespacedPersistentVolumeClaimStatus, type Params$replaceCoreV1NamespacedPod, type Params$replaceCoreV1NamespacedPodEphemeralcontainers, type Params$replaceCoreV1NamespacedPodStatus, type Params$replaceCoreV1NamespacedPodTemplate, type Params$replaceCoreV1NamespacedReplicationController, type Params$replaceCoreV1NamespacedReplicationControllerScale, type Params$replaceCoreV1NamespacedReplicationControllerStatus, type Params$replaceCoreV1NamespacedResourceQuota, type Params$replaceCoreV1NamespacedResourceQuotaStatus, type Params$replaceCoreV1NamespacedSecret, type Params$replaceCoreV1NamespacedService, type Params$replaceCoreV1NamespacedServiceAccount, type Params$replaceCoreV1NamespacedServiceStatus, type Params$replaceCoreV1Node, type Params$replaceCoreV1NodeStatus, type Params$replaceCoreV1PersistentVolume, type Params$replaceCoreV1PersistentVolumeStatus, type Params$replaceDiscoveryV1NamespacedEndpointSlice, type Params$replaceEventsV1NamespacedEvent, type Params$replaceFlowcontrolApiserverV1beta2FlowSchema, type Params$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus, type Params$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type Params$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus, type Params$replaceFlowcontrolApiserverV1beta3FlowSchema, type Params$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus, type Params$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type Params$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus, type Params$replaceInternalApiserverV1alpha1StorageVersion, type Params$replaceInternalApiserverV1alpha1StorageVersionStatus, type Params$replaceNetworkingV1IngressClass, type Params$replaceNetworkingV1NamespacedIngress, type Params$replaceNetworkingV1NamespacedIngressStatus, type Params$replaceNetworkingV1NamespacedNetworkPolicy, type Params$replaceNetworkingV1NamespacedNetworkPolicyStatus, type Params$replaceNetworkingV1alpha1ClusterCIDR, type Params$replaceNetworkingV1alpha1IPAddress, type Params$replaceNodeV1RuntimeClass, type Params$replacePolicyV1NamespacedPodDisruptionBudget, type Params$replacePolicyV1NamespacedPodDisruptionBudgetStatus, type Params$replaceRbacAuthorizationV1ClusterRole, type Params$replaceRbacAuthorizationV1ClusterRoleBinding, type Params$replaceRbacAuthorizationV1NamespacedRole, type Params$replaceRbacAuthorizationV1NamespacedRoleBinding, type Params$replaceResourceV1alpha2NamespacedPodSchedulingContext, type Params$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus, type Params$replaceResourceV1alpha2NamespacedResourceClaim, type Params$replaceResourceV1alpha2NamespacedResourceClaimStatus, type Params$replaceResourceV1alpha2NamespacedResourceClaimTemplate, type Params$replaceResourceV1alpha2ResourceClass, type Params$replaceSchedulingV1PriorityClass, type Params$replaceStorageV1CSIDriver, type Params$replaceStorageV1CSINode, type Params$replaceStorageV1NamespacedCSIStorageCapacity, type Params$replaceStorageV1StorageClass, type Params$replaceStorageV1VolumeAttachment, type Params$replaceStorageV1VolumeAttachmentStatus, type Params$watchAdmissionregistrationV1MutatingWebhookConfiguration, type Params$watchAdmissionregistrationV1MutatingWebhookConfigurationList, type Params$watchAdmissionregistrationV1ValidatingWebhookConfiguration, type Params$watchAdmissionregistrationV1ValidatingWebhookConfigurationList, type Params$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type Params$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type Params$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBindingList, type Params$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyList, type Params$watchApiextensionsV1CustomResourceDefinition, type Params$watchApiextensionsV1CustomResourceDefinitionList, type Params$watchApiregistrationV1APIService, type Params$watchApiregistrationV1APIServiceList, type Params$watchAppsV1ControllerRevisionListForAllNamespaces, type Params$watchAppsV1DaemonSetListForAllNamespaces, type Params$watchAppsV1DeploymentListForAllNamespaces, type Params$watchAppsV1NamespacedControllerRevision, type Params$watchAppsV1NamespacedControllerRevisionList, type Params$watchAppsV1NamespacedDaemonSet, type Params$watchAppsV1NamespacedDaemonSetList, type Params$watchAppsV1NamespacedDeployment, type Params$watchAppsV1NamespacedDeploymentList, type Params$watchAppsV1NamespacedReplicaSet, type Params$watchAppsV1NamespacedReplicaSetList, type Params$watchAppsV1NamespacedStatefulSet, type Params$watchAppsV1NamespacedStatefulSetList, type Params$watchAppsV1ReplicaSetListForAllNamespaces, type Params$watchAppsV1StatefulSetListForAllNamespaces, type Params$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces, type Params$watchAutoscalingV1NamespacedHorizontalPodAutoscaler, type Params$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList, type Params$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces, type Params$watchAutoscalingV2NamespacedHorizontalPodAutoscaler, type Params$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList, type Params$watchBatchV1CronJobListForAllNamespaces, type Params$watchBatchV1JobListForAllNamespaces, type Params$watchBatchV1NamespacedCronJob, type Params$watchBatchV1NamespacedCronJobList, type Params$watchBatchV1NamespacedJob, type Params$watchBatchV1NamespacedJobList, type Params$watchCertificatesV1CertificateSigningRequest, type Params$watchCertificatesV1CertificateSigningRequestList, type Params$watchCertificatesV1alpha1ClusterTrustBundle, type Params$watchCertificatesV1alpha1ClusterTrustBundleList, type Params$watchCoordinationV1LeaseListForAllNamespaces, type Params$watchCoordinationV1NamespacedLease, type Params$watchCoordinationV1NamespacedLeaseList, type Params$watchCoreV1ConfigMapListForAllNamespaces, type Params$watchCoreV1EndpointsListForAllNamespaces, type Params$watchCoreV1EventListForAllNamespaces, type Params$watchCoreV1LimitRangeListForAllNamespaces, type Params$watchCoreV1Namespace, type Params$watchCoreV1NamespaceList, type Params$watchCoreV1NamespacedConfigMap, type Params$watchCoreV1NamespacedConfigMapList, type Params$watchCoreV1NamespacedEndpoints, type Params$watchCoreV1NamespacedEndpointsList, type Params$watchCoreV1NamespacedEvent, type Params$watchCoreV1NamespacedEventList, type Params$watchCoreV1NamespacedLimitRange, type Params$watchCoreV1NamespacedLimitRangeList, type Params$watchCoreV1NamespacedPersistentVolumeClaim, type Params$watchCoreV1NamespacedPersistentVolumeClaimList, type Params$watchCoreV1NamespacedPod, type Params$watchCoreV1NamespacedPodList, type Params$watchCoreV1NamespacedPodTemplate, type Params$watchCoreV1NamespacedPodTemplateList, type Params$watchCoreV1NamespacedReplicationController, type Params$watchCoreV1NamespacedReplicationControllerList, type Params$watchCoreV1NamespacedResourceQuota, type Params$watchCoreV1NamespacedResourceQuotaList, type Params$watchCoreV1NamespacedSecret, type Params$watchCoreV1NamespacedSecretList, type Params$watchCoreV1NamespacedService, type Params$watchCoreV1NamespacedServiceAccount, type Params$watchCoreV1NamespacedServiceAccountList, type Params$watchCoreV1NamespacedServiceList, type Params$watchCoreV1Node, type Params$watchCoreV1NodeList, type Params$watchCoreV1PersistentVolume, type Params$watchCoreV1PersistentVolumeClaimListForAllNamespaces, type Params$watchCoreV1PersistentVolumeList, type Params$watchCoreV1PodListForAllNamespaces, type Params$watchCoreV1PodTemplateListForAllNamespaces, type Params$watchCoreV1ReplicationControllerListForAllNamespaces, type Params$watchCoreV1ResourceQuotaListForAllNamespaces, type Params$watchCoreV1SecretListForAllNamespaces, type Params$watchCoreV1ServiceAccountListForAllNamespaces, type Params$watchCoreV1ServiceListForAllNamespaces, type Params$watchDiscoveryV1EndpointSliceListForAllNamespaces, type Params$watchDiscoveryV1NamespacedEndpointSlice, type Params$watchDiscoveryV1NamespacedEndpointSliceList, type Params$watchEventsV1EventListForAllNamespaces, type Params$watchEventsV1NamespacedEvent, type Params$watchEventsV1NamespacedEventList, type Params$watchFlowcontrolApiserverV1beta2FlowSchema, type Params$watchFlowcontrolApiserverV1beta2FlowSchemaList, type Params$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type Params$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList, type Params$watchFlowcontrolApiserverV1beta3FlowSchema, type Params$watchFlowcontrolApiserverV1beta3FlowSchemaList, type Params$watchFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type Params$watchFlowcontrolApiserverV1beta3PriorityLevelConfigurationList, type Params$watchInternalApiserverV1alpha1StorageVersion, type Params$watchInternalApiserverV1alpha1StorageVersionList, type Params$watchNetworkingV1IngressClass, type Params$watchNetworkingV1IngressClassList, type Params$watchNetworkingV1IngressListForAllNamespaces, type Params$watchNetworkingV1NamespacedIngress, type Params$watchNetworkingV1NamespacedIngressList, type Params$watchNetworkingV1NamespacedNetworkPolicy, type Params$watchNetworkingV1NamespacedNetworkPolicyList, type Params$watchNetworkingV1NetworkPolicyListForAllNamespaces, type Params$watchNetworkingV1alpha1ClusterCIDR, type Params$watchNetworkingV1alpha1ClusterCIDRList, type Params$watchNetworkingV1alpha1IPAddress, type Params$watchNetworkingV1alpha1IPAddressList, type Params$watchNodeV1RuntimeClass, type Params$watchNodeV1RuntimeClassList, type Params$watchPolicyV1NamespacedPodDisruptionBudget, type Params$watchPolicyV1NamespacedPodDisruptionBudgetList, type Params$watchPolicyV1PodDisruptionBudgetListForAllNamespaces, type Params$watchRbacAuthorizationV1ClusterRole, type Params$watchRbacAuthorizationV1ClusterRoleBinding, type Params$watchRbacAuthorizationV1ClusterRoleBindingList, type Params$watchRbacAuthorizationV1ClusterRoleList, type Params$watchRbacAuthorizationV1NamespacedRole, type Params$watchRbacAuthorizationV1NamespacedRoleBinding, type Params$watchRbacAuthorizationV1NamespacedRoleBindingList, type Params$watchRbacAuthorizationV1NamespacedRoleList, type Params$watchRbacAuthorizationV1RoleBindingListForAllNamespaces, type Params$watchRbacAuthorizationV1RoleListForAllNamespaces, type Params$watchResourceV1alpha2NamespacedPodSchedulingContext, type Params$watchResourceV1alpha2NamespacedPodSchedulingContextList, type Params$watchResourceV1alpha2NamespacedResourceClaim, type Params$watchResourceV1alpha2NamespacedResourceClaimList, type Params$watchResourceV1alpha2NamespacedResourceClaimTemplate, type Params$watchResourceV1alpha2NamespacedResourceClaimTemplateList, type Params$watchResourceV1alpha2PodSchedulingContextListForAllNamespaces, type Params$watchResourceV1alpha2ResourceClaimListForAllNamespaces, type Params$watchResourceV1alpha2ResourceClaimTemplateListForAllNamespaces, type Params$watchResourceV1alpha2ResourceClass, type Params$watchResourceV1alpha2ResourceClassList, type Params$watchSchedulingV1PriorityClass, type Params$watchSchedulingV1PriorityClassList, type Params$watchStorageV1CSIDriver, type Params$watchStorageV1CSIDriverList, type Params$watchStorageV1CSINode, type Params$watchStorageV1CSINodeList, type Params$watchStorageV1CSIStorageCapacityListForAllNamespaces, type Params$watchStorageV1NamespacedCSIStorageCapacity, type Params$watchStorageV1NamespacedCSIStorageCapacityList, type Params$watchStorageV1StorageClass, type Params$watchStorageV1StorageClassList, type Params$watchStorageV1VolumeAttachment, type Params$watchStorageV1VolumeAttachmentList, type QueryParameter, type QueryParameters, type RequestArgs, RequestBodies, type RequestBody$createAdmissionregistrationV1MutatingWebhookConfiguration, type RequestBody$createAdmissionregistrationV1ValidatingWebhookConfiguration, type RequestBody$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type RequestBody$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type RequestBody$createApiextensionsV1CustomResourceDefinition, type RequestBody$createApiregistrationV1APIService, type RequestBody$createAppsV1NamespacedControllerRevision, type RequestBody$createAppsV1NamespacedDaemonSet, type RequestBody$createAppsV1NamespacedDeployment, type RequestBody$createAppsV1NamespacedReplicaSet, type RequestBody$createAppsV1NamespacedStatefulSet, type RequestBody$createAuthenticationV1TokenReview, type RequestBody$createAuthenticationV1alpha1SelfSubjectReview, type RequestBody$createAuthenticationV1beta1SelfSubjectReview, type RequestBody$createAuthorizationV1NamespacedLocalSubjectAccessReview, type RequestBody$createAuthorizationV1SelfSubjectAccessReview, type RequestBody$createAuthorizationV1SelfSubjectRulesReview, type RequestBody$createAuthorizationV1SubjectAccessReview, type RequestBody$createAutoscalingV1NamespacedHorizontalPodAutoscaler, type RequestBody$createAutoscalingV2NamespacedHorizontalPodAutoscaler, type RequestBody$createBatchV1NamespacedCronJob, type RequestBody$createBatchV1NamespacedJob, type RequestBody$createCertificatesV1CertificateSigningRequest, type RequestBody$createCertificatesV1alpha1ClusterTrustBundle, type RequestBody$createCoordinationV1NamespacedLease, type RequestBody$createCoreV1Namespace, type RequestBody$createCoreV1NamespacedBinding, type RequestBody$createCoreV1NamespacedConfigMap, type RequestBody$createCoreV1NamespacedEndpoints, type RequestBody$createCoreV1NamespacedEvent, type RequestBody$createCoreV1NamespacedLimitRange, type RequestBody$createCoreV1NamespacedPersistentVolumeClaim, type RequestBody$createCoreV1NamespacedPod, type RequestBody$createCoreV1NamespacedPodBinding, type RequestBody$createCoreV1NamespacedPodEviction, type RequestBody$createCoreV1NamespacedPodTemplate, type RequestBody$createCoreV1NamespacedReplicationController, type RequestBody$createCoreV1NamespacedResourceQuota, type RequestBody$createCoreV1NamespacedSecret, type RequestBody$createCoreV1NamespacedService, type RequestBody$createCoreV1NamespacedServiceAccount, type RequestBody$createCoreV1NamespacedServiceAccountToken, type RequestBody$createCoreV1Node, type RequestBody$createCoreV1PersistentVolume, type RequestBody$createDiscoveryV1NamespacedEndpointSlice, type RequestBody$createEventsV1NamespacedEvent, type RequestBody$createFlowcontrolApiserverV1beta2FlowSchema, type RequestBody$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type RequestBody$createFlowcontrolApiserverV1beta3FlowSchema, type RequestBody$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type RequestBody$createInternalApiserverV1alpha1StorageVersion, type RequestBody$createNetworkingV1IngressClass, type RequestBody$createNetworkingV1NamespacedIngress, type RequestBody$createNetworkingV1NamespacedNetworkPolicy, type RequestBody$createNetworkingV1alpha1ClusterCIDR, type RequestBody$createNetworkingV1alpha1IPAddress, type RequestBody$createNodeV1RuntimeClass, type RequestBody$createPolicyV1NamespacedPodDisruptionBudget, type RequestBody$createRbacAuthorizationV1ClusterRole, type RequestBody$createRbacAuthorizationV1ClusterRoleBinding, type RequestBody$createRbacAuthorizationV1NamespacedRole, type RequestBody$createRbacAuthorizationV1NamespacedRoleBinding, type RequestBody$createResourceV1alpha2NamespacedPodSchedulingContext, type RequestBody$createResourceV1alpha2NamespacedResourceClaim, type RequestBody$createResourceV1alpha2NamespacedResourceClaimTemplate, type RequestBody$createResourceV1alpha2ResourceClass, type RequestBody$createSchedulingV1PriorityClass, type RequestBody$createStorageV1CSIDriver, type RequestBody$createStorageV1CSINode, type RequestBody$createStorageV1NamespacedCSIStorageCapacity, type RequestBody$createStorageV1StorageClass, type RequestBody$createStorageV1VolumeAttachment, type RequestBody$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration, type RequestBody$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration, type RequestBody$deleteAdmissionregistrationV1MutatingWebhookConfiguration, type RequestBody$deleteAdmissionregistrationV1ValidatingWebhookConfiguration, type RequestBody$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy, type RequestBody$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding, type RequestBody$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type RequestBody$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type RequestBody$deleteApiextensionsV1CollectionCustomResourceDefinition, type RequestBody$deleteApiextensionsV1CustomResourceDefinition, type RequestBody$deleteApiregistrationV1APIService, type RequestBody$deleteApiregistrationV1CollectionAPIService, type RequestBody$deleteAppsV1CollectionNamespacedControllerRevision, type RequestBody$deleteAppsV1CollectionNamespacedDaemonSet, type RequestBody$deleteAppsV1CollectionNamespacedDeployment, type RequestBody$deleteAppsV1CollectionNamespacedReplicaSet, type RequestBody$deleteAppsV1CollectionNamespacedStatefulSet, type RequestBody$deleteAppsV1NamespacedControllerRevision, type RequestBody$deleteAppsV1NamespacedDaemonSet, type RequestBody$deleteAppsV1NamespacedDeployment, type RequestBody$deleteAppsV1NamespacedReplicaSet, type RequestBody$deleteAppsV1NamespacedStatefulSet, type RequestBody$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler, type RequestBody$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler, type RequestBody$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler, type RequestBody$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler, type RequestBody$deleteBatchV1CollectionNamespacedCronJob, type RequestBody$deleteBatchV1CollectionNamespacedJob, type RequestBody$deleteBatchV1NamespacedCronJob, type RequestBody$deleteBatchV1NamespacedJob, type RequestBody$deleteCertificatesV1CertificateSigningRequest, type RequestBody$deleteCertificatesV1CollectionCertificateSigningRequest, type RequestBody$deleteCertificatesV1alpha1ClusterTrustBundle, type RequestBody$deleteCertificatesV1alpha1CollectionClusterTrustBundle, type RequestBody$deleteCoordinationV1CollectionNamespacedLease, type RequestBody$deleteCoordinationV1NamespacedLease, type RequestBody$deleteCoreV1CollectionNamespacedConfigMap, type RequestBody$deleteCoreV1CollectionNamespacedEndpoints, type RequestBody$deleteCoreV1CollectionNamespacedEvent, type RequestBody$deleteCoreV1CollectionNamespacedLimitRange, type RequestBody$deleteCoreV1CollectionNamespacedPersistentVolumeClaim, type RequestBody$deleteCoreV1CollectionNamespacedPod, type RequestBody$deleteCoreV1CollectionNamespacedPodTemplate, type RequestBody$deleteCoreV1CollectionNamespacedReplicationController, type RequestBody$deleteCoreV1CollectionNamespacedResourceQuota, type RequestBody$deleteCoreV1CollectionNamespacedSecret, type RequestBody$deleteCoreV1CollectionNamespacedService, type RequestBody$deleteCoreV1CollectionNamespacedServiceAccount, type RequestBody$deleteCoreV1CollectionNode, type RequestBody$deleteCoreV1CollectionPersistentVolume, type RequestBody$deleteCoreV1Namespace, type RequestBody$deleteCoreV1NamespacedConfigMap, type RequestBody$deleteCoreV1NamespacedEndpoints, type RequestBody$deleteCoreV1NamespacedEvent, type RequestBody$deleteCoreV1NamespacedLimitRange, type RequestBody$deleteCoreV1NamespacedPersistentVolumeClaim, type RequestBody$deleteCoreV1NamespacedPod, type RequestBody$deleteCoreV1NamespacedPodTemplate, type RequestBody$deleteCoreV1NamespacedReplicationController, type RequestBody$deleteCoreV1NamespacedResourceQuota, type RequestBody$deleteCoreV1NamespacedSecret, type RequestBody$deleteCoreV1NamespacedService, type RequestBody$deleteCoreV1NamespacedServiceAccount, type RequestBody$deleteCoreV1Node, type RequestBody$deleteCoreV1PersistentVolume, type RequestBody$deleteDiscoveryV1CollectionNamespacedEndpointSlice, type RequestBody$deleteDiscoveryV1NamespacedEndpointSlice, type RequestBody$deleteEventsV1CollectionNamespacedEvent, type RequestBody$deleteEventsV1NamespacedEvent, type RequestBody$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema, type RequestBody$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration, type RequestBody$deleteFlowcontrolApiserverV1beta2FlowSchema, type RequestBody$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type RequestBody$deleteFlowcontrolApiserverV1beta3CollectionFlowSchema, type RequestBody$deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration, type RequestBody$deleteFlowcontrolApiserverV1beta3FlowSchema, type RequestBody$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type RequestBody$deleteInternalApiserverV1alpha1CollectionStorageVersion, type RequestBody$deleteInternalApiserverV1alpha1StorageVersion, type RequestBody$deleteNetworkingV1CollectionIngressClass, type RequestBody$deleteNetworkingV1CollectionNamespacedIngress, type RequestBody$deleteNetworkingV1CollectionNamespacedNetworkPolicy, type RequestBody$deleteNetworkingV1IngressClass, type RequestBody$deleteNetworkingV1NamespacedIngress, type RequestBody$deleteNetworkingV1NamespacedNetworkPolicy, type RequestBody$deleteNetworkingV1alpha1ClusterCIDR, type RequestBody$deleteNetworkingV1alpha1CollectionClusterCIDR, type RequestBody$deleteNetworkingV1alpha1CollectionIPAddress, type RequestBody$deleteNetworkingV1alpha1IPAddress, type RequestBody$deleteNodeV1CollectionRuntimeClass, type RequestBody$deleteNodeV1RuntimeClass, type RequestBody$deletePolicyV1CollectionNamespacedPodDisruptionBudget, type RequestBody$deletePolicyV1NamespacedPodDisruptionBudget, type RequestBody$deleteRbacAuthorizationV1ClusterRole, type RequestBody$deleteRbacAuthorizationV1ClusterRoleBinding, type RequestBody$deleteRbacAuthorizationV1CollectionClusterRole, type RequestBody$deleteRbacAuthorizationV1CollectionClusterRoleBinding, type RequestBody$deleteRbacAuthorizationV1CollectionNamespacedRole, type RequestBody$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding, type RequestBody$deleteRbacAuthorizationV1NamespacedRole, type RequestBody$deleteRbacAuthorizationV1NamespacedRoleBinding, type RequestBody$deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext, type RequestBody$deleteResourceV1alpha2CollectionNamespacedResourceClaim, type RequestBody$deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate, type RequestBody$deleteResourceV1alpha2CollectionResourceClass, type RequestBody$deleteResourceV1alpha2NamespacedPodSchedulingContext, type RequestBody$deleteResourceV1alpha2NamespacedResourceClaim, type RequestBody$deleteResourceV1alpha2NamespacedResourceClaimTemplate, type RequestBody$deleteResourceV1alpha2ResourceClass, type RequestBody$deleteSchedulingV1CollectionPriorityClass, type RequestBody$deleteSchedulingV1PriorityClass, type RequestBody$deleteStorageV1CSIDriver, type RequestBody$deleteStorageV1CSINode, type RequestBody$deleteStorageV1CollectionCSIDriver, type RequestBody$deleteStorageV1CollectionCSINode, type RequestBody$deleteStorageV1CollectionNamespacedCSIStorageCapacity, type RequestBody$deleteStorageV1CollectionStorageClass, type RequestBody$deleteStorageV1CollectionVolumeAttachment, type RequestBody$deleteStorageV1NamespacedCSIStorageCapacity, type RequestBody$deleteStorageV1StorageClass, type RequestBody$deleteStorageV1VolumeAttachment, type RequestBody$patchAdmissionregistrationV1MutatingWebhookConfiguration, type RequestBody$patchAdmissionregistrationV1ValidatingWebhookConfiguration, type RequestBody$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type RequestBody$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type RequestBody$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus, type RequestBody$patchApiextensionsV1CustomResourceDefinition, type RequestBody$patchApiextensionsV1CustomResourceDefinitionStatus, type RequestBody$patchApiregistrationV1APIService, type RequestBody$patchApiregistrationV1APIServiceStatus, type RequestBody$patchAppsV1NamespacedControllerRevision, type RequestBody$patchAppsV1NamespacedDaemonSet, type RequestBody$patchAppsV1NamespacedDaemonSetStatus, type RequestBody$patchAppsV1NamespacedDeployment, type RequestBody$patchAppsV1NamespacedDeploymentScale, type RequestBody$patchAppsV1NamespacedDeploymentStatus, type RequestBody$patchAppsV1NamespacedReplicaSet, type RequestBody$patchAppsV1NamespacedReplicaSetScale, type RequestBody$patchAppsV1NamespacedReplicaSetStatus, type RequestBody$patchAppsV1NamespacedStatefulSet, type RequestBody$patchAppsV1NamespacedStatefulSetScale, type RequestBody$patchAppsV1NamespacedStatefulSetStatus, type RequestBody$patchAutoscalingV1NamespacedHorizontalPodAutoscaler, type RequestBody$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus, type RequestBody$patchAutoscalingV2NamespacedHorizontalPodAutoscaler, type RequestBody$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus, type RequestBody$patchBatchV1NamespacedCronJob, type RequestBody$patchBatchV1NamespacedCronJobStatus, type RequestBody$patchBatchV1NamespacedJob, type RequestBody$patchBatchV1NamespacedJobStatus, type RequestBody$patchCertificatesV1CertificateSigningRequest, type RequestBody$patchCertificatesV1CertificateSigningRequestApproval, type RequestBody$patchCertificatesV1CertificateSigningRequestStatus, type RequestBody$patchCertificatesV1alpha1ClusterTrustBundle, type RequestBody$patchCoordinationV1NamespacedLease, type RequestBody$patchCoreV1Namespace, type RequestBody$patchCoreV1NamespaceStatus, type RequestBody$patchCoreV1NamespacedConfigMap, type RequestBody$patchCoreV1NamespacedEndpoints, type RequestBody$patchCoreV1NamespacedEvent, type RequestBody$patchCoreV1NamespacedLimitRange, type RequestBody$patchCoreV1NamespacedPersistentVolumeClaim, type RequestBody$patchCoreV1NamespacedPersistentVolumeClaimStatus, type RequestBody$patchCoreV1NamespacedPod, type RequestBody$patchCoreV1NamespacedPodEphemeralcontainers, type RequestBody$patchCoreV1NamespacedPodStatus, type RequestBody$patchCoreV1NamespacedPodTemplate, type RequestBody$patchCoreV1NamespacedReplicationController, type RequestBody$patchCoreV1NamespacedReplicationControllerScale, type RequestBody$patchCoreV1NamespacedReplicationControllerStatus, type RequestBody$patchCoreV1NamespacedResourceQuota, type RequestBody$patchCoreV1NamespacedResourceQuotaStatus, type RequestBody$patchCoreV1NamespacedSecret, type RequestBody$patchCoreV1NamespacedService, type RequestBody$patchCoreV1NamespacedServiceAccount, type RequestBody$patchCoreV1NamespacedServiceStatus, type RequestBody$patchCoreV1Node, type RequestBody$patchCoreV1NodeStatus, type RequestBody$patchCoreV1PersistentVolume, type RequestBody$patchCoreV1PersistentVolumeStatus, type RequestBody$patchDiscoveryV1NamespacedEndpointSlice, type RequestBody$patchEventsV1NamespacedEvent, type RequestBody$patchFlowcontrolApiserverV1beta2FlowSchema, type RequestBody$patchFlowcontrolApiserverV1beta2FlowSchemaStatus, type RequestBody$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type RequestBody$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus, type RequestBody$patchFlowcontrolApiserverV1beta3FlowSchema, type RequestBody$patchFlowcontrolApiserverV1beta3FlowSchemaStatus, type RequestBody$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type RequestBody$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus, type RequestBody$patchInternalApiserverV1alpha1StorageVersion, type RequestBody$patchInternalApiserverV1alpha1StorageVersionStatus, type RequestBody$patchNetworkingV1IngressClass, type RequestBody$patchNetworkingV1NamespacedIngress, type RequestBody$patchNetworkingV1NamespacedIngressStatus, type RequestBody$patchNetworkingV1NamespacedNetworkPolicy, type RequestBody$patchNetworkingV1NamespacedNetworkPolicyStatus, type RequestBody$patchNetworkingV1alpha1ClusterCIDR, type RequestBody$patchNetworkingV1alpha1IPAddress, type RequestBody$patchNodeV1RuntimeClass, type RequestBody$patchPolicyV1NamespacedPodDisruptionBudget, type RequestBody$patchPolicyV1NamespacedPodDisruptionBudgetStatus, type RequestBody$patchRbacAuthorizationV1ClusterRole, type RequestBody$patchRbacAuthorizationV1ClusterRoleBinding, type RequestBody$patchRbacAuthorizationV1NamespacedRole, type RequestBody$patchRbacAuthorizationV1NamespacedRoleBinding, type RequestBody$patchResourceV1alpha2NamespacedPodSchedulingContext, type RequestBody$patchResourceV1alpha2NamespacedPodSchedulingContextStatus, type RequestBody$patchResourceV1alpha2NamespacedResourceClaim, type RequestBody$patchResourceV1alpha2NamespacedResourceClaimStatus, type RequestBody$patchResourceV1alpha2NamespacedResourceClaimTemplate, type RequestBody$patchResourceV1alpha2ResourceClass, type RequestBody$patchSchedulingV1PriorityClass, type RequestBody$patchStorageV1CSIDriver, type RequestBody$patchStorageV1CSINode, type RequestBody$patchStorageV1NamespacedCSIStorageCapacity, type RequestBody$patchStorageV1StorageClass, type RequestBody$patchStorageV1VolumeAttachment, type RequestBody$patchStorageV1VolumeAttachmentStatus, type RequestBody$replaceAdmissionregistrationV1MutatingWebhookConfiguration, type RequestBody$replaceAdmissionregistrationV1ValidatingWebhookConfiguration, type RequestBody$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type RequestBody$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type RequestBody$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus, type RequestBody$replaceApiextensionsV1CustomResourceDefinition, type RequestBody$replaceApiextensionsV1CustomResourceDefinitionStatus, type RequestBody$replaceApiregistrationV1APIService, type RequestBody$replaceApiregistrationV1APIServiceStatus, type RequestBody$replaceAppsV1NamespacedControllerRevision, type RequestBody$replaceAppsV1NamespacedDaemonSet, type RequestBody$replaceAppsV1NamespacedDaemonSetStatus, type RequestBody$replaceAppsV1NamespacedDeployment, type RequestBody$replaceAppsV1NamespacedDeploymentScale, type RequestBody$replaceAppsV1NamespacedDeploymentStatus, type RequestBody$replaceAppsV1NamespacedReplicaSet, type RequestBody$replaceAppsV1NamespacedReplicaSetScale, type RequestBody$replaceAppsV1NamespacedReplicaSetStatus, type RequestBody$replaceAppsV1NamespacedStatefulSet, type RequestBody$replaceAppsV1NamespacedStatefulSetScale, type RequestBody$replaceAppsV1NamespacedStatefulSetStatus, type RequestBody$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler, type RequestBody$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus, type RequestBody$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler, type RequestBody$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus, type RequestBody$replaceBatchV1NamespacedCronJob, type RequestBody$replaceBatchV1NamespacedCronJobStatus, type RequestBody$replaceBatchV1NamespacedJob, type RequestBody$replaceBatchV1NamespacedJobStatus, type RequestBody$replaceCertificatesV1CertificateSigningRequest, type RequestBody$replaceCertificatesV1CertificateSigningRequestApproval, type RequestBody$replaceCertificatesV1CertificateSigningRequestStatus, type RequestBody$replaceCertificatesV1alpha1ClusterTrustBundle, type RequestBody$replaceCoordinationV1NamespacedLease, type RequestBody$replaceCoreV1Namespace, type RequestBody$replaceCoreV1NamespaceFinalize, type RequestBody$replaceCoreV1NamespaceStatus, type RequestBody$replaceCoreV1NamespacedConfigMap, type RequestBody$replaceCoreV1NamespacedEndpoints, type RequestBody$replaceCoreV1NamespacedEvent, type RequestBody$replaceCoreV1NamespacedLimitRange, type RequestBody$replaceCoreV1NamespacedPersistentVolumeClaim, type RequestBody$replaceCoreV1NamespacedPersistentVolumeClaimStatus, type RequestBody$replaceCoreV1NamespacedPod, type RequestBody$replaceCoreV1NamespacedPodEphemeralcontainers, type RequestBody$replaceCoreV1NamespacedPodStatus, type RequestBody$replaceCoreV1NamespacedPodTemplate, type RequestBody$replaceCoreV1NamespacedReplicationController, type RequestBody$replaceCoreV1NamespacedReplicationControllerScale, type RequestBody$replaceCoreV1NamespacedReplicationControllerStatus, type RequestBody$replaceCoreV1NamespacedResourceQuota, type RequestBody$replaceCoreV1NamespacedResourceQuotaStatus, type RequestBody$replaceCoreV1NamespacedSecret, type RequestBody$replaceCoreV1NamespacedService, type RequestBody$replaceCoreV1NamespacedServiceAccount, type RequestBody$replaceCoreV1NamespacedServiceStatus, type RequestBody$replaceCoreV1Node, type RequestBody$replaceCoreV1NodeStatus, type RequestBody$replaceCoreV1PersistentVolume, type RequestBody$replaceCoreV1PersistentVolumeStatus, type RequestBody$replaceDiscoveryV1NamespacedEndpointSlice, type RequestBody$replaceEventsV1NamespacedEvent, type RequestBody$replaceFlowcontrolApiserverV1beta2FlowSchema, type RequestBody$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus, type RequestBody$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type RequestBody$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus, type RequestBody$replaceFlowcontrolApiserverV1beta3FlowSchema, type RequestBody$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus, type RequestBody$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type RequestBody$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus, type RequestBody$replaceInternalApiserverV1alpha1StorageVersion, type RequestBody$replaceInternalApiserverV1alpha1StorageVersionStatus, type RequestBody$replaceNetworkingV1IngressClass, type RequestBody$replaceNetworkingV1NamespacedIngress, type RequestBody$replaceNetworkingV1NamespacedIngressStatus, type RequestBody$replaceNetworkingV1NamespacedNetworkPolicy, type RequestBody$replaceNetworkingV1NamespacedNetworkPolicyStatus, type RequestBody$replaceNetworkingV1alpha1ClusterCIDR, type RequestBody$replaceNetworkingV1alpha1IPAddress, type RequestBody$replaceNodeV1RuntimeClass, type RequestBody$replacePolicyV1NamespacedPodDisruptionBudget, type RequestBody$replacePolicyV1NamespacedPodDisruptionBudgetStatus, type RequestBody$replaceRbacAuthorizationV1ClusterRole, type RequestBody$replaceRbacAuthorizationV1ClusterRoleBinding, type RequestBody$replaceRbacAuthorizationV1NamespacedRole, type RequestBody$replaceRbacAuthorizationV1NamespacedRoleBinding, type RequestBody$replaceResourceV1alpha2NamespacedPodSchedulingContext, type RequestBody$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus, type RequestBody$replaceResourceV1alpha2NamespacedResourceClaim, type RequestBody$replaceResourceV1alpha2NamespacedResourceClaimStatus, type RequestBody$replaceResourceV1alpha2NamespacedResourceClaimTemplate, type RequestBody$replaceResourceV1alpha2ResourceClass, type RequestBody$replaceSchedulingV1PriorityClass, type RequestBody$replaceStorageV1CSIDriver, type RequestBody$replaceStorageV1CSINode, type RequestBody$replaceStorageV1NamespacedCSIStorageCapacity, type RequestBody$replaceStorageV1StorageClass, type RequestBody$replaceStorageV1VolumeAttachment, type RequestBody$replaceStorageV1VolumeAttachmentStatus, type RequestContentType$createAdmissionregistrationV1MutatingWebhookConfiguration, type RequestContentType$createAdmissionregistrationV1ValidatingWebhookConfiguration, type RequestContentType$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type RequestContentType$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type RequestContentType$createApiextensionsV1CustomResourceDefinition, type RequestContentType$createApiregistrationV1APIService, type RequestContentType$createAppsV1NamespacedControllerRevision, type RequestContentType$createAppsV1NamespacedDaemonSet, type RequestContentType$createAppsV1NamespacedDeployment, type RequestContentType$createAppsV1NamespacedReplicaSet, type RequestContentType$createAppsV1NamespacedStatefulSet, type RequestContentType$createAuthenticationV1TokenReview, type RequestContentType$createAuthenticationV1alpha1SelfSubjectReview, type RequestContentType$createAuthenticationV1beta1SelfSubjectReview, type RequestContentType$createAuthorizationV1NamespacedLocalSubjectAccessReview, type RequestContentType$createAuthorizationV1SelfSubjectAccessReview, type RequestContentType$createAuthorizationV1SelfSubjectRulesReview, type RequestContentType$createAuthorizationV1SubjectAccessReview, type RequestContentType$createAutoscalingV1NamespacedHorizontalPodAutoscaler, type RequestContentType$createAutoscalingV2NamespacedHorizontalPodAutoscaler, type RequestContentType$createBatchV1NamespacedCronJob, type RequestContentType$createBatchV1NamespacedJob, type RequestContentType$createCertificatesV1CertificateSigningRequest, type RequestContentType$createCertificatesV1alpha1ClusterTrustBundle, type RequestContentType$createCoordinationV1NamespacedLease, type RequestContentType$createCoreV1Namespace, type RequestContentType$createCoreV1NamespacedBinding, type RequestContentType$createCoreV1NamespacedConfigMap, type RequestContentType$createCoreV1NamespacedEndpoints, type RequestContentType$createCoreV1NamespacedEvent, type RequestContentType$createCoreV1NamespacedLimitRange, type RequestContentType$createCoreV1NamespacedPersistentVolumeClaim, type RequestContentType$createCoreV1NamespacedPod, type RequestContentType$createCoreV1NamespacedPodBinding, type RequestContentType$createCoreV1NamespacedPodEviction, type RequestContentType$createCoreV1NamespacedPodTemplate, type RequestContentType$createCoreV1NamespacedReplicationController, type RequestContentType$createCoreV1NamespacedResourceQuota, type RequestContentType$createCoreV1NamespacedSecret, type RequestContentType$createCoreV1NamespacedService, type RequestContentType$createCoreV1NamespacedServiceAccount, type RequestContentType$createCoreV1NamespacedServiceAccountToken, type RequestContentType$createCoreV1Node, type RequestContentType$createCoreV1PersistentVolume, type RequestContentType$createDiscoveryV1NamespacedEndpointSlice, type RequestContentType$createEventsV1NamespacedEvent, type RequestContentType$createFlowcontrolApiserverV1beta2FlowSchema, type RequestContentType$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type RequestContentType$createFlowcontrolApiserverV1beta3FlowSchema, type RequestContentType$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type RequestContentType$createInternalApiserverV1alpha1StorageVersion, type RequestContentType$createNetworkingV1IngressClass, type RequestContentType$createNetworkingV1NamespacedIngress, type RequestContentType$createNetworkingV1NamespacedNetworkPolicy, type RequestContentType$createNetworkingV1alpha1ClusterCIDR, type RequestContentType$createNetworkingV1alpha1IPAddress, type RequestContentType$createNodeV1RuntimeClass, type RequestContentType$createPolicyV1NamespacedPodDisruptionBudget, type RequestContentType$createRbacAuthorizationV1ClusterRole, type RequestContentType$createRbacAuthorizationV1ClusterRoleBinding, type RequestContentType$createRbacAuthorizationV1NamespacedRole, type RequestContentType$createRbacAuthorizationV1NamespacedRoleBinding, type RequestContentType$createResourceV1alpha2NamespacedPodSchedulingContext, type RequestContentType$createResourceV1alpha2NamespacedResourceClaim, type RequestContentType$createResourceV1alpha2NamespacedResourceClaimTemplate, type RequestContentType$createResourceV1alpha2ResourceClass, type RequestContentType$createSchedulingV1PriorityClass, type RequestContentType$createStorageV1CSIDriver, type RequestContentType$createStorageV1CSINode, type RequestContentType$createStorageV1NamespacedCSIStorageCapacity, type RequestContentType$createStorageV1StorageClass, type RequestContentType$createStorageV1VolumeAttachment, type RequestContentType$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration, type RequestContentType$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration, type RequestContentType$deleteAdmissionregistrationV1MutatingWebhookConfiguration, type RequestContentType$deleteAdmissionregistrationV1ValidatingWebhookConfiguration, type RequestContentType$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy, type RequestContentType$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding, type RequestContentType$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type RequestContentType$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type RequestContentType$deleteApiextensionsV1CollectionCustomResourceDefinition, type RequestContentType$deleteApiextensionsV1CustomResourceDefinition, type RequestContentType$deleteApiregistrationV1APIService, type RequestContentType$deleteApiregistrationV1CollectionAPIService, type RequestContentType$deleteAppsV1CollectionNamespacedControllerRevision, type RequestContentType$deleteAppsV1CollectionNamespacedDaemonSet, type RequestContentType$deleteAppsV1CollectionNamespacedDeployment, type RequestContentType$deleteAppsV1CollectionNamespacedReplicaSet, type RequestContentType$deleteAppsV1CollectionNamespacedStatefulSet, type RequestContentType$deleteAppsV1NamespacedControllerRevision, type RequestContentType$deleteAppsV1NamespacedDaemonSet, type RequestContentType$deleteAppsV1NamespacedDeployment, type RequestContentType$deleteAppsV1NamespacedReplicaSet, type RequestContentType$deleteAppsV1NamespacedStatefulSet, type RequestContentType$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler, type RequestContentType$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler, type RequestContentType$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler, type RequestContentType$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler, type RequestContentType$deleteBatchV1CollectionNamespacedCronJob, type RequestContentType$deleteBatchV1CollectionNamespacedJob, type RequestContentType$deleteBatchV1NamespacedCronJob, type RequestContentType$deleteBatchV1NamespacedJob, type RequestContentType$deleteCertificatesV1CertificateSigningRequest, type RequestContentType$deleteCertificatesV1CollectionCertificateSigningRequest, type RequestContentType$deleteCertificatesV1alpha1ClusterTrustBundle, type RequestContentType$deleteCertificatesV1alpha1CollectionClusterTrustBundle, type RequestContentType$deleteCoordinationV1CollectionNamespacedLease, type RequestContentType$deleteCoordinationV1NamespacedLease, type RequestContentType$deleteCoreV1CollectionNamespacedConfigMap, type RequestContentType$deleteCoreV1CollectionNamespacedEndpoints, type RequestContentType$deleteCoreV1CollectionNamespacedEvent, type RequestContentType$deleteCoreV1CollectionNamespacedLimitRange, type RequestContentType$deleteCoreV1CollectionNamespacedPersistentVolumeClaim, type RequestContentType$deleteCoreV1CollectionNamespacedPod, type RequestContentType$deleteCoreV1CollectionNamespacedPodTemplate, type RequestContentType$deleteCoreV1CollectionNamespacedReplicationController, type RequestContentType$deleteCoreV1CollectionNamespacedResourceQuota, type RequestContentType$deleteCoreV1CollectionNamespacedSecret, type RequestContentType$deleteCoreV1CollectionNamespacedService, type RequestContentType$deleteCoreV1CollectionNamespacedServiceAccount, type RequestContentType$deleteCoreV1CollectionNode, type RequestContentType$deleteCoreV1CollectionPersistentVolume, type RequestContentType$deleteCoreV1Namespace, type RequestContentType$deleteCoreV1NamespacedConfigMap, type RequestContentType$deleteCoreV1NamespacedEndpoints, type RequestContentType$deleteCoreV1NamespacedEvent, type RequestContentType$deleteCoreV1NamespacedLimitRange, type RequestContentType$deleteCoreV1NamespacedPersistentVolumeClaim, type RequestContentType$deleteCoreV1NamespacedPod, type RequestContentType$deleteCoreV1NamespacedPodTemplate, type RequestContentType$deleteCoreV1NamespacedReplicationController, type RequestContentType$deleteCoreV1NamespacedResourceQuota, type RequestContentType$deleteCoreV1NamespacedSecret, type RequestContentType$deleteCoreV1NamespacedService, type RequestContentType$deleteCoreV1NamespacedServiceAccount, type RequestContentType$deleteCoreV1Node, type RequestContentType$deleteCoreV1PersistentVolume, type RequestContentType$deleteDiscoveryV1CollectionNamespacedEndpointSlice, type RequestContentType$deleteDiscoveryV1NamespacedEndpointSlice, type RequestContentType$deleteEventsV1CollectionNamespacedEvent, type RequestContentType$deleteEventsV1NamespacedEvent, type RequestContentType$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema, type RequestContentType$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration, type RequestContentType$deleteFlowcontrolApiserverV1beta2FlowSchema, type RequestContentType$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type RequestContentType$deleteFlowcontrolApiserverV1beta3CollectionFlowSchema, type RequestContentType$deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration, type RequestContentType$deleteFlowcontrolApiserverV1beta3FlowSchema, type RequestContentType$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type RequestContentType$deleteInternalApiserverV1alpha1CollectionStorageVersion, type RequestContentType$deleteInternalApiserverV1alpha1StorageVersion, type RequestContentType$deleteNetworkingV1CollectionIngressClass, type RequestContentType$deleteNetworkingV1CollectionNamespacedIngress, type RequestContentType$deleteNetworkingV1CollectionNamespacedNetworkPolicy, type RequestContentType$deleteNetworkingV1IngressClass, type RequestContentType$deleteNetworkingV1NamespacedIngress, type RequestContentType$deleteNetworkingV1NamespacedNetworkPolicy, type RequestContentType$deleteNetworkingV1alpha1ClusterCIDR, type RequestContentType$deleteNetworkingV1alpha1CollectionClusterCIDR, type RequestContentType$deleteNetworkingV1alpha1CollectionIPAddress, type RequestContentType$deleteNetworkingV1alpha1IPAddress, type RequestContentType$deleteNodeV1CollectionRuntimeClass, type RequestContentType$deleteNodeV1RuntimeClass, type RequestContentType$deletePolicyV1CollectionNamespacedPodDisruptionBudget, type RequestContentType$deletePolicyV1NamespacedPodDisruptionBudget, type RequestContentType$deleteRbacAuthorizationV1ClusterRole, type RequestContentType$deleteRbacAuthorizationV1ClusterRoleBinding, type RequestContentType$deleteRbacAuthorizationV1CollectionClusterRole, type RequestContentType$deleteRbacAuthorizationV1CollectionClusterRoleBinding, type RequestContentType$deleteRbacAuthorizationV1CollectionNamespacedRole, type RequestContentType$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding, type RequestContentType$deleteRbacAuthorizationV1NamespacedRole, type RequestContentType$deleteRbacAuthorizationV1NamespacedRoleBinding, type RequestContentType$deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext, type RequestContentType$deleteResourceV1alpha2CollectionNamespacedResourceClaim, type RequestContentType$deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate, type RequestContentType$deleteResourceV1alpha2CollectionResourceClass, type RequestContentType$deleteResourceV1alpha2NamespacedPodSchedulingContext, type RequestContentType$deleteResourceV1alpha2NamespacedResourceClaim, type RequestContentType$deleteResourceV1alpha2NamespacedResourceClaimTemplate, type RequestContentType$deleteResourceV1alpha2ResourceClass, type RequestContentType$deleteSchedulingV1CollectionPriorityClass, type RequestContentType$deleteSchedulingV1PriorityClass, type RequestContentType$deleteStorageV1CSIDriver, type RequestContentType$deleteStorageV1CSINode, type RequestContentType$deleteStorageV1CollectionCSIDriver, type RequestContentType$deleteStorageV1CollectionCSINode, type RequestContentType$deleteStorageV1CollectionNamespacedCSIStorageCapacity, type RequestContentType$deleteStorageV1CollectionStorageClass, type RequestContentType$deleteStorageV1CollectionVolumeAttachment, type RequestContentType$deleteStorageV1NamespacedCSIStorageCapacity, type RequestContentType$deleteStorageV1StorageClass, type RequestContentType$deleteStorageV1VolumeAttachment, type RequestContentType$patchAdmissionregistrationV1MutatingWebhookConfiguration, type RequestContentType$patchAdmissionregistrationV1ValidatingWebhookConfiguration, type RequestContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type RequestContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type RequestContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus, type RequestContentType$patchApiextensionsV1CustomResourceDefinition, type RequestContentType$patchApiextensionsV1CustomResourceDefinitionStatus, type RequestContentType$patchApiregistrationV1APIService, type RequestContentType$patchApiregistrationV1APIServiceStatus, type RequestContentType$patchAppsV1NamespacedControllerRevision, type RequestContentType$patchAppsV1NamespacedDaemonSet, type RequestContentType$patchAppsV1NamespacedDaemonSetStatus, type RequestContentType$patchAppsV1NamespacedDeployment, type RequestContentType$patchAppsV1NamespacedDeploymentScale, type RequestContentType$patchAppsV1NamespacedDeploymentStatus, type RequestContentType$patchAppsV1NamespacedReplicaSet, type RequestContentType$patchAppsV1NamespacedReplicaSetScale, type RequestContentType$patchAppsV1NamespacedReplicaSetStatus, type RequestContentType$patchAppsV1NamespacedStatefulSet, type RequestContentType$patchAppsV1NamespacedStatefulSetScale, type RequestContentType$patchAppsV1NamespacedStatefulSetStatus, type RequestContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscaler, type RequestContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus, type RequestContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscaler, type RequestContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus, type RequestContentType$patchBatchV1NamespacedCronJob, type RequestContentType$patchBatchV1NamespacedCronJobStatus, type RequestContentType$patchBatchV1NamespacedJob, type RequestContentType$patchBatchV1NamespacedJobStatus, type RequestContentType$patchCertificatesV1CertificateSigningRequest, type RequestContentType$patchCertificatesV1CertificateSigningRequestApproval, type RequestContentType$patchCertificatesV1CertificateSigningRequestStatus, type RequestContentType$patchCertificatesV1alpha1ClusterTrustBundle, type RequestContentType$patchCoordinationV1NamespacedLease, type RequestContentType$patchCoreV1Namespace, type RequestContentType$patchCoreV1NamespaceStatus, type RequestContentType$patchCoreV1NamespacedConfigMap, type RequestContentType$patchCoreV1NamespacedEndpoints, type RequestContentType$patchCoreV1NamespacedEvent, type RequestContentType$patchCoreV1NamespacedLimitRange, type RequestContentType$patchCoreV1NamespacedPersistentVolumeClaim, type RequestContentType$patchCoreV1NamespacedPersistentVolumeClaimStatus, type RequestContentType$patchCoreV1NamespacedPod, type RequestContentType$patchCoreV1NamespacedPodEphemeralcontainers, type RequestContentType$patchCoreV1NamespacedPodStatus, type RequestContentType$patchCoreV1NamespacedPodTemplate, type RequestContentType$patchCoreV1NamespacedReplicationController, type RequestContentType$patchCoreV1NamespacedReplicationControllerScale, type RequestContentType$patchCoreV1NamespacedReplicationControllerStatus, type RequestContentType$patchCoreV1NamespacedResourceQuota, type RequestContentType$patchCoreV1NamespacedResourceQuotaStatus, type RequestContentType$patchCoreV1NamespacedSecret, type RequestContentType$patchCoreV1NamespacedService, type RequestContentType$patchCoreV1NamespacedServiceAccount, type RequestContentType$patchCoreV1NamespacedServiceStatus, type RequestContentType$patchCoreV1Node, type RequestContentType$patchCoreV1NodeStatus, type RequestContentType$patchCoreV1PersistentVolume, type RequestContentType$patchCoreV1PersistentVolumeStatus, type RequestContentType$patchDiscoveryV1NamespacedEndpointSlice, type RequestContentType$patchEventsV1NamespacedEvent, type RequestContentType$patchFlowcontrolApiserverV1beta2FlowSchema, type RequestContentType$patchFlowcontrolApiserverV1beta2FlowSchemaStatus, type RequestContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type RequestContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus, type RequestContentType$patchFlowcontrolApiserverV1beta3FlowSchema, type RequestContentType$patchFlowcontrolApiserverV1beta3FlowSchemaStatus, type RequestContentType$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type RequestContentType$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus, type RequestContentType$patchInternalApiserverV1alpha1StorageVersion, type RequestContentType$patchInternalApiserverV1alpha1StorageVersionStatus, type RequestContentType$patchNetworkingV1IngressClass, type RequestContentType$patchNetworkingV1NamespacedIngress, type RequestContentType$patchNetworkingV1NamespacedIngressStatus, type RequestContentType$patchNetworkingV1NamespacedNetworkPolicy, type RequestContentType$patchNetworkingV1NamespacedNetworkPolicyStatus, type RequestContentType$patchNetworkingV1alpha1ClusterCIDR, type RequestContentType$patchNetworkingV1alpha1IPAddress, type RequestContentType$patchNodeV1RuntimeClass, type RequestContentType$patchPolicyV1NamespacedPodDisruptionBudget, type RequestContentType$patchPolicyV1NamespacedPodDisruptionBudgetStatus, type RequestContentType$patchRbacAuthorizationV1ClusterRole, type RequestContentType$patchRbacAuthorizationV1ClusterRoleBinding, type RequestContentType$patchRbacAuthorizationV1NamespacedRole, type RequestContentType$patchRbacAuthorizationV1NamespacedRoleBinding, type RequestContentType$patchResourceV1alpha2NamespacedPodSchedulingContext, type RequestContentType$patchResourceV1alpha2NamespacedPodSchedulingContextStatus, type RequestContentType$patchResourceV1alpha2NamespacedResourceClaim, type RequestContentType$patchResourceV1alpha2NamespacedResourceClaimStatus, type RequestContentType$patchResourceV1alpha2NamespacedResourceClaimTemplate, type RequestContentType$patchResourceV1alpha2ResourceClass, type RequestContentType$patchSchedulingV1PriorityClass, type RequestContentType$patchStorageV1CSIDriver, type RequestContentType$patchStorageV1CSINode, type RequestContentType$patchStorageV1NamespacedCSIStorageCapacity, type RequestContentType$patchStorageV1StorageClass, type RequestContentType$patchStorageV1VolumeAttachment, type RequestContentType$patchStorageV1VolumeAttachmentStatus, type RequestContentType$replaceAdmissionregistrationV1MutatingWebhookConfiguration, type RequestContentType$replaceAdmissionregistrationV1ValidatingWebhookConfiguration, type RequestContentType$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type RequestContentType$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type RequestContentType$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus, type RequestContentType$replaceApiextensionsV1CustomResourceDefinition, type RequestContentType$replaceApiextensionsV1CustomResourceDefinitionStatus, type RequestContentType$replaceApiregistrationV1APIService, type RequestContentType$replaceApiregistrationV1APIServiceStatus, type RequestContentType$replaceAppsV1NamespacedControllerRevision, type RequestContentType$replaceAppsV1NamespacedDaemonSet, type RequestContentType$replaceAppsV1NamespacedDaemonSetStatus, type RequestContentType$replaceAppsV1NamespacedDeployment, type RequestContentType$replaceAppsV1NamespacedDeploymentScale, type RequestContentType$replaceAppsV1NamespacedDeploymentStatus, type RequestContentType$replaceAppsV1NamespacedReplicaSet, type RequestContentType$replaceAppsV1NamespacedReplicaSetScale, type RequestContentType$replaceAppsV1NamespacedReplicaSetStatus, type RequestContentType$replaceAppsV1NamespacedStatefulSet, type RequestContentType$replaceAppsV1NamespacedStatefulSetScale, type RequestContentType$replaceAppsV1NamespacedStatefulSetStatus, type RequestContentType$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler, type RequestContentType$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus, type RequestContentType$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler, type RequestContentType$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus, type RequestContentType$replaceBatchV1NamespacedCronJob, type RequestContentType$replaceBatchV1NamespacedCronJobStatus, type RequestContentType$replaceBatchV1NamespacedJob, type RequestContentType$replaceBatchV1NamespacedJobStatus, type RequestContentType$replaceCertificatesV1CertificateSigningRequest, type RequestContentType$replaceCertificatesV1CertificateSigningRequestApproval, type RequestContentType$replaceCertificatesV1CertificateSigningRequestStatus, type RequestContentType$replaceCertificatesV1alpha1ClusterTrustBundle, type RequestContentType$replaceCoordinationV1NamespacedLease, type RequestContentType$replaceCoreV1Namespace, type RequestContentType$replaceCoreV1NamespaceFinalize, type RequestContentType$replaceCoreV1NamespaceStatus, type RequestContentType$replaceCoreV1NamespacedConfigMap, type RequestContentType$replaceCoreV1NamespacedEndpoints, type RequestContentType$replaceCoreV1NamespacedEvent, type RequestContentType$replaceCoreV1NamespacedLimitRange, type RequestContentType$replaceCoreV1NamespacedPersistentVolumeClaim, type RequestContentType$replaceCoreV1NamespacedPersistentVolumeClaimStatus, type RequestContentType$replaceCoreV1NamespacedPod, type RequestContentType$replaceCoreV1NamespacedPodEphemeralcontainers, type RequestContentType$replaceCoreV1NamespacedPodStatus, type RequestContentType$replaceCoreV1NamespacedPodTemplate, type RequestContentType$replaceCoreV1NamespacedReplicationController, type RequestContentType$replaceCoreV1NamespacedReplicationControllerScale, type RequestContentType$replaceCoreV1NamespacedReplicationControllerStatus, type RequestContentType$replaceCoreV1NamespacedResourceQuota, type RequestContentType$replaceCoreV1NamespacedResourceQuotaStatus, type RequestContentType$replaceCoreV1NamespacedSecret, type RequestContentType$replaceCoreV1NamespacedService, type RequestContentType$replaceCoreV1NamespacedServiceAccount, type RequestContentType$replaceCoreV1NamespacedServiceStatus, type RequestContentType$replaceCoreV1Node, type RequestContentType$replaceCoreV1NodeStatus, type RequestContentType$replaceCoreV1PersistentVolume, type RequestContentType$replaceCoreV1PersistentVolumeStatus, type RequestContentType$replaceDiscoveryV1NamespacedEndpointSlice, type RequestContentType$replaceEventsV1NamespacedEvent, type RequestContentType$replaceFlowcontrolApiserverV1beta2FlowSchema, type RequestContentType$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus, type RequestContentType$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type RequestContentType$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus, type RequestContentType$replaceFlowcontrolApiserverV1beta3FlowSchema, type RequestContentType$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus, type RequestContentType$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type RequestContentType$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus, type RequestContentType$replaceInternalApiserverV1alpha1StorageVersion, type RequestContentType$replaceInternalApiserverV1alpha1StorageVersionStatus, type RequestContentType$replaceNetworkingV1IngressClass, type RequestContentType$replaceNetworkingV1NamespacedIngress, type RequestContentType$replaceNetworkingV1NamespacedIngressStatus, type RequestContentType$replaceNetworkingV1NamespacedNetworkPolicy, type RequestContentType$replaceNetworkingV1NamespacedNetworkPolicyStatus, type RequestContentType$replaceNetworkingV1alpha1ClusterCIDR, type RequestContentType$replaceNetworkingV1alpha1IPAddress, type RequestContentType$replaceNodeV1RuntimeClass, type RequestContentType$replacePolicyV1NamespacedPodDisruptionBudget, type RequestContentType$replacePolicyV1NamespacedPodDisruptionBudgetStatus, type RequestContentType$replaceRbacAuthorizationV1ClusterRole, type RequestContentType$replaceRbacAuthorizationV1ClusterRoleBinding, type RequestContentType$replaceRbacAuthorizationV1NamespacedRole, type RequestContentType$replaceRbacAuthorizationV1NamespacedRoleBinding, type RequestContentType$replaceResourceV1alpha2NamespacedPodSchedulingContext, type RequestContentType$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus, type RequestContentType$replaceResourceV1alpha2NamespacedResourceClaim, type RequestContentType$replaceResourceV1alpha2NamespacedResourceClaimStatus, type RequestContentType$replaceResourceV1alpha2NamespacedResourceClaimTemplate, type RequestContentType$replaceResourceV1alpha2ResourceClass, type RequestContentType$replaceSchedulingV1PriorityClass, type RequestContentType$replaceStorageV1CSIDriver, type RequestContentType$replaceStorageV1CSINode, type RequestContentType$replaceStorageV1NamespacedCSIStorageCapacity, type RequestContentType$replaceStorageV1StorageClass, type RequestContentType$replaceStorageV1VolumeAttachment, type RequestContentType$replaceStorageV1VolumeAttachmentStatus, type Response$connectCoreV1DeleteNamespacedPodProxy$Status$200, type Response$connectCoreV1DeleteNamespacedPodProxyWithPath$Status$200, type Response$connectCoreV1DeleteNamespacedServiceProxy$Status$200, type Response$connectCoreV1DeleteNamespacedServiceProxyWithPath$Status$200, type Response$connectCoreV1DeleteNodeProxy$Status$200, type Response$connectCoreV1DeleteNodeProxyWithPath$Status$200, type Response$connectCoreV1GetNamespacedPodAttach$Status$200, type Response$connectCoreV1GetNamespacedPodExec$Status$200, type Response$connectCoreV1GetNamespacedPodPortforward$Status$200, type Response$connectCoreV1GetNamespacedPodProxy$Status$200, type Response$connectCoreV1GetNamespacedPodProxyWithPath$Status$200, type Response$connectCoreV1GetNamespacedServiceProxy$Status$200, type Response$connectCoreV1GetNamespacedServiceProxyWithPath$Status$200, type Response$connectCoreV1GetNodeProxy$Status$200, type Response$connectCoreV1GetNodeProxyWithPath$Status$200, type Response$connectCoreV1HeadNamespacedPodProxy$Status$200, type Response$connectCoreV1HeadNamespacedPodProxyWithPath$Status$200, type Response$connectCoreV1HeadNamespacedServiceProxy$Status$200, type Response$connectCoreV1HeadNamespacedServiceProxyWithPath$Status$200, type Response$connectCoreV1HeadNodeProxy$Status$200, type Response$connectCoreV1HeadNodeProxyWithPath$Status$200, type Response$connectCoreV1OptionsNamespacedPodProxy$Status$200, type Response$connectCoreV1OptionsNamespacedPodProxyWithPath$Status$200, type Response$connectCoreV1OptionsNamespacedServiceProxy$Status$200, type Response$connectCoreV1OptionsNamespacedServiceProxyWithPath$Status$200, type Response$connectCoreV1OptionsNodeProxy$Status$200, type Response$connectCoreV1OptionsNodeProxyWithPath$Status$200, type Response$connectCoreV1PatchNamespacedPodProxy$Status$200, type Response$connectCoreV1PatchNamespacedPodProxyWithPath$Status$200, type Response$connectCoreV1PatchNamespacedServiceProxy$Status$200, type Response$connectCoreV1PatchNamespacedServiceProxyWithPath$Status$200, type Response$connectCoreV1PatchNodeProxy$Status$200, type Response$connectCoreV1PatchNodeProxyWithPath$Status$200, type Response$connectCoreV1PostNamespacedPodAttach$Status$200, type Response$connectCoreV1PostNamespacedPodExec$Status$200, type Response$connectCoreV1PostNamespacedPodPortforward$Status$200, type Response$connectCoreV1PostNamespacedPodProxy$Status$200, type Response$connectCoreV1PostNamespacedPodProxyWithPath$Status$200, type Response$connectCoreV1PostNamespacedServiceProxy$Status$200, type Response$connectCoreV1PostNamespacedServiceProxyWithPath$Status$200, type Response$connectCoreV1PostNodeProxy$Status$200, type Response$connectCoreV1PostNodeProxyWithPath$Status$200, type Response$connectCoreV1PutNamespacedPodProxy$Status$200, type Response$connectCoreV1PutNamespacedPodProxyWithPath$Status$200, type Response$connectCoreV1PutNamespacedServiceProxy$Status$200, type Response$connectCoreV1PutNamespacedServiceProxyWithPath$Status$200, type Response$connectCoreV1PutNodeProxy$Status$200, type Response$connectCoreV1PutNodeProxyWithPath$Status$200, type Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$200, type Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$201, type Response$createAdmissionregistrationV1MutatingWebhookConfiguration$Status$202, type Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200, type Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201, type Response$createAdmissionregistrationV1ValidatingWebhookConfiguration$Status$202, type Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200, type Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$201, type Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$202, type Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200, type Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$201, type Response$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$202, type Response$createApiextensionsV1CustomResourceDefinition$Status$200, type Response$createApiextensionsV1CustomResourceDefinition$Status$201, type Response$createApiextensionsV1CustomResourceDefinition$Status$202, type Response$createApiregistrationV1APIService$Status$200, type Response$createApiregistrationV1APIService$Status$201, type Response$createApiregistrationV1APIService$Status$202, type Response$createAppsV1NamespacedControllerRevision$Status$200, type Response$createAppsV1NamespacedControllerRevision$Status$201, type Response$createAppsV1NamespacedControllerRevision$Status$202, type Response$createAppsV1NamespacedDaemonSet$Status$200, type Response$createAppsV1NamespacedDaemonSet$Status$201, type Response$createAppsV1NamespacedDaemonSet$Status$202, type Response$createAppsV1NamespacedDeployment$Status$200, type Response$createAppsV1NamespacedDeployment$Status$201, type Response$createAppsV1NamespacedDeployment$Status$202, type Response$createAppsV1NamespacedReplicaSet$Status$200, type Response$createAppsV1NamespacedReplicaSet$Status$201, type Response$createAppsV1NamespacedReplicaSet$Status$202, type Response$createAppsV1NamespacedStatefulSet$Status$200, type Response$createAppsV1NamespacedStatefulSet$Status$201, type Response$createAppsV1NamespacedStatefulSet$Status$202, type Response$createAuthenticationV1TokenReview$Status$200, type Response$createAuthenticationV1TokenReview$Status$201, type Response$createAuthenticationV1TokenReview$Status$202, type Response$createAuthenticationV1alpha1SelfSubjectReview$Status$200, type Response$createAuthenticationV1alpha1SelfSubjectReview$Status$201, type Response$createAuthenticationV1alpha1SelfSubjectReview$Status$202, type Response$createAuthenticationV1beta1SelfSubjectReview$Status$200, type Response$createAuthenticationV1beta1SelfSubjectReview$Status$201, type Response$createAuthenticationV1beta1SelfSubjectReview$Status$202, type Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$200, type Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$201, type Response$createAuthorizationV1NamespacedLocalSubjectAccessReview$Status$202, type Response$createAuthorizationV1SelfSubjectAccessReview$Status$200, type Response$createAuthorizationV1SelfSubjectAccessReview$Status$201, type Response$createAuthorizationV1SelfSubjectAccessReview$Status$202, type Response$createAuthorizationV1SelfSubjectRulesReview$Status$200, type Response$createAuthorizationV1SelfSubjectRulesReview$Status$201, type Response$createAuthorizationV1SelfSubjectRulesReview$Status$202, type Response$createAuthorizationV1SubjectAccessReview$Status$200, type Response$createAuthorizationV1SubjectAccessReview$Status$201, type Response$createAuthorizationV1SubjectAccessReview$Status$202, type Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200, type Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201, type Response$createAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$202, type Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200, type Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201, type Response$createAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$202, type Response$createBatchV1NamespacedCronJob$Status$200, type Response$createBatchV1NamespacedCronJob$Status$201, type Response$createBatchV1NamespacedCronJob$Status$202, type Response$createBatchV1NamespacedJob$Status$200, type Response$createBatchV1NamespacedJob$Status$201, type Response$createBatchV1NamespacedJob$Status$202, type Response$createCertificatesV1CertificateSigningRequest$Status$200, type Response$createCertificatesV1CertificateSigningRequest$Status$201, type Response$createCertificatesV1CertificateSigningRequest$Status$202, type Response$createCertificatesV1alpha1ClusterTrustBundle$Status$200, type Response$createCertificatesV1alpha1ClusterTrustBundle$Status$201, type Response$createCertificatesV1alpha1ClusterTrustBundle$Status$202, type Response$createCoordinationV1NamespacedLease$Status$200, type Response$createCoordinationV1NamespacedLease$Status$201, type Response$createCoordinationV1NamespacedLease$Status$202, type Response$createCoreV1Namespace$Status$200, type Response$createCoreV1Namespace$Status$201, type Response$createCoreV1Namespace$Status$202, type Response$createCoreV1NamespacedBinding$Status$200, type Response$createCoreV1NamespacedBinding$Status$201, type Response$createCoreV1NamespacedBinding$Status$202, type Response$createCoreV1NamespacedConfigMap$Status$200, type Response$createCoreV1NamespacedConfigMap$Status$201, type Response$createCoreV1NamespacedConfigMap$Status$202, type Response$createCoreV1NamespacedEndpoints$Status$200, type Response$createCoreV1NamespacedEndpoints$Status$201, type Response$createCoreV1NamespacedEndpoints$Status$202, type Response$createCoreV1NamespacedEvent$Status$200, type Response$createCoreV1NamespacedEvent$Status$201, type Response$createCoreV1NamespacedEvent$Status$202, type Response$createCoreV1NamespacedLimitRange$Status$200, type Response$createCoreV1NamespacedLimitRange$Status$201, type Response$createCoreV1NamespacedLimitRange$Status$202, type Response$createCoreV1NamespacedPersistentVolumeClaim$Status$200, type Response$createCoreV1NamespacedPersistentVolumeClaim$Status$201, type Response$createCoreV1NamespacedPersistentVolumeClaim$Status$202, type Response$createCoreV1NamespacedPod$Status$200, type Response$createCoreV1NamespacedPod$Status$201, type Response$createCoreV1NamespacedPod$Status$202, type Response$createCoreV1NamespacedPodBinding$Status$200, type Response$createCoreV1NamespacedPodBinding$Status$201, type Response$createCoreV1NamespacedPodBinding$Status$202, type Response$createCoreV1NamespacedPodEviction$Status$200, type Response$createCoreV1NamespacedPodEviction$Status$201, type Response$createCoreV1NamespacedPodEviction$Status$202, type Response$createCoreV1NamespacedPodTemplate$Status$200, type Response$createCoreV1NamespacedPodTemplate$Status$201, type Response$createCoreV1NamespacedPodTemplate$Status$202, type Response$createCoreV1NamespacedReplicationController$Status$200, type Response$createCoreV1NamespacedReplicationController$Status$201, type Response$createCoreV1NamespacedReplicationController$Status$202, type Response$createCoreV1NamespacedResourceQuota$Status$200, type Response$createCoreV1NamespacedResourceQuota$Status$201, type Response$createCoreV1NamespacedResourceQuota$Status$202, type Response$createCoreV1NamespacedSecret$Status$200, type Response$createCoreV1NamespacedSecret$Status$201, type Response$createCoreV1NamespacedSecret$Status$202, type Response$createCoreV1NamespacedService$Status$200, type Response$createCoreV1NamespacedService$Status$201, type Response$createCoreV1NamespacedService$Status$202, type Response$createCoreV1NamespacedServiceAccount$Status$200, type Response$createCoreV1NamespacedServiceAccount$Status$201, type Response$createCoreV1NamespacedServiceAccount$Status$202, type Response$createCoreV1NamespacedServiceAccountToken$Status$200, type Response$createCoreV1NamespacedServiceAccountToken$Status$201, type Response$createCoreV1NamespacedServiceAccountToken$Status$202, type Response$createCoreV1Node$Status$200, type Response$createCoreV1Node$Status$201, type Response$createCoreV1Node$Status$202, type Response$createCoreV1PersistentVolume$Status$200, type Response$createCoreV1PersistentVolume$Status$201, type Response$createCoreV1PersistentVolume$Status$202, type Response$createDiscoveryV1NamespacedEndpointSlice$Status$200, type Response$createDiscoveryV1NamespacedEndpointSlice$Status$201, type Response$createDiscoveryV1NamespacedEndpointSlice$Status$202, type Response$createEventsV1NamespacedEvent$Status$200, type Response$createEventsV1NamespacedEvent$Status$201, type Response$createEventsV1NamespacedEvent$Status$202, type Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$200, type Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$201, type Response$createFlowcontrolApiserverV1beta2FlowSchema$Status$202, type Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200, type Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201, type Response$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$202, type Response$createFlowcontrolApiserverV1beta3FlowSchema$Status$200, type Response$createFlowcontrolApiserverV1beta3FlowSchema$Status$201, type Response$createFlowcontrolApiserverV1beta3FlowSchema$Status$202, type Response$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200, type Response$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$201, type Response$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$202, type Response$createInternalApiserverV1alpha1StorageVersion$Status$200, type Response$createInternalApiserverV1alpha1StorageVersion$Status$201, type Response$createInternalApiserverV1alpha1StorageVersion$Status$202, type Response$createNetworkingV1IngressClass$Status$200, type Response$createNetworkingV1IngressClass$Status$201, type Response$createNetworkingV1IngressClass$Status$202, type Response$createNetworkingV1NamespacedIngress$Status$200, type Response$createNetworkingV1NamespacedIngress$Status$201, type Response$createNetworkingV1NamespacedIngress$Status$202, type Response$createNetworkingV1NamespacedNetworkPolicy$Status$200, type Response$createNetworkingV1NamespacedNetworkPolicy$Status$201, type Response$createNetworkingV1NamespacedNetworkPolicy$Status$202, type Response$createNetworkingV1alpha1ClusterCIDR$Status$200, type Response$createNetworkingV1alpha1ClusterCIDR$Status$201, type Response$createNetworkingV1alpha1ClusterCIDR$Status$202, type Response$createNetworkingV1alpha1IPAddress$Status$200, type Response$createNetworkingV1alpha1IPAddress$Status$201, type Response$createNetworkingV1alpha1IPAddress$Status$202, type Response$createNodeV1RuntimeClass$Status$200, type Response$createNodeV1RuntimeClass$Status$201, type Response$createNodeV1RuntimeClass$Status$202, type Response$createPolicyV1NamespacedPodDisruptionBudget$Status$200, type Response$createPolicyV1NamespacedPodDisruptionBudget$Status$201, type Response$createPolicyV1NamespacedPodDisruptionBudget$Status$202, type Response$createRbacAuthorizationV1ClusterRole$Status$200, type Response$createRbacAuthorizationV1ClusterRole$Status$201, type Response$createRbacAuthorizationV1ClusterRole$Status$202, type Response$createRbacAuthorizationV1ClusterRoleBinding$Status$200, type Response$createRbacAuthorizationV1ClusterRoleBinding$Status$201, type Response$createRbacAuthorizationV1ClusterRoleBinding$Status$202, type Response$createRbacAuthorizationV1NamespacedRole$Status$200, type Response$createRbacAuthorizationV1NamespacedRole$Status$201, type Response$createRbacAuthorizationV1NamespacedRole$Status$202, type Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$200, type Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$201, type Response$createRbacAuthorizationV1NamespacedRoleBinding$Status$202, type Response$createResourceV1alpha2NamespacedPodSchedulingContext$Status$200, type Response$createResourceV1alpha2NamespacedPodSchedulingContext$Status$201, type Response$createResourceV1alpha2NamespacedPodSchedulingContext$Status$202, type Response$createResourceV1alpha2NamespacedResourceClaim$Status$200, type Response$createResourceV1alpha2NamespacedResourceClaim$Status$201, type Response$createResourceV1alpha2NamespacedResourceClaim$Status$202, type Response$createResourceV1alpha2NamespacedResourceClaimTemplate$Status$200, type Response$createResourceV1alpha2NamespacedResourceClaimTemplate$Status$201, type Response$createResourceV1alpha2NamespacedResourceClaimTemplate$Status$202, type Response$createResourceV1alpha2ResourceClass$Status$200, type Response$createResourceV1alpha2ResourceClass$Status$201, type Response$createResourceV1alpha2ResourceClass$Status$202, type Response$createSchedulingV1PriorityClass$Status$200, type Response$createSchedulingV1PriorityClass$Status$201, type Response$createSchedulingV1PriorityClass$Status$202, type Response$createStorageV1CSIDriver$Status$200, type Response$createStorageV1CSIDriver$Status$201, type Response$createStorageV1CSIDriver$Status$202, type Response$createStorageV1CSINode$Status$200, type Response$createStorageV1CSINode$Status$201, type Response$createStorageV1CSINode$Status$202, type Response$createStorageV1NamespacedCSIStorageCapacity$Status$200, type Response$createStorageV1NamespacedCSIStorageCapacity$Status$201, type Response$createStorageV1NamespacedCSIStorageCapacity$Status$202, type Response$createStorageV1StorageClass$Status$200, type Response$createStorageV1StorageClass$Status$201, type Response$createStorageV1StorageClass$Status$202, type Response$createStorageV1VolumeAttachment$Status$200, type Response$createStorageV1VolumeAttachment$Status$201, type Response$createStorageV1VolumeAttachment$Status$202, type Response$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration$Status$200, type Response$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration$Status$200, type Response$deleteAdmissionregistrationV1MutatingWebhookConfiguration$Status$200, type Response$deleteAdmissionregistrationV1MutatingWebhookConfiguration$Status$202, type Response$deleteAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200, type Response$deleteAdmissionregistrationV1ValidatingWebhookConfiguration$Status$202, type Response$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy$Status$200, type Response$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding$Status$200, type Response$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200, type Response$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$202, type Response$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200, type Response$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$202, type Response$deleteApiextensionsV1CollectionCustomResourceDefinition$Status$200, type Response$deleteApiextensionsV1CustomResourceDefinition$Status$200, type Response$deleteApiextensionsV1CustomResourceDefinition$Status$202, type Response$deleteApiregistrationV1APIService$Status$200, type Response$deleteApiregistrationV1APIService$Status$202, type Response$deleteApiregistrationV1CollectionAPIService$Status$200, type Response$deleteAppsV1CollectionNamespacedControllerRevision$Status$200, type Response$deleteAppsV1CollectionNamespacedDaemonSet$Status$200, type Response$deleteAppsV1CollectionNamespacedDeployment$Status$200, type Response$deleteAppsV1CollectionNamespacedReplicaSet$Status$200, type Response$deleteAppsV1CollectionNamespacedStatefulSet$Status$200, type Response$deleteAppsV1NamespacedControllerRevision$Status$200, type Response$deleteAppsV1NamespacedControllerRevision$Status$202, type Response$deleteAppsV1NamespacedDaemonSet$Status$200, type Response$deleteAppsV1NamespacedDaemonSet$Status$202, type Response$deleteAppsV1NamespacedDeployment$Status$200, type Response$deleteAppsV1NamespacedDeployment$Status$202, type Response$deleteAppsV1NamespacedReplicaSet$Status$200, type Response$deleteAppsV1NamespacedReplicaSet$Status$202, type Response$deleteAppsV1NamespacedStatefulSet$Status$200, type Response$deleteAppsV1NamespacedStatefulSet$Status$202, type Response$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler$Status$200, type Response$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200, type Response$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$202, type Response$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler$Status$200, type Response$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200, type Response$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$202, type Response$deleteBatchV1CollectionNamespacedCronJob$Status$200, type Response$deleteBatchV1CollectionNamespacedJob$Status$200, type Response$deleteBatchV1NamespacedCronJob$Status$200, type Response$deleteBatchV1NamespacedCronJob$Status$202, type Response$deleteBatchV1NamespacedJob$Status$200, type Response$deleteBatchV1NamespacedJob$Status$202, type Response$deleteCertificatesV1CertificateSigningRequest$Status$200, type Response$deleteCertificatesV1CertificateSigningRequest$Status$202, type Response$deleteCertificatesV1CollectionCertificateSigningRequest$Status$200, type Response$deleteCertificatesV1alpha1ClusterTrustBundle$Status$200, type Response$deleteCertificatesV1alpha1ClusterTrustBundle$Status$202, type Response$deleteCertificatesV1alpha1CollectionClusterTrustBundle$Status$200, type Response$deleteCoordinationV1CollectionNamespacedLease$Status$200, type Response$deleteCoordinationV1NamespacedLease$Status$200, type Response$deleteCoordinationV1NamespacedLease$Status$202, type Response$deleteCoreV1CollectionNamespacedConfigMap$Status$200, type Response$deleteCoreV1CollectionNamespacedEndpoints$Status$200, type Response$deleteCoreV1CollectionNamespacedEvent$Status$200, type Response$deleteCoreV1CollectionNamespacedLimitRange$Status$200, type Response$deleteCoreV1CollectionNamespacedPersistentVolumeClaim$Status$200, type Response$deleteCoreV1CollectionNamespacedPod$Status$200, type Response$deleteCoreV1CollectionNamespacedPodTemplate$Status$200, type Response$deleteCoreV1CollectionNamespacedReplicationController$Status$200, type Response$deleteCoreV1CollectionNamespacedResourceQuota$Status$200, type Response$deleteCoreV1CollectionNamespacedSecret$Status$200, type Response$deleteCoreV1CollectionNamespacedService$Status$200, type Response$deleteCoreV1CollectionNamespacedServiceAccount$Status$200, type Response$deleteCoreV1CollectionNode$Status$200, type Response$deleteCoreV1CollectionPersistentVolume$Status$200, type Response$deleteCoreV1Namespace$Status$200, type Response$deleteCoreV1Namespace$Status$202, type Response$deleteCoreV1NamespacedConfigMap$Status$200, type Response$deleteCoreV1NamespacedConfigMap$Status$202, type Response$deleteCoreV1NamespacedEndpoints$Status$200, type Response$deleteCoreV1NamespacedEndpoints$Status$202, type Response$deleteCoreV1NamespacedEvent$Status$200, type Response$deleteCoreV1NamespacedEvent$Status$202, type Response$deleteCoreV1NamespacedLimitRange$Status$200, type Response$deleteCoreV1NamespacedLimitRange$Status$202, type Response$deleteCoreV1NamespacedPersistentVolumeClaim$Status$200, type Response$deleteCoreV1NamespacedPersistentVolumeClaim$Status$202, type Response$deleteCoreV1NamespacedPod$Status$200, type Response$deleteCoreV1NamespacedPod$Status$202, type Response$deleteCoreV1NamespacedPodTemplate$Status$200, type Response$deleteCoreV1NamespacedPodTemplate$Status$202, type Response$deleteCoreV1NamespacedReplicationController$Status$200, type Response$deleteCoreV1NamespacedReplicationController$Status$202, type Response$deleteCoreV1NamespacedResourceQuota$Status$200, type Response$deleteCoreV1NamespacedResourceQuota$Status$202, type Response$deleteCoreV1NamespacedSecret$Status$200, type Response$deleteCoreV1NamespacedSecret$Status$202, type Response$deleteCoreV1NamespacedService$Status$200, type Response$deleteCoreV1NamespacedService$Status$202, type Response$deleteCoreV1NamespacedServiceAccount$Status$200, type Response$deleteCoreV1NamespacedServiceAccount$Status$202, type Response$deleteCoreV1Node$Status$200, type Response$deleteCoreV1Node$Status$202, type Response$deleteCoreV1PersistentVolume$Status$200, type Response$deleteCoreV1PersistentVolume$Status$202, type Response$deleteDiscoveryV1CollectionNamespacedEndpointSlice$Status$200, type Response$deleteDiscoveryV1NamespacedEndpointSlice$Status$200, type Response$deleteDiscoveryV1NamespacedEndpointSlice$Status$202, type Response$deleteEventsV1CollectionNamespacedEvent$Status$200, type Response$deleteEventsV1NamespacedEvent$Status$200, type Response$deleteEventsV1NamespacedEvent$Status$202, type Response$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema$Status$200, type Response$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration$Status$200, type Response$deleteFlowcontrolApiserverV1beta2FlowSchema$Status$200, type Response$deleteFlowcontrolApiserverV1beta2FlowSchema$Status$202, type Response$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200, type Response$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$202, type Response$deleteFlowcontrolApiserverV1beta3CollectionFlowSchema$Status$200, type Response$deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration$Status$200, type Response$deleteFlowcontrolApiserverV1beta3FlowSchema$Status$200, type Response$deleteFlowcontrolApiserverV1beta3FlowSchema$Status$202, type Response$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200, type Response$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$202, type Response$deleteInternalApiserverV1alpha1CollectionStorageVersion$Status$200, type Response$deleteInternalApiserverV1alpha1StorageVersion$Status$200, type Response$deleteInternalApiserverV1alpha1StorageVersion$Status$202, type Response$deleteNetworkingV1CollectionIngressClass$Status$200, type Response$deleteNetworkingV1CollectionNamespacedIngress$Status$200, type Response$deleteNetworkingV1CollectionNamespacedNetworkPolicy$Status$200, type Response$deleteNetworkingV1IngressClass$Status$200, type Response$deleteNetworkingV1IngressClass$Status$202, type Response$deleteNetworkingV1NamespacedIngress$Status$200, type Response$deleteNetworkingV1NamespacedIngress$Status$202, type Response$deleteNetworkingV1NamespacedNetworkPolicy$Status$200, type Response$deleteNetworkingV1NamespacedNetworkPolicy$Status$202, type Response$deleteNetworkingV1alpha1ClusterCIDR$Status$200, type Response$deleteNetworkingV1alpha1ClusterCIDR$Status$202, type Response$deleteNetworkingV1alpha1CollectionClusterCIDR$Status$200, type Response$deleteNetworkingV1alpha1CollectionIPAddress$Status$200, type Response$deleteNetworkingV1alpha1IPAddress$Status$200, type Response$deleteNetworkingV1alpha1IPAddress$Status$202, type Response$deleteNodeV1CollectionRuntimeClass$Status$200, type Response$deleteNodeV1RuntimeClass$Status$200, type Response$deleteNodeV1RuntimeClass$Status$202, type Response$deletePolicyV1CollectionNamespacedPodDisruptionBudget$Status$200, type Response$deletePolicyV1NamespacedPodDisruptionBudget$Status$200, type Response$deletePolicyV1NamespacedPodDisruptionBudget$Status$202, type Response$deleteRbacAuthorizationV1ClusterRole$Status$200, type Response$deleteRbacAuthorizationV1ClusterRole$Status$202, type Response$deleteRbacAuthorizationV1ClusterRoleBinding$Status$200, type Response$deleteRbacAuthorizationV1ClusterRoleBinding$Status$202, type Response$deleteRbacAuthorizationV1CollectionClusterRole$Status$200, type Response$deleteRbacAuthorizationV1CollectionClusterRoleBinding$Status$200, type Response$deleteRbacAuthorizationV1CollectionNamespacedRole$Status$200, type Response$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding$Status$200, type Response$deleteRbacAuthorizationV1NamespacedRole$Status$200, type Response$deleteRbacAuthorizationV1NamespacedRole$Status$202, type Response$deleteRbacAuthorizationV1NamespacedRoleBinding$Status$200, type Response$deleteRbacAuthorizationV1NamespacedRoleBinding$Status$202, type Response$deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext$Status$200, type Response$deleteResourceV1alpha2CollectionNamespacedResourceClaim$Status$200, type Response$deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate$Status$200, type Response$deleteResourceV1alpha2CollectionResourceClass$Status$200, type Response$deleteResourceV1alpha2NamespacedPodSchedulingContext$Status$200, type Response$deleteResourceV1alpha2NamespacedPodSchedulingContext$Status$202, type Response$deleteResourceV1alpha2NamespacedResourceClaim$Status$200, type Response$deleteResourceV1alpha2NamespacedResourceClaim$Status$202, type Response$deleteResourceV1alpha2NamespacedResourceClaimTemplate$Status$200, type Response$deleteResourceV1alpha2NamespacedResourceClaimTemplate$Status$202, type Response$deleteResourceV1alpha2ResourceClass$Status$200, type Response$deleteResourceV1alpha2ResourceClass$Status$202, type Response$deleteSchedulingV1CollectionPriorityClass$Status$200, type Response$deleteSchedulingV1PriorityClass$Status$200, type Response$deleteSchedulingV1PriorityClass$Status$202, type Response$deleteStorageV1CSIDriver$Status$200, type Response$deleteStorageV1CSIDriver$Status$202, type Response$deleteStorageV1CSINode$Status$200, type Response$deleteStorageV1CSINode$Status$202, type Response$deleteStorageV1CollectionCSIDriver$Status$200, type Response$deleteStorageV1CollectionCSINode$Status$200, type Response$deleteStorageV1CollectionNamespacedCSIStorageCapacity$Status$200, type Response$deleteStorageV1CollectionStorageClass$Status$200, type Response$deleteStorageV1CollectionVolumeAttachment$Status$200, type Response$deleteStorageV1NamespacedCSIStorageCapacity$Status$200, type Response$deleteStorageV1NamespacedCSIStorageCapacity$Status$202, type Response$deleteStorageV1StorageClass$Status$200, type Response$deleteStorageV1StorageClass$Status$202, type Response$deleteStorageV1VolumeAttachment$Status$200, type Response$deleteStorageV1VolumeAttachment$Status$202, type Response$getAPIVersions$Status$200, type Response$getAdmissionregistrationAPIGroup$Status$200, type Response$getAdmissionregistrationV1APIResources$Status$200, type Response$getAdmissionregistrationV1alpha1APIResources$Status$200, type Response$getApiextensionsAPIGroup$Status$200, type Response$getApiextensionsV1APIResources$Status$200, type Response$getApiregistrationAPIGroup$Status$200, type Response$getApiregistrationV1APIResources$Status$200, type Response$getAppsAPIGroup$Status$200, type Response$getAppsV1APIResources$Status$200, type Response$getAuthenticationAPIGroup$Status$200, type Response$getAuthenticationV1APIResources$Status$200, type Response$getAuthenticationV1alpha1APIResources$Status$200, type Response$getAuthenticationV1beta1APIResources$Status$200, type Response$getAuthorizationAPIGroup$Status$200, type Response$getAuthorizationV1APIResources$Status$200, type Response$getAutoscalingAPIGroup$Status$200, type Response$getAutoscalingV1APIResources$Status$200, type Response$getAutoscalingV2APIResources$Status$200, type Response$getBatchAPIGroup$Status$200, type Response$getBatchV1APIResources$Status$200, type Response$getCertificatesAPIGroup$Status$200, type Response$getCertificatesV1APIResources$Status$200, type Response$getCertificatesV1alpha1APIResources$Status$200, type Response$getCodeVersion$Status$200, type Response$getCoordinationAPIGroup$Status$200, type Response$getCoordinationV1APIResources$Status$200, type Response$getCoreAPIVersions$Status$200, type Response$getCoreV1APIResources$Status$200, type Response$getDiscoveryAPIGroup$Status$200, type Response$getDiscoveryV1APIResources$Status$200, type Response$getEventsAPIGroup$Status$200, type Response$getEventsV1APIResources$Status$200, type Response$getFlowcontrolApiserverAPIGroup$Status$200, type Response$getFlowcontrolApiserverV1beta2APIResources$Status$200, type Response$getFlowcontrolApiserverV1beta3APIResources$Status$200, type Response$getInternalApiserverAPIGroup$Status$200, type Response$getInternalApiserverV1alpha1APIResources$Status$200, type Response$getNetworkingAPIGroup$Status$200, type Response$getNetworkingV1APIResources$Status$200, type Response$getNetworkingV1alpha1APIResources$Status$200, type Response$getNodeAPIGroup$Status$200, type Response$getNodeV1APIResources$Status$200, type Response$getPolicyAPIGroup$Status$200, type Response$getPolicyV1APIResources$Status$200, type Response$getRbacAuthorizationAPIGroup$Status$200, type Response$getRbacAuthorizationV1APIResources$Status$200, type Response$getResourceAPIGroup$Status$200, type Response$getResourceV1alpha2APIResources$Status$200, type Response$getSchedulingAPIGroup$Status$200, type Response$getSchedulingV1APIResources$Status$200, type Response$getServiceAccountIssuerOpenIDConfiguration$Status$200, type Response$getServiceAccountIssuerOpenIDKeyset$Status$200, type Response$getStorageAPIGroup$Status$200, type Response$getStorageV1APIResources$Status$200, type Response$listAdmissionregistrationV1MutatingWebhookConfiguration$Status$200, type Response$listAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200, type Response$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200, type Response$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200, type Response$listApiextensionsV1CustomResourceDefinition$Status$200, type Response$listApiregistrationV1APIService$Status$200, type Response$listAppsV1ControllerRevisionForAllNamespaces$Status$200, type Response$listAppsV1DaemonSetForAllNamespaces$Status$200, type Response$listAppsV1DeploymentForAllNamespaces$Status$200, type Response$listAppsV1NamespacedControllerRevision$Status$200, type Response$listAppsV1NamespacedDaemonSet$Status$200, type Response$listAppsV1NamespacedDeployment$Status$200, type Response$listAppsV1NamespacedReplicaSet$Status$200, type Response$listAppsV1NamespacedStatefulSet$Status$200, type Response$listAppsV1ReplicaSetForAllNamespaces$Status$200, type Response$listAppsV1StatefulSetForAllNamespaces$Status$200, type Response$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces$Status$200, type Response$listAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200, type Response$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces$Status$200, type Response$listAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200, type Response$listBatchV1CronJobForAllNamespaces$Status$200, type Response$listBatchV1JobForAllNamespaces$Status$200, type Response$listBatchV1NamespacedCronJob$Status$200, type Response$listBatchV1NamespacedJob$Status$200, type Response$listCertificatesV1CertificateSigningRequest$Status$200, type Response$listCertificatesV1alpha1ClusterTrustBundle$Status$200, type Response$listCoordinationV1LeaseForAllNamespaces$Status$200, type Response$listCoordinationV1NamespacedLease$Status$200, type Response$listCoreV1ComponentStatus$Status$200, type Response$listCoreV1ConfigMapForAllNamespaces$Status$200, type Response$listCoreV1EndpointsForAllNamespaces$Status$200, type Response$listCoreV1EventForAllNamespaces$Status$200, type Response$listCoreV1LimitRangeForAllNamespaces$Status$200, type Response$listCoreV1Namespace$Status$200, type Response$listCoreV1NamespacedConfigMap$Status$200, type Response$listCoreV1NamespacedEndpoints$Status$200, type Response$listCoreV1NamespacedEvent$Status$200, type Response$listCoreV1NamespacedLimitRange$Status$200, type Response$listCoreV1NamespacedPersistentVolumeClaim$Status$200, type Response$listCoreV1NamespacedPod$Status$200, type Response$listCoreV1NamespacedPodTemplate$Status$200, type Response$listCoreV1NamespacedReplicationController$Status$200, type Response$listCoreV1NamespacedResourceQuota$Status$200, type Response$listCoreV1NamespacedSecret$Status$200, type Response$listCoreV1NamespacedService$Status$200, type Response$listCoreV1NamespacedServiceAccount$Status$200, type Response$listCoreV1Node$Status$200, type Response$listCoreV1PersistentVolume$Status$200, type Response$listCoreV1PersistentVolumeClaimForAllNamespaces$Status$200, type Response$listCoreV1PodForAllNamespaces$Status$200, type Response$listCoreV1PodTemplateForAllNamespaces$Status$200, type Response$listCoreV1ReplicationControllerForAllNamespaces$Status$200, type Response$listCoreV1ResourceQuotaForAllNamespaces$Status$200, type Response$listCoreV1SecretForAllNamespaces$Status$200, type Response$listCoreV1ServiceAccountForAllNamespaces$Status$200, type Response$listCoreV1ServiceForAllNamespaces$Status$200, type Response$listDiscoveryV1EndpointSliceForAllNamespaces$Status$200, type Response$listDiscoveryV1NamespacedEndpointSlice$Status$200, type Response$listEventsV1EventForAllNamespaces$Status$200, type Response$listEventsV1NamespacedEvent$Status$200, type Response$listFlowcontrolApiserverV1beta2FlowSchema$Status$200, type Response$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200, type Response$listFlowcontrolApiserverV1beta3FlowSchema$Status$200, type Response$listFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200, type Response$listInternalApiserverV1alpha1StorageVersion$Status$200, type Response$listNetworkingV1IngressClass$Status$200, type Response$listNetworkingV1IngressForAllNamespaces$Status$200, type Response$listNetworkingV1NamespacedIngress$Status$200, type Response$listNetworkingV1NamespacedNetworkPolicy$Status$200, type Response$listNetworkingV1NetworkPolicyForAllNamespaces$Status$200, type Response$listNetworkingV1alpha1ClusterCIDR$Status$200, type Response$listNetworkingV1alpha1IPAddress$Status$200, type Response$listNodeV1RuntimeClass$Status$200, type Response$listPolicyV1NamespacedPodDisruptionBudget$Status$200, type Response$listPolicyV1PodDisruptionBudgetForAllNamespaces$Status$200, type Response$listRbacAuthorizationV1ClusterRole$Status$200, type Response$listRbacAuthorizationV1ClusterRoleBinding$Status$200, type Response$listRbacAuthorizationV1NamespacedRole$Status$200, type Response$listRbacAuthorizationV1NamespacedRoleBinding$Status$200, type Response$listRbacAuthorizationV1RoleBindingForAllNamespaces$Status$200, type Response$listRbacAuthorizationV1RoleForAllNamespaces$Status$200, type Response$listResourceV1alpha2NamespacedPodSchedulingContext$Status$200, type Response$listResourceV1alpha2NamespacedResourceClaim$Status$200, type Response$listResourceV1alpha2NamespacedResourceClaimTemplate$Status$200, type Response$listResourceV1alpha2PodSchedulingContextForAllNamespaces$Status$200, type Response$listResourceV1alpha2ResourceClaimForAllNamespaces$Status$200, type Response$listResourceV1alpha2ResourceClaimTemplateForAllNamespaces$Status$200, type Response$listResourceV1alpha2ResourceClass$Status$200, type Response$listSchedulingV1PriorityClass$Status$200, type Response$listStorageV1CSIDriver$Status$200, type Response$listStorageV1CSINode$Status$200, type Response$listStorageV1CSIStorageCapacityForAllNamespaces$Status$200, type Response$listStorageV1NamespacedCSIStorageCapacity$Status$200, type Response$listStorageV1StorageClass$Status$200, type Response$listStorageV1VolumeAttachment$Status$200, type Response$patchAdmissionregistrationV1MutatingWebhookConfiguration$Status$200, type Response$patchAdmissionregistrationV1MutatingWebhookConfiguration$Status$201, type Response$patchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200, type Response$patchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201, type Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200, type Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$201, type Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200, type Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$201, type Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$200, type Response$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$201, type Response$patchApiextensionsV1CustomResourceDefinition$Status$200, type Response$patchApiextensionsV1CustomResourceDefinition$Status$201, type Response$patchApiextensionsV1CustomResourceDefinitionStatus$Status$200, type Response$patchApiextensionsV1CustomResourceDefinitionStatus$Status$201, type Response$patchApiregistrationV1APIService$Status$200, type Response$patchApiregistrationV1APIService$Status$201, type Response$patchApiregistrationV1APIServiceStatus$Status$200, type Response$patchApiregistrationV1APIServiceStatus$Status$201, type Response$patchAppsV1NamespacedControllerRevision$Status$200, type Response$patchAppsV1NamespacedControllerRevision$Status$201, type Response$patchAppsV1NamespacedDaemonSet$Status$200, type Response$patchAppsV1NamespacedDaemonSet$Status$201, type Response$patchAppsV1NamespacedDaemonSetStatus$Status$200, type Response$patchAppsV1NamespacedDaemonSetStatus$Status$201, type Response$patchAppsV1NamespacedDeployment$Status$200, type Response$patchAppsV1NamespacedDeployment$Status$201, type Response$patchAppsV1NamespacedDeploymentScale$Status$200, type Response$patchAppsV1NamespacedDeploymentScale$Status$201, type Response$patchAppsV1NamespacedDeploymentStatus$Status$200, type Response$patchAppsV1NamespacedDeploymentStatus$Status$201, type Response$patchAppsV1NamespacedReplicaSet$Status$200, type Response$patchAppsV1NamespacedReplicaSet$Status$201, type Response$patchAppsV1NamespacedReplicaSetScale$Status$200, type Response$patchAppsV1NamespacedReplicaSetScale$Status$201, type Response$patchAppsV1NamespacedReplicaSetStatus$Status$200, type Response$patchAppsV1NamespacedReplicaSetStatus$Status$201, type Response$patchAppsV1NamespacedStatefulSet$Status$200, type Response$patchAppsV1NamespacedStatefulSet$Status$201, type Response$patchAppsV1NamespacedStatefulSetScale$Status$200, type Response$patchAppsV1NamespacedStatefulSetScale$Status$201, type Response$patchAppsV1NamespacedStatefulSetStatus$Status$200, type Response$patchAppsV1NamespacedStatefulSetStatus$Status$201, type Response$patchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200, type Response$patchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201, type Response$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200, type Response$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$201, type Response$patchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200, type Response$patchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201, type Response$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200, type Response$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$201, type Response$patchBatchV1NamespacedCronJob$Status$200, type Response$patchBatchV1NamespacedCronJob$Status$201, type Response$patchBatchV1NamespacedCronJobStatus$Status$200, type Response$patchBatchV1NamespacedCronJobStatus$Status$201, type Response$patchBatchV1NamespacedJob$Status$200, type Response$patchBatchV1NamespacedJob$Status$201, type Response$patchBatchV1NamespacedJobStatus$Status$200, type Response$patchBatchV1NamespacedJobStatus$Status$201, type Response$patchCertificatesV1CertificateSigningRequest$Status$200, type Response$patchCertificatesV1CertificateSigningRequest$Status$201, type Response$patchCertificatesV1CertificateSigningRequestApproval$Status$200, type Response$patchCertificatesV1CertificateSigningRequestApproval$Status$201, type Response$patchCertificatesV1CertificateSigningRequestStatus$Status$200, type Response$patchCertificatesV1CertificateSigningRequestStatus$Status$201, type Response$patchCertificatesV1alpha1ClusterTrustBundle$Status$200, type Response$patchCertificatesV1alpha1ClusterTrustBundle$Status$201, type Response$patchCoordinationV1NamespacedLease$Status$200, type Response$patchCoordinationV1NamespacedLease$Status$201, type Response$patchCoreV1Namespace$Status$200, type Response$patchCoreV1Namespace$Status$201, type Response$patchCoreV1NamespaceStatus$Status$200, type Response$patchCoreV1NamespaceStatus$Status$201, type Response$patchCoreV1NamespacedConfigMap$Status$200, type Response$patchCoreV1NamespacedConfigMap$Status$201, type Response$patchCoreV1NamespacedEndpoints$Status$200, type Response$patchCoreV1NamespacedEndpoints$Status$201, type Response$patchCoreV1NamespacedEvent$Status$200, type Response$patchCoreV1NamespacedEvent$Status$201, type Response$patchCoreV1NamespacedLimitRange$Status$200, type Response$patchCoreV1NamespacedLimitRange$Status$201, type Response$patchCoreV1NamespacedPersistentVolumeClaim$Status$200, type Response$patchCoreV1NamespacedPersistentVolumeClaim$Status$201, type Response$patchCoreV1NamespacedPersistentVolumeClaimStatus$Status$200, type Response$patchCoreV1NamespacedPersistentVolumeClaimStatus$Status$201, type Response$patchCoreV1NamespacedPod$Status$200, type Response$patchCoreV1NamespacedPod$Status$201, type Response$patchCoreV1NamespacedPodEphemeralcontainers$Status$200, type Response$patchCoreV1NamespacedPodEphemeralcontainers$Status$201, type Response$patchCoreV1NamespacedPodStatus$Status$200, type Response$patchCoreV1NamespacedPodStatus$Status$201, type Response$patchCoreV1NamespacedPodTemplate$Status$200, type Response$patchCoreV1NamespacedPodTemplate$Status$201, type Response$patchCoreV1NamespacedReplicationController$Status$200, type Response$patchCoreV1NamespacedReplicationController$Status$201, type Response$patchCoreV1NamespacedReplicationControllerScale$Status$200, type Response$patchCoreV1NamespacedReplicationControllerScale$Status$201, type Response$patchCoreV1NamespacedReplicationControllerStatus$Status$200, type Response$patchCoreV1NamespacedReplicationControllerStatus$Status$201, type Response$patchCoreV1NamespacedResourceQuota$Status$200, type Response$patchCoreV1NamespacedResourceQuota$Status$201, type Response$patchCoreV1NamespacedResourceQuotaStatus$Status$200, type Response$patchCoreV1NamespacedResourceQuotaStatus$Status$201, type Response$patchCoreV1NamespacedSecret$Status$200, type Response$patchCoreV1NamespacedSecret$Status$201, type Response$patchCoreV1NamespacedService$Status$200, type Response$patchCoreV1NamespacedService$Status$201, type Response$patchCoreV1NamespacedServiceAccount$Status$200, type Response$patchCoreV1NamespacedServiceAccount$Status$201, type Response$patchCoreV1NamespacedServiceStatus$Status$200, type Response$patchCoreV1NamespacedServiceStatus$Status$201, type Response$patchCoreV1Node$Status$200, type Response$patchCoreV1Node$Status$201, type Response$patchCoreV1NodeStatus$Status$200, type Response$patchCoreV1NodeStatus$Status$201, type Response$patchCoreV1PersistentVolume$Status$200, type Response$patchCoreV1PersistentVolume$Status$201, type Response$patchCoreV1PersistentVolumeStatus$Status$200, type Response$patchCoreV1PersistentVolumeStatus$Status$201, type Response$patchDiscoveryV1NamespacedEndpointSlice$Status$200, type Response$patchDiscoveryV1NamespacedEndpointSlice$Status$201, type Response$patchEventsV1NamespacedEvent$Status$200, type Response$patchEventsV1NamespacedEvent$Status$201, type Response$patchFlowcontrolApiserverV1beta2FlowSchema$Status$200, type Response$patchFlowcontrolApiserverV1beta2FlowSchema$Status$201, type Response$patchFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200, type Response$patchFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$201, type Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200, type Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201, type Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200, type Response$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$201, type Response$patchFlowcontrolApiserverV1beta3FlowSchema$Status$200, type Response$patchFlowcontrolApiserverV1beta3FlowSchema$Status$201, type Response$patchFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$200, type Response$patchFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$201, type Response$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200, type Response$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$201, type Response$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$200, type Response$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$201, type Response$patchInternalApiserverV1alpha1StorageVersion$Status$200, type Response$patchInternalApiserverV1alpha1StorageVersion$Status$201, type Response$patchInternalApiserverV1alpha1StorageVersionStatus$Status$200, type Response$patchInternalApiserverV1alpha1StorageVersionStatus$Status$201, type Response$patchNetworkingV1IngressClass$Status$200, type Response$patchNetworkingV1IngressClass$Status$201, type Response$patchNetworkingV1NamespacedIngress$Status$200, type Response$patchNetworkingV1NamespacedIngress$Status$201, type Response$patchNetworkingV1NamespacedIngressStatus$Status$200, type Response$patchNetworkingV1NamespacedIngressStatus$Status$201, type Response$patchNetworkingV1NamespacedNetworkPolicy$Status$200, type Response$patchNetworkingV1NamespacedNetworkPolicy$Status$201, type Response$patchNetworkingV1NamespacedNetworkPolicyStatus$Status$200, type Response$patchNetworkingV1NamespacedNetworkPolicyStatus$Status$201, type Response$patchNetworkingV1alpha1ClusterCIDR$Status$200, type Response$patchNetworkingV1alpha1ClusterCIDR$Status$201, type Response$patchNetworkingV1alpha1IPAddress$Status$200, type Response$patchNetworkingV1alpha1IPAddress$Status$201, type Response$patchNodeV1RuntimeClass$Status$200, type Response$patchNodeV1RuntimeClass$Status$201, type Response$patchPolicyV1NamespacedPodDisruptionBudget$Status$200, type Response$patchPolicyV1NamespacedPodDisruptionBudget$Status$201, type Response$patchPolicyV1NamespacedPodDisruptionBudgetStatus$Status$200, type Response$patchPolicyV1NamespacedPodDisruptionBudgetStatus$Status$201, type Response$patchRbacAuthorizationV1ClusterRole$Status$200, type Response$patchRbacAuthorizationV1ClusterRole$Status$201, type Response$patchRbacAuthorizationV1ClusterRoleBinding$Status$200, type Response$patchRbacAuthorizationV1ClusterRoleBinding$Status$201, type Response$patchRbacAuthorizationV1NamespacedRole$Status$200, type Response$patchRbacAuthorizationV1NamespacedRole$Status$201, type Response$patchRbacAuthorizationV1NamespacedRoleBinding$Status$200, type Response$patchRbacAuthorizationV1NamespacedRoleBinding$Status$201, type Response$patchResourceV1alpha2NamespacedPodSchedulingContext$Status$200, type Response$patchResourceV1alpha2NamespacedPodSchedulingContext$Status$201, type Response$patchResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$200, type Response$patchResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$201, type Response$patchResourceV1alpha2NamespacedResourceClaim$Status$200, type Response$patchResourceV1alpha2NamespacedResourceClaim$Status$201, type Response$patchResourceV1alpha2NamespacedResourceClaimStatus$Status$200, type Response$patchResourceV1alpha2NamespacedResourceClaimStatus$Status$201, type Response$patchResourceV1alpha2NamespacedResourceClaimTemplate$Status$200, type Response$patchResourceV1alpha2NamespacedResourceClaimTemplate$Status$201, type Response$patchResourceV1alpha2ResourceClass$Status$200, type Response$patchResourceV1alpha2ResourceClass$Status$201, type Response$patchSchedulingV1PriorityClass$Status$200, type Response$patchSchedulingV1PriorityClass$Status$201, type Response$patchStorageV1CSIDriver$Status$200, type Response$patchStorageV1CSIDriver$Status$201, type Response$patchStorageV1CSINode$Status$200, type Response$patchStorageV1CSINode$Status$201, type Response$patchStorageV1NamespacedCSIStorageCapacity$Status$200, type Response$patchStorageV1NamespacedCSIStorageCapacity$Status$201, type Response$patchStorageV1StorageClass$Status$200, type Response$patchStorageV1StorageClass$Status$201, type Response$patchStorageV1VolumeAttachment$Status$200, type Response$patchStorageV1VolumeAttachment$Status$201, type Response$patchStorageV1VolumeAttachmentStatus$Status$200, type Response$patchStorageV1VolumeAttachmentStatus$Status$201, type Response$readAdmissionregistrationV1MutatingWebhookConfiguration$Status$200, type Response$readAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200, type Response$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200, type Response$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200, type Response$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$200, type Response$readApiextensionsV1CustomResourceDefinition$Status$200, type Response$readApiextensionsV1CustomResourceDefinitionStatus$Status$200, type Response$readApiregistrationV1APIService$Status$200, type Response$readApiregistrationV1APIServiceStatus$Status$200, type Response$readAppsV1NamespacedControllerRevision$Status$200, type Response$readAppsV1NamespacedDaemonSet$Status$200, type Response$readAppsV1NamespacedDaemonSetStatus$Status$200, type Response$readAppsV1NamespacedDeployment$Status$200, type Response$readAppsV1NamespacedDeploymentScale$Status$200, type Response$readAppsV1NamespacedDeploymentStatus$Status$200, type Response$readAppsV1NamespacedReplicaSet$Status$200, type Response$readAppsV1NamespacedReplicaSetScale$Status$200, type Response$readAppsV1NamespacedReplicaSetStatus$Status$200, type Response$readAppsV1NamespacedStatefulSet$Status$200, type Response$readAppsV1NamespacedStatefulSetScale$Status$200, type Response$readAppsV1NamespacedStatefulSetStatus$Status$200, type Response$readAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200, type Response$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200, type Response$readAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200, type Response$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200, type Response$readBatchV1NamespacedCronJob$Status$200, type Response$readBatchV1NamespacedCronJobStatus$Status$200, type Response$readBatchV1NamespacedJob$Status$200, type Response$readBatchV1NamespacedJobStatus$Status$200, type Response$readCertificatesV1CertificateSigningRequest$Status$200, type Response$readCertificatesV1CertificateSigningRequestApproval$Status$200, type Response$readCertificatesV1CertificateSigningRequestStatus$Status$200, type Response$readCertificatesV1alpha1ClusterTrustBundle$Status$200, type Response$readCoordinationV1NamespacedLease$Status$200, type Response$readCoreV1ComponentStatus$Status$200, type Response$readCoreV1Namespace$Status$200, type Response$readCoreV1NamespaceStatus$Status$200, type Response$readCoreV1NamespacedConfigMap$Status$200, type Response$readCoreV1NamespacedEndpoints$Status$200, type Response$readCoreV1NamespacedEvent$Status$200, type Response$readCoreV1NamespacedLimitRange$Status$200, type Response$readCoreV1NamespacedPersistentVolumeClaim$Status$200, type Response$readCoreV1NamespacedPersistentVolumeClaimStatus$Status$200, type Response$readCoreV1NamespacedPod$Status$200, type Response$readCoreV1NamespacedPodEphemeralcontainers$Status$200, type Response$readCoreV1NamespacedPodLog$Status$200, type Response$readCoreV1NamespacedPodStatus$Status$200, type Response$readCoreV1NamespacedPodTemplate$Status$200, type Response$readCoreV1NamespacedReplicationController$Status$200, type Response$readCoreV1NamespacedReplicationControllerScale$Status$200, type Response$readCoreV1NamespacedReplicationControllerStatus$Status$200, type Response$readCoreV1NamespacedResourceQuota$Status$200, type Response$readCoreV1NamespacedResourceQuotaStatus$Status$200, type Response$readCoreV1NamespacedSecret$Status$200, type Response$readCoreV1NamespacedService$Status$200, type Response$readCoreV1NamespacedServiceAccount$Status$200, type Response$readCoreV1NamespacedServiceStatus$Status$200, type Response$readCoreV1Node$Status$200, type Response$readCoreV1NodeStatus$Status$200, type Response$readCoreV1PersistentVolume$Status$200, type Response$readCoreV1PersistentVolumeStatus$Status$200, type Response$readDiscoveryV1NamespacedEndpointSlice$Status$200, type Response$readEventsV1NamespacedEvent$Status$200, type Response$readFlowcontrolApiserverV1beta2FlowSchema$Status$200, type Response$readFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200, type Response$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200, type Response$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200, type Response$readFlowcontrolApiserverV1beta3FlowSchema$Status$200, type Response$readFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$200, type Response$readFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200, type Response$readFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$200, type Response$readInternalApiserverV1alpha1StorageVersion$Status$200, type Response$readInternalApiserverV1alpha1StorageVersionStatus$Status$200, type Response$readNetworkingV1IngressClass$Status$200, type Response$readNetworkingV1NamespacedIngress$Status$200, type Response$readNetworkingV1NamespacedIngressStatus$Status$200, type Response$readNetworkingV1NamespacedNetworkPolicy$Status$200, type Response$readNetworkingV1NamespacedNetworkPolicyStatus$Status$200, type Response$readNetworkingV1alpha1ClusterCIDR$Status$200, type Response$readNetworkingV1alpha1IPAddress$Status$200, type Response$readNodeV1RuntimeClass$Status$200, type Response$readPolicyV1NamespacedPodDisruptionBudget$Status$200, type Response$readPolicyV1NamespacedPodDisruptionBudgetStatus$Status$200, type Response$readRbacAuthorizationV1ClusterRole$Status$200, type Response$readRbacAuthorizationV1ClusterRoleBinding$Status$200, type Response$readRbacAuthorizationV1NamespacedRole$Status$200, type Response$readRbacAuthorizationV1NamespacedRoleBinding$Status$200, type Response$readResourceV1alpha2NamespacedPodSchedulingContext$Status$200, type Response$readResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$200, type Response$readResourceV1alpha2NamespacedResourceClaim$Status$200, type Response$readResourceV1alpha2NamespacedResourceClaimStatus$Status$200, type Response$readResourceV1alpha2NamespacedResourceClaimTemplate$Status$200, type Response$readResourceV1alpha2ResourceClass$Status$200, type Response$readSchedulingV1PriorityClass$Status$200, type Response$readStorageV1CSIDriver$Status$200, type Response$readStorageV1CSINode$Status$200, type Response$readStorageV1NamespacedCSIStorageCapacity$Status$200, type Response$readStorageV1StorageClass$Status$200, type Response$readStorageV1VolumeAttachment$Status$200, type Response$readStorageV1VolumeAttachmentStatus$Status$200, type Response$replaceAdmissionregistrationV1MutatingWebhookConfiguration$Status$200, type Response$replaceAdmissionregistrationV1MutatingWebhookConfiguration$Status$201, type Response$replaceAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200, type Response$replaceAdmissionregistrationV1ValidatingWebhookConfiguration$Status$201, type Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200, type Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$201, type Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200, type Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$201, type Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$200, type Response$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus$Status$201, type Response$replaceApiextensionsV1CustomResourceDefinition$Status$200, type Response$replaceApiextensionsV1CustomResourceDefinition$Status$201, type Response$replaceApiextensionsV1CustomResourceDefinitionStatus$Status$200, type Response$replaceApiextensionsV1CustomResourceDefinitionStatus$Status$201, type Response$replaceApiregistrationV1APIService$Status$200, type Response$replaceApiregistrationV1APIService$Status$201, type Response$replaceApiregistrationV1APIServiceStatus$Status$200, type Response$replaceApiregistrationV1APIServiceStatus$Status$201, type Response$replaceAppsV1NamespacedControllerRevision$Status$200, type Response$replaceAppsV1NamespacedControllerRevision$Status$201, type Response$replaceAppsV1NamespacedDaemonSet$Status$200, type Response$replaceAppsV1NamespacedDaemonSet$Status$201, type Response$replaceAppsV1NamespacedDaemonSetStatus$Status$200, type Response$replaceAppsV1NamespacedDaemonSetStatus$Status$201, type Response$replaceAppsV1NamespacedDeployment$Status$200, type Response$replaceAppsV1NamespacedDeployment$Status$201, type Response$replaceAppsV1NamespacedDeploymentScale$Status$200, type Response$replaceAppsV1NamespacedDeploymentScale$Status$201, type Response$replaceAppsV1NamespacedDeploymentStatus$Status$200, type Response$replaceAppsV1NamespacedDeploymentStatus$Status$201, type Response$replaceAppsV1NamespacedReplicaSet$Status$200, type Response$replaceAppsV1NamespacedReplicaSet$Status$201, type Response$replaceAppsV1NamespacedReplicaSetScale$Status$200, type Response$replaceAppsV1NamespacedReplicaSetScale$Status$201, type Response$replaceAppsV1NamespacedReplicaSetStatus$Status$200, type Response$replaceAppsV1NamespacedReplicaSetStatus$Status$201, type Response$replaceAppsV1NamespacedStatefulSet$Status$200, type Response$replaceAppsV1NamespacedStatefulSet$Status$201, type Response$replaceAppsV1NamespacedStatefulSetScale$Status$200, type Response$replaceAppsV1NamespacedStatefulSetScale$Status$201, type Response$replaceAppsV1NamespacedStatefulSetStatus$Status$200, type Response$replaceAppsV1NamespacedStatefulSetStatus$Status$201, type Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200, type Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$201, type Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$200, type Response$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus$Status$201, type Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200, type Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$201, type Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$200, type Response$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus$Status$201, type Response$replaceBatchV1NamespacedCronJob$Status$200, type Response$replaceBatchV1NamespacedCronJob$Status$201, type Response$replaceBatchV1NamespacedCronJobStatus$Status$200, type Response$replaceBatchV1NamespacedCronJobStatus$Status$201, type Response$replaceBatchV1NamespacedJob$Status$200, type Response$replaceBatchV1NamespacedJob$Status$201, type Response$replaceBatchV1NamespacedJobStatus$Status$200, type Response$replaceBatchV1NamespacedJobStatus$Status$201, type Response$replaceCertificatesV1CertificateSigningRequest$Status$200, type Response$replaceCertificatesV1CertificateSigningRequest$Status$201, type Response$replaceCertificatesV1CertificateSigningRequestApproval$Status$200, type Response$replaceCertificatesV1CertificateSigningRequestApproval$Status$201, type Response$replaceCertificatesV1CertificateSigningRequestStatus$Status$200, type Response$replaceCertificatesV1CertificateSigningRequestStatus$Status$201, type Response$replaceCertificatesV1alpha1ClusterTrustBundle$Status$200, type Response$replaceCertificatesV1alpha1ClusterTrustBundle$Status$201, type Response$replaceCoordinationV1NamespacedLease$Status$200, type Response$replaceCoordinationV1NamespacedLease$Status$201, type Response$replaceCoreV1Namespace$Status$200, type Response$replaceCoreV1Namespace$Status$201, type Response$replaceCoreV1NamespaceFinalize$Status$200, type Response$replaceCoreV1NamespaceFinalize$Status$201, type Response$replaceCoreV1NamespaceStatus$Status$200, type Response$replaceCoreV1NamespaceStatus$Status$201, type Response$replaceCoreV1NamespacedConfigMap$Status$200, type Response$replaceCoreV1NamespacedConfigMap$Status$201, type Response$replaceCoreV1NamespacedEndpoints$Status$200, type Response$replaceCoreV1NamespacedEndpoints$Status$201, type Response$replaceCoreV1NamespacedEvent$Status$200, type Response$replaceCoreV1NamespacedEvent$Status$201, type Response$replaceCoreV1NamespacedLimitRange$Status$200, type Response$replaceCoreV1NamespacedLimitRange$Status$201, type Response$replaceCoreV1NamespacedPersistentVolumeClaim$Status$200, type Response$replaceCoreV1NamespacedPersistentVolumeClaim$Status$201, type Response$replaceCoreV1NamespacedPersistentVolumeClaimStatus$Status$200, type Response$replaceCoreV1NamespacedPersistentVolumeClaimStatus$Status$201, type Response$replaceCoreV1NamespacedPod$Status$200, type Response$replaceCoreV1NamespacedPod$Status$201, type Response$replaceCoreV1NamespacedPodEphemeralcontainers$Status$200, type Response$replaceCoreV1NamespacedPodEphemeralcontainers$Status$201, type Response$replaceCoreV1NamespacedPodStatus$Status$200, type Response$replaceCoreV1NamespacedPodStatus$Status$201, type Response$replaceCoreV1NamespacedPodTemplate$Status$200, type Response$replaceCoreV1NamespacedPodTemplate$Status$201, type Response$replaceCoreV1NamespacedReplicationController$Status$200, type Response$replaceCoreV1NamespacedReplicationController$Status$201, type Response$replaceCoreV1NamespacedReplicationControllerScale$Status$200, type Response$replaceCoreV1NamespacedReplicationControllerScale$Status$201, type Response$replaceCoreV1NamespacedReplicationControllerStatus$Status$200, type Response$replaceCoreV1NamespacedReplicationControllerStatus$Status$201, type Response$replaceCoreV1NamespacedResourceQuota$Status$200, type Response$replaceCoreV1NamespacedResourceQuota$Status$201, type Response$replaceCoreV1NamespacedResourceQuotaStatus$Status$200, type Response$replaceCoreV1NamespacedResourceQuotaStatus$Status$201, type Response$replaceCoreV1NamespacedSecret$Status$200, type Response$replaceCoreV1NamespacedSecret$Status$201, type Response$replaceCoreV1NamespacedService$Status$200, type Response$replaceCoreV1NamespacedService$Status$201, type Response$replaceCoreV1NamespacedServiceAccount$Status$200, type Response$replaceCoreV1NamespacedServiceAccount$Status$201, type Response$replaceCoreV1NamespacedServiceStatus$Status$200, type Response$replaceCoreV1NamespacedServiceStatus$Status$201, type Response$replaceCoreV1Node$Status$200, type Response$replaceCoreV1Node$Status$201, type Response$replaceCoreV1NodeStatus$Status$200, type Response$replaceCoreV1NodeStatus$Status$201, type Response$replaceCoreV1PersistentVolume$Status$200, type Response$replaceCoreV1PersistentVolume$Status$201, type Response$replaceCoreV1PersistentVolumeStatus$Status$200, type Response$replaceCoreV1PersistentVolumeStatus$Status$201, type Response$replaceDiscoveryV1NamespacedEndpointSlice$Status$200, type Response$replaceDiscoveryV1NamespacedEndpointSlice$Status$201, type Response$replaceEventsV1NamespacedEvent$Status$200, type Response$replaceEventsV1NamespacedEvent$Status$201, type Response$replaceFlowcontrolApiserverV1beta2FlowSchema$Status$200, type Response$replaceFlowcontrolApiserverV1beta2FlowSchema$Status$201, type Response$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$200, type Response$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus$Status$201, type Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200, type Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$201, type Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$200, type Response$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus$Status$201, type Response$replaceFlowcontrolApiserverV1beta3FlowSchema$Status$200, type Response$replaceFlowcontrolApiserverV1beta3FlowSchema$Status$201, type Response$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$200, type Response$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus$Status$201, type Response$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200, type Response$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$201, type Response$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$200, type Response$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus$Status$201, type Response$replaceInternalApiserverV1alpha1StorageVersion$Status$200, type Response$replaceInternalApiserverV1alpha1StorageVersion$Status$201, type Response$replaceInternalApiserverV1alpha1StorageVersionStatus$Status$200, type Response$replaceInternalApiserverV1alpha1StorageVersionStatus$Status$201, type Response$replaceNetworkingV1IngressClass$Status$200, type Response$replaceNetworkingV1IngressClass$Status$201, type Response$replaceNetworkingV1NamespacedIngress$Status$200, type Response$replaceNetworkingV1NamespacedIngress$Status$201, type Response$replaceNetworkingV1NamespacedIngressStatus$Status$200, type Response$replaceNetworkingV1NamespacedIngressStatus$Status$201, type Response$replaceNetworkingV1NamespacedNetworkPolicy$Status$200, type Response$replaceNetworkingV1NamespacedNetworkPolicy$Status$201, type Response$replaceNetworkingV1NamespacedNetworkPolicyStatus$Status$200, type Response$replaceNetworkingV1NamespacedNetworkPolicyStatus$Status$201, type Response$replaceNetworkingV1alpha1ClusterCIDR$Status$200, type Response$replaceNetworkingV1alpha1ClusterCIDR$Status$201, type Response$replaceNetworkingV1alpha1IPAddress$Status$200, type Response$replaceNetworkingV1alpha1IPAddress$Status$201, type Response$replaceNodeV1RuntimeClass$Status$200, type Response$replaceNodeV1RuntimeClass$Status$201, type Response$replacePolicyV1NamespacedPodDisruptionBudget$Status$200, type Response$replacePolicyV1NamespacedPodDisruptionBudget$Status$201, type Response$replacePolicyV1NamespacedPodDisruptionBudgetStatus$Status$200, type Response$replacePolicyV1NamespacedPodDisruptionBudgetStatus$Status$201, type Response$replaceRbacAuthorizationV1ClusterRole$Status$200, type Response$replaceRbacAuthorizationV1ClusterRole$Status$201, type Response$replaceRbacAuthorizationV1ClusterRoleBinding$Status$200, type Response$replaceRbacAuthorizationV1ClusterRoleBinding$Status$201, type Response$replaceRbacAuthorizationV1NamespacedRole$Status$200, type Response$replaceRbacAuthorizationV1NamespacedRole$Status$201, type Response$replaceRbacAuthorizationV1NamespacedRoleBinding$Status$200, type Response$replaceRbacAuthorizationV1NamespacedRoleBinding$Status$201, type Response$replaceResourceV1alpha2NamespacedPodSchedulingContext$Status$200, type Response$replaceResourceV1alpha2NamespacedPodSchedulingContext$Status$201, type Response$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$200, type Response$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus$Status$201, type Response$replaceResourceV1alpha2NamespacedResourceClaim$Status$200, type Response$replaceResourceV1alpha2NamespacedResourceClaim$Status$201, type Response$replaceResourceV1alpha2NamespacedResourceClaimStatus$Status$200, type Response$replaceResourceV1alpha2NamespacedResourceClaimStatus$Status$201, type Response$replaceResourceV1alpha2NamespacedResourceClaimTemplate$Status$200, type Response$replaceResourceV1alpha2NamespacedResourceClaimTemplate$Status$201, type Response$replaceResourceV1alpha2ResourceClass$Status$200, type Response$replaceResourceV1alpha2ResourceClass$Status$201, type Response$replaceSchedulingV1PriorityClass$Status$200, type Response$replaceSchedulingV1PriorityClass$Status$201, type Response$replaceStorageV1CSIDriver$Status$200, type Response$replaceStorageV1CSIDriver$Status$201, type Response$replaceStorageV1CSINode$Status$200, type Response$replaceStorageV1CSINode$Status$201, type Response$replaceStorageV1NamespacedCSIStorageCapacity$Status$200, type Response$replaceStorageV1NamespacedCSIStorageCapacity$Status$201, type Response$replaceStorageV1StorageClass$Status$200, type Response$replaceStorageV1StorageClass$Status$201, type Response$replaceStorageV1VolumeAttachment$Status$200, type Response$replaceStorageV1VolumeAttachment$Status$201, type Response$replaceStorageV1VolumeAttachmentStatus$Status$200, type Response$replaceStorageV1VolumeAttachmentStatus$Status$201, type Response$watchAdmissionregistrationV1MutatingWebhookConfiguration$Status$200, type Response$watchAdmissionregistrationV1MutatingWebhookConfigurationList$Status$200, type Response$watchAdmissionregistrationV1ValidatingWebhookConfiguration$Status$200, type Response$watchAdmissionregistrationV1ValidatingWebhookConfigurationList$Status$200, type Response$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy$Status$200, type Response$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding$Status$200, type Response$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBindingList$Status$200, type Response$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyList$Status$200, type Response$watchApiextensionsV1CustomResourceDefinition$Status$200, type Response$watchApiextensionsV1CustomResourceDefinitionList$Status$200, type Response$watchApiregistrationV1APIService$Status$200, type Response$watchApiregistrationV1APIServiceList$Status$200, type Response$watchAppsV1ControllerRevisionListForAllNamespaces$Status$200, type Response$watchAppsV1DaemonSetListForAllNamespaces$Status$200, type Response$watchAppsV1DeploymentListForAllNamespaces$Status$200, type Response$watchAppsV1NamespacedControllerRevision$Status$200, type Response$watchAppsV1NamespacedControllerRevisionList$Status$200, type Response$watchAppsV1NamespacedDaemonSet$Status$200, type Response$watchAppsV1NamespacedDaemonSetList$Status$200, type Response$watchAppsV1NamespacedDeployment$Status$200, type Response$watchAppsV1NamespacedDeploymentList$Status$200, type Response$watchAppsV1NamespacedReplicaSet$Status$200, type Response$watchAppsV1NamespacedReplicaSetList$Status$200, type Response$watchAppsV1NamespacedStatefulSet$Status$200, type Response$watchAppsV1NamespacedStatefulSetList$Status$200, type Response$watchAppsV1ReplicaSetListForAllNamespaces$Status$200, type Response$watchAppsV1StatefulSetListForAllNamespaces$Status$200, type Response$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces$Status$200, type Response$watchAutoscalingV1NamespacedHorizontalPodAutoscaler$Status$200, type Response$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList$Status$200, type Response$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces$Status$200, type Response$watchAutoscalingV2NamespacedHorizontalPodAutoscaler$Status$200, type Response$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList$Status$200, type Response$watchBatchV1CronJobListForAllNamespaces$Status$200, type Response$watchBatchV1JobListForAllNamespaces$Status$200, type Response$watchBatchV1NamespacedCronJob$Status$200, type Response$watchBatchV1NamespacedCronJobList$Status$200, type Response$watchBatchV1NamespacedJob$Status$200, type Response$watchBatchV1NamespacedJobList$Status$200, type Response$watchCertificatesV1CertificateSigningRequest$Status$200, type Response$watchCertificatesV1CertificateSigningRequestList$Status$200, type Response$watchCertificatesV1alpha1ClusterTrustBundle$Status$200, type Response$watchCertificatesV1alpha1ClusterTrustBundleList$Status$200, type Response$watchCoordinationV1LeaseListForAllNamespaces$Status$200, type Response$watchCoordinationV1NamespacedLease$Status$200, type Response$watchCoordinationV1NamespacedLeaseList$Status$200, type Response$watchCoreV1ConfigMapListForAllNamespaces$Status$200, type Response$watchCoreV1EndpointsListForAllNamespaces$Status$200, type Response$watchCoreV1EventListForAllNamespaces$Status$200, type Response$watchCoreV1LimitRangeListForAllNamespaces$Status$200, type Response$watchCoreV1Namespace$Status$200, type Response$watchCoreV1NamespaceList$Status$200, type Response$watchCoreV1NamespacedConfigMap$Status$200, type Response$watchCoreV1NamespacedConfigMapList$Status$200, type Response$watchCoreV1NamespacedEndpoints$Status$200, type Response$watchCoreV1NamespacedEndpointsList$Status$200, type Response$watchCoreV1NamespacedEvent$Status$200, type Response$watchCoreV1NamespacedEventList$Status$200, type Response$watchCoreV1NamespacedLimitRange$Status$200, type Response$watchCoreV1NamespacedLimitRangeList$Status$200, type Response$watchCoreV1NamespacedPersistentVolumeClaim$Status$200, type Response$watchCoreV1NamespacedPersistentVolumeClaimList$Status$200, type Response$watchCoreV1NamespacedPod$Status$200, type Response$watchCoreV1NamespacedPodList$Status$200, type Response$watchCoreV1NamespacedPodTemplate$Status$200, type Response$watchCoreV1NamespacedPodTemplateList$Status$200, type Response$watchCoreV1NamespacedReplicationController$Status$200, type Response$watchCoreV1NamespacedReplicationControllerList$Status$200, type Response$watchCoreV1NamespacedResourceQuota$Status$200, type Response$watchCoreV1NamespacedResourceQuotaList$Status$200, type Response$watchCoreV1NamespacedSecret$Status$200, type Response$watchCoreV1NamespacedSecretList$Status$200, type Response$watchCoreV1NamespacedService$Status$200, type Response$watchCoreV1NamespacedServiceAccount$Status$200, type Response$watchCoreV1NamespacedServiceAccountList$Status$200, type Response$watchCoreV1NamespacedServiceList$Status$200, type Response$watchCoreV1Node$Status$200, type Response$watchCoreV1NodeList$Status$200, type Response$watchCoreV1PersistentVolume$Status$200, type Response$watchCoreV1PersistentVolumeClaimListForAllNamespaces$Status$200, type Response$watchCoreV1PersistentVolumeList$Status$200, type Response$watchCoreV1PodListForAllNamespaces$Status$200, type Response$watchCoreV1PodTemplateListForAllNamespaces$Status$200, type Response$watchCoreV1ReplicationControllerListForAllNamespaces$Status$200, type Response$watchCoreV1ResourceQuotaListForAllNamespaces$Status$200, type Response$watchCoreV1SecretListForAllNamespaces$Status$200, type Response$watchCoreV1ServiceAccountListForAllNamespaces$Status$200, type Response$watchCoreV1ServiceListForAllNamespaces$Status$200, type Response$watchDiscoveryV1EndpointSliceListForAllNamespaces$Status$200, type Response$watchDiscoveryV1NamespacedEndpointSlice$Status$200, type Response$watchDiscoveryV1NamespacedEndpointSliceList$Status$200, type Response$watchEventsV1EventListForAllNamespaces$Status$200, type Response$watchEventsV1NamespacedEvent$Status$200, type Response$watchEventsV1NamespacedEventList$Status$200, type Response$watchFlowcontrolApiserverV1beta2FlowSchema$Status$200, type Response$watchFlowcontrolApiserverV1beta2FlowSchemaList$Status$200, type Response$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration$Status$200, type Response$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList$Status$200, type Response$watchFlowcontrolApiserverV1beta3FlowSchema$Status$200, type Response$watchFlowcontrolApiserverV1beta3FlowSchemaList$Status$200, type Response$watchFlowcontrolApiserverV1beta3PriorityLevelConfiguration$Status$200, type Response$watchFlowcontrolApiserverV1beta3PriorityLevelConfigurationList$Status$200, type Response$watchInternalApiserverV1alpha1StorageVersion$Status$200, type Response$watchInternalApiserverV1alpha1StorageVersionList$Status$200, type Response$watchNetworkingV1IngressClass$Status$200, type Response$watchNetworkingV1IngressClassList$Status$200, type Response$watchNetworkingV1IngressListForAllNamespaces$Status$200, type Response$watchNetworkingV1NamespacedIngress$Status$200, type Response$watchNetworkingV1NamespacedIngressList$Status$200, type Response$watchNetworkingV1NamespacedNetworkPolicy$Status$200, type Response$watchNetworkingV1NamespacedNetworkPolicyList$Status$200, type Response$watchNetworkingV1NetworkPolicyListForAllNamespaces$Status$200, type Response$watchNetworkingV1alpha1ClusterCIDR$Status$200, type Response$watchNetworkingV1alpha1ClusterCIDRList$Status$200, type Response$watchNetworkingV1alpha1IPAddress$Status$200, type Response$watchNetworkingV1alpha1IPAddressList$Status$200, type Response$watchNodeV1RuntimeClass$Status$200, type Response$watchNodeV1RuntimeClassList$Status$200, type Response$watchPolicyV1NamespacedPodDisruptionBudget$Status$200, type Response$watchPolicyV1NamespacedPodDisruptionBudgetList$Status$200, type Response$watchPolicyV1PodDisruptionBudgetListForAllNamespaces$Status$200, type Response$watchRbacAuthorizationV1ClusterRole$Status$200, type Response$watchRbacAuthorizationV1ClusterRoleBinding$Status$200, type Response$watchRbacAuthorizationV1ClusterRoleBindingList$Status$200, type Response$watchRbacAuthorizationV1ClusterRoleList$Status$200, type Response$watchRbacAuthorizationV1NamespacedRole$Status$200, type Response$watchRbacAuthorizationV1NamespacedRoleBinding$Status$200, type Response$watchRbacAuthorizationV1NamespacedRoleBindingList$Status$200, type Response$watchRbacAuthorizationV1NamespacedRoleList$Status$200, type Response$watchRbacAuthorizationV1RoleBindingListForAllNamespaces$Status$200, type Response$watchRbacAuthorizationV1RoleListForAllNamespaces$Status$200, type Response$watchResourceV1alpha2NamespacedPodSchedulingContext$Status$200, type Response$watchResourceV1alpha2NamespacedPodSchedulingContextList$Status$200, type Response$watchResourceV1alpha2NamespacedResourceClaim$Status$200, type Response$watchResourceV1alpha2NamespacedResourceClaimList$Status$200, type Response$watchResourceV1alpha2NamespacedResourceClaimTemplate$Status$200, type Response$watchResourceV1alpha2NamespacedResourceClaimTemplateList$Status$200, type Response$watchResourceV1alpha2PodSchedulingContextListForAllNamespaces$Status$200, type Response$watchResourceV1alpha2ResourceClaimListForAllNamespaces$Status$200, type Response$watchResourceV1alpha2ResourceClaimTemplateListForAllNamespaces$Status$200, type Response$watchResourceV1alpha2ResourceClass$Status$200, type Response$watchResourceV1alpha2ResourceClassList$Status$200, type Response$watchSchedulingV1PriorityClass$Status$200, type Response$watchSchedulingV1PriorityClassList$Status$200, type Response$watchStorageV1CSIDriver$Status$200, type Response$watchStorageV1CSIDriverList$Status$200, type Response$watchStorageV1CSINode$Status$200, type Response$watchStorageV1CSINodeList$Status$200, type Response$watchStorageV1CSIStorageCapacityListForAllNamespaces$Status$200, type Response$watchStorageV1NamespacedCSIStorageCapacity$Status$200, type Response$watchStorageV1NamespacedCSIStorageCapacityList$Status$200, type Response$watchStorageV1StorageClass$Status$200, type Response$watchStorageV1StorageClassList$Status$200, type Response$watchStorageV1VolumeAttachment$Status$200, type Response$watchStorageV1VolumeAttachmentList$Status$200, type ResponseContentType$connectCoreV1DeleteNamespacedPodProxy, type ResponseContentType$connectCoreV1DeleteNamespacedPodProxyWithPath, type ResponseContentType$connectCoreV1DeleteNamespacedServiceProxy, type ResponseContentType$connectCoreV1DeleteNamespacedServiceProxyWithPath, type ResponseContentType$connectCoreV1DeleteNodeProxy, type ResponseContentType$connectCoreV1DeleteNodeProxyWithPath, type ResponseContentType$connectCoreV1GetNamespacedPodAttach, type ResponseContentType$connectCoreV1GetNamespacedPodExec, type ResponseContentType$connectCoreV1GetNamespacedPodPortforward, type ResponseContentType$connectCoreV1GetNamespacedPodProxy, type ResponseContentType$connectCoreV1GetNamespacedPodProxyWithPath, type ResponseContentType$connectCoreV1GetNamespacedServiceProxy, type ResponseContentType$connectCoreV1GetNamespacedServiceProxyWithPath, type ResponseContentType$connectCoreV1GetNodeProxy, type ResponseContentType$connectCoreV1GetNodeProxyWithPath, type ResponseContentType$connectCoreV1HeadNamespacedPodProxy, type ResponseContentType$connectCoreV1HeadNamespacedPodProxyWithPath, type ResponseContentType$connectCoreV1HeadNamespacedServiceProxy, type ResponseContentType$connectCoreV1HeadNamespacedServiceProxyWithPath, type ResponseContentType$connectCoreV1HeadNodeProxy, type ResponseContentType$connectCoreV1HeadNodeProxyWithPath, type ResponseContentType$connectCoreV1OptionsNamespacedPodProxy, type ResponseContentType$connectCoreV1OptionsNamespacedPodProxyWithPath, type ResponseContentType$connectCoreV1OptionsNamespacedServiceProxy, type ResponseContentType$connectCoreV1OptionsNamespacedServiceProxyWithPath, type ResponseContentType$connectCoreV1OptionsNodeProxy, type ResponseContentType$connectCoreV1OptionsNodeProxyWithPath, type ResponseContentType$connectCoreV1PatchNamespacedPodProxy, type ResponseContentType$connectCoreV1PatchNamespacedPodProxyWithPath, type ResponseContentType$connectCoreV1PatchNamespacedServiceProxy, type ResponseContentType$connectCoreV1PatchNamespacedServiceProxyWithPath, type ResponseContentType$connectCoreV1PatchNodeProxy, type ResponseContentType$connectCoreV1PatchNodeProxyWithPath, type ResponseContentType$connectCoreV1PostNamespacedPodAttach, type ResponseContentType$connectCoreV1PostNamespacedPodExec, type ResponseContentType$connectCoreV1PostNamespacedPodPortforward, type ResponseContentType$connectCoreV1PostNamespacedPodProxy, type ResponseContentType$connectCoreV1PostNamespacedPodProxyWithPath, type ResponseContentType$connectCoreV1PostNamespacedServiceProxy, type ResponseContentType$connectCoreV1PostNamespacedServiceProxyWithPath, type ResponseContentType$connectCoreV1PostNodeProxy, type ResponseContentType$connectCoreV1PostNodeProxyWithPath, type ResponseContentType$connectCoreV1PutNamespacedPodProxy, type ResponseContentType$connectCoreV1PutNamespacedPodProxyWithPath, type ResponseContentType$connectCoreV1PutNamespacedServiceProxy, type ResponseContentType$connectCoreV1PutNamespacedServiceProxyWithPath, type ResponseContentType$connectCoreV1PutNodeProxy, type ResponseContentType$connectCoreV1PutNodeProxyWithPath, type ResponseContentType$createAdmissionregistrationV1MutatingWebhookConfiguration, type ResponseContentType$createAdmissionregistrationV1ValidatingWebhookConfiguration, type ResponseContentType$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type ResponseContentType$createAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type ResponseContentType$createApiextensionsV1CustomResourceDefinition, type ResponseContentType$createApiregistrationV1APIService, type ResponseContentType$createAppsV1NamespacedControllerRevision, type ResponseContentType$createAppsV1NamespacedDaemonSet, type ResponseContentType$createAppsV1NamespacedDeployment, type ResponseContentType$createAppsV1NamespacedReplicaSet, type ResponseContentType$createAppsV1NamespacedStatefulSet, type ResponseContentType$createAuthenticationV1TokenReview, type ResponseContentType$createAuthenticationV1alpha1SelfSubjectReview, type ResponseContentType$createAuthenticationV1beta1SelfSubjectReview, type ResponseContentType$createAuthorizationV1NamespacedLocalSubjectAccessReview, type ResponseContentType$createAuthorizationV1SelfSubjectAccessReview, type ResponseContentType$createAuthorizationV1SelfSubjectRulesReview, type ResponseContentType$createAuthorizationV1SubjectAccessReview, type ResponseContentType$createAutoscalingV1NamespacedHorizontalPodAutoscaler, type ResponseContentType$createAutoscalingV2NamespacedHorizontalPodAutoscaler, type ResponseContentType$createBatchV1NamespacedCronJob, type ResponseContentType$createBatchV1NamespacedJob, type ResponseContentType$createCertificatesV1CertificateSigningRequest, type ResponseContentType$createCertificatesV1alpha1ClusterTrustBundle, type ResponseContentType$createCoordinationV1NamespacedLease, type ResponseContentType$createCoreV1Namespace, type ResponseContentType$createCoreV1NamespacedBinding, type ResponseContentType$createCoreV1NamespacedConfigMap, type ResponseContentType$createCoreV1NamespacedEndpoints, type ResponseContentType$createCoreV1NamespacedEvent, type ResponseContentType$createCoreV1NamespacedLimitRange, type ResponseContentType$createCoreV1NamespacedPersistentVolumeClaim, type ResponseContentType$createCoreV1NamespacedPod, type ResponseContentType$createCoreV1NamespacedPodBinding, type ResponseContentType$createCoreV1NamespacedPodEviction, type ResponseContentType$createCoreV1NamespacedPodTemplate, type ResponseContentType$createCoreV1NamespacedReplicationController, type ResponseContentType$createCoreV1NamespacedResourceQuota, type ResponseContentType$createCoreV1NamespacedSecret, type ResponseContentType$createCoreV1NamespacedService, type ResponseContentType$createCoreV1NamespacedServiceAccount, type ResponseContentType$createCoreV1NamespacedServiceAccountToken, type ResponseContentType$createCoreV1Node, type ResponseContentType$createCoreV1PersistentVolume, type ResponseContentType$createDiscoveryV1NamespacedEndpointSlice, type ResponseContentType$createEventsV1NamespacedEvent, type ResponseContentType$createFlowcontrolApiserverV1beta2FlowSchema, type ResponseContentType$createFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type ResponseContentType$createFlowcontrolApiserverV1beta3FlowSchema, type ResponseContentType$createFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type ResponseContentType$createInternalApiserverV1alpha1StorageVersion, type ResponseContentType$createNetworkingV1IngressClass, type ResponseContentType$createNetworkingV1NamespacedIngress, type ResponseContentType$createNetworkingV1NamespacedNetworkPolicy, type ResponseContentType$createNetworkingV1alpha1ClusterCIDR, type ResponseContentType$createNetworkingV1alpha1IPAddress, type ResponseContentType$createNodeV1RuntimeClass, type ResponseContentType$createPolicyV1NamespacedPodDisruptionBudget, type ResponseContentType$createRbacAuthorizationV1ClusterRole, type ResponseContentType$createRbacAuthorizationV1ClusterRoleBinding, type ResponseContentType$createRbacAuthorizationV1NamespacedRole, type ResponseContentType$createRbacAuthorizationV1NamespacedRoleBinding, type ResponseContentType$createResourceV1alpha2NamespacedPodSchedulingContext, type ResponseContentType$createResourceV1alpha2NamespacedResourceClaim, type ResponseContentType$createResourceV1alpha2NamespacedResourceClaimTemplate, type ResponseContentType$createResourceV1alpha2ResourceClass, type ResponseContentType$createSchedulingV1PriorityClass, type ResponseContentType$createStorageV1CSIDriver, type ResponseContentType$createStorageV1CSINode, type ResponseContentType$createStorageV1NamespacedCSIStorageCapacity, type ResponseContentType$createStorageV1StorageClass, type ResponseContentType$createStorageV1VolumeAttachment, type ResponseContentType$deleteAdmissionregistrationV1CollectionMutatingWebhookConfiguration, type ResponseContentType$deleteAdmissionregistrationV1CollectionValidatingWebhookConfiguration, type ResponseContentType$deleteAdmissionregistrationV1MutatingWebhookConfiguration, type ResponseContentType$deleteAdmissionregistrationV1ValidatingWebhookConfiguration, type ResponseContentType$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicy, type ResponseContentType$deleteAdmissionregistrationV1alpha1CollectionValidatingAdmissionPolicyBinding, type ResponseContentType$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type ResponseContentType$deleteAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type ResponseContentType$deleteApiextensionsV1CollectionCustomResourceDefinition, type ResponseContentType$deleteApiextensionsV1CustomResourceDefinition, type ResponseContentType$deleteApiregistrationV1APIService, type ResponseContentType$deleteApiregistrationV1CollectionAPIService, type ResponseContentType$deleteAppsV1CollectionNamespacedControllerRevision, type ResponseContentType$deleteAppsV1CollectionNamespacedDaemonSet, type ResponseContentType$deleteAppsV1CollectionNamespacedDeployment, type ResponseContentType$deleteAppsV1CollectionNamespacedReplicaSet, type ResponseContentType$deleteAppsV1CollectionNamespacedStatefulSet, type ResponseContentType$deleteAppsV1NamespacedControllerRevision, type ResponseContentType$deleteAppsV1NamespacedDaemonSet, type ResponseContentType$deleteAppsV1NamespacedDeployment, type ResponseContentType$deleteAppsV1NamespacedReplicaSet, type ResponseContentType$deleteAppsV1NamespacedStatefulSet, type ResponseContentType$deleteAutoscalingV1CollectionNamespacedHorizontalPodAutoscaler, type ResponseContentType$deleteAutoscalingV1NamespacedHorizontalPodAutoscaler, type ResponseContentType$deleteAutoscalingV2CollectionNamespacedHorizontalPodAutoscaler, type ResponseContentType$deleteAutoscalingV2NamespacedHorizontalPodAutoscaler, type ResponseContentType$deleteBatchV1CollectionNamespacedCronJob, type ResponseContentType$deleteBatchV1CollectionNamespacedJob, type ResponseContentType$deleteBatchV1NamespacedCronJob, type ResponseContentType$deleteBatchV1NamespacedJob, type ResponseContentType$deleteCertificatesV1CertificateSigningRequest, type ResponseContentType$deleteCertificatesV1CollectionCertificateSigningRequest, type ResponseContentType$deleteCertificatesV1alpha1ClusterTrustBundle, type ResponseContentType$deleteCertificatesV1alpha1CollectionClusterTrustBundle, type ResponseContentType$deleteCoordinationV1CollectionNamespacedLease, type ResponseContentType$deleteCoordinationV1NamespacedLease, type ResponseContentType$deleteCoreV1CollectionNamespacedConfigMap, type ResponseContentType$deleteCoreV1CollectionNamespacedEndpoints, type ResponseContentType$deleteCoreV1CollectionNamespacedEvent, type ResponseContentType$deleteCoreV1CollectionNamespacedLimitRange, type ResponseContentType$deleteCoreV1CollectionNamespacedPersistentVolumeClaim, type ResponseContentType$deleteCoreV1CollectionNamespacedPod, type ResponseContentType$deleteCoreV1CollectionNamespacedPodTemplate, type ResponseContentType$deleteCoreV1CollectionNamespacedReplicationController, type ResponseContentType$deleteCoreV1CollectionNamespacedResourceQuota, type ResponseContentType$deleteCoreV1CollectionNamespacedSecret, type ResponseContentType$deleteCoreV1CollectionNamespacedService, type ResponseContentType$deleteCoreV1CollectionNamespacedServiceAccount, type ResponseContentType$deleteCoreV1CollectionNode, type ResponseContentType$deleteCoreV1CollectionPersistentVolume, type ResponseContentType$deleteCoreV1Namespace, type ResponseContentType$deleteCoreV1NamespacedConfigMap, type ResponseContentType$deleteCoreV1NamespacedEndpoints, type ResponseContentType$deleteCoreV1NamespacedEvent, type ResponseContentType$deleteCoreV1NamespacedLimitRange, type ResponseContentType$deleteCoreV1NamespacedPersistentVolumeClaim, type ResponseContentType$deleteCoreV1NamespacedPod, type ResponseContentType$deleteCoreV1NamespacedPodTemplate, type ResponseContentType$deleteCoreV1NamespacedReplicationController, type ResponseContentType$deleteCoreV1NamespacedResourceQuota, type ResponseContentType$deleteCoreV1NamespacedSecret, type ResponseContentType$deleteCoreV1NamespacedService, type ResponseContentType$deleteCoreV1NamespacedServiceAccount, type ResponseContentType$deleteCoreV1Node, type ResponseContentType$deleteCoreV1PersistentVolume, type ResponseContentType$deleteDiscoveryV1CollectionNamespacedEndpointSlice, type ResponseContentType$deleteDiscoveryV1NamespacedEndpointSlice, type ResponseContentType$deleteEventsV1CollectionNamespacedEvent, type ResponseContentType$deleteEventsV1NamespacedEvent, type ResponseContentType$deleteFlowcontrolApiserverV1beta2CollectionFlowSchema, type ResponseContentType$deleteFlowcontrolApiserverV1beta2CollectionPriorityLevelConfiguration, type ResponseContentType$deleteFlowcontrolApiserverV1beta2FlowSchema, type ResponseContentType$deleteFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type ResponseContentType$deleteFlowcontrolApiserverV1beta3CollectionFlowSchema, type ResponseContentType$deleteFlowcontrolApiserverV1beta3CollectionPriorityLevelConfiguration, type ResponseContentType$deleteFlowcontrolApiserverV1beta3FlowSchema, type ResponseContentType$deleteFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type ResponseContentType$deleteInternalApiserverV1alpha1CollectionStorageVersion, type ResponseContentType$deleteInternalApiserverV1alpha1StorageVersion, type ResponseContentType$deleteNetworkingV1CollectionIngressClass, type ResponseContentType$deleteNetworkingV1CollectionNamespacedIngress, type ResponseContentType$deleteNetworkingV1CollectionNamespacedNetworkPolicy, type ResponseContentType$deleteNetworkingV1IngressClass, type ResponseContentType$deleteNetworkingV1NamespacedIngress, type ResponseContentType$deleteNetworkingV1NamespacedNetworkPolicy, type ResponseContentType$deleteNetworkingV1alpha1ClusterCIDR, type ResponseContentType$deleteNetworkingV1alpha1CollectionClusterCIDR, type ResponseContentType$deleteNetworkingV1alpha1CollectionIPAddress, type ResponseContentType$deleteNetworkingV1alpha1IPAddress, type ResponseContentType$deleteNodeV1CollectionRuntimeClass, type ResponseContentType$deleteNodeV1RuntimeClass, type ResponseContentType$deletePolicyV1CollectionNamespacedPodDisruptionBudget, type ResponseContentType$deletePolicyV1NamespacedPodDisruptionBudget, type ResponseContentType$deleteRbacAuthorizationV1ClusterRole, type ResponseContentType$deleteRbacAuthorizationV1ClusterRoleBinding, type ResponseContentType$deleteRbacAuthorizationV1CollectionClusterRole, type ResponseContentType$deleteRbacAuthorizationV1CollectionClusterRoleBinding, type ResponseContentType$deleteRbacAuthorizationV1CollectionNamespacedRole, type ResponseContentType$deleteRbacAuthorizationV1CollectionNamespacedRoleBinding, type ResponseContentType$deleteRbacAuthorizationV1NamespacedRole, type ResponseContentType$deleteRbacAuthorizationV1NamespacedRoleBinding, type ResponseContentType$deleteResourceV1alpha2CollectionNamespacedPodSchedulingContext, type ResponseContentType$deleteResourceV1alpha2CollectionNamespacedResourceClaim, type ResponseContentType$deleteResourceV1alpha2CollectionNamespacedResourceClaimTemplate, type ResponseContentType$deleteResourceV1alpha2CollectionResourceClass, type ResponseContentType$deleteResourceV1alpha2NamespacedPodSchedulingContext, type ResponseContentType$deleteResourceV1alpha2NamespacedResourceClaim, type ResponseContentType$deleteResourceV1alpha2NamespacedResourceClaimTemplate, type ResponseContentType$deleteResourceV1alpha2ResourceClass, type ResponseContentType$deleteSchedulingV1CollectionPriorityClass, type ResponseContentType$deleteSchedulingV1PriorityClass, type ResponseContentType$deleteStorageV1CSIDriver, type ResponseContentType$deleteStorageV1CSINode, type ResponseContentType$deleteStorageV1CollectionCSIDriver, type ResponseContentType$deleteStorageV1CollectionCSINode, type ResponseContentType$deleteStorageV1CollectionNamespacedCSIStorageCapacity, type ResponseContentType$deleteStorageV1CollectionStorageClass, type ResponseContentType$deleteStorageV1CollectionVolumeAttachment, type ResponseContentType$deleteStorageV1NamespacedCSIStorageCapacity, type ResponseContentType$deleteStorageV1StorageClass, type ResponseContentType$deleteStorageV1VolumeAttachment, type ResponseContentType$getAPIVersions, type ResponseContentType$getAdmissionregistrationAPIGroup, type ResponseContentType$getAdmissionregistrationV1APIResources, type ResponseContentType$getAdmissionregistrationV1alpha1APIResources, type ResponseContentType$getApiextensionsAPIGroup, type ResponseContentType$getApiextensionsV1APIResources, type ResponseContentType$getApiregistrationAPIGroup, type ResponseContentType$getApiregistrationV1APIResources, type ResponseContentType$getAppsAPIGroup, type ResponseContentType$getAppsV1APIResources, type ResponseContentType$getAuthenticationAPIGroup, type ResponseContentType$getAuthenticationV1APIResources, type ResponseContentType$getAuthenticationV1alpha1APIResources, type ResponseContentType$getAuthenticationV1beta1APIResources, type ResponseContentType$getAuthorizationAPIGroup, type ResponseContentType$getAuthorizationV1APIResources, type ResponseContentType$getAutoscalingAPIGroup, type ResponseContentType$getAutoscalingV1APIResources, type ResponseContentType$getAutoscalingV2APIResources, type ResponseContentType$getBatchAPIGroup, type ResponseContentType$getBatchV1APIResources, type ResponseContentType$getCertificatesAPIGroup, type ResponseContentType$getCertificatesV1APIResources, type ResponseContentType$getCertificatesV1alpha1APIResources, type ResponseContentType$getCodeVersion, type ResponseContentType$getCoordinationAPIGroup, type ResponseContentType$getCoordinationV1APIResources, type ResponseContentType$getCoreAPIVersions, type ResponseContentType$getCoreV1APIResources, type ResponseContentType$getDiscoveryAPIGroup, type ResponseContentType$getDiscoveryV1APIResources, type ResponseContentType$getEventsAPIGroup, type ResponseContentType$getEventsV1APIResources, type ResponseContentType$getFlowcontrolApiserverAPIGroup, type ResponseContentType$getFlowcontrolApiserverV1beta2APIResources, type ResponseContentType$getFlowcontrolApiserverV1beta3APIResources, type ResponseContentType$getInternalApiserverAPIGroup, type ResponseContentType$getInternalApiserverV1alpha1APIResources, type ResponseContentType$getNetworkingAPIGroup, type ResponseContentType$getNetworkingV1APIResources, type ResponseContentType$getNetworkingV1alpha1APIResources, type ResponseContentType$getNodeAPIGroup, type ResponseContentType$getNodeV1APIResources, type ResponseContentType$getPolicyAPIGroup, type ResponseContentType$getPolicyV1APIResources, type ResponseContentType$getRbacAuthorizationAPIGroup, type ResponseContentType$getRbacAuthorizationV1APIResources, type ResponseContentType$getResourceAPIGroup, type ResponseContentType$getResourceV1alpha2APIResources, type ResponseContentType$getSchedulingAPIGroup, type ResponseContentType$getSchedulingV1APIResources, type ResponseContentType$getServiceAccountIssuerOpenIDConfiguration, type ResponseContentType$getServiceAccountIssuerOpenIDKeyset, type ResponseContentType$getStorageAPIGroup, type ResponseContentType$getStorageV1APIResources, type ResponseContentType$listAdmissionregistrationV1MutatingWebhookConfiguration, type ResponseContentType$listAdmissionregistrationV1ValidatingWebhookConfiguration, type ResponseContentType$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type ResponseContentType$listAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type ResponseContentType$listApiextensionsV1CustomResourceDefinition, type ResponseContentType$listApiregistrationV1APIService, type ResponseContentType$listAppsV1ControllerRevisionForAllNamespaces, type ResponseContentType$listAppsV1DaemonSetForAllNamespaces, type ResponseContentType$listAppsV1DeploymentForAllNamespaces, type ResponseContentType$listAppsV1NamespacedControllerRevision, type ResponseContentType$listAppsV1NamespacedDaemonSet, type ResponseContentType$listAppsV1NamespacedDeployment, type ResponseContentType$listAppsV1NamespacedReplicaSet, type ResponseContentType$listAppsV1NamespacedStatefulSet, type ResponseContentType$listAppsV1ReplicaSetForAllNamespaces, type ResponseContentType$listAppsV1StatefulSetForAllNamespaces, type ResponseContentType$listAutoscalingV1HorizontalPodAutoscalerForAllNamespaces, type ResponseContentType$listAutoscalingV1NamespacedHorizontalPodAutoscaler, type ResponseContentType$listAutoscalingV2HorizontalPodAutoscalerForAllNamespaces, type ResponseContentType$listAutoscalingV2NamespacedHorizontalPodAutoscaler, type ResponseContentType$listBatchV1CronJobForAllNamespaces, type ResponseContentType$listBatchV1JobForAllNamespaces, type ResponseContentType$listBatchV1NamespacedCronJob, type ResponseContentType$listBatchV1NamespacedJob, type ResponseContentType$listCertificatesV1CertificateSigningRequest, type ResponseContentType$listCertificatesV1alpha1ClusterTrustBundle, type ResponseContentType$listCoordinationV1LeaseForAllNamespaces, type ResponseContentType$listCoordinationV1NamespacedLease, type ResponseContentType$listCoreV1ComponentStatus, type ResponseContentType$listCoreV1ConfigMapForAllNamespaces, type ResponseContentType$listCoreV1EndpointsForAllNamespaces, type ResponseContentType$listCoreV1EventForAllNamespaces, type ResponseContentType$listCoreV1LimitRangeForAllNamespaces, type ResponseContentType$listCoreV1Namespace, type ResponseContentType$listCoreV1NamespacedConfigMap, type ResponseContentType$listCoreV1NamespacedEndpoints, type ResponseContentType$listCoreV1NamespacedEvent, type ResponseContentType$listCoreV1NamespacedLimitRange, type ResponseContentType$listCoreV1NamespacedPersistentVolumeClaim, type ResponseContentType$listCoreV1NamespacedPod, type ResponseContentType$listCoreV1NamespacedPodTemplate, type ResponseContentType$listCoreV1NamespacedReplicationController, type ResponseContentType$listCoreV1NamespacedResourceQuota, type ResponseContentType$listCoreV1NamespacedSecret, type ResponseContentType$listCoreV1NamespacedService, type ResponseContentType$listCoreV1NamespacedServiceAccount, type ResponseContentType$listCoreV1Node, type ResponseContentType$listCoreV1PersistentVolume, type ResponseContentType$listCoreV1PersistentVolumeClaimForAllNamespaces, type ResponseContentType$listCoreV1PodForAllNamespaces, type ResponseContentType$listCoreV1PodTemplateForAllNamespaces, type ResponseContentType$listCoreV1ReplicationControllerForAllNamespaces, type ResponseContentType$listCoreV1ResourceQuotaForAllNamespaces, type ResponseContentType$listCoreV1SecretForAllNamespaces, type ResponseContentType$listCoreV1ServiceAccountForAllNamespaces, type ResponseContentType$listCoreV1ServiceForAllNamespaces, type ResponseContentType$listDiscoveryV1EndpointSliceForAllNamespaces, type ResponseContentType$listDiscoveryV1NamespacedEndpointSlice, type ResponseContentType$listEventsV1EventForAllNamespaces, type ResponseContentType$listEventsV1NamespacedEvent, type ResponseContentType$listFlowcontrolApiserverV1beta2FlowSchema, type ResponseContentType$listFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type ResponseContentType$listFlowcontrolApiserverV1beta3FlowSchema, type ResponseContentType$listFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type ResponseContentType$listInternalApiserverV1alpha1StorageVersion, type ResponseContentType$listNetworkingV1IngressClass, type ResponseContentType$listNetworkingV1IngressForAllNamespaces, type ResponseContentType$listNetworkingV1NamespacedIngress, type ResponseContentType$listNetworkingV1NamespacedNetworkPolicy, type ResponseContentType$listNetworkingV1NetworkPolicyForAllNamespaces, type ResponseContentType$listNetworkingV1alpha1ClusterCIDR, type ResponseContentType$listNetworkingV1alpha1IPAddress, type ResponseContentType$listNodeV1RuntimeClass, type ResponseContentType$listPolicyV1NamespacedPodDisruptionBudget, type ResponseContentType$listPolicyV1PodDisruptionBudgetForAllNamespaces, type ResponseContentType$listRbacAuthorizationV1ClusterRole, type ResponseContentType$listRbacAuthorizationV1ClusterRoleBinding, type ResponseContentType$listRbacAuthorizationV1NamespacedRole, type ResponseContentType$listRbacAuthorizationV1NamespacedRoleBinding, type ResponseContentType$listRbacAuthorizationV1RoleBindingForAllNamespaces, type ResponseContentType$listRbacAuthorizationV1RoleForAllNamespaces, type ResponseContentType$listResourceV1alpha2NamespacedPodSchedulingContext, type ResponseContentType$listResourceV1alpha2NamespacedResourceClaim, type ResponseContentType$listResourceV1alpha2NamespacedResourceClaimTemplate, type ResponseContentType$listResourceV1alpha2PodSchedulingContextForAllNamespaces, type ResponseContentType$listResourceV1alpha2ResourceClaimForAllNamespaces, type ResponseContentType$listResourceV1alpha2ResourceClaimTemplateForAllNamespaces, type ResponseContentType$listResourceV1alpha2ResourceClass, type ResponseContentType$listSchedulingV1PriorityClass, type ResponseContentType$listStorageV1CSIDriver, type ResponseContentType$listStorageV1CSINode, type ResponseContentType$listStorageV1CSIStorageCapacityForAllNamespaces, type ResponseContentType$listStorageV1NamespacedCSIStorageCapacity, type ResponseContentType$listStorageV1StorageClass, type ResponseContentType$listStorageV1VolumeAttachment, type ResponseContentType$patchAdmissionregistrationV1MutatingWebhookConfiguration, type ResponseContentType$patchAdmissionregistrationV1ValidatingWebhookConfiguration, type ResponseContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type ResponseContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type ResponseContentType$patchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus, type ResponseContentType$patchApiextensionsV1CustomResourceDefinition, type ResponseContentType$patchApiextensionsV1CustomResourceDefinitionStatus, type ResponseContentType$patchApiregistrationV1APIService, type ResponseContentType$patchApiregistrationV1APIServiceStatus, type ResponseContentType$patchAppsV1NamespacedControllerRevision, type ResponseContentType$patchAppsV1NamespacedDaemonSet, type ResponseContentType$patchAppsV1NamespacedDaemonSetStatus, type ResponseContentType$patchAppsV1NamespacedDeployment, type ResponseContentType$patchAppsV1NamespacedDeploymentScale, type ResponseContentType$patchAppsV1NamespacedDeploymentStatus, type ResponseContentType$patchAppsV1NamespacedReplicaSet, type ResponseContentType$patchAppsV1NamespacedReplicaSetScale, type ResponseContentType$patchAppsV1NamespacedReplicaSetStatus, type ResponseContentType$patchAppsV1NamespacedStatefulSet, type ResponseContentType$patchAppsV1NamespacedStatefulSetScale, type ResponseContentType$patchAppsV1NamespacedStatefulSetStatus, type ResponseContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscaler, type ResponseContentType$patchAutoscalingV1NamespacedHorizontalPodAutoscalerStatus, type ResponseContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscaler, type ResponseContentType$patchAutoscalingV2NamespacedHorizontalPodAutoscalerStatus, type ResponseContentType$patchBatchV1NamespacedCronJob, type ResponseContentType$patchBatchV1NamespacedCronJobStatus, type ResponseContentType$patchBatchV1NamespacedJob, type ResponseContentType$patchBatchV1NamespacedJobStatus, type ResponseContentType$patchCertificatesV1CertificateSigningRequest, type ResponseContentType$patchCertificatesV1CertificateSigningRequestApproval, type ResponseContentType$patchCertificatesV1CertificateSigningRequestStatus, type ResponseContentType$patchCertificatesV1alpha1ClusterTrustBundle, type ResponseContentType$patchCoordinationV1NamespacedLease, type ResponseContentType$patchCoreV1Namespace, type ResponseContentType$patchCoreV1NamespaceStatus, type ResponseContentType$patchCoreV1NamespacedConfigMap, type ResponseContentType$patchCoreV1NamespacedEndpoints, type ResponseContentType$patchCoreV1NamespacedEvent, type ResponseContentType$patchCoreV1NamespacedLimitRange, type ResponseContentType$patchCoreV1NamespacedPersistentVolumeClaim, type ResponseContentType$patchCoreV1NamespacedPersistentVolumeClaimStatus, type ResponseContentType$patchCoreV1NamespacedPod, type ResponseContentType$patchCoreV1NamespacedPodEphemeralcontainers, type ResponseContentType$patchCoreV1NamespacedPodStatus, type ResponseContentType$patchCoreV1NamespacedPodTemplate, type ResponseContentType$patchCoreV1NamespacedReplicationController, type ResponseContentType$patchCoreV1NamespacedReplicationControllerScale, type ResponseContentType$patchCoreV1NamespacedReplicationControllerStatus, type ResponseContentType$patchCoreV1NamespacedResourceQuota, type ResponseContentType$patchCoreV1NamespacedResourceQuotaStatus, type ResponseContentType$patchCoreV1NamespacedSecret, type ResponseContentType$patchCoreV1NamespacedService, type ResponseContentType$patchCoreV1NamespacedServiceAccount, type ResponseContentType$patchCoreV1NamespacedServiceStatus, type ResponseContentType$patchCoreV1Node, type ResponseContentType$patchCoreV1NodeStatus, type ResponseContentType$patchCoreV1PersistentVolume, type ResponseContentType$patchCoreV1PersistentVolumeStatus, type ResponseContentType$patchDiscoveryV1NamespacedEndpointSlice, type ResponseContentType$patchEventsV1NamespacedEvent, type ResponseContentType$patchFlowcontrolApiserverV1beta2FlowSchema, type ResponseContentType$patchFlowcontrolApiserverV1beta2FlowSchemaStatus, type ResponseContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type ResponseContentType$patchFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus, type ResponseContentType$patchFlowcontrolApiserverV1beta3FlowSchema, type ResponseContentType$patchFlowcontrolApiserverV1beta3FlowSchemaStatus, type ResponseContentType$patchFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type ResponseContentType$patchFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus, type ResponseContentType$patchInternalApiserverV1alpha1StorageVersion, type ResponseContentType$patchInternalApiserverV1alpha1StorageVersionStatus, type ResponseContentType$patchNetworkingV1IngressClass, type ResponseContentType$patchNetworkingV1NamespacedIngress, type ResponseContentType$patchNetworkingV1NamespacedIngressStatus, type ResponseContentType$patchNetworkingV1NamespacedNetworkPolicy, type ResponseContentType$patchNetworkingV1NamespacedNetworkPolicyStatus, type ResponseContentType$patchNetworkingV1alpha1ClusterCIDR, type ResponseContentType$patchNetworkingV1alpha1IPAddress, type ResponseContentType$patchNodeV1RuntimeClass, type ResponseContentType$patchPolicyV1NamespacedPodDisruptionBudget, type ResponseContentType$patchPolicyV1NamespacedPodDisruptionBudgetStatus, type ResponseContentType$patchRbacAuthorizationV1ClusterRole, type ResponseContentType$patchRbacAuthorizationV1ClusterRoleBinding, type ResponseContentType$patchRbacAuthorizationV1NamespacedRole, type ResponseContentType$patchRbacAuthorizationV1NamespacedRoleBinding, type ResponseContentType$patchResourceV1alpha2NamespacedPodSchedulingContext, type ResponseContentType$patchResourceV1alpha2NamespacedPodSchedulingContextStatus, type ResponseContentType$patchResourceV1alpha2NamespacedResourceClaim, type ResponseContentType$patchResourceV1alpha2NamespacedResourceClaimStatus, type ResponseContentType$patchResourceV1alpha2NamespacedResourceClaimTemplate, type ResponseContentType$patchResourceV1alpha2ResourceClass, type ResponseContentType$patchSchedulingV1PriorityClass, type ResponseContentType$patchStorageV1CSIDriver, type ResponseContentType$patchStorageV1CSINode, type ResponseContentType$patchStorageV1NamespacedCSIStorageCapacity, type ResponseContentType$patchStorageV1StorageClass, type ResponseContentType$patchStorageV1VolumeAttachment, type ResponseContentType$patchStorageV1VolumeAttachmentStatus, type ResponseContentType$readAdmissionregistrationV1MutatingWebhookConfiguration, type ResponseContentType$readAdmissionregistrationV1ValidatingWebhookConfiguration, type ResponseContentType$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type ResponseContentType$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type ResponseContentType$readAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus, type ResponseContentType$readApiextensionsV1CustomResourceDefinition, type ResponseContentType$readApiextensionsV1CustomResourceDefinitionStatus, type ResponseContentType$readApiregistrationV1APIService, type ResponseContentType$readApiregistrationV1APIServiceStatus, type ResponseContentType$readAppsV1NamespacedControllerRevision, type ResponseContentType$readAppsV1NamespacedDaemonSet, type ResponseContentType$readAppsV1NamespacedDaemonSetStatus, type ResponseContentType$readAppsV1NamespacedDeployment, type ResponseContentType$readAppsV1NamespacedDeploymentScale, type ResponseContentType$readAppsV1NamespacedDeploymentStatus, type ResponseContentType$readAppsV1NamespacedReplicaSet, type ResponseContentType$readAppsV1NamespacedReplicaSetScale, type ResponseContentType$readAppsV1NamespacedReplicaSetStatus, type ResponseContentType$readAppsV1NamespacedStatefulSet, type ResponseContentType$readAppsV1NamespacedStatefulSetScale, type ResponseContentType$readAppsV1NamespacedStatefulSetStatus, type ResponseContentType$readAutoscalingV1NamespacedHorizontalPodAutoscaler, type ResponseContentType$readAutoscalingV1NamespacedHorizontalPodAutoscalerStatus, type ResponseContentType$readAutoscalingV2NamespacedHorizontalPodAutoscaler, type ResponseContentType$readAutoscalingV2NamespacedHorizontalPodAutoscalerStatus, type ResponseContentType$readBatchV1NamespacedCronJob, type ResponseContentType$readBatchV1NamespacedCronJobStatus, type ResponseContentType$readBatchV1NamespacedJob, type ResponseContentType$readBatchV1NamespacedJobStatus, type ResponseContentType$readCertificatesV1CertificateSigningRequest, type ResponseContentType$readCertificatesV1CertificateSigningRequestApproval, type ResponseContentType$readCertificatesV1CertificateSigningRequestStatus, type ResponseContentType$readCertificatesV1alpha1ClusterTrustBundle, type ResponseContentType$readCoordinationV1NamespacedLease, type ResponseContentType$readCoreV1ComponentStatus, type ResponseContentType$readCoreV1Namespace, type ResponseContentType$readCoreV1NamespaceStatus, type ResponseContentType$readCoreV1NamespacedConfigMap, type ResponseContentType$readCoreV1NamespacedEndpoints, type ResponseContentType$readCoreV1NamespacedEvent, type ResponseContentType$readCoreV1NamespacedLimitRange, type ResponseContentType$readCoreV1NamespacedPersistentVolumeClaim, type ResponseContentType$readCoreV1NamespacedPersistentVolumeClaimStatus, type ResponseContentType$readCoreV1NamespacedPod, type ResponseContentType$readCoreV1NamespacedPodEphemeralcontainers, type ResponseContentType$readCoreV1NamespacedPodLog, type ResponseContentType$readCoreV1NamespacedPodStatus, type ResponseContentType$readCoreV1NamespacedPodTemplate, type ResponseContentType$readCoreV1NamespacedReplicationController, type ResponseContentType$readCoreV1NamespacedReplicationControllerScale, type ResponseContentType$readCoreV1NamespacedReplicationControllerStatus, type ResponseContentType$readCoreV1NamespacedResourceQuota, type ResponseContentType$readCoreV1NamespacedResourceQuotaStatus, type ResponseContentType$readCoreV1NamespacedSecret, type ResponseContentType$readCoreV1NamespacedService, type ResponseContentType$readCoreV1NamespacedServiceAccount, type ResponseContentType$readCoreV1NamespacedServiceStatus, type ResponseContentType$readCoreV1Node, type ResponseContentType$readCoreV1NodeStatus, type ResponseContentType$readCoreV1PersistentVolume, type ResponseContentType$readCoreV1PersistentVolumeStatus, type ResponseContentType$readDiscoveryV1NamespacedEndpointSlice, type ResponseContentType$readEventsV1NamespacedEvent, type ResponseContentType$readFlowcontrolApiserverV1beta2FlowSchema, type ResponseContentType$readFlowcontrolApiserverV1beta2FlowSchemaStatus, type ResponseContentType$readFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type ResponseContentType$readFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus, type ResponseContentType$readFlowcontrolApiserverV1beta3FlowSchema, type ResponseContentType$readFlowcontrolApiserverV1beta3FlowSchemaStatus, type ResponseContentType$readFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type ResponseContentType$readFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus, type ResponseContentType$readInternalApiserverV1alpha1StorageVersion, type ResponseContentType$readInternalApiserverV1alpha1StorageVersionStatus, type ResponseContentType$readNetworkingV1IngressClass, type ResponseContentType$readNetworkingV1NamespacedIngress, type ResponseContentType$readNetworkingV1NamespacedIngressStatus, type ResponseContentType$readNetworkingV1NamespacedNetworkPolicy, type ResponseContentType$readNetworkingV1NamespacedNetworkPolicyStatus, type ResponseContentType$readNetworkingV1alpha1ClusterCIDR, type ResponseContentType$readNetworkingV1alpha1IPAddress, type ResponseContentType$readNodeV1RuntimeClass, type ResponseContentType$readPolicyV1NamespacedPodDisruptionBudget, type ResponseContentType$readPolicyV1NamespacedPodDisruptionBudgetStatus, type ResponseContentType$readRbacAuthorizationV1ClusterRole, type ResponseContentType$readRbacAuthorizationV1ClusterRoleBinding, type ResponseContentType$readRbacAuthorizationV1NamespacedRole, type ResponseContentType$readRbacAuthorizationV1NamespacedRoleBinding, type ResponseContentType$readResourceV1alpha2NamespacedPodSchedulingContext, type ResponseContentType$readResourceV1alpha2NamespacedPodSchedulingContextStatus, type ResponseContentType$readResourceV1alpha2NamespacedResourceClaim, type ResponseContentType$readResourceV1alpha2NamespacedResourceClaimStatus, type ResponseContentType$readResourceV1alpha2NamespacedResourceClaimTemplate, type ResponseContentType$readResourceV1alpha2ResourceClass, type ResponseContentType$readSchedulingV1PriorityClass, type ResponseContentType$readStorageV1CSIDriver, type ResponseContentType$readStorageV1CSINode, type ResponseContentType$readStorageV1NamespacedCSIStorageCapacity, type ResponseContentType$readStorageV1StorageClass, type ResponseContentType$readStorageV1VolumeAttachment, type ResponseContentType$readStorageV1VolumeAttachmentStatus, type ResponseContentType$replaceAdmissionregistrationV1MutatingWebhookConfiguration, type ResponseContentType$replaceAdmissionregistrationV1ValidatingWebhookConfiguration, type ResponseContentType$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type ResponseContentType$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type ResponseContentType$replaceAdmissionregistrationV1alpha1ValidatingAdmissionPolicyStatus, type ResponseContentType$replaceApiextensionsV1CustomResourceDefinition, type ResponseContentType$replaceApiextensionsV1CustomResourceDefinitionStatus, type ResponseContentType$replaceApiregistrationV1APIService, type ResponseContentType$replaceApiregistrationV1APIServiceStatus, type ResponseContentType$replaceAppsV1NamespacedControllerRevision, type ResponseContentType$replaceAppsV1NamespacedDaemonSet, type ResponseContentType$replaceAppsV1NamespacedDaemonSetStatus, type ResponseContentType$replaceAppsV1NamespacedDeployment, type ResponseContentType$replaceAppsV1NamespacedDeploymentScale, type ResponseContentType$replaceAppsV1NamespacedDeploymentStatus, type ResponseContentType$replaceAppsV1NamespacedReplicaSet, type ResponseContentType$replaceAppsV1NamespacedReplicaSetScale, type ResponseContentType$replaceAppsV1NamespacedReplicaSetStatus, type ResponseContentType$replaceAppsV1NamespacedStatefulSet, type ResponseContentType$replaceAppsV1NamespacedStatefulSetScale, type ResponseContentType$replaceAppsV1NamespacedStatefulSetStatus, type ResponseContentType$replaceAutoscalingV1NamespacedHorizontalPodAutoscaler, type ResponseContentType$replaceAutoscalingV1NamespacedHorizontalPodAutoscalerStatus, type ResponseContentType$replaceAutoscalingV2NamespacedHorizontalPodAutoscaler, type ResponseContentType$replaceAutoscalingV2NamespacedHorizontalPodAutoscalerStatus, type ResponseContentType$replaceBatchV1NamespacedCronJob, type ResponseContentType$replaceBatchV1NamespacedCronJobStatus, type ResponseContentType$replaceBatchV1NamespacedJob, type ResponseContentType$replaceBatchV1NamespacedJobStatus, type ResponseContentType$replaceCertificatesV1CertificateSigningRequest, type ResponseContentType$replaceCertificatesV1CertificateSigningRequestApproval, type ResponseContentType$replaceCertificatesV1CertificateSigningRequestStatus, type ResponseContentType$replaceCertificatesV1alpha1ClusterTrustBundle, type ResponseContentType$replaceCoordinationV1NamespacedLease, type ResponseContentType$replaceCoreV1Namespace, type ResponseContentType$replaceCoreV1NamespaceFinalize, type ResponseContentType$replaceCoreV1NamespaceStatus, type ResponseContentType$replaceCoreV1NamespacedConfigMap, type ResponseContentType$replaceCoreV1NamespacedEndpoints, type ResponseContentType$replaceCoreV1NamespacedEvent, type ResponseContentType$replaceCoreV1NamespacedLimitRange, type ResponseContentType$replaceCoreV1NamespacedPersistentVolumeClaim, type ResponseContentType$replaceCoreV1NamespacedPersistentVolumeClaimStatus, type ResponseContentType$replaceCoreV1NamespacedPod, type ResponseContentType$replaceCoreV1NamespacedPodEphemeralcontainers, type ResponseContentType$replaceCoreV1NamespacedPodStatus, type ResponseContentType$replaceCoreV1NamespacedPodTemplate, type ResponseContentType$replaceCoreV1NamespacedReplicationController, type ResponseContentType$replaceCoreV1NamespacedReplicationControllerScale, type ResponseContentType$replaceCoreV1NamespacedReplicationControllerStatus, type ResponseContentType$replaceCoreV1NamespacedResourceQuota, type ResponseContentType$replaceCoreV1NamespacedResourceQuotaStatus, type ResponseContentType$replaceCoreV1NamespacedSecret, type ResponseContentType$replaceCoreV1NamespacedService, type ResponseContentType$replaceCoreV1NamespacedServiceAccount, type ResponseContentType$replaceCoreV1NamespacedServiceStatus, type ResponseContentType$replaceCoreV1Node, type ResponseContentType$replaceCoreV1NodeStatus, type ResponseContentType$replaceCoreV1PersistentVolume, type ResponseContentType$replaceCoreV1PersistentVolumeStatus, type ResponseContentType$replaceDiscoveryV1NamespacedEndpointSlice, type ResponseContentType$replaceEventsV1NamespacedEvent, type ResponseContentType$replaceFlowcontrolApiserverV1beta2FlowSchema, type ResponseContentType$replaceFlowcontrolApiserverV1beta2FlowSchemaStatus, type ResponseContentType$replaceFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type ResponseContentType$replaceFlowcontrolApiserverV1beta2PriorityLevelConfigurationStatus, type ResponseContentType$replaceFlowcontrolApiserverV1beta3FlowSchema, type ResponseContentType$replaceFlowcontrolApiserverV1beta3FlowSchemaStatus, type ResponseContentType$replaceFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type ResponseContentType$replaceFlowcontrolApiserverV1beta3PriorityLevelConfigurationStatus, type ResponseContentType$replaceInternalApiserverV1alpha1StorageVersion, type ResponseContentType$replaceInternalApiserverV1alpha1StorageVersionStatus, type ResponseContentType$replaceNetworkingV1IngressClass, type ResponseContentType$replaceNetworkingV1NamespacedIngress, type ResponseContentType$replaceNetworkingV1NamespacedIngressStatus, type ResponseContentType$replaceNetworkingV1NamespacedNetworkPolicy, type ResponseContentType$replaceNetworkingV1NamespacedNetworkPolicyStatus, type ResponseContentType$replaceNetworkingV1alpha1ClusterCIDR, type ResponseContentType$replaceNetworkingV1alpha1IPAddress, type ResponseContentType$replaceNodeV1RuntimeClass, type ResponseContentType$replacePolicyV1NamespacedPodDisruptionBudget, type ResponseContentType$replacePolicyV1NamespacedPodDisruptionBudgetStatus, type ResponseContentType$replaceRbacAuthorizationV1ClusterRole, type ResponseContentType$replaceRbacAuthorizationV1ClusterRoleBinding, type ResponseContentType$replaceRbacAuthorizationV1NamespacedRole, type ResponseContentType$replaceRbacAuthorizationV1NamespacedRoleBinding, type ResponseContentType$replaceResourceV1alpha2NamespacedPodSchedulingContext, type ResponseContentType$replaceResourceV1alpha2NamespacedPodSchedulingContextStatus, type ResponseContentType$replaceResourceV1alpha2NamespacedResourceClaim, type ResponseContentType$replaceResourceV1alpha2NamespacedResourceClaimStatus, type ResponseContentType$replaceResourceV1alpha2NamespacedResourceClaimTemplate, type ResponseContentType$replaceResourceV1alpha2ResourceClass, type ResponseContentType$replaceSchedulingV1PriorityClass, type ResponseContentType$replaceStorageV1CSIDriver, type ResponseContentType$replaceStorageV1CSINode, type ResponseContentType$replaceStorageV1NamespacedCSIStorageCapacity, type ResponseContentType$replaceStorageV1StorageClass, type ResponseContentType$replaceStorageV1VolumeAttachment, type ResponseContentType$replaceStorageV1VolumeAttachmentStatus, type ResponseContentType$watchAdmissionregistrationV1MutatingWebhookConfiguration, type ResponseContentType$watchAdmissionregistrationV1MutatingWebhookConfigurationList, type ResponseContentType$watchAdmissionregistrationV1ValidatingWebhookConfiguration, type ResponseContentType$watchAdmissionregistrationV1ValidatingWebhookConfigurationList, type ResponseContentType$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicy, type ResponseContentType$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBinding, type ResponseContentType$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyBindingList, type ResponseContentType$watchAdmissionregistrationV1alpha1ValidatingAdmissionPolicyList, type ResponseContentType$watchApiextensionsV1CustomResourceDefinition, type ResponseContentType$watchApiextensionsV1CustomResourceDefinitionList, type ResponseContentType$watchApiregistrationV1APIService, type ResponseContentType$watchApiregistrationV1APIServiceList, type ResponseContentType$watchAppsV1ControllerRevisionListForAllNamespaces, type ResponseContentType$watchAppsV1DaemonSetListForAllNamespaces, type ResponseContentType$watchAppsV1DeploymentListForAllNamespaces, type ResponseContentType$watchAppsV1NamespacedControllerRevision, type ResponseContentType$watchAppsV1NamespacedControllerRevisionList, type ResponseContentType$watchAppsV1NamespacedDaemonSet, type ResponseContentType$watchAppsV1NamespacedDaemonSetList, type ResponseContentType$watchAppsV1NamespacedDeployment, type ResponseContentType$watchAppsV1NamespacedDeploymentList, type ResponseContentType$watchAppsV1NamespacedReplicaSet, type ResponseContentType$watchAppsV1NamespacedReplicaSetList, type ResponseContentType$watchAppsV1NamespacedStatefulSet, type ResponseContentType$watchAppsV1NamespacedStatefulSetList, type ResponseContentType$watchAppsV1ReplicaSetListForAllNamespaces, type ResponseContentType$watchAppsV1StatefulSetListForAllNamespaces, type ResponseContentType$watchAutoscalingV1HorizontalPodAutoscalerListForAllNamespaces, type ResponseContentType$watchAutoscalingV1NamespacedHorizontalPodAutoscaler, type ResponseContentType$watchAutoscalingV1NamespacedHorizontalPodAutoscalerList, type ResponseContentType$watchAutoscalingV2HorizontalPodAutoscalerListForAllNamespaces, type ResponseContentType$watchAutoscalingV2NamespacedHorizontalPodAutoscaler, type ResponseContentType$watchAutoscalingV2NamespacedHorizontalPodAutoscalerList, type ResponseContentType$watchBatchV1CronJobListForAllNamespaces, type ResponseContentType$watchBatchV1JobListForAllNamespaces, type ResponseContentType$watchBatchV1NamespacedCronJob, type ResponseContentType$watchBatchV1NamespacedCronJobList, type ResponseContentType$watchBatchV1NamespacedJob, type ResponseContentType$watchBatchV1NamespacedJobList, type ResponseContentType$watchCertificatesV1CertificateSigningRequest, type ResponseContentType$watchCertificatesV1CertificateSigningRequestList, type ResponseContentType$watchCertificatesV1alpha1ClusterTrustBundle, type ResponseContentType$watchCertificatesV1alpha1ClusterTrustBundleList, type ResponseContentType$watchCoordinationV1LeaseListForAllNamespaces, type ResponseContentType$watchCoordinationV1NamespacedLease, type ResponseContentType$watchCoordinationV1NamespacedLeaseList, type ResponseContentType$watchCoreV1ConfigMapListForAllNamespaces, type ResponseContentType$watchCoreV1EndpointsListForAllNamespaces, type ResponseContentType$watchCoreV1EventListForAllNamespaces, type ResponseContentType$watchCoreV1LimitRangeListForAllNamespaces, type ResponseContentType$watchCoreV1Namespace, type ResponseContentType$watchCoreV1NamespaceList, type ResponseContentType$watchCoreV1NamespacedConfigMap, type ResponseContentType$watchCoreV1NamespacedConfigMapList, type ResponseContentType$watchCoreV1NamespacedEndpoints, type ResponseContentType$watchCoreV1NamespacedEndpointsList, type ResponseContentType$watchCoreV1NamespacedEvent, type ResponseContentType$watchCoreV1NamespacedEventList, type ResponseContentType$watchCoreV1NamespacedLimitRange, type ResponseContentType$watchCoreV1NamespacedLimitRangeList, type ResponseContentType$watchCoreV1NamespacedPersistentVolumeClaim, type ResponseContentType$watchCoreV1NamespacedPersistentVolumeClaimList, type ResponseContentType$watchCoreV1NamespacedPod, type ResponseContentType$watchCoreV1NamespacedPodList, type ResponseContentType$watchCoreV1NamespacedPodTemplate, type ResponseContentType$watchCoreV1NamespacedPodTemplateList, type ResponseContentType$watchCoreV1NamespacedReplicationController, type ResponseContentType$watchCoreV1NamespacedReplicationControllerList, type ResponseContentType$watchCoreV1NamespacedResourceQuota, type ResponseContentType$watchCoreV1NamespacedResourceQuotaList, type ResponseContentType$watchCoreV1NamespacedSecret, type ResponseContentType$watchCoreV1NamespacedSecretList, type ResponseContentType$watchCoreV1NamespacedService, type ResponseContentType$watchCoreV1NamespacedServiceAccount, type ResponseContentType$watchCoreV1NamespacedServiceAccountList, type ResponseContentType$watchCoreV1NamespacedServiceList, type ResponseContentType$watchCoreV1Node, type ResponseContentType$watchCoreV1NodeList, type ResponseContentType$watchCoreV1PersistentVolume, type ResponseContentType$watchCoreV1PersistentVolumeClaimListForAllNamespaces, type ResponseContentType$watchCoreV1PersistentVolumeList, type ResponseContentType$watchCoreV1PodListForAllNamespaces, type ResponseContentType$watchCoreV1PodTemplateListForAllNamespaces, type ResponseContentType$watchCoreV1ReplicationControllerListForAllNamespaces, type ResponseContentType$watchCoreV1ResourceQuotaListForAllNamespaces, type ResponseContentType$watchCoreV1SecretListForAllNamespaces, type ResponseContentType$watchCoreV1ServiceAccountListForAllNamespaces, type ResponseContentType$watchCoreV1ServiceListForAllNamespaces, type ResponseContentType$watchDiscoveryV1EndpointSliceListForAllNamespaces, type ResponseContentType$watchDiscoveryV1NamespacedEndpointSlice, type ResponseContentType$watchDiscoveryV1NamespacedEndpointSliceList, type ResponseContentType$watchEventsV1EventListForAllNamespaces, type ResponseContentType$watchEventsV1NamespacedEvent, type ResponseContentType$watchEventsV1NamespacedEventList, type ResponseContentType$watchFlowcontrolApiserverV1beta2FlowSchema, type ResponseContentType$watchFlowcontrolApiserverV1beta2FlowSchemaList, type ResponseContentType$watchFlowcontrolApiserverV1beta2PriorityLevelConfiguration, type ResponseContentType$watchFlowcontrolApiserverV1beta2PriorityLevelConfigurationList, type ResponseContentType$watchFlowcontrolApiserverV1beta3FlowSchema, type ResponseContentType$watchFlowcontrolApiserverV1beta3FlowSchemaList, type ResponseContentType$watchFlowcontrolApiserverV1beta3PriorityLevelConfiguration, type ResponseContentType$watchFlowcontrolApiserverV1beta3PriorityLevelConfigurationList, type ResponseContentType$watchInternalApiserverV1alpha1StorageVersion, type ResponseContentType$watchInternalApiserverV1alpha1StorageVersionList, type ResponseContentType$watchNetworkingV1IngressClass, type ResponseContentType$watchNetworkingV1IngressClassList, type ResponseContentType$watchNetworkingV1IngressListForAllNamespaces, type ResponseContentType$watchNetworkingV1NamespacedIngress, type ResponseContentType$watchNetworkingV1NamespacedIngressList, type ResponseContentType$watchNetworkingV1NamespacedNetworkPolicy, type ResponseContentType$watchNetworkingV1NamespacedNetworkPolicyList, type ResponseContentType$watchNetworkingV1NetworkPolicyListForAllNamespaces, type ResponseContentType$watchNetworkingV1alpha1ClusterCIDR, type ResponseContentType$watchNetworkingV1alpha1ClusterCIDRList, type ResponseContentType$watchNetworkingV1alpha1IPAddress, type ResponseContentType$watchNetworkingV1alpha1IPAddressList, type ResponseContentType$watchNodeV1RuntimeClass, type ResponseContentType$watchNodeV1RuntimeClassList, type ResponseContentType$watchPolicyV1NamespacedPodDisruptionBudget, type ResponseContentType$watchPolicyV1NamespacedPodDisruptionBudgetList, type ResponseContentType$watchPolicyV1PodDisruptionBudgetListForAllNamespaces, type ResponseContentType$watchRbacAuthorizationV1ClusterRole, type ResponseContentType$watchRbacAuthorizationV1ClusterRoleBinding, type ResponseContentType$watchRbacAuthorizationV1ClusterRoleBindingList, type ResponseContentType$watchRbacAuthorizationV1ClusterRoleList, type ResponseContentType$watchRbacAuthorizationV1NamespacedRole, type ResponseContentType$watchRbacAuthorizationV1NamespacedRoleBinding, type ResponseContentType$watchRbacAuthorizationV1NamespacedRoleBindingList, type ResponseContentType$watchRbacAuthorizationV1NamespacedRoleList, type ResponseContentType$watchRbacAuthorizationV1RoleBindingListForAllNamespaces, type ResponseContentType$watchRbacAuthorizationV1RoleListForAllNamespaces, type ResponseContentType$watchResourceV1alpha2NamespacedPodSchedulingContext, type ResponseContentType$watchResourceV1alpha2NamespacedPodSchedulingContextList, type ResponseContentType$watchResourceV1alpha2NamespacedResourceClaim, type ResponseContentType$watchResourceV1alpha2NamespacedResourceClaimList, type ResponseContentType$watchResourceV1alpha2NamespacedResourceClaimTemplate, type ResponseContentType$watchResourceV1alpha2NamespacedResourceClaimTemplateList, type ResponseContentType$watchResourceV1alpha2PodSchedulingContextListForAllNamespaces, type ResponseContentType$watchResourceV1alpha2ResourceClaimListForAllNamespaces, type ResponseContentType$watchResourceV1alpha2ResourceClaimTemplateListForAllNamespaces, type ResponseContentType$watchResourceV1alpha2ResourceClass, type ResponseContentType$watchResourceV1alpha2ResourceClassList, type ResponseContentType$watchSchedulingV1PriorityClass, type ResponseContentType$watchSchedulingV1PriorityClassList, type ResponseContentType$watchStorageV1CSIDriver, type ResponseContentType$watchStorageV1CSIDriverList, type ResponseContentType$watchStorageV1CSINode, type ResponseContentType$watchStorageV1CSINodeList, type ResponseContentType$watchStorageV1CSIStorageCapacityListForAllNamespaces, type ResponseContentType$watchStorageV1NamespacedCSIStorageCapacity, type ResponseContentType$watchStorageV1NamespacedCSIStorageCapacityList, type ResponseContentType$watchStorageV1StorageClass, type ResponseContentType$watchStorageV1StorageClassList, type ResponseContentType$watchStorageV1VolumeAttachment, type ResponseContentType$watchStorageV1VolumeAttachmentList, Schemas, type SuccessResponses };
